<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Degemer mat war $product';
$labels['username'] = 'Anv an arveriad';
$labels['password'] = 'Ger-Tremen';
$labels['server'] = 'Dafariad';
$labels['login'] = 'Kennaskañ';
$labels['logout'] = 'Digennaskañ';
$labels['mail'] = 'Postel elektronek';
$labels['settings'] = 'Arventennoù';
$labels['addressbook'] = 'Karned chomlec\'hioù';
$labels['inbox'] = 'Boest degemer';
$labels['drafts'] = 'Brouilhedoù';
$labels['sent'] = 'Kaset';
$labels['trash'] = 'Pod-lastez';
$labels['junk'] = 'Stroboù';
$labels['show_real_foldernames'] = 'Diskouez anvioù gwir teuliadoù arbennik';
$labels['subject'] = 'Sujed';
$labels['from'] = 'Eus';
$labels['sender'] = 'Kaser';
$labels['to'] = 'Da';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Cci';
$labels['replyto'] = 'Respont-da';
$labels['followupto'] = 'Treuskas da';
$labels['date'] = 'Deiz';
$labels['size'] = 'Ment';
$labels['priority'] = 'Kentwir';
$labels['organization'] = 'Aozadur';
$labels['readstatus'] = 'Stad al lenn';
$labels['listoptions'] = 'Dibarzhioù ar roll...';
$labels['mailboxlist'] = 'Teuliadoù';
$labels['messagesfromto'] = 'Kemennadoù eus $from da $to war $count';
$labels['threadsfromto'] = 'Sujedoù $from da $to war $count';
$labels['messagenrof'] = 'Kemennad $nr war $count';
$labels['fromtoshort'] = '$from - $to war $count';
$labels['copy'] = 'Eilañ';
$labels['move'] = 'Dilec\'hiañ';
$labels['moveto'] = 'Dilec\'hiañ da...';
$labels['copyto'] = 'Eilañ da…';
$labels['download'] = 'Pellgargañ';
$labels['open'] = 'Digeriñ';
$labels['showattachment'] = 'Diskouez';
$labels['showanyway'] = 'Diskouez anezhañ memestra';
$labels['filename'] = 'Anv ar restr';
$labels['filesize'] = 'Ment ar restr';
$labels['addtoaddressbook'] = 'Ouzhpennañ er c\'harned chomlec\'hioù';
$labels['sun'] = 'Sul';
$labels['mon'] = 'Lun';
$labels['tue'] = 'Meu';
$labels['wed'] = 'Mer';
$labels['thu'] = 'Yao';
$labels['fri'] = 'Gwe';
$labels['sat'] = 'Sad';
$labels['sunday'] = 'Sul';
$labels['monday'] = 'Lun';
$labels['tuesday'] = 'Meurzh';
$labels['wednesday'] = 'Merc\'her';
$labels['thursday'] = 'Yaou';
$labels['friday'] = 'Gwener';
$labels['saturday'] = 'Sadorn';
$labels['jan'] = 'Gen';
$labels['feb'] = 'C\'hwe';
$labels['mar'] = 'Meu';
$labels['apr'] = 'Ebr';
$labels['may'] = 'Mae';
$labels['jun'] = 'Mez';
$labels['jul'] = 'Gou';
$labels['aug'] = 'Eos';
$labels['sep'] = 'Gwe';
$labels['oct'] = 'Her';
$labels['nov'] = 'Du';
$labels['dec'] = 'Ker';
$labels['longjan'] = 'Genver';
$labels['longfeb'] = 'C\'hwevrer';
$labels['longmar'] = 'Meurzh';
$labels['longapr'] = 'Ebrel';
$labels['longmay'] = 'Mae';
$labels['longjun'] = 'Mezheven';
$labels['longjul'] = 'Gouere';
$labels['longaug'] = 'Eost';
$labels['longsep'] = 'Gwengolo';
$labels['longoct'] = 'Here';
$labels['longnov'] = 'Du';
$labels['longdec'] = 'Kerzu';
$labels['today'] = 'Hiziv';
$labels['refresh'] = 'Azgrenaat';
$labels['checkmail'] = 'Gwiriañ kemennadoù nevez';
$labels['compose'] = 'Skrivañ ur c\'hemennad nevez';
$labels['writenewmessage'] = 'Skrivañ ur c\'hemennad nevez';
$labels['reply'] = 'Respont';
$labels['replytomessage'] = 'Respont d\'ar kaser';
$labels['replytoallmessage'] = 'Respont d\'an holl';
$labels['replyall'] = 'Respont d\'an holl';
$labels['replylist'] = 'Respont d\'ar roll';
$labels['forward'] = 'Treuzkas';
$labels['forwardinline'] = 'Treuzkas er gemennadenn';
$labels['forwardattachment'] = 'Treuskas evel pezh stag';
$labels['forwardmessage'] = 'Treuzkas ar c\'hemennad';
$labels['deletemessage'] = 'Dilec\'hiañ ar c\'hemennad er pod-lastez';
$labels['movemessagetotrash'] = 'lakit er pod lastez';
$labels['printmessage'] = 'Moulañ ar c\'hemennad-se';
$labels['previousmessage'] = 'Gwelout ar c"hemennad a-raok';
$labels['firstmessage'] = 'Gwelout ar c\'hemennad kentañ';
$labels['nextmessage'] = 'Gwelout ar c\'hemennad da heul';
$labels['lastmessage'] = 'Gwelout ar c\'hemennad diwezhañ';
$labels['backtolist'] = 'Distreiñ el listenn kemennadoù';
$labels['viewsource'] = 'Gwelout an tarzh';
$labels['mark'] = 'merkañ';
$labels['markmessages'] = 'Merkañ ar c\'hemennad';
$labels['markread'] = 'E-giz lennet';
$labels['markunread'] = 'E-giz anlennet';
$labels['markflagged'] = 'spilhennet';
$labels['markunflagged'] = 'n\'eo ket bet spilhennet';
$labels['moreactions'] = 'muioc\'h a dibab';
$labels['folders-all'] = 'Holl teuliadoù';
$labels['more'] = 'muioc\'h';
$labels['back'] = 'distro';
$labels['options'] = 'Dibarzhioù';
$labels['first'] = 'Kentañ';
$labels['last'] = 'Diwezhañ';
$labels['previous'] = 'Kent';
$labels['next'] = 'War-Lerc\'h';
$labels['select'] = 'Diuzañ';
$labels['all'] = 'An holl';
$labels['none'] = 'Ebet';
$labels['currpage'] = 'Pajenn';
$labels['isread'] = 'Lennet';
$labels['unread'] = 'Na lennet';
$labels['flagged'] = 'Merket';
$labels['unflagged'] = 'N\'eo ket merket';
$labels['unanswered'] = 'Respontet ebet';
$labels['withattachment'] = 'Gant restroù staget';
$labels['deleted'] = 'Dilammet';
$labels['undeleted'] = 'N\'eo ket bet dilammet';
$labels['replied'] = 'Respontet';
$labels['forwarded'] = 'Treuzkaset';
$labels['invert'] = 'Tuginañ';
$labels['filter'] = 'Sil';
$labels['list'] = 'Listennañ';
$labels['threads'] = 'Neudennadoù';
$labels['expand-all'] = 'Diskouez an holl';
$labels['expand-unread'] = 'Diskouez ar re anlennet';
$labels['collapse-all'] = 'Serriñ an holl';
$labels['threaded'] = 'Dre neudennadoù';
$labels['autoexpand_threads'] = 'Diskouez an neudennadoù ar gemennadenn';
$labels['do_expand'] = 'an holl steudadoù';
$labels['expand_only_unread'] = 'Gant kemennadennoù anlennet nemetken';
$labels['fromto'] = 'Eus/ Da';
$labels['flag'] = 'Merket';
$labels['attachment'] = 'Restroù staget';
$labels['nonesort'] = 'Ebet';
$labels['sentdate'] = 'Deiz kas';
$labels['arrival'] = 'Deiz erruet';
$labels['asc'] = 'War-grec\'h';
$labels['desc'] = 'war ziskenn';
$labels['listcolumns'] = 'Roll bannoù';
$labels['listsorting'] = 'Bann rummañ';
$labels['listorder'] = 'Urzh ar rummañ';
$labels['listmode'] = 'Mod roll';
$labels['layoutlist'] = 'Listennañ';
$labels['folderactions'] = 'Gweredoù an teuliad...';
$labels['compact'] = 'Koazhet';
$labels['empty'] = 'Goulo';
$labels['importmessages'] = 'Enporzhiañ kemennadennoù';
$labels['quota'] = 'Arver ar gantenn';
$labels['unknown'] = 'Dianav';
$labels['unlimited'] = 'didermen';
$labels['quotatype'] = 'Doare ';
$labels['quotatotal'] = 'Bevenn';
$labels['quotaused'] = 'Arveret';
$labels['quotastorage'] = 'Egor kantenn';
$labels['quotamessage'] = 'Niver a gemenadennoù';
$labels['quicksearch'] = 'Klask prim';
$labels['resetsearch'] = 'Aderaouekaat ar c\'hlask';
$labels['searchmod'] = 'Kemmer klask';
$labels['msgtext'] = 'Kemennadenn a-bezh';
$labels['body'] = 'Korf';
$labels['type'] = 'Doare';
$labels['namex'] = 'Anv';
$labels['searchscope'] = 'Ledennad';
$labels['currentfolder'] = 'Teuliad bremanel';
$labels['subfolders'] = 'An hini-mañ hag an isteuliadoù';
$labels['allfolders'] = 'Holl teuliadoù';
$labels['searchinterval-1W'] = 'kozhoc\'h eget ur sizhun';
$labels['searchinterval-1M'] = 'kozhoc\'h eget ur miz';
$labels['searchinterval-1Y'] = 'kozhoc\'h eget ur bloaz';
$labels['searchinterval1W'] = 'nevesoc\'h eget ur sizhun';
$labels['searchinterval1M'] = 'nevezoc\'h eget ur miz';
$labels['searchinterval1Y'] = 'nevezoc\'h eget ur bloaz';
$labels['openinextwin'] = 'Digeriñ en ur prenestr nevez';
$labels['emlsave'] = 'Pellgargañ (.eml)';
$labels['changeformattext'] = 'Skrammañ e mentrezh testenn blaen';
$labels['changeformathtml'] = 'Skrammañ e mentrezh HTML';
$labels['editasnew'] = 'Embann evel unan nevez';
$labels['send'] = 'Kas';
$labels['sendmessage'] = 'Kas ar c\'hemennad diouzhtu';
$labels['savemessage'] = 'Gwarediñ ar brouilhed-se';
$labels['addattachment'] = 'Stagañ ur restr';
$labels['charset'] = 'Engodadur';
$labels['editortype'] = 'Furmad aozer';
$labels['returnreceipt'] = 'Testeni degemer';
$labels['dsn'] = 'Rebuziñ stad an treuzkas';
$labels['mailreplyintro'] = 'D\'an/ar $date eo bet skrivet gant $sender:';
$labels['originalmessage'] = 'Kemennadenn orin';
$labels['selectimage'] = 'Diuzañ ur skeudenn';
$labels['addimage'] = 'Ouzhpennañ ur skeudenn';
$labels['selectmedia'] = 'Diuzañ ur film';
$labels['addmedia'] = 'Ouzhpennañ ur film';
$labels['encrypt'] = 'Enringegañ';
$labels['encryptmessage'] = 'Enrinegañ ar gemennadenn';
$labels['encryptmessagemailvelope'] = 'Enrinegañ ar gemennadenn gant ';
$labels['importpubkeys'] = 'Enporzhiañ an alc\'hwezioù foran';
$labels['encryptedsendialog'] = 'O kas ur gemennadenn enrineget';
$labels['keyid'] = 'Naoudi an alc\'hwez';
$labels['keylength'] = 'a vitoù';
$labels['keyexpired'] = 'Diamzeret';
$labels['keyrevoked'] = 'Dizorniet';
$labels['insert'] = 'Enlakaat';
$labels['recipient'] = 'Degemerer';
$labels['editidents'] = 'Embann ar pivelezhioù';
$labels['spellcheck'] = 'Skrivañ';
$labels['checkspelling'] = 'Gwiriañ ar reizhskrivadur';
$labels['resumeediting'] = 'Distreiñ en aozer';
$labels['revertto'] = 'Distreiñ en/r';
$labels['restore'] = 'Assav';
$labels['restoremessage'] = 'Assav ar gemennadenn';
$labels['ignore'] = 'Leuskel';
$labels['responses'] = 'Respontoù';
$labels['insertresponse'] = 'Enlakaat ur respont';
$labels['manageresponses'] = 'Ardeiñ ar respontoù';
$labels['newresponse'] = 'Krouiñ ur respont nevez';
$labels['addresponse'] = 'Ouzhpennañ ur respont';
$labels['editresponse'] = 'Kemmañ ar respont';
$labels['editresponses'] = 'Embann respontoù';
$labels['responsename'] = 'Anv';
$labels['responsetext'] = 'Testenn ar respont';
$labels['attach'] = 'Kenstagañ';
$labels['attachments'] = 'Restroù staget';
$labels['upload'] = 'Pellgas';
$labels['uploadprogress'] = '$percent ($current war $total)';
$labels['close'] = 'Serriñ';
$labels['messageoptions'] = 'Dibarzhioù ar gemennadenn...';
$labels['togglecomposeoptions'] = 'Trec\'haoliñ dibarzhioù kenaozañ';
$labels['low'] = 'Izel';
$labels['lowest'] = 'An izelañ';
$labels['normal'] = 'Reizh';
$labels['high'] = 'Uhel';
$labels['highest'] = 'An uhelañ';
$labels['nosubject'] = '(danvez ebet)';
$labels['showimages'] = 'Diskouez ar skeudennoù';
$labels['alwaysshow'] = 'Atav diskouez skeudennoù a-berzh $sender';
$labels['isdraft'] = 'Ur brouilhed eo.';
$labels['andnmore'] = '$nr muioc\'h...';
$labels['togglemoreheaders'] = 'Diskouez muioc\'h a dalbennoù kemennadenn';
$labels['togglefullheaders'] = 'Trec\'haoliñ talbennoù kemennadenn diaoz';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'testenn kriz';
$labels['savesentmessagein'] = 'Enrollañ ar gemennadenn kaset e';
$labels['dontsave'] = 'Na enrollañ';
$labels['maxuploadsize'] = 'Ar vent vrasañ aotreet eo $size';
$labels['addcc'] = 'Ouzhpennañ Cc';
$labels['addbcc'] = 'Ouzhpennañ Bcc';
$labels['addreplyto'] = 'Ouzhpennañ Respont-da';
$labels['addfollowupto'] = 'Ouzhpennañ Kas-en-dro-da';
$labels['mdnrequest'] = 'Goulennet eo bet gant kaser ar gemennadenn bezañ rebuzet ur wech lennet ar gemennadenn ganeoc\'h. Fallout a ra deoc\'h rebuziñ ar c\'haser?';
$labels['receiptread'] = 'Testeni-degemer (lenn)';
$labels['yourmessage'] = 'Un testeni-degemer evit ho kemennadenn eo';
$labels['receiptnote'] = 'Evezhiadenn: An testeni-se a dalv eo bet skrammet ar gemennadenn war urzhiataer an degemerer. N\'eus gwarant ebet eo bet lennet pe komprenet endalc\'had ar gemennadenn.';
$labels['name'] = 'Anv da ziskouez';
$labels['firstname'] = 'Raganv';
$labels['surname'] = 'Anv';
$labels['middlename'] = 'Anv kreiz';
$labels['nameprefix'] = 'Rakger';
$labels['namesuffix'] = 'Lostger';
$labels['nickname'] = 'Lesanv';
$labels['jobtitle'] = 'Titl labour';
$labels['department'] = 'Departamant';
$labels['gender'] = 'Rev';
$labels['maidenname'] = 'Anv orin';
$labels['email'] = 'Postel';
$labels['phone'] = 'Pellgomz';
$labels['address'] = 'Chomlec\'h';
$labels['street'] = 'Straed';
$labels['locality'] = 'Kêr';
$labels['zipcode'] = 'Kod Post';
$labels['region'] = 'Stad/Proviñs';
$labels['country'] = 'Bro';
$labels['birthday'] = 'Deiz ha bloaz';
$labels['anniversary'] = 'Deiz ha bloaz';
$labels['website'] = 'Lec\'hienn';
$labels['instantmessenger'] = 'Postelerezh prim';
$labels['notes'] = 'Notennoù';
$labels['male'] = 'paotr';
$labels['female'] = 'plac\'h';
$labels['manager'] = 'Merour';
$labels['assistant'] = 'Skoazeller';
$labels['spouse'] = 'Pried';
$labels['allfields'] = 'An holl vaeziennoù';
$labels['search'] = 'Klask';
$labels['searchresult'] = 'Disoc\'hoù an enklask';
$labels['advsearch'] = 'Klask kempleshoc\'h';
$labels['advanced'] = 'Araokaet';
$labels['other'] = 'All';
$labels['printcontact'] = 'Moullañ an darempred';
$labels['qrcode'] = 'KR Kod';
$labels['typehome'] = 'Degemer';
$labels['typework'] = 'Labour';
$labels['typeother'] = 'All';
$labels['typemobile'] = 'Hezoug';
$labels['typemain'] = 'Pennañ';
$labels['typehomefax'] = 'Faks ar gêr';
$labels['typeworkfax'] = 'Faks al labour';
$labels['typecar'] = 'Gwetur';
$labels['typepager'] = 'Pajenner';
$labels['typevideo'] = 'Video';
$labels['typeassistant'] = 'Skoazeller';
$labels['typehomepage'] = 'Pajenn degemer';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Ouzhpennañ ur vaezienn...';
$labels['addcontact'] = 'Ouzhpennañ un darempred';
$labels['editcontact'] = 'Cheñch an darempred';
$labels['contacts'] = 'darempred';
$labels['contactproperties'] = 'Perzhioù an darempred';
$labels['contactnameandorg'] = 'Anv hag aozadur';
$labels['personalinfo'] = 'Titouroù personel';
$labels['personal'] = 'Personel';
$labels['contactphoto'] = 'Skeudenn darempred';
$labels['edit'] = 'Embann';
$labels['cancel'] = 'Nullañ';
$labels['save'] = 'Enrollañ';
$labels['delete'] = 'Dilemel';
$labels['discard'] = 'Dilezel';
$labels['rename'] = 'Adenvel';
$labels['addphoto'] = 'Ouzhpennañ';
$labels['replacephoto'] = 'Amsaviñ';
$labels['uploadphoto'] = 'Pellgas ur skeudenn';
$labels['newcontact'] = 'Krouiñ un darempred nevez';
$labels['deletecontact'] = 'Dilemel an darempredoù diuzet';
$labels['composeto'] = 'Skrivañ ur gemennadenn da';
$labels['contactsfromto'] = 'Darempredoù eus $from ouzh $to war $count';
$labels['print'] = 'Moullañ';
$labels['export'] = 'Ezporzhiañ';
$labels['exportall'] = 'Ezporzhiañ an holl';
$labels['exportsel'] = 'Ezporzhiañ ar re diuzet';
$labels['exportvcards'] = 'Ezporzhiañ an darempredoù er mentrezh vCard';
$labels['newgroup'] = 'Krouiñ ur strollad nevez';
$labels['addgroup'] = 'Ouzhpennañ ur strollad';
$labels['grouprename'] = 'Adeñvel ar strollad';
$labels['groupdelete'] = 'Dilemel ar strollad';
$labels['groupremoveselected'] = 'Dilemel an darempredoù diuzet eus ar strollad';
$labels['uponelevel'] = 'Pignat eus ul live';
$labels['previouspage'] = 'Diskouez ar bajenn gent';
$labels['firstpage'] = 'Diskouez ar bajenn gentañ';
$labels['nextpage'] = 'Diskouez ar pajenn da heul';
$labels['lastpage'] = 'Gwelout ar bajenn ziwezhañ';
$labels['group'] = 'Strollad';
$labels['groups'] = 'Strolladoù';
$labels['listgroup'] = 'Roll izili ar strollad';
$labels['personaladrbook'] = 'Chomlec\'h personel';
$labels['searchsave'] = 'enrollane an enklask';
$labels['searchdelete'] = 'dilemel an enklask';
$labels['import'] = 'enporzhiañ';
$labels['importcontacts'] = 'Enporzhiañ darempredoù';
$labels['importtarget'] = 'Ouzhpennañ an darempredoù da';
$labels['importreplace'] = 'Amsaviñ ar c\'harned chomlec\'hioù a-bezh';
$labels['importgroups'] = 'Enporzhiañ deverkadurioù strolladoù';
$labels['importgroupsall'] = 'An holl (krouiñ strolladoù m\'eo ret)';
$labels['importgroupsexisting'] = 'Evit ar strolladoù ma zo diouto hepken';
$labels['done'] = 'Graet eo';
$labels['settingsfor'] = 'Arventennoù evit';
$labels['about'] = 'Diwar-benn';
$labels['preferences'] = 'Gwellvezioù';
$labels['userpreferences'] = 'Gwellvezioù an arveriad';
$labels['editpreferences'] = 'Embann gwellvezioù an arveriad';
$labels['identities'] = 'Pivelezhioù';
$labels['manageidentities'] = 'Ardeiñ ar pivelezhioù';
$labels['newidentity'] = 'Krouiñ ur pivelezh nevez';
$labels['addidentity'] = 'Ouzhpennañ ur pivelezh';
$labels['editidentity'] = 'Embann ur pivelezh';
$labels['identityencryption'] = 'Enrinegañ';
$labels['preferhtml'] = 'Diskouez en HTML';
$labels['defaultcharset'] = 'Spletad arouezennoù dre ziouer';
$labels['htmlmessage'] = 'Kemennadenn HTML';
$labels['messagepart'] = 'Lodenn';
$labels['digitalsig'] = 'Sinadur niverel';
$labels['dateformat'] = 'Mentrezh an deiziad';
$labels['timeformat'] = 'Mentrezh an eur';
$labels['prettydate'] = 'Deiziadoù kaer';
$labels['setdefault'] = 'Arventennoù dre ziouer';
$labels['autodetect'] = 'Emgefre';
$labels['language'] = 'Yezh';
$labels['timezone'] = 'Gwerzhid-eur';
$labels['pagesize'] = 'Niver a linenn dre bajenn';
$labels['signature'] = 'Sinadur';
$labels['dstactive'] = 'Eur an hañv';
$labels['showinextwin'] = 'Digeriñ ar gemennadenn e-barzh ur prenestr nevez';
$labels['composeextwin'] = 'Skrivañ e-barzh ur prenestr nevez';
$labels['htmleditor'] = 'Skrivañ ur gemennadenn er mentrezh HTML';
$labels['htmlonreply'] = 'en ur respont d\'ur gemennadenn HTML';
$labels['htmlonreplyandforward'] = 'en un dreuzkas pe en ur respont d\'ur gemennadenn HTML ';
$labels['htmlsignature'] = 'Sinadur HTML';
$labels['showemail'] = 'Diskouez ar chomlec\'h postel gant an anv skrammañ';
$labels['previewpane'] = 'Diskouez panel alberz';
$labels['skin'] = 'Neuze an etrefas';
$labels['logoutclear'] = 'Skarzhañ ar c\'hest en ur zigennaskañ';
$labels['logoutcompact'] = 'Boest degemer koazhet en ur zigennaskañ';
$labels['uisettings'] = 'Ketal arveriad';
$labels['serversettings'] = 'Arventennoù an dafariad';
$labels['mailboxview'] = 'Gwel boest posteloù';
$labels['mdnrequests'] = 'War c\'houlenn evit an testeni-degemer';
$labels['askuser'] = 'goulenn ganin';
$labels['autosend'] = 'Kas un testeni degemer';
$labels['autosendknown'] = 'kas un testeni degemer d\'am darempredoù, goulenn ganin e mod all';
$labels['autosendknownignore'] = 'kas un testeni degemer d\'am darempredoù, leuskel e mod all';
$labels['ignorerequest'] = 'leuskel ar goulenn';
$labels['readwhendeleted'] = 'Merkañ ar gemennadenn evel lennet p\'eo lamet kuit';
$labels['flagfordeletion'] = 'Merkañ ar gemennadenn da vezañ lamet kuit e plas lemel kuit';
$labels['skipdeleted'] = 'Chom hep skrammañ kemennadennoù dilamet';
$labels['deletealways'] = 'Ma c\'hwit dilec\'hiañ ar c\'hemennadennoù d\'ar c\'hest, lemel anezho kuit';
$labels['deletejunk'] = 'Lemel kuit ar c\'hemennadennoù el lastez war-eeun';
$labels['showremoteimages'] = 'Lemel kuit ar skeudennoù enkorfet a-bell';
$labels['fromknownsenders'] = 'a-berzh kaserien anavezet';
$labels['always'] = 'atav';
$labels['alwaysbutplain'] = 'atav, war-bouez pa vez respontet d\'un destenn blaen';
$labels['showinlineimages'] = 'Skrammañ ar skeudennoù kenstaget dindan ar gemennadenn';
$labels['autosavedraft'] = 'Enrollan ar brouilhedoù ent emgefreek';
$labels['everynminutes'] = 'Bep $n a vunutennoù';
$labels['refreshinterval'] = 'Azgrenaat (gwiriañ posteloù nevez, hag all.)';
$labels['never'] = 'morse';
$labels['immediately'] = 'diouzhtu';
$labels['messagesdisplaying'] = 'O skrammañ kemennadennoù';
$labels['messagescomposition'] = 'O skrivañ kemennadennoù';
$labels['mimeparamfolding'] = 'Anvioù ar c\'henstagadurioù';
$labels['2231folding'] = 'RFC 2231 a-bezh (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'RFC 2047 a-bezh (ar re all)';
$labels['force7bit'] = 'Arverañ an enbonegañ MIME evit an arouezennoù 8-bit';
$labels['savelocalstorage'] = "Enrollañ e kadaviñ lec'hel ar merdeer (padennek)";
$labels['advancedoptions'] = 'Dibarzhioù araokaet';
$labels['toggleadvancedoptions'] = 'Trec\'haoliñ an dibarzhioù araoket';
$labels['focusonnewmessage'] = 'Stiañ prenestr ar merdeer pa \'z eus ur gemennadenn nevez';
$labels['checkallfolders'] = 'Gwiriañ an holl deuliadoù evit kemennadennoù nevez';
$labels['defaultfont'] = 'Nodrezh dre ziouer ar c\'hemennadennoù HTML';
$labels['mainoptions'] = 'Dibarzhioù dre ziouer';
$labels['browseroptions'] = 'Dibarzhioù ar merdeer';
$labels['section'] = 'Rann';
$labels['maintenance'] = 'Trezlac\'h';
$labels['newmessage'] = 'Kemennadenn nevez';
$labels['signatureoptions'] = 'Dibarzhioù sinadur';
$labels['whenreplying'] = 'Pa vez respontet';
$labels['replyempty'] = 'Chom hep menegiñ ar gemennadenn orin';
$labels['replytopposting'] = 'kregiñ ar gemennadenn nevez a-us d\'ar meneg';
$labels['replybottomposting'] = 'kregiñ ar gemennadenn nevez dindan ar meneg';
$labels['replyremovesignature'] = 'Pa vez respontet, dilemel ar sinadur orin eus ar gemennadenn ';
$labels['autoaddsignature'] = 'Ouzhpennañ ar sinadur ent emgefreek';
$labels['newmessageonly'] = 'evit ar c\'hemennadennoù nevez hepken';
$labels['replyandforwardonly'] = 'evit ar respontoù hag an treuzkasoù hepken';
$labels['insertsignature'] = 'Enlakaat ar sinadur';
$labels['sigbelow'] = 'Lakaat ar sinadur a-us d\'ar gemennadenn veneget';
$labels['sigseparator'] = 'Rediañ an disranner skoueriek er sinadurioù';
$labels['afternseconds'] = 'goude $n eilenn';
$labels['reqmdn'] = 'Atav goulenn un testeni degemer';
$labels['reqdsn'] = 'Atav goulenn ur rebuziñ stad ar c\'has';
$labels['replysamefolder'] = 'Lakaat ar respontoù en teuliad lec\'h m\'emañ ar gemennadenn orin';
$labels['defaultabook'] = 'Karned chomlec\'hioù dre ziouer';
$labels['autocompletesingle'] = 'Tremen ar chomlec\'hioù postel dazeilel er c\'hlokadur emgefreek ';
$labels['listnamedisplay'] = 'Rollañ an darempredoù evel';
$labels['spellcheckbeforesend'] = 'Gwiriekaat ar reizhskrivañ a-raok kas ur gemennadenn';
$labels['spellcheckoptions'] = 'Dibarzhioù reizhskrivañ';
$labels['spellcheckignoresyms'] = 'Leuskel ar gerioù gant arouezennoù';
$labels['spellcheckignorenums'] = 'Leuskel ar gerioù gant niverennoù';
$labels['spellcheckignorecaps'] = 'Leuskel ar gerioù gant pennlizherennoù hepken';
$labels['addtodict'] = 'Ouzhpennañ d\'ar geriadur';
$labels['mailtoprotohandler'] = 'Dornataour komenad marilhañ  evit mailto: ereoù';
$labels['standardwindows'] = 'Dornata prenestroù diflugell evel prenestroù skoueriek';
$labels['forwardmode'] = 'Treuzkas posteloù';
$labels['inline'] = 'enkorfet';
$labels['asattachment'] = 'kenstaget';
$labels['replyallmode'] = 'Gwered dre ziouer an afell [Respont d\'an holl]';
$labels['replyalldefault'] = 'respont d\'an holl';
$labels['replyalllist'] = 'respont d\'ar roll posteloù hepken (m\'eo kavet)';
$labels['allmessages'] = 'An holl posteloù';
$labels['folder'] = 'Teuliad';
$labels['folders'] = 'Teuliadoù';
$labels['foldername'] = 'Anv an teuliad';
$labels['subscribed'] = 'Koumananter';
$labels['messagecount'] = 'Kemennadennoù';
$labels['create'] = 'Krouiñ';
$labels['createfolder'] = 'Krouiñ un teuliad nevez';
$labels['managefolders'] = 'Ardeiñ an teuliadoù';
$labels['specialfolders'] = 'Teuliadoù arbennik';
$labels['properties'] = 'Perzhioù';
$labels['folderproperties'] = 'Perzhioù an teuliad';
$labels['parentfolder'] = 'Teuliad kar';
$labels['location'] = 'Lec\'hiadur';
$labels['info'] = 'Titouroù';
$labels['getfoldersize'] = 'Klikit da gaout ment an teuliad';
$labels['changesubscription'] = 'Klikit da gemmañ ar c\'houmanant';
$labels['foldertype'] = 'Rizh an teuliad';
$labels['personalfolder'] = 'Teuliad prevez';
$labels['otherfolder'] = 'Teuliad an arveriaded all';
$labels['sharedfolder'] = 'Teuliad foran';
$labels['findfolders'] = 'Kavout teuliadoù';
$labels['namespace.personal'] = 'Personel';
$labels['namespace.other'] = 'Arveriaded all';
$labels['namespace.shared'] = 'Rannet';
$labels['encryptioncreatekey'] = 'Krouiñ un daouad alc\'hwezioù nevez';
$labels['encryption'] = 'Enrinegañ';
$labels['sortby'] = 'Rummañ dre';
$labels['sortasc'] = 'Rumm diagentad';
$labels['sortdesc'] = 'Rumm diskennad';
$labels['undo'] = 'Dizober';
$labels['installedplugins'] = 'Enlugelladoù staliet';
$labels['plugin'] = 'Enlugellad';
$labels['version'] = 'Handelv';
$labels['source'] = 'Tarzh';
$labels['license'] = 'Lañvaz';
$labels['support'] = 'Skoazell';
$labels['B'] = 'Eizhbit';
$labels['KB'] = 'KE';
$labels['MB'] = 'ME';
$labels['GB'] = 'GE';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Saozneg';
$labels['westerneuropean'] = 'Kornôg Europa';
$labels['easterneuropean'] = 'Reter Europa';
$labels['southeasterneuropean'] = 'Gevred Europa';
$labels['baltic'] = 'Baltek';
$labels['cyrillic'] = 'Kirillek';
$labels['arabic'] = 'Arabeg';
$labels['greek'] = 'Gresianeg';
$labels['hebrew'] = 'Hebraek';
$labels['turkish'] = 'Turkeg';
$labels['nordic'] = 'Nordeg';
$labels['thai'] = 'Thai';
$labels['celtic'] = 'Keltieg';
$labels['vietnamese'] = 'Vietnameg';
$labels['japanese'] = 'Japaneg';
$labels['korean'] = 'Koreaneg';
$labels['chinese'] = 'Sinaeg';
$labels['arialabeltopnav'] = 'Reoliadur ar prenestr';
$labels['arialabeltasknav'] = 'Trevelloù arload';
$labels['arialabeltoolbar'] = 'Barrenn ostilhoù arload';
$labels['arialabelactivetask'] = 'Trevell oberiant';
$labels['arialabelmessagessearchfilter'] = 'Sil roll kemennadennoù';
$labels['arialabelmailsearchform'] = 'Furmad klask kemennadennoù';
$labels['arialabelcontactsearchform'] = 'Furmskrid klask darempredoù';
$labels['arialabelmailquicksearchbox'] = 'Enankad klask posteloù';
$labels['arialabelquicksearchbox'] = 'Enankad klask';
$labels['arialabelfoldersearchfilter'] = 'Sil roll teuliadoù';
$labels['arialabelfoldersearchform'] = 'Furmskrid klask teuliadoù';
$labels['arialabelfolderlist'] = 'Diuzad teuliadoù posteloù';
$labels['arialabelmessagelist'] = 'Roll kemennadennoù';
$labels['arialabelmailpreviewframe'] = 'Alberzh kemennadennoù';
$labels['arialabelmailboxmenu'] = 'Lañser gweredoù an teuliad';
$labels['arialabellistselectmenu'] = 'Lañser roll an diuzad';
$labels['arialabelthreadselectmenu'] = 'Lañser roll an neudennoù';
$labels['arialabelmessagelistoptions'] = 'Skrammañ roll ar c\'hemennadennoù ha dibarzhioù rummañ';
$labels['arialabelmailimportdialog'] = 'Boestad emziviz enporzhiañ ur gemennadenn';
$labels['arialabelmessagenav'] = 'Merdeiñ kemennadennoù';
$labels['arialabelmessagebody'] = 'Korf ar gemennadenn';
$labels['arialabelmessageactions'] = 'Gwerdeoù ar gemennadenn';
$labels['arialabelcontactquicksearch'] = 'Furmskrid klask darempredoù';
$labels['arialabelcontactsearchbox'] = 'Enankad klask darempredoù';
$labels['arialabelmessageheaders'] = 'Talbennoù ar gemennadenn';
$labels['arialabelforwardingoptions'] = 'Dibarzhioù treuzkas';
$labels['arialabelreplyalloptions'] = 'Dibarzhioù respont d\'an holl';
$labels['arialabelmoremessageactions'] = 'Dibarzhioù kemennadenn ouzhpenn';
$labels['arialabelmarkmessagesas'] = 'Merkañ ar c\'hemennadennoù diuzet evel...';
$labels['arialabelcomposeoptions'] = 'Dibarzhioù skrivañ';
$labels['arialabelresponsesmenu'] = 'Lañser respontoù er voest';
$labels['arialabelattachmentuploadform'] = 'Furmskrid pellgas stagadennoù';
$labels['arialabelattachmentpreview'] = 'Alberz ar stagadennoù';
$labels['ariasummarycomposecontacts'] = 'Roll an darempredoù ha strolladoù da ziuzañ evel degemererien';
$labels['arialabelcontactexportoptions'] = 'Dibarzhioù ezporzhiañ darempredoù';
$labels['arialabelabookgroupoptions'] = 'Dibarzhioù karned chomlec\'h/strolladoù';
$labels['arialabelpreferencesform'] = 'Gwellvezioù a-berzh';
$labels['arialabelidentityeditfrom'] = 'Furmskrid embann ar pivelezh';
$labels['arialabelresponseeditfrom'] = 'Furmskrid embann ar respont';
$labels['arialabelsearchterms'] = 'Termennoù enklask';
$labels['helplistnavigation'] = 'Rollañ merdeiñ ar c\'hlavier';
$labels['helplistkeyboardnavigation'] = "Biroù a-us/en-traoñ: Dilec'hiañ linenn stiet/diuzet
Esaouiñ: stiañ al linenn
Pennlizh. + a-us/en-traoñ: diuzañ linennoù ouzhpenn a-us/e traoñ
Reol + esaouiñ: Ouzhpennañ linennoù stiet d'an diuzad/Dilemel eus an diuzad";
$labels['helplistkeyboardnavmessages'] = "Biroù kleiz/dehou: astenn/diskar neudennoù kemennadennoù (e mod neudenn hepken)
Enankañ: Digeriñ ar gemennadenn stiet/diuzet.
Dilemel: Dilec'hiañ ar c'hemennadennoù diuzet d'ar c'hest.";
$labels['helplistkeyboardnavcontacts'] = "Enankañ: Digeriñ an darempred stiet/diuzet.";
