<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['messagedelete'] = 'रद्दी टोकरीमा हाल्नुहोस';
$labels['del'] = 'मेटाउनुहोस';
$labels['notifymethodmailto'] = 'ई-मेल';
$labels['datetest'] = 'तारिख';
$labels['vacation.subject'] = 'विषय';
