<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Զտիչներ';
$labels['managefilters'] = 'Կառավարել ստացվող նամակների զտիչները';
$labels['filtername'] = 'Զտիչի անուն';
$labels['newfilter'] = 'Նոր զտիչ';
$labels['filteradd'] = 'Ավելացնել զտիչ';
$labels['filterdel'] = 'Ջնջել զտիչը';
$labels['moveup'] = 'Բարձրացնել';
$labels['movedown'] = 'Իջեցնել';
$labels['filterallof'] = 'հետևյալ բոլոր պահանջներին համապատասխանող';
$labels['filteranyof'] = 'հետևյալ պահանջներից ցանկացածին համապատասխանող';
$labels['filterany'] = 'բոլոր հաղորդագրությունները';
$labels['filtercontains'] = 'պարունակում է';
$labels['filternotcontains'] = 'չի պարունակում';
$labels['filteris'] = 'հավասար է';
$labels['filterisnot'] = 'հավասար չէ';
$labels['filterexists'] = 'գոյություն ունի';
$labels['filternotexists'] = 'գոյություն չունի';
$labels['filtermatches'] = 'բավարարում է արտահայտությանը';
$labels['filternotmatches'] = 'չի բավարարում արտահայտությանը';
$labels['filterregex'] = 'բավարարում է կանոնավոր արտահայտությանը';
$labels['filternotregex'] = 'չի բավարարում կանոնավոր արտահայտությանը';
$labels['filterunder'] = 'տակ';
$labels['filterover'] = 'վրա';
$labels['addrule'] = 'Ավելացնել պայմանը';
$labels['delrule'] = 'Ջնջել պայմանը';
$labels['messagemoveto'] = 'Տեղափոխել հաղորդագրությունը';
$labels['messageredirect'] = 'Վերահասցեվորել հաղորդագրությունը';
$labels['messagecopyto'] = 'Պատճենել հաղորդագրությունը';
$labels['messagesendcopy'] = 'Ուղարկել հաղորդագրության պատճեն';
$labels['messagereply'] = 'Պատասխանել հաղորդագրությամբ';
$labels['messagedelete'] = 'Ջնջել հաղորդագրությունը';
$labels['messagediscard'] = 'Հեռացնել, հաղորդագրությամբ';
$labels['messagesrules'] = 'Ստացվող հաղորդագրությունների համար';
$labels['messagesactions'] = '…կատարել հետևյալ գործողությունները.';
$labels['add'] = 'Ավելացնել';
$labels['del'] = 'Ջնջել';
$labels['sender'] = 'Ուղարկող';
$labels['recipient'] = 'Ստացող';
$labels['vacationdays'] = 'Ինչ հաճախությամբ ուղարկել հաղորդագրությունները (օրեր)`';
$labels['vacationreason'] = 'Հաղորդագրության բովանդակություն (արձակուրդի պատճառ)`';
$labels['vacationsubject'] = 'Հաղորդագրության վերնագիր`';
$labels['rulestop'] = 'Դադարել պայմանների ստուգումը';
$labels['enable'] = 'Միացնել/Անջատել';
$labels['filtersets'] = 'Զտիչների համալիրներ';
$labels['filterdef'] = 'Զտիչի սահմանում';
$labels['active'] = 'ակտիվ';
$labels['none'] = 'ոչ մեկը';
$labels['fromset'] = 'համալիրից';
$labels['fromfile'] = 'ֆայլից';
$labels['filterdisabled'] = 'Զտիչը անջատված է';
$labels['countisgreaterthan'] = 'քանակը գերազանցում է';
$labels['countisgreaterthanequal'] = 'քանակը գերազանցում է կամ հավասար է';
$labels['countislessthan'] = 'քանակը պակաս է';
$labels['countislessthanequal'] = 'քանակը պակաս է կամ հավասար է';
$labels['countequals'] = 'քանակը հավասար է';
$labels['valueisgreaterthan'] = 'արժեքը գերազանցում է';
$labels['valueisgreaterthanequal'] = 'արժեքը գերազանցում է կամ հավասար է';
$labels['valueislessthan'] = 'արժեքը պակաս է';
$labels['valueislessthanequal'] = 'արժեքը պակաս է կամ հավասար է';
$labels['valueequals'] = 'արժեքը հավասար է';
$labels['setflags'] = 'Հաղորդագրությունը նշել որպես';
$labels['addflags'] = 'Ավելացնել նշաններ հաղորդագրությանը';
$labels['removeflags'] = 'Հեռացնել նշաններ հաղորդագրությունից';
$labels['flagread'] = 'Ընթերցված';
$labels['flagdeleted'] = 'Ջնջված';
$labels['flaganswered'] = 'Պատասխանված';
$labels['flagflagged'] = 'Նշված';
$labels['flagdraft'] = 'Սևագիր';
$labels['notifymethodmailto'] = 'Էկ–փոստ';
$labels['notifymethodtel'] = 'Հեռախոս';
$labels['filtercreate'] = 'Ստեղծել զտիչ';
$labels['usedata'] = 'Զտիչում օգտագործել հետևյալ տեղեկությունը.';
$labels['nextstep'] = 'Հաջորդ քայլ';
$labels['...'] = '…';
$labels['datetest'] = 'Ամսաթիվ';
$labels['advancedopts'] = 'Հավելյալ ընտրանքներ';
$labels['body'] = 'Մարմին';
$labels['address'] = 'հասցե';
$labels['envelope'] = 'ծրար';
$labels['modifier'] = 'փոփոխիչ`';
$labels['text'] = 'տեքստ';
$labels['undecoded'] = 'մաքուր';
$labels['contenttype'] = 'բովանդակության տիպ';
$labels['modtype'] = 'տիպ`';
$labels['allparts'] = 'բոլորը';
$labels['domain'] = 'տիրույթ';
$labels['localpart'] = 'լոկալ մաս';
$labels['user'] = 'օգտվող';
$labels['detail'] = 'մաս';
$labels['comparator'] = 'համեմատիչ`';
$labels['default'] = 'լռակյաց';
$labels['octet'] = 'անփոփոխ (օկտետ)';
$labels['asciicasemap'] = 'case insensitive (ascii-casemap)';
$labels['asciinumeric'] = 'numeric (ascii-numeric)';
$labels['spamtestequals'] = 'հավասար է';
$labels['spamtestnotequals'] = 'հավասար չէ';
$labels['vacation.subject'] = 'Վերնագիր';
$labels['vacation.body'] = 'Մարմին';
$labels['vacation.keep'] = 'Պահել';
$messages['filterunknownerror'] = 'Սերվերի անհայտ սխալ';
$messages['filterconnerror'] = 'Սերվերի հետ կապի խնդիր։';
$messages['filterdeleted'] = 'Զտիչը ջնջվեց։';
$messages['filtersaved'] = 'Զտիչը պահպանվեց։';
$messages['filterdeleteconfirm'] = 'Դուք իսկապե՞ս ցանկանում եք ջնջել նշված զտիչը։';
$messages['ruledeleteconfirm'] = 'Դուք իսկապե՞ս ցանկանում եք ջնջել նշված պայմանը։';
$messages['actiondeleteconfirm'] = 'Դուք իսկապե՞ս ցանկանում եք ջնջել նշված գործողությունը։';
$messages['forbiddenchars'] = 'Դաշտում առկա են արգելված նիշեր։';
$messages['cannotbeempty'] = 'Դաշտը դատարկ չի կարող լինել։';
$messages['ruleexist'] = 'Տրված անունով զտիչ արդեն գոյություն ունի։';
$messages['deactivated'] = 'Զտիչի միացված է։';
$messages['activated'] = 'Զտիչի անջատված է։';
$messages['moved'] = 'Զտիչի տեղափոխված է։';
$messages['nametoolong'] = 'Անունը չափազանց երկար է։';
$messages['namereserved'] = 'Անթույլատրելի անուն։';
$messages['setexist'] = 'Համալիրը արդեն գոյություն ունի։';
$messages['nodata'] = 'Պահանջվում է նշել գոնե մեկ դիրք։';
