<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-password/
*/

$labels['changepasswd']  = 'Parolni almashtirish';
$labels['curpasswd']  = 'Hozirgi parol';
$labels['newpasswd']  = 'Yangi parol';
$labels['confpasswd']  = 'Yangi parolni tasdiqlash';
$messages['nopassword'] = 'Iltimos, yangi parolni kiriting';
$messages['nocurpassword'] = 'Iltimos, yangi parolni kiriting';
$messages['passwordincorrect'] = 'Hozirgi parol noto‘g‘ri yozildi';
$messages['passwordinconsistency'] = 'Parollar mos emas, qaytadan urinub ko‘ring';
$messages['crypterror'] = 'Yangi parol saqlanmadi. Shifrlash funksiyasi yoqilmagan';
$messages['connecterror'] = 'Yangi parol saqlanmadi. Ulanishda xatolik.';
$messages['internalerror'] = 'Yangi parol saqlanmadi.';
$messages['passwordshort'] = 'Parol uzunligi kamida $length simvol bo‘lishi kerak.';
$messages['passwordweak'] = 'Parol kamida bitta raqamga ega bo‘lishi va punktuatsiya simvollari mavjud bo‘lishi kerak.';
$messages['passwordforbidden'] = 'Parol tarkibida ruxsat etilmagan simvol mavjud';
$messages['firstloginchange'] = 'Bu sizning birinchi marta tizimga kirishingiz, iltimos parolingizni o‘zgartiring.';
$messages['disablednotice'] = 'Hozir tizimga xizmat ko‘rsatilmoqda va parolni o‘zgartirish funksiyasi hozirda amalda emas. Barchasi tezda o‘z normal holatiga qaytadi. Noqulayliklar uchun uzr.';
$messages['passwinhistory'] = 'Bu paroldan avval foydalanilgan.';
$messages['samepasswd'] = 'Yangi parol avvalgisidan farqlanishi lozim.';
$messages['passwdexpirewarning'] = 'Ogohlantirish! Sizning parolingiz muddati tugamoqda, bu $expirationdatetime muddatdan avval uni almashtiring.';
$messages['passwdexpired'] = 'Sizning parolingiz eskirdi, uni hoziroq o‘zgartiring.';
$messages['passwdconstraintviolation'] = 'Parol cheklovlari buzilgan, ehtimol parolingiz juda sodda.';
