tinymce.addI18n('eo',{
"Redo": "Refari",
"Undo": "Malfari",
"Cut": "Eltran\u0109i",
"Copy": "Kopii",
"Paste": "Englui",
"Select all": "Elekti \u0109ion",
"New document": "Nova dokumento",
"Ok": "Bone",
"Cancel": "Nuligi",
"Visual aids": "Videblaj helpiloj",
"Bold": "Dika",
"Italic": "Oblikva",
"Underline": "Substreki",
"Strikethrough": "Trastreki",
"Superscript": "Superskribi",
"Subscript": "Malsuperskribi",
"Clear formatting": "Forigi formatigon",
"Align left": "Ordigu maldekstren",
"Align center": "Ordigu centren",
"Align right": "Ordigu dekstren",
"Justify": "Ordigu la\u016dflanke",
"Bullet list": "Punkta listo",
"Numbered list": "Numera listo",
"Decrease indent": "Malpliigu alineon",
"Increase indent": "Pliigu alineon",
"Close": "Fermi",
"Formats": "Formatoj",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Via retumilo ne subtenas rektan aliron al bufro. Bonvolu antata\u016de uzi klavarajn kombinojn Ctrl+X\/C\/V.",
"Headers": "\u0108apoj",
"Header 1": "\u0108apo 1",
"Header 2": "\u0108apo 2",
"Header 3": "\u0108apo 3",
"Header 4": "\u0108apo 4",
"Header 5": "\u0108apo 5",
"Header 6": "\u0108apo 6",
"Headings": "Titoloj",
"Heading 1": "Titolo 1",
"Heading 2": "Titolo 2",
"Heading 3": "Titolo 3",
"Heading 4": "Titolo 4",
"Heading 5": "Titolo 5",
"Heading 6": "Titolo 6",
"Preformatted": "Anta\u016dformatigita",
"Div": "Div",
"Pre": "Pre",
"Code": "Kodo",
"Paragraph": "Alineo",
"Blockquote": "Mar\u011denigo",
"Inline": "Enlinie",
"Blocks": "Blokoj",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "La engluado nun okazas en simpla teksta re\u011dimo. La enhavo estos engluata kiel simpla teksto \u011dis anta\u016d vi for\u015daltos tiun \u0109i opcion.",
"Fonts": "Tiparoj",
"Font Sizes": "Tiparaj grandoj",
"Class": "Klaso",
"Browse for an image": "Rigardi por iu bildo",
"OR": "A\u016c",
"Drop an image here": "\u0134etu iun bildon \u0109i tien",
"Upload": "Al\u015duti",
"Block": "Bloko",
"Align": "\u011cisrandigi ",
"Default": "Implicite",
"Circle": "Cirklo",
"Disc": "Disko",
"Square": "Kvadrato",
"Lower Alpha": "Minuskla alfabeta",
"Lower Greek": "Minuskla greka",
"Lower Roman": "Minuskla latina",
"Upper Alpha": "Majuskla alfabeta",
"Upper Roman": "Majuskla latina",
"Anchor...": "Ankro...",
"Name": "Nomo",
"Id": "Identigilo",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "Identigilo devas komenci\u011di per litero sekvata nur per literoj, ciferoj, streketoj, punktoj, dupunktoj a\u016d substrekoj.",
"You have unsaved changes are you sure you want to navigate away?": "Vi havas nekonservitajn \u015dan\u011dojn, \u0109u vi certe deziras eliri?",
"Restore last draft": "Restarigu lastan malneton",
"Special character...": "Speciala signo...",
"Source code": "Fonta kodo",
"Insert\/Edit code sample": "Enmeti\/Redakti kodospecimenon",
"Language": "Lingvo",
"Code sample...": "Kodospecimeno...",
"Color Picker": "Kolorelektilo",
"R": "R",
"G": "G",
"B": "B",
"Left to right": "Maldekstro dekstren",
"Right to left": "Dekstro maldekstren",
"Emoticons...": "Miensimboloj...",
"Metadata and Document Properties": "Metadatumoj kaj ecoj de dokumento",
"Title": "Titolo",
"Keywords": "\u015closilvortoj",
"Description": "Priskribo",
"Robots": "Robotoj",
"Author": "A\u016dtoro",
"Encoding": "Enkodigo",
"Fullscreen": "Tutekrane",
"Action": "Ago",
"Shortcut": "\u015cparvojo",
"Help": "Helpo",
"Address": "Adreso",
"Focus to menubar": "Enfokusigi al menubreto",
"Focus to toolbar": "Enfokusigi al ilobreto",
"Focus to element path": "Enfokusigi al elementvojo",
"Focus to contextual toolbar": "Enfokusigi al kunteksta ilobreto",
"Insert link (if link plugin activated)": "Enmeti ligilon (se ligila komprogramo estas aktivigita)",
"Save (if save plugin activated)": "Konservi (se konserva komprogramo estas aktivigita)",
"Find (if searchreplace plugin activated)": "Ser\u0109i (se ser\u0109a komprogramo estas aktivigita)",
"Plugins installed ({0}):": "Kromprogramoj instalitaj ({0}): ",
"Premium plugins:": "Premiaj kromprogramoj:",
"Learn more...": "Legu aldone...",
"You are using {0}": "Vi uzas {0}",
"Plugins": "Kromprogramoj",
"Handy Shortcuts": "Komfortaj \u015dparvojoj",
"Horizontal line": "Horizontala linio",
"Insert\/edit image": "Enmetu\/redaktu bildon",
"Image description": "Bilda priskribo",
"Source": "Fonto",
"Dimensions": "Dimensioj",
"Constrain proportions": "Relativigu proporciojn",
"General": "\u011cenerale",
"Advanced": "Por spertuloj",
"Style": "Stilo",
"Vertical space": "Vertikala spaco",
"Horizontal space": "Horizontala spaco",
"Border": "Limo",
"Insert image": "Enmetu bildon",
"Image...": "Bildo...",
"Image list": "Bildlisto",
"Rotate counterclockwise": "Rotaciu kontra\u016d horlo\u011do",
"Rotate clockwise": "Rotaciu la\u016d horlo\u011do",
"Flip vertically": "Respegulu vertikale",
"Flip horizontally": "Respegulu horizontale",
"Edit image": "Redaktu bildon",
"Image options": "Bildaj opcioj",
"Zoom in": "Plilar\u011digu",
"Zoom out": "Malplilar\u011digu",
"Crop": "Randtran\u0109u",
"Resize": "\u015can\u011du dimensiojn",
"Orientation": "Orientigo",
"Brightness": "Heleco",
"Sharpen": "Akrigu",
"Contrast": "Kontrasto",
"Color levels": "Kolorniveloj",
"Gamma": "Gamo",
"Invert": "Inversigu",
"Apply": "Apliku",
"Back": "Reen",
"Insert date\/time": "Enmetu daton\/tempon",
"Date\/time": "Dato\/tempo",
"Insert\/Edit Link": "Enmeti\/redakti ligilon",
"Insert\/edit link": "Enmetu\/redaktu ligilon",
"Text to display": "Montrata teksto",
"Url": "Urlo",
"Open link in...": "Sekvi ligilon per...",
"Current window": "Aktuala fenestro",
"None": "Nenio",
"New window": "Nova fenestro",
"Remove link": "Forigu ligilon",
"Anchors": "Ankroj",
"Link...": "Ligilo...",
"Paste or type a link": "Engluu a\u016d enigu ligilon",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "La enmetita URLo \u015dajnas esti retadreso. \u0108u vi deziras aldoni prefikson mailto:?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "La enmetita URLo \u015dajnas esti ekstera ligilo. \u0108u vi deziras aldoni nepran prefikson http:\/\/?",
"Link list": "Ligila listo",
"Insert video": "Enmetu videon",
"Insert\/edit video": "Enmetu\/redaktu videon",
"Insert\/edit media": "Enmeti\/redakti a\u016ddovida\u0135on  ",
"Alternative source": "Alternativa fonto",
"Alternative source URL": "URLo de alternativa fonto",
"Media poster (Image URL)": "Ligilo al a\u016ddovida\u0135o (URLo de bildo)",
"Paste your embed code below:": "Engluu vian internan kodon \u0109i-sube:",
"Embed": "Enkonstruu",
"Media...": "A\u016ddovida\u0135o...",
"Nonbreaking space": "Nerompebla spaco",
"Page break": "Pa\u011da fino",
"Paste as text": "Engluu kiel tekston",
"Preview": "Provrigardo",
"Print...": "Presi...",
"Save": "Konservi",
"Find": "Trovi",
"Replace with": "Anstata\u016digi per",
"Replace": "Anstata\u016digi",
"Replace all": "Anstata\u016digi\u0109ion",
"Previous": "Anta\u016da",
"Next": "Posta",
"Find and replace...": "Ser\u0109i kaj anstata\u016di... ",
"Could not find the specified string.": "Malsukceso trovi la indikitan sinsekvon",
"Match case": "Sekvi usklecon",
"Find whole words only": "Ser\u0109i nur tutan vorton",
"Spell check": "Kontroli literumadon",
"Ignore": "Ignoru",
"Ignore all": "Ignoru \u0109ion",
"Finish": "Finu",
"Add to Dictionary": "Aldonu al vortaro",
"Insert table": "Enmetu tabelon",
"Table properties": "Tabelaj ecoj",
"Delete table": "Forigu tabelon",
"Cell": "\u0108elo",
"Row": "Vico",
"Column": "Kolumno",
"Cell properties": "\u0108elaj ecoj",
"Merge cells": "Kunigu \u0109elojn",
"Split cell": "Disdividu \u0109elon",
"Insert row before": "Enmetu vicon anta\u016d",
"Insert row after": "Enmetu vicon poste",
"Delete row": "Forigu vicon",
"Row properties": "Vicaj ecoj",
"Cut row": "Eltran\u0109u vicon",
"Copy row": "Kopiu vicon",
"Paste row before": "Engluu vicon anta\u016d",
"Paste row after": "Engluu vicon poste",
"Insert column before": "Enmetu kolumnon anta\u016d",
"Insert column after": "Enmetu kolumnon poste",
"Delete column": "Forigu kolumnon",
"Cols": "Kolumonoj",
"Rows": "Vicoj",
"Width": "Lar\u011do",
"Height": "Alto",
"Cell spacing": "\u0108elspacoj",
"Cell padding": "\u0108elmar\u011denoj",
"Show caption": "Montri apudskribon",
"Left": "Maldekstro",
"Center": "Centro",
"Right": "Dekstro",
"Cell type": "\u0108ela tipo",
"Scope": "Amplekso",
"Alignment": "Aligo",
"H Align": "H aligo",
"V Align": "V aligo",
"Top": "Supro",
"Middle": "Mezo",
"Bottom": "Subo",
"Header cell": "\u0108apa \u0109elo",
"Row group": "Vica grupo",
"Column group": "Kolumna grupo",
"Row type": "Vica tipo",
"Header": "\u0108apo",
"Body": "Korpo",
"Footer": "Piedo",
"Border color": "Lima koloro",
"Insert template...": "Enmeti \u015dablonon...",
"Templates": "\u015cablonoj",
"Template": "\u015cablono",
"Text color": "Teksta koloro",
"Background color": "Fona koloro",
"Custom...": "Propra...",
"Custom color": "Propra koloro",
"No color": "Neniu koloro",
"Remove color": "Forigi koloron",
"Table of Contents": "Enhavotabelo",
"Show blocks": "Montru blokojn",
"Show invisible characters": "Montru nevideblajn karaktrojn",
"Word count": "Vortnombro ",
"Count": "Nombri",
"Document": "Dokumento",
"Selection": "Elekto",
"Words": "Vortoj",
"Words: {0}": "Vortoj: {0}",
"{0} words": "{0} vortoj",
"File": "Dokumento",
"Edit": "Redakti",
"Insert": "Enmeti",
"View": "Vidi",
"Format": "Aspektigi",
"Table": "Tabelo",
"Tools": "Iloj",
"Powered by {0}": "Funkciigita de {0}",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Ri\u0109teksta Areo. Premu ALT-F9 por menuo. Premu ALT-F10 por menuejo. Premu ALT-0 por helpo",
"Image title": "Titolo de bildo",
"Border width": "Lar\u011do de bordero",
"Border style": "Stilo de bordero",
"Error": "Eraro",
"Warn": "Averto",
"Valid": "Valida",
"To open the popup, press Shift+Enter": "Por aperigi \u015dprucfenestron premu fulmoklavon Shift+Enter ",
"Rich Text Area. Press ALT-0 for help.": "Ri\u0109teksta loko. Premu fulmoklavon ALT-0 por helpo.",
"System Font": "Sistema tiparo",
"Failed to upload image: {0}": "Al\u015dutado de bildo {0} malsukcesis",
"Failed to load plugin: {0} from url {1}": "\u015cargado de kromprogramo {0} el URLo {1} malsukcesis",
"Failed to load plugin url: {0}": "\u015cargado por kroprograma URLo {0} malsukcesis",
"Failed to initialize plugin: {0}": "Pravalorizado de krompogramo {0} malsukcesis",
"example": "ekzemplo",
"Search": "Ser\u0109i",
"All": "\u0108io",
"Currency": "Valuto",
"Text": "Teksto",
"Quotations": "Cita\u0135oj",
"Mathematical": "Matematika",
"Extended Latin": "Etendita la latina",
"Symbols": "Simboloj",
"Arrows": "Sagsimboloj",
"User Defined": "Propre difinita ",
"dollar sign": "signo de usona dolaro",
"currency sign": "valutsigno",
"euro-currency sign": "signo de e\u016dro",
"colon sign": "dupunkto",
"cruzeiro sign": "signo de brazila kruzero",
"french franc sign": "signo de francia franko",
"lira sign": "signo de itala liro",
"mill sign": "signo de milono de baza monunuo",
"naira sign": "signo de ni\u011deria najro",
"peseta sign": "signo de hispana peseto",
"rupee sign": "signo de rupio",
"won sign": "signo de koreia \u016dono",
"new sheqel sign": "signo de israela siklo",
"dong sign": "signo de vjetnama dongo",
"kip sign": "signo de laosa kipo",
"tugrik sign": "signo de mongola tugriko",
"drachma sign": "signo de greka dra\u0125mo",
"german penny symbol": "signo de pfenigo",
"peso sign": "signo de peso",
"guarani sign": "signo de paragvaja gvaranio",
"austral sign": "signo de argentina a\u016dstralo",
"hryvnia sign": "signo de ukrainia hrivno",
"cedi sign": "signo de ganaa cedio",
"livre tournois sign": "signo de pundo de Turo",
"spesmilo sign": "signo de spesmilo",
"tenge sign": "signo de kaza\u0125a tengo",
"indian rupee sign": "signo de barata rupio",
"turkish lira sign": "signo de turka liro",
"nordic mark sign": "signo de marko",
"manat sign": "signo de azerbaj\u011dana manato",
"ruble sign": "signo de rusia rublo",
"yen character": "signo de japana eno",
"yuan character": "signo de \u0109ina renminbio",
"yuan character, in hong kong and taiwan": "signo de juano, Hongkongo kaj Tajvano",
"yen\/yuan character variant one": "alia varianto de signo de eno\/juano",
"Loading emoticons...": "\u015cargado de mienvinjetoj",
"Could not load emoticons": "Ne povas \u015dargi mienvinjetojn",
"People": "Homoj",
"Animals and Nature": "Bestoj kaj naturo",
"Food and Drink": "Man\u011da\u0135o kaj trinka\u0135o",
"Activity": "Aktiveco",
"Travel and Places": "Voja\u011doj kaj lokoj",
"Objects": "Objektoj",
"Flags": "Flagoj",
"Characters": "Simboloj",
"Characters (no spaces)": "Simboloj (senspacetaj)",
"{0} characters": "{0} signojn",
"Error: Form submit field collision.": "Eraro: kolizio de kampoj dum sendado de formularo.",
"Error: No form element found.": "Eraro: elementoj de formularo forestas",
"Update": "\u011cisdatigi",
"Color swatch": "Specimenaro de koloroj",
"Turquoise": "Turkisa",
"Green": "Verda",
"Blue": "Blua",
"Purple": "Purpura",
"Navy Blue": "Helblua",
"Dark Turquoise": "Malhela turkisa",
"Dark Green": "Malhela verda",
"Medium Blue": "Meza blua",
"Medium Purple": "Meza purpla",
"Midnight Blue": "Nigroblua",
"Yellow": "Flava",
"Orange": "Oran\u011da",
"Red": "Ru\u011da",
"Light Gray": "Helgriza",
"Gray": "Griza",
"Dark Yellow": "Malhela flava",
"Dark Orange": "Malhela oran\u011da",
"Dark Red": "Malhela ru\u011da",
"Medium Gray": "Meza griza",
"Dark Gray": "Malhela griza",
"Light Green": "Helverda",
"Light Yellow": "Helflava",
"Light Red": "Helru\u011da",
"Light Purple": "Helpurpura",
"Light Blue": "Helblua",
"Dark Purple": "Malhelpurpura",
"Dark Blue": "Malhelblua",
"Black": "Nigra",
"White": "Blanka",
"Switch to or from fullscreen mode": "Tra\u015dan\u011di tutekranan re\u011dimon",
"Open help dialog": "Malfermi helpan dialogon",
"history": "historio",
"styles": "stilo",
"formatting": "tekstaran\u011do",
"alignment": "niveleco",
"indentation": "krommar\u011deno",
"permanent pen": "konstanta plumo",
"comments": "komentoj",
"Format Painter": "Formatelektilo",
"Insert\/edit iframe": "Enmeti\/redakti enkonstruitan framon (iframe)",
"Capitalization": "Komenci per majuskla",
"lowercase": "minuskla",
"UPPERCASE": "MAJUSKLA",
"Title Case": "Uskleco de titolo",
"Permanent Pen Properties": "Konstantaj ecoj de plumo",
"Permanent pen properties...": "Konstantaj ecoj de plumo",
"Font": "Tiparo",
"Size": "Grando",
"More...": "Pli...",
"Spellcheck Language": "Lingvo por literumi",
"Select...": "Elektu...",
"Preferences": "Agordoj",
"Yes": "Jes",
"No": "Ne",
"Keyboard Navigation": "Perklavara movi\u011dado",
"Version": "Versio",
"Anchor": "Ankro",
"Special character": "Speciala karaktro",
"Color": "Koloro",
"Emoticons": "Emociikonoj",
"Document properties": "Dokumentaj trajtoj",
"Insert link": "Enmetu ligilon",
"Target": "Celo",
"Poster": "Afi\u015do",
"Print": "Presu",
"Whole words": "Tutaj vortoj",
"Find and replace": "Trovi kaj anstata\u016digi",
"Prev": "Anta\u016da",
"Spellcheck": "Literumu",
"Caption": "Cita\u0135o",
"Insert template": "Enmetu \u015dablonon"
});