<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Tere tulemast! See on $product.';
$labels['username'] = 'Kasutajanimi';
$labels['password'] = 'Parool';
$labels['server'] = 'Server';
$labels['login'] = 'Logi sisse';
$labels['oauthlogin'] = 'Logi sisse kasutades $provider';
$labels['menu'] = 'Menüü';
$labels['logout'] = 'Logi välja';
$labels['mail'] = 'Postkast';
$labels['settings'] = 'Seaded';
$labels['addressbook'] = 'Aadressiraamat';
$labels['darkmode'] = 'Tume režiim';
$labels['lightmode'] = 'Hele režiim';
$labels['inbox'] = 'Saabuvad';
$labels['drafts'] = 'Mustandid';
$labels['sent'] = 'Saadetud';
$labels['trash'] = 'Prügikast';
$labels['junk'] = 'Rämps';
$labels['show_real_foldernames'] = 'Näita eriliste kaustade päris nimesid';
$labels['subject'] = 'Pealkiri';
$labels['from'] = 'Saatja';
$labels['sender'] = 'Saatja';
$labels['to'] = 'Saaja';
$labels['cc'] = 'Koopia';
$labels['bcc'] = 'Pimekoopia';
$labels['replyto'] = 'Vastus aadressile';
$labels['followupto'] = 'Followup-To';
$labels['date'] = 'Kuupäev';
$labels['size'] = 'Suurus';
$labels['priority'] = 'Tähtsus';
$labels['organization'] = 'Organisatsioon';
$labels['readstatus'] = 'Lugemise staatus';
$labels['listoptions'] = 'Nimekirja valikud…';
$labels['listoptionstitle'] = 'Nimekirja valikud';
$labels['mailboxlist'] = 'Kaustad';
$labels['messagesfromto'] = 'Kirjed $from kuni $to, kokku $count';
$labels['threadsfromto'] = 'Lõimed $from kuni $to, kokku $count';
$labels['messagenrof'] = 'Kiri $nr, kokku $count';
$labels['fromtoshort'] = '$from – $to kokku $count';
$labels['copy'] = 'Kopeeri';
$labels['move'] = 'Liiguta';
$labels['moveto'] = 'liiguta kausta...';
$labels['copyto'] = 'Kopeeri...';
$labels['download'] = 'laadi arvutisse';
$labels['open'] = 'Ava';
$labels['showattachment'] = 'Näita';
$labels['showanyway'] = 'Näita ikka';
$labels['filename'] = 'Faili nimi';
$labels['filesize'] = 'Faili suurus';
$labels['addtoaddressbook'] = 'Lisa aadressiraamatusse';
$labels['sun'] = 'P';
$labels['mon'] = 'E';
$labels['tue'] = 'T';
$labels['wed'] = 'K';
$labels['thu'] = 'N';
$labels['fri'] = 'R';
$labels['sat'] = 'L';
$labels['sunday'] = 'Pühapäev';
$labels['monday'] = 'Esmaspäev';
$labels['tuesday'] = 'Teisipäev';
$labels['wednesday'] = 'Kolmapäev';
$labels['thursday'] = 'Neljapäev';
$labels['friday'] = 'Reede';
$labels['saturday'] = 'Laupäev';
$labels['jan'] = 'jaan';
$labels['feb'] = 'veebr';
$labels['mar'] = 'märts';
$labels['apr'] = 'apr';
$labels['may'] = 'Mai';
$labels['jun'] = 'juuni';
$labels['jul'] = 'juuli';
$labels['aug'] = 'aug';
$labels['sep'] = 'sept';
$labels['oct'] = 'okt';
$labels['nov'] = 'nov';
$labels['dec'] = 'dets';
$labels['longjan'] = 'Jaanuar';
$labels['longfeb'] = 'Veebruar';
$labels['longmar'] = 'Märts';
$labels['longapr'] = 'Aprill';
$labels['longmay'] = 'Mai';
$labels['longjun'] = 'Juuni';
$labels['longjul'] = 'Juuli';
$labels['longaug'] = 'August';
$labels['longsep'] = 'September';
$labels['longoct'] = 'Oktoober';
$labels['longnov'] = 'November';
$labels['longdec'] = 'Detsember';
$labels['today'] = 'Täna';
$labels['refresh'] = 'Värskenda';
$labels['checkmail'] = 'Kontrolli uusi kirju';
$labels['compose'] = 'Koosta kiri';
$labels['writenewmessage'] = 'Kirjuta uus kiri';
$labels['reply'] = 'Vasta';
$labels['replytomessage'] = 'Vasta kirjale';
$labels['replytoallmessage'] = 'Vasta saatjale ja teistele kirja saanutele';
$labels['replyall'] = 'Vasta kõigile';
$labels['replylist'] = 'Vasta meilinglisti';
$labels['forward'] = 'Edasta';
$labels['forwardinline'] = 'Edasta kirja sees';
$labels['forwardattachment'] = 'Edasta manusena';
$labels['forwardmessage'] = 'Edasta see kiri';
$labels['bounce'] = 'Saada uuesti';
$labels['deletemessage'] = 'Kustuta kiri';
$labels['movemessagetotrash'] = 'Liiguta kiri prügikasti';
$labels['printmessage'] = 'Trüki kiri';
$labels['previousmessage'] = 'Näita eelmist kirja';
$labels['firstmessage'] = 'Näita esimest kirja';
$labels['nextmessage'] = 'Näita järgmist kirja';
$labels['lastmessage'] = 'Näita viimast kirja';
$labels['backtolist'] = 'Tagasi kirjade nimekirja';
$labels['viewsource'] = 'Näita lähtekoodi';
$labels['mark'] = 'Märgista';
$labels['markmessages'] = 'Märgi kirjad';
$labels['markread'] = 'Loetuks';
$labels['markunread'] = 'Mitte loetuks';
$labels['markflagged'] = 'Lisa lipik';
$labels['markunflagged'] = 'Eemalda lipik';
$labels['moreactions'] = 'Muud toimingud...';
$labels['markallread'] = 'Märgi kõik loetuks';
$labels['folders-cur'] = 'Valitud kaustad ainult';
$labels['folders-sub'] = 'Valitud kaustad ja selle alamkaustad';
$labels['folders-all'] = 'Kõik kaustad';
$labels['more'] = 'Rohkem';
$labels['back'] = 'Tagasi';
$labels['options'] = 'Valikud';
$labels['composeoptions'] = 'Koostamise valikud';
$labels['optionsandattachments'] = 'Valikud ja manused';
$labels['actions'] = 'Tegevused';
$labels['first'] = 'Esimene';
$labels['last'] = 'Viimane';
$labels['previous'] = 'Eelmine';
$labels['next'] = 'Järgmine';
$labels['select'] = 'Vali';
$labels['selection'] = 'Valik';
$labels['all'] = 'kõik';
$labels['none'] = 'Puudub';
$labels['currpage'] = 'Praegune leht';
$labels['isread'] = 'Loe';
$labels['unread'] = 'Lugemata';
$labels['flagged'] = 'Märgistatud';
$labels['unflagged'] = 'Märgistamatta';
$labels['unanswered'] = 'Vastamata';
$labels['withattachment'] = 'Koos manusega';
$labels['deleted'] = 'Kustutatud';
$labels['undeleted'] = 'Pole kustutatud';
$labels['replied'] = 'Vastatud';
$labels['forwarded'] = 'Edastatud';
$labels['invert'] = 'Vaheta';
$labels['filter'] = 'Filtreeri';
$labels['list'] = 'Nimekiri';
$labels['threads'] = 'Lõimed';
$labels['expand-all'] = 'Laienda kõik';
$labels['expand-unread'] = 'Laienda lugemata';
$labels['collapse-all'] = 'Pane kõik kokku';
$labels['threaded'] = 'Lõimedena';
$labels['showunread'] = 'Näita lugemata sõnumeid';
$labels['autoexpand_threads'] = 'Laienda kirjade lõimed';
$labels['do_expand'] = 'kõik lõimed';
$labels['expand_only_unread'] = 'ainult lugemata kirjadega';
$labels['fromto'] = 'Saatja/saaja';
$labels['flag'] = 'Märgista';
$labels['attachment'] = 'Manus';
$labels['nonesort'] = 'Puudub';
$labels['sentdate'] = 'Saatmise kuupäev';
$labels['arrival'] = 'Saamise kuupäev';
$labels['asc'] = 'kasvavalt';
$labels['desc'] = 'kahanevalt';
$labels['listcolumns'] = 'Näita veerge';
$labels['listsorting'] = 'Järjestus veerg';
$labels['listorder'] = 'Järjestus suund';
$labels['listmode'] = 'Nimekirja vaatamise režiim';
$labels['lmode'] = 'Nimekirja režiim';
$labels['layout'] = 'Paigutus';
$labels['layoutwidescreen'] = 'Laiekraan';
$labels['layoutdesktop'] = 'Lauaarvuti';
$labels['layoutlist'] = 'Nimekiri';
$labels['layoutwidescreendesc'] = 'Laiekraan (3-paani vaade)';
$labels['layoutdesktopdesc'] = 'Töölaud (lai nimekiri ja kirja ülevaade allpool)';
$labels['layoutlistdesc'] = 'Nimekiri (kirja ülevaadet ei ole)';
$labels['folderactions'] = 'Kausta tegevused...';
$labels['compact'] = 'Tihenda';
$labels['empty'] = 'Tühjenda';
$labels['importmessages'] = 'Impordi kirju';
$labels['mailimportdesc'] = 'Saate ülesse laadida faile, mis on <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> või <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a> formaadis.';
$labels['mailimportzip'] = 'Mitut faili on võimalik kokku pakkida zip arhiiviks.';
$labels['quota'] = 'Kettakasutus';
$labels['unknown'] = 'teadmata';
$labels['unlimited'] = 'piiramatu';
$labels['quotatype'] = 'Piirangu tüüp';
$labels['quotatotal'] = 'Limiit';
$labels['quotaused'] = 'Kasutatud';
$labels['quotastorage'] = 'Ketta ruum';
$labels['quotamessage'] = 'Kirjade arv';
$labels['shortheaderdate'] = 'Kuupäeval $date';
$labels['shortheaderto'] = 'Saajale $to päeval $date';
$labels['shortheaderfrom'] = 'Saatjalt $from päeval $date';
$labels['quicksearch'] = 'Kiirotsing';
$labels['searchplaceholder'] = 'Otsimine...';
$labels['resetsearch'] = 'Lähtesta otsing';
$labels['searchmod'] = 'Otsingu laiendid';
$labels['msgtext'] = 'Kogu kirjast';
$labels['body'] = 'Keha';
$labels['type'] = 'Tüüp';
$labels['namex'] = 'Nimi';
$labels['searchscope'] = 'Skoop';
$labels['currentfolder'] = 'Käesolev kaust';
$labels['subfolders'] = 'See ja alamkaust';
$labels['allfolders'] = 'Kõik kaustad';
$labels['searchinterval-1W'] = 'vanemad kui nädal';
$labels['searchinterval-1M'] = 'vanemad kui kuu';
$labels['searchinterval-1Y'] = 'vanemad kui aasta';
$labels['searchinterval1W'] = 'värskemad kui nädal';
$labels['searchinterval1M'] = 'värskemad kui kuu';
$labels['searchinterval1Y'] = 'värskemad kui aasta';
$labels['openinextwin'] = 'Ava uues aknas';
$labels['emlsave'] = 'Salvesta (.eml)';
$labels['changeformattext'] = 'Näita lihttekstina';
$labels['changeformathtml'] = 'Näita HTMLis';
$labels['editasnew'] = 'Kasuta uue kirja põhjana';
$labels['send'] = 'Saada';
$labels['sendmessage'] = 'Saada kiri kohe';
$labels['savemessage'] = 'Salvesta mustand';
$labels['addattachment'] = 'Lisa fail';
$labels['charset'] = 'Märgistik';
$labels['editortype'] = 'Redaktori tüüp';
$labels['returnreceipt'] = 'Kättesaamiskinnitus';
$labels['dsn'] = 'Kohalejõudmise teavitus';
$labels['mailreplyintro'] = '$date kirjutas $sender:';
$labels['originalmessage'] = 'Esialgne kiri';
$labels['selectimage'] = 'Vali pilt';
$labels['addimage'] = 'Lisa pilt';
$labels['selectmedia'] = 'Vali film';
$labels['addmedia'] = 'Lisa film';
$labels['encrypt'] = 'Krüpti';
$labels['encryptmessage'] = 'Krüpti kiri';
$labels['encryptmessagemailvelope'] = 'Krüpteeri kiri kasutades Mailvelope';
$labels['importpubkeys'] = 'Impordi avalikud võtmed';
$labels['encryptedsendialog'] = 'Saadan krüptitud kirja';
$labels['encryptandsign'] = 'Krüpteeri ja allkirjasta';
$labels['keyid'] = 'Võtme ID';
$labels['keylength'] = 'Bitte';
$labels['keyexpired'] = 'Aegunud';
$labels['keyrevoked'] = 'Tühistatud';
$labels['bccinstead'] = 'Kasuta Pimekoopiat';
$labels['addheader'] = 'Lisa saaja (päis)';
$labels['insert'] = 'Lisa';
$labels['insertcontact'] = 'Lisa kontakt(id)';
$labels['recipient'] = 'Saaja';
$labels['recipientedit'] = 'Saaja muutmine';
$labels['editidents'] = 'Muuda Identiteete';
$labels['spellcheck'] = 'Õigekiri';
$labels['checkspelling'] = 'Kontrolli õigekirja';
$labels['resumeediting'] = 'Jätka muutmist';
$labels['revertto'] = 'Pööra tagasi';
$labels['restore'] = 'Taasta';
$labels['restoremessage'] = 'Taasta kiri?';
$labels['ignore'] = 'Igroneeri';
$labels['responses'] = 'Vastused';
$labels['insertresponse'] = 'Lisa vastus';
$labels['manageresponses'] = 'Halda vastuseid';
$labels['newresponse'] = 'Loo uus vastus';
$labels['addresponse'] = 'Lisa vastus';
$labels['editresponse'] = 'Muuda vastust';
$labels['editresponses'] = 'Muuda vastuseid';
$labels['responsename'] = 'Nimi';
$labels['responsetext'] = 'Vastuse sisu';
$labels['attach'] = 'Manusta';
$labels['attachments'] = 'Manused';
$labels['upload'] = 'Kinnita manus';
$labels['uploadprogress'] = '$percent ($current / $total)';
$labels['close'] = 'Sulge';
$labels['messageoptions'] = 'Kirja valikud...';
$labels['togglecomposeoptions'] = 'Muuda koostamise valikuid';
$labels['attachmentrename'] = 'Nimeta manus ümber';
$labels['low'] = 'Madal';
$labels['lowest'] = 'Madalaim';
$labels['normal'] = 'Tavaline';
$labels['high'] = 'Kõrge';
$labels['highest'] = 'Kõrgeim';
$labels['nosubject'] = '(teema puudub)';
$labels['showimages'] = 'Näita pilte';
$labels['allow'] = 'Luba';
$labels['alwaysshow'] = 'Näita alati $sender saadetud pilte';
$labels['alwaysallow'] = 'Alati luba $sender';
$labels['isdraft'] = 'See on mustand.';
$labels['andnmore'] = '$nr veel…';
$labels['details'] = 'Detailid';
$labels['summary'] = 'Kokkuvõte';
$labels['headers'] = 'Päised';
$labels['allheaders'] = 'Kõik päised...';
$labels['togglemoreheaders'] = 'Näita rohkem kirja päiseid';
$labels['togglefullheaders'] = 'Näita/peida algseid päiseid';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Lihttekst';
$labels['savesentmessagein'] = 'Salvesta saadetud kirjad kausta';
$labels['dontsave'] = 'ära salvesta';
$labels['maxuploadsize'] = 'Faili maksimaalne lubatud suurus on $size';
$labels['addcc'] = 'Lisa koopia';
$labels['addbcc'] = 'Lisa pimekoopia';
$labels['addreplyto'] = 'Lisa vastus aadressile';
$labels['addfollowupto'] = 'Lisa Followup-To';
$labels['sendreceipt'] = 'Kas saata lugemise kinnitus?';
$labels['mdnrequest'] = 'Selle kirja saatja soovib saada kinnitust kirja lugemise kohta. Kas soovid kinnituse saata?';
$labels['receiptread'] = 'Kättesaamiskinnitus (loetud)';
$labels['yourmessage'] = 'See on sinu saadetud kirja kättesaamiskinnitus';
$labels['receiptnote'] = 'Märkus: Kättesaamiskinnituse saamine tähendab ainult seda, et saaja on kirja avanud. Pole mingit garantiid, et ta kirja tegelikult luges ja selle sisust aru sai.';
$labels['sendalwaysto'] = 'Saada alati e-postile $email';
$labels['zoomin'] = 'Suurenda';
$labels['zoomout'] = 'Vähenda';
$labels['rotate'] = 'Keera';
$labels['increaseimage'] = 'Suurenda pildi suurust';
$labels['decreaseimage'] = 'Vähenda pildi suurust';
$labels['rotateimage'] = 'Keera pilti';
$labels['showtools'] = 'Kuva pildi tööriistad';
$labels['hidetools'] = 'Peida pildi tööriistad';
$labels['name'] = 'Näidatav nimi';
$labels['firstname'] = 'Eesnimi';
$labels['surname'] = 'Perekonnanimi';
$labels['middlename'] = 'Keskmine nimi';
$labels['nameprefix'] = 'Eesliide';
$labels['namesuffix'] = 'Järelliide';
$labels['nickname'] = 'Hüüdnimi';
$labels['jobtitle'] = 'Töökoht';
$labels['department'] = 'Osakond';
$labels['gender'] = 'Sugu';
$labels['maidenname'] = 'Neiupõlve nimi';
$labels['email'] = 'E-post';
$labels['phone'] = 'Telefon';
$labels['address'] = 'Aadress';
$labels['street'] = 'Tänav';
$labels['locality'] = 'Linn';
$labels['zipcode'] = 'Postiindeks';
$labels['region'] = 'Piirkond';
$labels['country'] = 'Riik';
$labels['birthday'] = 'Sünnipäev';
$labels['anniversary'] = 'Tähtpäev';
$labels['website'] = 'Veebileht';
$labels['instantmessenger'] = 'Kiirsuhtlus';
$labels['notes'] = 'Märkused';
$labels['male'] = 'mees';
$labels['female'] = 'naine';
$labels['manager'] = 'Juht';
$labels['assistant'] = 'Assistent';
$labels['spouse'] = 'Abikaasa';
$labels['allfields'] = 'Kõik väljad';
$labels['search'] = 'Otsi';
$labels['searchresult'] = 'Otsingutulemused';
$labels['advsearch'] = 'Täpsem otsing';
$labels['advanced'] = 'Edasijõudnutele';
$labels['other'] = 'Muu';
$labels['printcontact'] = 'Prindi kontakt';
$labels['qrcode'] = 'QR kood';
$labels['typehome'] = 'Kodu';
$labels['typework'] = 'Töö';
$labels['typeother'] = 'Muu';
$labels['typemobile'] = 'Mobiil';
$labels['typemain'] = 'Peamine';
$labels['typehomefax'] = 'Kodune fax';
$labels['typeworkfax'] = 'Töö fax';
$labels['typecar'] = 'Auto';
$labels['typepager'] = 'Piipar';
$labels['typevideo'] = 'Video';
$labels['typeassistant'] = 'Assistent';
$labels['typehomepage'] = 'Veebileht';
$labels['typeblog'] = 'Ajaveeb';
$labels['typeprofile'] = 'Profiil';
$labels['addfield'] = 'Lisa väli...';
$labels['addcontact'] = 'Lisa kontakt';
$labels['editcontact'] = 'Muuda kontakti';
$labels['contacts'] = 'Kontaktid';
$labels['contactproperties'] = 'Kontakti omadused';
$labels['contactnameandorg'] = 'Nimi ja Organisatsioon';
$labels['personalinfo'] = 'Isiklik info';
$labels['personal'] = 'Isiklik';
$labels['contactphoto'] = 'Kontakti pilt';
$labels['edit'] = 'Muuda';
$labels['cancel'] = 'Katkesta';
$labels['save'] = 'Salvesta';
$labels['delete'] = 'Kustuta';
$labels['discard'] = 'Loobu';
$labels['continue'] = 'Jätka';
$labels['ok'] = 'OK';
$labels['rename'] = 'Nimeta ümber';
$labels['addphoto'] = 'Lisa';
$labels['replacephoto'] = 'Asenda';
$labels['uploadphoto'] = 'Lisa foto';
$labels['choosefile'] = 'Vali fail...';
$labels['choosefiles'] = 'Vali failid...';
$labels['browse'] = 'Sirvi';
$labels['newcontact'] = 'Loo uus kontakt';
$labels['deletecontact'] = 'Kustuta märgistatud kontaktid';
$labels['composeto'] = 'Kirjuta kiri';
$labels['contactsfromto'] = 'Kirjed $from kuni $to, kokku $count';
$labels['print'] = 'Trüki';
$labels['export'] = 'Ekspordi';
$labels['exportall'] = 'Ekspordi kõik';
$labels['exportsel'] = 'Ekspordi valitud';
$labels['exportvcards'] = 'Ekspordi kontaktid vCardi formaadis';
$labels['newgroup'] = 'Loo uus grupp';
$labels['addgroup'] = 'Lisa grupp';
$labels['grouprename'] = 'Nimeta grupp ümber';
$labels['groupdelete'] = 'Kustuta grupp';
$labels['groupassign'] = 'Lisa gruppi';
$labels['groupremove'] = 'Eemalda grupist';
$labels['groupremoveselected'] = 'Eemalda valitud kontaktid grupist';
$labels['uponelevel'] = 'Üks tase kõrgemale';
$labels['previouspage'] = 'Näita eelmist lehte';
$labels['firstpage'] = 'Näita esimest komplekti';
$labels['nextpage'] = 'Näita järgmist lehte';
$labels['lastpage'] = 'Näita viimast komplekti';
$labels['group'] = 'Grupp';
$labels['groups'] = 'Grupid';
$labels['listgroup'] = 'Näita grupi liikmeid';
$labels['personaladrbook'] = 'Isiklikud aadressid';
$labels['searchsave'] = 'Salvesta otsing';
$labels['searchdelete'] = 'Kustuta otsing';
$labels['import'] = 'Impordi';
$labels['importcontacts'] = 'Impordi kontakte';
$labels['importfromfile'] = 'Impordi failist';
$labels['importtarget'] = 'Lisa kontaktid ';
$labels['importreplace'] = 'Asenda kogu aadressiraamat';
$labels['importgroups'] = 'Impordi grupi ülessanded';
$labels['importgroupsall'] = 'Kõik (loo vajadusel grupid)';
$labels['importgroupsexisting'] = 'Ainult olemasolevatele gruppidele';
$labels['importdesc'] = 'Saate ülesse laadida kontakte olemasolevast aadressi raamatust. <br/>Hetkel on toetatud aadresside importimine <a href="https://en.wikipedia.org/wiki/VCard">vCard</a>või CSV(komaga eraldatud) andmete formaadis. ';
$labels['fieldnotmapped'] = 'Väli pole seotud (ära impordi)';
$labels['skipheader'] = 'Ära impordi esimest rida (päis)';
$labels['done'] = 'Valmis';
$labels['settingsfor'] = 'Kasutajaeelistused kontole';
$labels['about'] = 'Programmist lähemalt';
$labels['preferences'] = 'Eelistused';
$labels['userpreferences'] = 'Kasutaja eelistused';
$labels['editpreferences'] = 'Muuda kasutaja eelistusi';
$labels['identities'] = 'Identiteedid';
$labels['manageidentities'] = 'Halda identiteete';
$labels['newidentity'] = 'Loo uus identiteet';
$labels['addidentity'] = 'Lisa identiteet';
$labels['editidentity'] = 'Muuda identiteeti';
$labels['identityencryption'] = 'Krüpteerimine';
$labels['preferhtml'] = 'Eelista HTMLi';
$labels['defaultcharset'] = 'Vaikimisi märgistik';
$labels['htmlmessage'] = 'HTML kirjad';
$labels['messagepart'] = 'Osa';
$labels['digitalsig'] = 'Digitaalne allkiri';
$labels['dateformat'] = 'Kuupäeva vorming';
$labels['timeformat'] = 'Aja vorming';
$labels['prettydate'] = 'Kenad kuupäevad';
$labels['setdefault'] = 'Muuda vaikeseadeks';
$labels['autodetect'] = 'Automaatne';
$labels['language'] = 'Keel';
$labels['timezone'] = 'Ajavöönd';
$labels['pagesize'] = 'Ridu lehe kohta';
$labels['signature'] = 'Allkiri';
$labels['dstactive'] = 'Suveaeg';
$labels['showinextwin'] = 'Ava kiri uues aknas';
$labels['composeextwin'] = 'Koosta uues aknas';
$labels['htmleditor'] = 'Kasuta HTML redaktorit';
$labels['htmlonreply'] = 'vaid HTML-vormingus kirjale vastamisel';
$labels['htmlonreplyandforward'] = 'edastamisel või HTML kirjale vastates';
$labels['htmlsignature'] = 'HTML allkiri';
$labels['showemail'] = 'Näita nime juures e-posti aadressi';
$labels['previewpane'] = 'Näita eelvaate akent';
$labels['skin'] = 'Kliendi välimus';
$labels['logoutclear'] = 'Tühjenda väljumisel prügikast';
$labels['logoutcompact'] = 'Tihenda väljumisel sissetulevate kaust';
$labels['uisettings'] = 'Kasutajaliides';
$labels['serversettings'] = 'Serveri seaded';
$labels['mailboxview'] = 'Postkasti vaade';
$labels['mdnrequests'] = 'Kättesaamiskinnitus';
$labels['askuser'] = 'küsi kasutajalt';
$labels['autosend'] = 'saada automaatselt';
$labels['autosendknown'] = 'saada automaatselt minu kontaktidele, teised küsi üle';
$labels['autosendknownignore'] = 'saada automaatselt minu kontaktidele, teisi ignoreeri';
$labels['ignorerequest'] = 'eira palvet';
$labels['readwhendeleted'] = 'Märgi kiri kustutamisel loetuks';
$labels['flagfordeletion'] = 'Kustutamise asemel märgi kiri kustutatavaks';
$labels['skipdeleted'] = 'Ära näita kustutatud kirju';
$labels['deletealways'] = 'Kui kirjade prügikasti liigutamine nurjub, siis kustuta need';
$labels['deletejunk'] = 'Kustuta Rämps kaustas olevad kirjad kohe';
$labels['showremoteimages'] = 'Näita kirjas kaugelt kaasatud pilte';
$labels['fromknownsenders'] = 'tuntud saatjatelt';
$labels['fromtrustedsenders'] = 'usaldusväärsetelt saatjatelt';
$labels['frommycontacts'] = 'minu kontaktidelt';
$labels['always'] = 'alati';
$labels['alwaysbutplain'] = 'alati, välja arvatud lihttekstile vastates';
$labels['showinlineimages'] = 'Näita manustatud pilte kirja all';
$labels['autosavedraft'] = 'Salvesta mustandid automaatselt';
$labels['everynminutes'] = 'iga $n minuti tagant';
$labels['refreshinterval'] = 'Värskenda (kontrolli uusi kirju, jne.)';
$labels['never'] = 'mitte kunagi';
$labels['immediately'] = 'otsekohe';
$labels['messagesdisplaying'] = 'Kirjade näitamine';
$labels['messagescomposition'] = 'Kirja koostamine';
$labels['mimeparamfolding'] = 'Manuste nimed';
$labels['2231folding'] = 'Täielik RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Täielik RFC 2047 (muu)';
$labels['force7bit'] = '8-bitiste märkide puhul kasuta MIME kodeerimist';
$labels['savelocalstorage'] = "Salvesta veebilehitseja kohalikku hoidlasse (ajutiselt)";
$labels['advancedoptions'] = 'Lisaseadistused';
$labels['toggleadvancedoptions'] = 'Näita lisaseadistusi';
$labels['focusonnewmessage'] = 'Fookusta brauseri aken uue kirja korral';
$labels['checkallfolders'] = 'Kontrolli uusi kirju kõigist kaustadest';
$labels['displaynext'] = 'Näita pärast kustutamist või liigutamist järgmist sissekannet nimekirjas';
$labels['defaultfont'] = 'HTML kirjade vaikefont';
$labels['mainoptions'] = 'Peamised valikud';
$labels['browseroptions'] = 'Sirvimis valikud';
$labels['section'] = 'Osa';
$labels['maintenance'] = 'Hooldus';
$labels['newmessage'] = 'Uus kiri';
$labels['signatureoptions'] = 'Allkirja valikud';
$labels['whenreplying'] = 'Vastates';
$labels['replyempty'] = 'ära tsiteeri esialgset kirja';
$labels['replytopposting'] = 'alusta uue kirjaga esialgse kohal';
$labels['replybottomposting'] = 'alusta uue kirjaga esialgse all';
$labels['replyremovesignature'] = 'Vastates eemalda kirjast esialgne allkiri';
$labels['autoaddsignature'] = 'Lisa allkiri automaatselt';
$labels['newmessageonly'] = 'ainult uutele';
$labels['replyandforwardonly'] = 'ainult vastates ja edastades';
$labels['insertsignature'] = 'Sisesta allkiri';
$labels['sigbelow'] = 'Pane allkiri tsiteeritud kirja alla';
$labels['automarkread'] = 'Märgi sõnum loetuks';
$labels['afternseconds'] = '$n sekundi pärast';
$labels['reqmdn'] = 'Nõua alati kättesaamiskinnitust';
$labels['reqdsn'] = 'Nõua alati kohalejõudmisteavitust';
$labels['replysamefolder'] = 'Paiguta vastused samasse kausta, millele vastatakse';
$labels['defaultabook'] = 'Vaikimisi aadressiraamat';
$labels['autocompletesingle'] = 'Automaatlõpetuses jäta alternatiivne e-posti aadress vahele';
$labels['listnamedisplay'] = 'Näita kontakte kui';
$labels['contactformmode'] = 'Konktaktivormi režiim';
$labels['privatemode'] = 'Privaatne (kodu)';
$labels['businessmode'] = 'Töö (Kontor)';
$labels['collectedaddresses'] = 'Kogutud aadressid';
$labels['collectedrecipients'] = 'Kogutud saajad';
$labels['collectedrecipientsopt'] = 'Salvesta väljuvad kontaktid:';
$labels['collectedsendersopt'] = 'Salvesta usaldusväärsed saatjad:';
$labels['trustedsenders'] = 'Usaldusväärsed saatjad';
$labels['spellcheckbeforesend'] = 'Kontrolli õigekirja enne saatmist';
$labels['spellcheckoptions'] = 'Õigekirjakontrolli valikud';
$labels['spellcheckignoresyms'] = 'Ignoreeri sõnu, milles on sümbolid';
$labels['spellcheckignorenums'] = 'Ignoreeri sõnu, milles on numbreid';
$labels['spellcheckignorecaps'] = 'Ignoreeri suurte tähtedega kirjutatud sõnu';
$labels['addtodict'] = 'Lisa sõnastikku';
$labels['mailtoprotohandler'] = 'Kasuta mailto: linkide avamisel';
$labels['standardwindows'] = 'Käsitle hüpikaknaid tavaliste akendena';
$labels['forwardmode'] = 'Kirja edastamine';
$labels['inline'] = 'kirja sees';
$labels['asattachment'] = 'manusena';
$labels['replyallmode'] = 'Vaike käitumine [Vasta kõigile] nupul';
$labels['replyalldefault'] = 'Vasta kõigile';
$labels['replyalllist'] = 'vasta ainult postiloendile (juhul kui leitud)';
$labels['allmessages'] = 'kõik kirjad';
$labels['folder'] = 'Kaust';
$labels['folders'] = 'Kaustad';
$labels['foldername'] = 'Kausta nimi';
$labels['subscribed'] = 'Näitan';
$labels['messagecount'] = 'Kirju';
$labels['create'] = 'Loo';
$labels['createfolder'] = 'Uue kausta loomine';
$labels['managefolders'] = 'Halda kaustu';
$labels['specialfolders'] = 'Erilised kaustad';
$labels['properties'] = 'Omadused';
$labels['folderproperties'] = 'Kausta omadused';
$labels['parentfolder'] = 'Ülemine kaust';
$labels['location'] = 'Asukoht';
$labels['info'] = 'Teave';
$labels['getfoldersize'] = 'Kliki kausta suuruse teadasaamiseks';
$labels['changesubscription'] = 'Kliki kausta tellimuste muutmiseks';
$labels['foldertype'] = 'Kausta tüüp';
$labels['personalfolder'] = 'Isiklik kaust';
$labels['otherfolder'] = 'Teiste kasutajate kaust';
$labels['sharedfolder'] = 'Avalik kaust';
$labels['findfolders'] = 'Otsi kaustasi';
$labels['findcontacts'] = 'Otsi kontakte';
$labels['findmail'] = 'Otsi maile';
$labels['namespace.personal'] = 'Isiklik';
$labels['namespace.other'] = 'Teised kasutajad';
$labels['namespace.shared'] = 'Jagatud';
$labels['dualuselabel'] = 'Võib sisaldada ainult';
$labels['dualusemail'] = 'sõnumid';
$labels['dualusefolder'] = 'Kataloogid';
$labels['generate'] = 'Genereeri';
$labels['encryptioncreatekey'] = 'Loo uus võtme paar';
$labels['openmailvelopesettings'] = 'Ava Mailvelope seaded';
$labels['encryption'] = 'Krüpteerimine';
$labels['mailvelopeoptions'] = 'Mailvelope valikud';
$labels['mailvelopemainkeyring'] = 'Kasuta Mailvelope peamist võtmerõngast';
$labels['sortby'] = 'Järjesta';
$labels['sortasc'] = 'Järjesta kasvavalt';
$labels['sortdesc'] = 'Järjesta kahanevalt';
$labels['undo'] = 'Võta tagasi';
$labels['installedplugins'] = 'Paigaldatud pluginad';
$labels['plugin'] = 'Plugin';
$labels['version'] = 'Versioon';
$labels['source'] = 'Allikas';
$labels['destination'] = 'Sihtkoht';
$labels['license'] = 'Litsents';
$labels['support'] = 'Küsi abi';
$labels['savedsearches'] = 'Salvestatud otsingud';
$labels['dateformatY'] = 'YYYY';
$labels['dateformaty'] = 'YY';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KiB';
$labels['MB'] = 'MiB';
$labels['GB'] = 'GiB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'inglise';
$labels['westerneuropean'] = 'Lääne-Euroopa';
$labels['easterneuropean'] = 'Ida-Euroopa';
$labels['southeasterneuropean'] = 'Kagu-Euroopa';
$labels['baltic'] = 'balti';
$labels['cyrillic'] = 'kirillitsa';
$labels['arabic'] = 'araabia';
$labels['greek'] = 'kreeka';
$labels['hebrew'] = 'heebrea';
$labels['turkish'] = 'türgi';
$labels['nordic'] = 'põhjamaa';
$labels['thai'] = 'tai';
$labels['celtic'] = 'keldi';
$labels['vietnamese'] = 'vietnami';
$labels['japanese'] = 'jaapani';
$labels['korean'] = 'korea';
$labels['chinese'] = 'hiina';
$labels['arialabeltopnav'] = 'Akna kontroll';
$labels['arialabeltasknav'] = 'Rakenduse ülesanded';
$labels['arialabeltoolbar'] = 'Rakenduse tööriba';
$labels['arialabelactivetask'] = 'Aktiivne ülesanne';
$labels['arialabelmessagessearchfilter'] = 'E-kirja näitamise filter';
$labels['arialabelmailsearchform'] = 'E-kirja otsimise vorm';
$labels['arialabelcontactsearchform'] = 'Kontakti otsimise vorm';
$labels['arialabelmailquicksearchbox'] = 'E-kirja otsingu sisend';
$labels['arialabelquicksearchbox'] = 'Otsingu sisend';
$labels['arialabelfoldersearchfilter'] = 'Kausta näitamise filter';
$labels['arialabelfoldersearchform'] = 'Kausta otsimise vorm';
$labels['arialabelfolderlist'] = 'E-kirja kausta valik';
$labels['arialabelmessagelist'] = 'E-kirjade näitamine';
$labels['arialabelmailpreviewframe'] = 'Kirja eelvaade';
$labels['arialabelmailboxmenu'] = 'Kausta tegevuste menüü';
$labels['arialabellistselectmenu'] = 'Nimekirja valiku menüü';
$labels['arialabelthreadselectmenu'] = 'Lõimede näitamise menüü';
$labels['arialabelmessagelistoptions'] = 'Kirjade näitamise ja sorteerimise võimalused';
$labels['arialabelmailimportdialog'] = 'Kirja importi dialoog';
$labels['arialabelmessagenav'] = 'Kirja navigatsioon';
$labels['arialabelmessagebody'] = 'Kirja sisu';
$labels['arialabelmessageactions'] = 'Kirja tegevus';
$labels['arialabelcontactquicksearch'] = 'Kontakti otsingu vorm';
$labels['arialabelcontactsearchbox'] = 'Kontakti otsingu sisend';
$labels['arialabelmessageheaders'] = 'Kirja päis';
$labels['arialabelforwardingoptions'] = 'Edasisuunamise valikud';
$labels['arialabelreplyalloptions'] = 'Vasta kõigile valikud';
$labels['arialabelmoremessageactions'] = 'Rohkem kirja tegevusi';
$labels['arialabelmorecontactactions'] = 'Veel kontakti tegevusi';
$labels['arialabelmarkmessagesas'] = 'Märgi valitud kirjad';
$labels['arialabelcomposeoptions'] = 'Koostamise valikud';
$labels['arialabelresponsesmenu'] = 'Vastuse mallide menüü';
$labels['arialabelattachmentuploadform'] = 'Manuse ülesselaadimise vorm';
$labels['arialabelattachmentmenu'] = 'Manuse valikud';
$labels['arialabelmailtomenu'] = 'Meiliaadressi valikud';
$labels['arialabelattachmentpreview'] = 'Manuse eelvaade';
$labels['ariasummarycomposecontacts'] = 'Nimekiri kontaktidest ja gruppidest keda valida vastuvõtjateks';
$labels['arialabelcontactexportoptions'] = 'Kontakti ekspordi võimalused';
$labels['arialabelabookgroupoptions'] = 'Telefoniraamatu/grupi võimalused';
$labels['arialabelpreferencesform'] = 'Eelistuste vorm';
$labels['arialabelidentityeditfrom'] = 'Identiteedi muutmis vorm';
$labels['arialabelresponseeditfrom'] = 'Vastuse muutmis vorm';
$labels['arialabelsearchterms'] = 'Otsingusõnad';
$labels['arialabelimagetools'] = 'Pildi tööriistad';
$labels['helplistnavigation'] = 'Näita klaviatuuri navigatsiooni';
$labels['helplistkeyboardnavigation'] = "Nooled üles/alla: Muuda rida fokuseeri/vali
Tühik: Vali fokuseeritud rida
Shift + üles/alla: Vali lisaks rida alt/ülevalt
Ctrl + Space: Lisa fokuseeritud rida valikusse/eemalda valikust";
$labels['helplistkeyboardnavmessages'] = "Nooled paremale/vasakule: laienda/peida kirjade lõimed
Enter: Ava valitud/fokuseeritud kiri
Delete: Liigutda valitud kiri prügikasti.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Ava valitud/fokuseeritud kontakt";
