<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Filtre';
$labels['managefilters'] = 'Správa filtrov prichádzajúcej pošty';
$labels['filtername'] = 'Názov filtra';
$labels['newfilter'] = 'Nový filter';
$labels['filteradd'] = 'Pridať filter';
$labels['filterdel'] = 'Vymazať filter';
$labels['rules'] = 'Pravidlá';
$labels['actions'] = 'Akcie';
$labels['scope'] = 'Rozsah';
$labels['moveup'] = 'Presunúť nahor';
$labels['movedown'] = 'Presunúť nadol';
$labels['filterallof'] = 'vyhovujúca všetkým z nasledujúcich pravidiel';
$labels['filteranyof'] = 'vyhovujúca ľubovoľnému z nasledujúcich pravidiel';
$labels['filterany'] = 'všetky správy';
$labels['filtercontains'] = 'obsahuje';
$labels['filternotcontains'] = 'neobsahuje';
$labels['filteris'] = 'sa rovná';
$labels['filterisnot'] = 'sa nerovná';
$labels['filterexists'] = 'existuje';
$labels['filternotexists'] = 'neexistuje';
$labels['filtermatches'] = 'vyhovuje výrazu';
$labels['filternotmatches'] = 'nevyhovuje výrazu';
$labels['filterregex'] = 'vyhovuje regulárnemu výrazu';
$labels['filternotregex'] = 'nevyhovuje regulárnemu výrazu';
$labels['filterunder'] = 'pod';
$labels['filterover'] = 'nad';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'Časť MIME:';
$labels['mime-message'] = 'správa';
$labels['mime-anychild'] = 'akékoľvek';
$labels['mime-type'] = 'typ';
$labels['mime-subtype'] = 'pod-typ';
$labels['mime-contenttype'] = 'typ obsahu';
$labels['mime-param'] = 'parameter';
$labels['addrule'] = 'Pridať pravidlo';
$labels['delrule'] = 'Vymazať pravidlo';
$labels['messagemoveto'] = 'Presunúť správu do';
$labels['messageredirect'] = 'Presmerovať správu na';
$labels['messagecopyto'] = 'Kopírovať správu do';
$labels['messagesendcopy'] = 'Poslať kópiu správy na adresu';
$labels['messagereply'] = 'Odpovedať správou';
$labels['messagedelete'] = 'Vymazať správu';
$labels['messagediscard'] = 'Vymazať a poslať správu na';
$labels['messagekeep'] = 'Ponechať správu v Doručenej pošte';
$labels['messagesrules'] = 'Pre prichádzajúcu poštu:';
$labels['messagesactions'] = '...vykonať tieto akcie:';
$labels['add'] = 'Pridať';
$labels['del'] = 'Vymazať';
$labels['sender'] = 'Odosielateľ';
$labels['recipient'] = 'Príjemca';
$labels['vacationaddr'] = 'Moje e-mailové adresy:';
$labels['vacationdays'] = 'Ako často odosielať správy (v dňoch):';
$labels['vacationinterval'] = 'Ako často odosielať správy:';
$labels['vacationreason'] = 'Telo správy (dôvod neprítomnosti):';
$labels['vacationfrom'] = 'Adresa odosielateľa pre odpoveď:';
$labels['vacationsubject'] = 'Predmet správy:';
$labels['days'] = 'dní';
$labels['seconds'] = 'sekúnd';
$labels['rulestop'] = 'Koniec pravidiel';
$labels['enable'] = 'Zapnúť/vypnúť';
$labels['filterset'] = 'Súprava filtrov';
$labels['filtersets'] = 'Súpravy filtrov';
$labels['filtersetadd'] = 'Pridať súpravu filtrov';
$labels['filtersetdel'] = 'Vymazať súpravu filtrov';
$labels['filtersetact'] = 'Aktivovať aktuálnu súpravu filtrov';
$labels['filtersetdeact'] = 'Deaktivovať aktuálnu súpravu filtrov';
$labels['filterseteditraw'] = 'Upraviť súpravu filtrov';
$labels['filtersetswitch'] = 'Zapnúť/vypnúť súpravu filtrov';
$labels['filterdef'] = 'Definícia filtra';
$labels['filtersetname'] = 'Názov súpravy filtrov';
$labels['newfilterset'] = 'Nová súprava filtrov';
$labels['active'] = 'aktívna';
$labels['none'] = 'žiadne';
$labels['fromset'] = 'zo súpravy';
$labels['fromfile'] = 'zo súboru';
$labels['filterdisabled'] = 'Filter vypnutý';
$labels['filterenabled'] = 'Filter zapnutý';
$labels['countisgreaterthan'] = 'počet je väčší ako';
$labels['countisgreaterthanequal'] = 'počet je väčší alebo rovný ako';
$labels['countislessthan'] = 'počet je menší ako';
$labels['countislessthanequal'] = 'počet je menší alebo rovný ako';
$labels['countequals'] = 'počet je rovný';
$labels['countnotequals'] = 'počet sa nerovná';
$labels['valueisgreaterthan'] = 'hodnota je väčšia ako';
$labels['valueisgreaterthanequal'] = 'hodnota je väčšia alebo rovná ako';
$labels['valueislessthan'] = 'hodnota je menšia ako';
$labels['valueislessthanequal'] = 'hodnota je menšia alebo rovná ako';
$labels['valueequals'] = 'hodnota je rovná ako';
$labels['valuenotequals'] = 'hodnota sa nerovná';
$labels['setflags'] = 'Nastaviť príznaky správy';
$labels['addflags'] = 'Pridať príznaky správy';
$labels['removeflags'] = 'Odstrániť príznaky zo správy';
$labels['flagread'] = 'Prečítané';
$labels['flagdeleted'] = 'Vymazané';
$labels['flaganswered'] = 'Odpovedané';
$labels['flagflagged'] = 'Označené príznakom';
$labels['flagdraft'] = 'Koncept';
$labels['addheader'] = 'Pridať hlavičku do správy';
$labels['deleteheader'] = 'Odstrániť hlavičku zo správy';
$labels['headername'] = 'Názov hlavičky';
$labels['headervalue'] = 'Hodnota hlavičky';
$labels['headerpos'] = 'Pozícia hlavičky';
$labels['headeratstart'] = 'na začiatku';
$labels['headeratend'] = 'na konci';
$labels['headeroccurrence'] = 'Výskyt/pozícia hlavičky';
$labels['headerfromstart'] = 'od začiatku';
$labels['headerfromend'] = 'od konca';
$labels['headerpatterns'] = 'Vzory pre hodnotu hlavičky';
$labels['headermatchtype'] = 'typ zhody:';
$labels['setvariable'] = 'Nastaviť premennú';
$labels['setvarname'] = 'Názov premennej:';
$labels['setvarvalue'] = 'Hodnota premennej:';
$labels['setvarmodifiers'] = 'Modifikátory:';
$labels['varlower'] = 'malé písmená';
$labels['varupper'] = 'VEĽKÉ PÍSMENÁ';
$labels['varlowerfirst'] = 'prvé písmeno malé';
$labels['varupperfirst'] = 'prvé písmeno veľké';
$labels['varquotewildcard'] = 'k špeciálnym znakom pridať úvodzovky';
$labels['varlength'] = 'dĺžka';
$labels['notify'] = 'Odoslať oznámenie';
$labels['notifytarget'] = 'Cieľ notifikácie:';
$labels['notifymessage'] = 'Notifikačná správa (voliteľne):';
$labels['notifyoptions'] = 'Nastavenia notifikácie (voliteľné):';
$labels['notifyfrom'] = 'Odosielateľ notifikácie (voliteľne):';
$labels['notifyimportance'] = 'Priorita:';
$labels['notifyimportancelow'] = 'nízka';
$labels['notifyimportancenormal'] = 'normálna';
$labels['notifyimportancehigh'] = 'vysoká';
$labels['notifymethodmailto'] = 'E-mail';
$labels['notifymethodtel'] = 'Telefón';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Vytvoriť filter';
$labels['usedata'] = 'Použiť tieto údaje vo filtri:';
$labels['nextstep'] = 'Ďalší krok';
$labels['...'] = '...';
$labels['string'] = 'Reťazec';
$labels['currdate'] = 'Aktuálny dátum';
$labels['datetest'] = 'Dátum';
$labels['dateheader'] = 'záhlavie:';
$labels['year'] = 'rok';
$labels['month'] = 'mesiac';
$labels['day'] = 'deň';
$labels['date'] = 'dátum (rrrr-mm-dd)';
$labels['julian'] = 'dátum (podľa Juliánskeho kalendára)';
$labels['hour'] = 'hod.';
$labels['minute'] = 'min.';
$labels['second'] = 'sek.';
$labels['time'] = 'čas (hh:mm:ss)';
$labels['iso8601'] = 'dátum (ISO8601)';
$labels['std11'] = 'dátum (RFC2822)';
$labels['zone'] = 'časové pásmo';
$labels['weekday'] = 'deň v týždni (0-6)';
$labels['advancedopts'] = 'Rozšírené nastavenia';
$labels['body'] = 'Telo';
$labels['address'] = 'adresa';
$labels['envelope'] = 'obálka';
$labels['modifier'] = 'modifikátor:';
$labels['text'] = 'text';
$labels['undecoded'] = 'nedekódované (raw)';
$labels['contenttype'] = 'typ obsahu';
$labels['modtype'] = 'typ:';
$labels['allparts'] = 'všetko';
$labels['domain'] = 'doména';
$labels['localpart'] = 'lokálna časť';
$labels['user'] = 'používateľ';
$labels['detail'] = 'detail';
$labels['comparator'] = 'porovnávač:';
$labels['default'] = 'predvolené';
$labels['octet'] = 'striktný (osmičkový)';
$labels['asciicasemap'] = 'nerozlišuje veľké a malé písmená (ascii tabuľka znakov)';
$labels['asciinumeric'] = 'numerické (ascii čísla)';
$labels['index'] = 'index:';
$labels['indexlast'] = 'dozadu';
$labels['spamtest'] = 'Úroveň pre nevyžiadanú poštu';
$labels['spamtestisgreaterthan'] = 'je viac ako';
$labels['spamtestisgreaterthanequal'] = 'je viac alebo sa rovná ako';
$labels['spamtestislessthan'] = 'je menej ako';
$labels['spamtestislessthanequal'] = 'je menej alebo sa rovná ako';
$labels['spamtestequals'] = 'sa rovná';
$labels['spamtestnotequals'] = 'sa nerovná';
$labels['spamtestisunknown'] = 'nie je známa';
$labels['vacation'] = 'Mimo kancelárie';
$labels['vacation.reply'] = 'Odpoveď na správu';
$labels['vacation.advanced'] = 'Pokročilé nastavenia';
$labels['vacation.from'] = 'Adresa odosielateľa pre odpoveď';
$labels['vacation.subject'] = 'Predmet';
$labels['vacation.body'] = 'Telo';
$labels['vacation.start'] = 'Čas začiatku';
$labels['vacation.end'] = 'Čas ukončenia';
$labels['vacation.status'] = 'Stav';
$labels['vacation.on'] = 'Zap.';
$labels['vacation.off'] = 'Vyp.';
$labels['vacation.addresses'] = 'Moje e-mailové adresy';
$labels['vacation.interval'] = 'Interval odpovedania';
$labels['vacation.after'] = 'Aplikovať pravidlo "mimo kancelárie" po';
$labels['vacation.saving'] = 'Ukladanie údajov...';
$labels['vacation.action'] = 'Akcia pre prichádzajúcu správu';
$labels['vacation.keep'] = 'Zachovať';
$labels['vacation.discard'] = 'Vyhodiť do koša';
$labels['vacation.redirect'] = 'Presmerovať na';
$labels['vacation.copy'] = 'Poslať kópiu na';
$labels['forward'] = 'Preposlanie';
$labels['forward.redirect'] = 'Presmerovať na';
$labels['forward.copy'] = 'Poslať kópiu na';
$labels['forward.on'] = 'Zap.';
$labels['forward.off'] = 'Vyp.';
$labels['forward.status'] = 'Stav:';
$labels['forward.action'] = 'Pre prichádzajúce e-maily vykonať nasledujúcu akciu:';
$labels['forward.saving'] = 'Ukladanie údajov...';
$labels['filladdresses'] = 'Vyplniť všetko mojimi adresami';
$labels['arialabelfiltersetactions'] = 'Akcie zo súpravy filtrov';
$labels['arialabelfilteractions'] = 'Akcie filtra';
$labels['arialabelfilterform'] = 'Nastavenia filtra';
$labels['ariasummaryfilterslist'] = 'Zoznam filtrov';
$labels['ariasummaryfiltersetslist'] = 'Zoznam súprav s filtrami';
$labels['filterstitle'] = 'Upraviť filtre prichádzajúcich e-mailov';
$labels['vacationtitle'] = 'Upraviť pravidlo pre čas mimo kancelárie';
$labels['forwardtitle'] = 'Upraviť pravidlo preposielania správy';
$labels['message'] = 'Správa';
$labels['duplicate'] = 'je duplikátom';
$labels['notduplicate'] = 'nie je duplikátom';
$labels['duplicate.handle'] = 'postup:';
$labels['duplicate.header'] = 'záhlavie:';
$labels['duplicate.uniqueid'] = 'identifikátor:';
$labels['duplicate.seconds'] = 'časový limit (sek.):';
$labels['duplicate.last'] = 'relatívne voči poslednému spusteniu';
$messages['filterunknownerror'] = 'Neznáma chyba servera.';
$messages['filterconnerror'] = 'Nepodarilo sa pripojiť k serveru.';
$messages['filterdeleteerror'] = 'Nemožno vymazať filter. Nastala chyba servera.';
$messages['filterdeleted'] = 'Filter bol úspešne vymazaný.';
$messages['filtersaved'] = 'Filter bol úspešne uložený.';
$messages['filtersaveerror'] = 'Nemožno uložiť filter. Nastala chyba servera.';
$messages['filterformerror'] = 'Formulár pre filtrovanie obsahuje chyby.';
$messages['filterdeleteconfirm'] = 'Naozaj chcete vymazať vybraný filter?';
$messages['ruledeleteconfirm'] = 'Naozaj chcete vymazať vybrané pravidlo?';
$messages['actiondeleteconfirm'] = 'Naozaj chcete vymazať vybranú akciu?';
$messages['forbiddenchars'] = 'Pole obsahuje nepovolené znaky.';
$messages['cannotbeempty'] = 'Pole nemôže byť prázdne.';
$messages['ruleexist'] = 'Filter so zadaným názvom už existuje.';
$messages['setactivateerror'] = 'Nemožno aktivovať vybranú súpravu filtrov. Nastala chyba servera.';
$messages['setdeactivateerror'] = 'Nemožno deaktivovať vybranú súpravu filtrov. Nastala chyba servera.';
$messages['setdeleteerror'] = 'Nemožno vymazať vybranú súpravu filtrov. Nastala chyba servera.';
$messages['setactivated'] = 'Súprava filtrov bola úspešne aktivovaná.';
$messages['setdeactivated'] = 'Súprava filtrov bola úspešne deaktivovaná.';
$messages['setdeleted'] = 'Súprava filtrov bola úspešne vymazaná.';
$messages['setupdated'] = 'Súprava filtrov bola úspešne aktualizovaná.';
$messages['setdeleteconfirm'] = 'Naozaj chcete vymazať vybranú súpravu filtrov?';
$messages['setcreateerror'] = 'Nemožno vytvoriť súpravu filtrov. Nastala chyba servera.';
$messages['setcreated'] = 'Súprava filtrov bola úspešne vytvorená.';
$messages['activateerror'] = 'Nemožno aktivovať vybraný filter (vybrané filtre). Nastala chyba servera.';
$messages['deactivateerror'] = 'Nemožno vypnúť vybraný filter (vybrané filtre). Nastala chyba servera.';
$messages['deactivated'] = 'Filtre boli úspešne vypnuté.';
$messages['activated'] = 'Filtre boli úspešne zapnuté.';
$messages['moved'] = 'Filter bol úspešne presunutý.';
$messages['moveerror'] = 'Nemožno presunúť vybraný filter. Nastala chyba servera.';
$messages['nametoolong'] = 'Názov je príliš dlhý.';
$messages['namereserved'] = 'Rezervovaný názov.';
$messages['setexist'] = 'Súprava už existuje.';
$messages['nodata'] = 'Aspoň jedna pozícia musí byť zvolená!';
$messages['invaliddateformat'] = 'Neplatný formát dátumu alebo časti dátumu';
$messages['saveerror'] = 'Údaje nemožno uložiť. Nastala chyba servera.';
$messages['vacationsaved'] = 'Údaje pre čas mimo kancelárie boli úspešne uložené.';
$messages['forwardsaved'] = 'Údaje o preposlaní boli úspešne uložené.';
$messages['emptyvacationbody'] = 'Musíte zadať telo správy, zobrazovanej v čase neprítomnosti!';
$messages['duplicate.conflict.err'] = 'Hlavička a aj unikátny identifikátor nie sú povolené.';
$messages['disabledaction'] = 'Akcia nie je povolená.';
$messages['lastindexempty'] = 'Index sa vyžaduje pri počítaní od konca';
$messages['noflagset'] = 'Musí byť vybraný aspoň jeden príznak.';
