<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Filtra';
$labels['managefilters'] = 'Administroni filtra për postë ardhëse';
$labels['filtername'] = 'Emri i filtrit';
$labels['newfilter'] = 'Filtër i ri';
$labels['filteradd'] = 'Shtoni filtër';
$labels['filterdel'] = 'Fshije filtrin';
$labels['rules'] = 'Rregullat';
$labels['actions'] = 'Veprimet';
$labels['scope'] = 'Shtrirje';
$labels['moveup'] = 'Levize lart';
$labels['movedown'] = 'Levize poshtë';
$labels['filterallof'] = 'që ka përputhje me krejt rregullat vijues';
$labels['filteranyof'] = 'që ka përputhje me cilindo nga rregullat vijues';
$labels['filterany'] = 'krejt mesazhet';
$labels['filtercontains'] = 'përmban';
$labels['filternotcontains'] = 'nuk përmban';
$labels['filteris'] = 'është baras me';
$labels['filterisnot'] = 's’është baras me';
$labels['filterexists'] = 'ekziston';
$labels['filternotexists'] = 's’ekziston';
$labels['filtermatches'] = 'ka përputhje me shprehjen';
$labels['filternotmatches'] = 's’ka përputhje me shprehjen';
$labels['filterregex'] = 'ka përputhje me shprehjen rregullt';
$labels['filternotregex'] = 's’ka përputhje me shprehjen e rregullt';
$labels['filterunder'] = 'nën';
$labels['filterover'] = 'mbi';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'Pjesë MIME:';
$labels['mime-message'] = 'mesazh';
$labels['mime-anychild'] = 'çfarëdo';
$labels['mime-type'] = 'lloj';
$labels['mime-subtype'] = 'nënlloj';
$labels['mime-contenttype'] = 'lloji i përmbajtjes';
$labels['mime-param'] = 'parametër';
$labels['addrule'] = 'Shtoni rregull';
$labels['delrule'] = 'Fshije rregullin';
$labels['messagemoveto'] = 'Kaloje mesazhin te';
$labels['messageredirect'] = 'Ridrejtoje mesazhin te';
$labels['messagecopyto'] = 'Kopjoje mesazhin te';
$labels['messagesendcopy'] = 'Dërgo kopje mesazhi te';
$labels['messagereply'] = 'Përgjigju me mesazh';
$labels['messagedelete'] = 'Fshije mesazhin';
$labels['messagediscard'] = 'Hidhe tej mesazhin';
$labels['messagekeep'] = 'Mbaje mesazhin te Të marrët';
$labels['messagesrules'] = 'Për postë ardhëse:';
$labels['messagesactions'] = '…përmbush veprimet vijuese:';
$labels['add'] = 'Shtoje';
$labels['del'] = 'Fshije';
$labels['sender'] = 'Dërgues';
$labels['recipient'] = 'Marrës';
$labels['vacationaddr'] = 'Adresat e mia email:';
$labels['vacationdays'] = 'Sa shpesh dërgon mesazhe (në ditë):';
$labels['vacationinterval'] = 'Sa shpesh të dërgohen mesazhet:';
$labels['vacationreason'] = 'Lëndë mesazhi (arsye për pushime):';
$labels['vacationfrom'] = 'Adresë dërguesi për përgjigje:';
$labels['vacationsubject'] = 'Subjekt mesazhi:';
$labels['days'] = 'ditë';
$labels['seconds'] = 'sekonda';
$labels['rulestop'] = 'Ndale mbikëqyrjen e rregullave';
$labels['enable'] = 'Aktivizoje/Çaktivizoje';
$labels['filterset'] = 'Grup filtrash';
$labels['filtersets'] = 'Grupe filtrash';
$labels['filtersetadd'] = 'Shtoni grup filtrash';
$labels['filtersetdel'] = 'Fshije grupin e filtrave';
$labels['filtersetact'] = 'Aktivizo grupin e tanishëm të filtrave';
$labels['filtersetdeact'] = 'Çaktivizo grupin e tanishëm të filtrave';
$labels['filterseteditraw'] = 'Përpunoni grup filtrash';
$labels['filtersetswitch'] = 'Aktivizoni/çaktivizoni grup filtrash';
$labels['filterdef'] = 'Përkufizim filtri';
$labels['filtersetname'] = 'Emër grupi filtrash';
$labels['newfilterset'] = 'Grup i ri filtrash';
$labels['active'] = 'aktiv';
$labels['none'] = 'asnjë';
$labels['fromset'] = 'prej grupi';
$labels['fromfile'] = 'prej kartele';
$labels['filterdisabled'] = 'Filtër i çaktivizuar';
$labels['filterenabled'] = 'Filtri u aktivizua';
$labels['countisgreaterthan'] = 'numri është më i madh se';
$labels['countisgreaterthanequal'] = 'numri është më i madh ose baras me';
$labels['countislessthan'] = 'numri është më i vogël se';
$labels['countislessthanequal'] = 'numri është më i vogël ose baras me';
$labels['countequals'] = 'numri është baras me';
$labels['countnotequals'] = 'numri s’është baras me';
$labels['valueisgreaterthan'] = 'vlera është më e madhe se';
$labels['valueisgreaterthanequal'] = 'vlera është më e madh ose baras me';
$labels['valueislessthan'] = 'vlera është më e vogël se';
$labels['valueislessthanequal'] = 'vlera është më e vogël ose baras me';
$labels['valueequals'] = 'vlera është baras me';
$labels['valuenotequals'] = 'vlera s’është baras me';
$labels['setflags'] = 'Caktoni shenja për mesazhin';
$labels['addflags'] = 'Shtoni shenja te mesazhi';
$labels['removeflags'] = 'Hiqni shenja prej mesazhit';
$labels['flagread'] = 'I e lexuar';
$labels['flagdeleted'] = 'I fshirë';
$labels['flaganswered'] = 'Me përgjigje';
$labels['flagflagged'] = 'Me shenjë';
$labels['flagdraft'] = 'Skicë';
$labels['addheader'] = 'Shto krye te mesazhi';
$labels['deleteheader'] = 'Hiq kryet nga mesazhi';
$labels['headername'] = 'Emër kryesh';
$labels['headervalue'] = 'Vlerë kryesh';
$labels['headerpos'] = 'Pozicion kryesh';
$labels['headeratstart'] = 'në fillim';
$labels['headeratend'] = 'në fund';
$labels['headeroccurrence'] = 'Hasje/pozicion kryeje';
$labels['headerfromstart'] = 'nga fillimi';
$labels['headerfromend'] = 'nga fundi';
$labels['headerpatterns'] = 'Rregullsi vlere kryesh';
$labels['headermatchtype'] = 'lloj përputhjeje:';
$labels['setvariable'] = 'Caktoni ndryshore';
$labels['setvarname'] = 'Emër ndryshoreje:';
$labels['setvarvalue'] = 'Vlerë ndryshoreje:';
$labels['setvarmodifiers'] = 'Modifikues:';
$labels['varlower'] = 'me të vogla';
$labels['varupper'] = 'me të mëdha';
$labels['varlowerfirst'] = 'Shenja e parë me të vogla';
$labels['varupperfirst'] = 'shenja e parë me të mëdha';
$labels['varquotewildcard'] = 'shenja speciale citimi';
$labels['varlength'] = 'gjatësi';
$labels['notify'] = 'Dërgo njoftim';
$labels['notifytarget'] = 'Objektiv njoftimi:';
$labels['notifymessage'] = 'Mesazh njoftimi (opsionale):';
$labels['notifyoptions'] = 'Opsione njoftimi (opsionale):';
$labels['notifyfrom'] = 'Dërgues njoftimi (opsionale):';
$labels['notifyimportance'] = 'Rëndësi:';
$labels['notifyimportancelow'] = 'e ulët';
$labels['notifyimportancenormal'] = 'normale';
$labels['notifyimportancehigh'] = 'e lartë';
$labels['notifymethodmailto'] = 'Email';
$labels['notifymethodtel'] = 'Telefon';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Krijoje filtrin';
$labels['usedata'] = 'Përdor të dhënat vijuese te filtri:';
$labels['nextstep'] = 'Hapi Pasues';
$labels['...'] = '…';
$labels['string'] = 'Varg';
$labels['currdate'] = 'Datë e tanishme';
$labels['datetest'] = 'Datë';
$labels['dateheader'] = 'krye:';
$labels['year'] = 'vit';
$labels['month'] = 'muaj';
$labels['day'] = 'ditë';
$labels['date'] = 'datë (yyyy-mm-dd)';
$labels['julian'] = 'datë (sipas kalendarit julian)';
$labels['hour'] = 'orë';
$labels['minute'] = 'minutë';
$labels['second'] = 'sekondë';
$labels['time'] = 'kohë (hh:mm:ss)';
$labels['iso8601'] = 'datë (ISO8601)';
$labels['std11'] = 'datë (RFC2822)';
$labels['zone'] = 'brez orar';
$labels['weekday'] = 'ditë e javës (0-6)';
$labels['advancedopts'] = 'Mundësi të mëtejshme';
$labels['body'] = 'Lëndë';
$labels['address'] = 'adresë';
$labels['envelope'] = 'zarf';
$labels['modifier'] = 'modifikues:';
$labels['text'] = 'tekst';
$labels['undecoded'] = 'i pakoduar (i papërpunuar)';
$labels['contenttype'] = 'lloj lënde';
$labels['modtype'] = 'lloj:';
$labels['allparts'] = 'krejt';
$labels['domain'] = 'përkatësi';
$labels['localpart'] = 'pjesë lokale';
$labels['user'] = 'përdorues';
$labels['detail'] = 'hollësi';
$labels['comparator'] = 'krahasues:';
$labels['default'] = 'parazgjedhje';
$labels['octet'] = 'strikt (tetëshe)';
$labels['asciicasemap'] = 'i pavarur nga shkrimi me të mëdha apo të vogla (ascii-casemap)';
$labels['asciinumeric'] = 'numerike (ascii-numeric)';
$labels['index'] = 'tregues:';
$labels['indexlast'] = 'mbrapsht';
$labels['spamtest'] = 'Shkallë spam-i';
$labels['spamtestisgreaterthan'] = 'është më i madh se';
$labels['spamtestisgreaterthanequal'] = 'është më i madh ose baras me';
$labels['spamtestislessthan'] = 'është më i vogël';
$labels['spamtestislessthanequal'] = 'është më i vogël ose baras me';
$labels['spamtestequals'] = 'është baras me';
$labels['spamtestnotequals'] = 's’është baras me';
$labels['spamtestisunknown'] = 'është i panjohur';
$labels['vacation'] = 'Jashtë zyre';
$labels['vacation.reply'] = 'Mesazh përgjigjeje';
$labels['vacation.advanced'] = 'Rregullime të mëtejshme';
$labels['vacation.from'] = 'Përgjigju dërguesit';
$labels['vacation.subject'] = 'Subjekt';
$labels['vacation.body'] = 'Lëndë';
$labels['vacation.start'] = 'Kohë fillimi';
$labels['vacation.end'] = 'Kohë përfundimi';
$labels['vacation.status'] = 'Gjendje';
$labels['vacation.on'] = 'On';
$labels['vacation.off'] = 'Off';
$labels['vacation.addresses'] = 'Adresat e mia email';
$labels['vacation.interval'] = 'Interval përgjigjeje';
$labels['vacation.after'] = 'Vendose rregullin "jashtë zyre" pas';
$labels['vacation.saving'] = 'Po ruhen të dhënat…';
$labels['vacation.action'] = 'Veprim për mesazh ardhës';
$labels['vacation.keep'] = 'Mbaje';
$labels['vacation.discard'] = 'Hidhe tej';
$labels['vacation.redirect'] = 'Ridrejtoje te';
$labels['vacation.copy'] = 'Dërgo kopje te';
$labels['forward'] = 'Përcjellje';
$labels['forward.redirect'] = 'Ridrejtoje te';
$labels['forward.copy'] = 'Dërgo kopje te';
$labels['forward.on'] = 'On';
$labels['forward.off'] = 'Off';
$labels['forward.status'] = 'Gjendje:';
$labels['forward.action'] = 'Për postë mesazhe ardhës kryej veprimin vijues:';
$labels['forward.saving'] = 'Po ruhen të dhënat…';
$labels['filladdresses'] = 'Plotësoje me krejt adresat e mia';
$labels['arialabelfiltersetactions'] = 'Veprime grupi filtrash';
$labels['arialabelfilteractions'] = 'Veprime filtri';
$labels['arialabelfilterform'] = 'Veti filtri';
$labels['ariasummaryfilterslist'] = 'Listë filtrash';
$labels['ariasummaryfiltersetslist'] = 'Listë grupe filtrash';
$labels['filterstitle'] = 'Përpunoni filtra për postë ardhëse';
$labels['vacationtitle'] = 'Përpunoni rregullin jashtë-zyre';
$labels['forwardtitle'] = 'Përpunoni rregull përcjellje mesazhesh';
$labels['message'] = 'Mesazh';
$labels['duplicate'] = 'është përsëdytje';
$labels['notduplicate'] = 's’është përsëdytje';
$labels['duplicate.handle'] = 'trajtim:';
$labels['duplicate.header'] = 'krye:';
$labels['duplicate.uniqueid'] = 'identifikues:';
$labels['duplicate.seconds'] = 'mbarim kohe (sekonda):';
$labels['duplicate.last'] = 'relative ndaj përmbushjes së fundit';
$messages['filterunknownerror'] = 'Gabim i panjohur shërbyesi.';
$messages['filterconnerror'] = 'S’arrihet të lidhet me shërbyesin.';
$messages['filterdeleteerror'] = 'S’arrihet të fshihet filtri. Ndodhi gabim shërbyesi.';
$messages['filterdeleted'] = 'Grupi u fshi me sukses.';
$messages['filtersaved'] = 'Filtri u ruajt me sukses.';
$messages['filtersaveerror'] = 'S’arrihet të ruhet filtri. Ndodhi një gabim shërbyesi.';
$messages['filterformerror'] = 'Formulari i filtrit përmban gabime.';
$messages['filterdeleteconfirm'] = 'Doni vërtet të fshihet filtri i përzgjedhur?';
$messages['ruledeleteconfirm'] = 'Jeni i sigurt se doni të fshihet rregulli i përzgjedhur?';
$messages['actiondeleteconfirm'] = 'Jeni i sigurt se doni të fshihet veprimi i përzgjedhur?';
$messages['forbiddenchars'] = 'Shenja të ndaluara te fusha.';
$messages['cannotbeempty'] = 'Fusha s’mund të jetë e zbrazët.';
$messages['ruleexist'] = 'Ka tashmë një filtër me emrin e treguar.';
$messages['setactivateerror'] = 'Nuk mund të aktivizohet grupi i filtrave të zgjedhur. Ndodhi një gabim në server.';
$messages['setdeactivateerror'] = 'Nuk mund të çaktivizohet grupi i filtrave të zgjedhur. Ndodhi një gabim në server.';
$messages['setdeleteerror'] = 'S’arrihet të fshihet grupi i përzgjedhur i filtrave. Ndodhi një gabim shërbyesi.';
$messages['setactivated'] = 'Grupi i filtrave u aktivizua me sukses.';
$messages['setdeactivated'] = 'Grupi i filtrave u çaktivizua me sukses.';
$messages['setdeleted'] = 'Grupi i filtrave u fshi me sukses.';
$messages['setupdated'] = 'Grupi i filtrave u përditësua me sukses.';
$messages['setdeleteconfirm'] = 'Jeni i sigurt se doni të fshihet grupi i përzgjedhur i filtrave?';
$messages['setcreateerror'] = 'S’arrihet të krijohet grup filtrash. Ndodhi gabim shërbyesi.';
$messages['setcreated'] = 'Grupi i filtrave u krijua me sukses.';
$messages['activateerror'] = 'S’arrihet të aktivizohet filtri(at) e përzgjedhur. Ndodhi një gabim shërbyesi.';
$messages['deactivateerror'] = 'S’arrihet të çaktivizohet filtri(at) e përzgjedhur. Ndodhi një gabim shërbyesi.';
$messages['deactivated'] = 'Filtri(at) u çaktivizua me sukses.';
$messages['activated'] = 'Filtri(at) u aktivizua me sukses.';
$messages['moved'] = 'Filtri u lëviz me sukses.';
$messages['moveerror'] = 'S’arrihet të lëvizet filtri i përzgjedhur. Ndodhi një gabim shërbyesi.';
$messages['nametoolong'] = 'Emër shumë i gjatë.';
$messages['namereserved'] = 'Emër i rezervuar.';
$messages['setexist'] = 'Ka tashmë një grup të tillë.';
$messages['nodata'] = 'Duhet përzgjedhur të paktën një pozicion!';
$messages['invaliddateformat'] = 'Format i pavlefshëm date ose pjese date';
$messages['saveerror'] = 'S’arrihet të ruhen të dhëna. Ndodhi një gabim shërbyesi.';
$messages['vacationsaved'] = 'Të dhënat "jashtë zyre" u ruajtën me sukses.';
$messages['forwardsaved'] = 'Të dhënat e përcjelljes u ruajtën me sukses.';
$messages['emptyvacationbody'] = 'Lënda e mesazhit të pushimeve është e domosdoshme!';
$messages['duplicate.conflict.err'] = 'S’lejohet përdorimi i njëkohshëm i kryes dhe identifikuesit unik.';
$messages['disabledaction'] = 'Veprim jo i lejuar.';
$messages['lastindexempty'] = 'Treguesi është i domosdoshëm kur numërohet nga fundi';
$messages['noflagset'] = 'Duhet përzgjedhur të paktën një shenjë';
