<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = ' $product میں خوش آمدید';
$labels['username'] = 'صارف';
$labels['password'] = 'پاسورڈ';
$labels['server'] = 'سَروَر';
$labels['login'] = 'فولڈرز کا اصلی نام';
$labels['menu'] = 'مینو';
$labels['logout'] = 'لاگ آؤٹ';
$labels['mail'] = 'میل';
$labels['settings'] = 'ترتیبات';
$labels['addressbook'] = 'ایڈریس بک';
$labels['inbox'] = 'ان باکس';
$labels['drafts'] = 'ڈرافٹ';
$labels['sent'] = 'بھیجا ہوا میل';
$labels['trash'] = 'ردی کی ٹوکری';
$labels['junk'] = 'جنک میل';
$labels['show_real_foldernames'] = 'فولڈرز کا اصلی نام';
$labels['subject'] = 'مضمون';
$labels['from'] = 'از';
$labels['sender'] = 'بھیجنے والا';
$labels['date'] = 'تاریخ';
$labels['size'] = 'سائز';
$labels['mailboxlist'] = 'فولڈرز';
$labels['move'] = 'منتقل کریں';
$labels['download'] = 'ڈاؤن لوڈ';
$labels['open'] = 'کھولیں';
$labels['showattachment'] = 'دیکھایں';
$labels['showanyway'] = 'جیسا بھی ہے ظاہر کر دیں';
$labels['sun'] = 'اتوار';
$labels['mon'] = 'پیر';
$labels['tue'] = 'منگل';
$labels['wed'] = 'بدھ';
$labels['thu'] = 'جمرات';
$labels['fri'] = 'جمہ';
$labels['sat'] = 'ہفتہ';
$labels['sunday'] = 'اتوار';
$labels['monday'] = 'پیر';
$labels['tuesday'] = 'منگل';
$labels['wednesday'] = 'بدھ';
$labels['thursday'] = 'جمرات';
$labels['friday'] = 'جمہ';
$labels['saturday'] = 'ہفتہ';
$labels['jan'] = 'جنوری';
$labels['feb'] = 'فروری';
$labels['mar'] = 'مارچ';
$labels['apr'] = 'اپریل';
$labels['may'] = 'مئی';
$labels['jun'] = 'جون';
$labels['jul'] = 'جولائی';
$labels['aug'] = 'ٓآ گست';
$labels['sep'] = 'ستمبر';
$labels['oct'] = 'اُکتوبر';
$labels['nov'] = 'نومبر';
$labels['dec'] = 'دسمبر';
$labels['longjan'] = 'جنوری';
$labels['longfeb'] = 'فروری';
$labels['longmar'] = 'مارچ';
$labels['longapr'] = 'اپریل';
$labels['longmay'] = 'مئی';
$labels['longjun'] = 'جون';
$labels['longjul'] = 'جولائی';
$labels['longaug'] = 'ٓآگست';
$labels['longsep'] = 'ستمبر';
$labels['longoct'] = 'اکتوبر';
$labels['longnov'] = 'نومبر';
$labels['longdec'] = 'دسمبر';
$labels['today'] = 'آج ';
$labels['refresh'] = 'تازہ';
$labels['checkmail'] = 'نیا میسج دیکھیں';
$labels['compose'] = 'نیا میسج ';
$labels['writenewmessage'] = 'نیا میسج لکھیں';
$labels['reply'] = 'میسج کا جواب';
$labels['replytomessage'] = 'بھیجنے والے کو جواب دیں';
$labels['replyall'] = 'سب کو جواب دیں';
$labels['forward'] = 'آگےبھجوائیں';
$labels['markread'] = 'جیسے پڑھ لیا ہو';
$labels['markunread'] = 'جیسے ابھی نہ پڑھا ہو';
$labels['more'] = 'مزید';
$labels['back'] = 'واپس';
$labels['select'] = 'مۃنتخب کریں';
$labels['all'] = 'تمام';
$labels['none'] = 'کوئی نہیں';
$labels['currpage'] = 'موجودہ حفحہ';
$labels['unread'] = 'نہیں پڑھا';
$labels['deleted'] = 'ختم ہو گیا';
$labels['undeleted'] = 'ختم نہیں ہُوا';
$labels['invert'] = 'شکل تبدیل کریں';
$labels['list'] = 'لِسٹ';
$labels['expand-all'] = 'تمام کھولیں';
$labels['attachment'] = 'مُنسلَک شُدہ';
$labels['nonesort'] = 'کوئی نہیں';
$labels['layoutlist'] = 'لِسٹ';
$labels['folders'] = 'فولڈرز';
