<?php return array(
    'root' => array(
        'name' => 'roundcube/roundcubemail',
        'pretty_version' => 'dev-master',
        'version' => 'dev-master',
        'reference' => '39da42bacb746d323e00ce5e293fc0463db7baf0',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'bacon/bacon-qr-code' => array(
            'pretty_version' => '2.0.7',
            'version' => '2.0.7.0',
            'reference' => 'd70c840f68657ce49094b8d91f9ee0cc07fbf66c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../bacon/bacon-qr-code',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'dasprid/enum' => array(
            'pretty_version' => '1.0.3',
            'version' => '1.0.3.0',
            'reference' => '5abf82f213618696dda8e3bf6f64dd042d8542b2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../dasprid/enum',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/guzzle' => array(
            'pretty_version' => '7.4.5',
            'version' => '7.4.5.0',
            'reference' => '1dd98b0564cb3f6bd16ce683cb755f94c10fbd82',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/guzzle',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/promises' => array(
            'pretty_version' => '1.5.1',
            'version' => '1.5.1.0',
            'reference' => 'fe752aedc9fd8fcca3fe7ad05d419d32998a06da',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/promises',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/psr7' => array(
            'pretty_version' => '2.4.0',
            'version' => '2.4.0.0',
            'reference' => '13388f00956b1503577598873fffb5ae994b5737',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'kolab/net_ldap3' => array(
            'pretty_version' => 'v1.1.4',
            'version' => '1.1.4.0',
            'reference' => 'ec4f0d6918aa4b5364e99e1132e0a5a9b3ab23ab',
            'type' => 'library',
            'install_path' => __DIR__ . '/../kolab/net_ldap3',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'masterminds/html5' => array(
            'pretty_version' => '2.7.5',
            'version' => '2.7.5.0',
            'reference' => 'f640ac1bdddff06ea333a920c95bbad8872429ab',
            'type' => 'library',
            'install_path' => __DIR__ . '/../masterminds/html5',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/auth_sasl' => array(
            'pretty_version' => 'v1.1.0',
            'version' => '1.1.0.0',
            'reference' => 'db1ead3dc0bf986d2bab0dbc04d114800cf91dee',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/auth_sasl',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/console_commandline' => array(
            'pretty_version' => 'v1.2.4',
            'version' => '1.2.4.0',
            'reference' => 'cce06166765c5da31f3e8c1acf42512c64344cdb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/console_commandline',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/console_getopt' => array(
            'pretty_version' => 'v1.4.3',
            'version' => '1.4.3.0',
            'reference' => 'a41f8d3e668987609178c7c4a9fe48fecac53fa0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/console_getopt',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/crypt_gpg' => array(
            'pretty_version' => 'v1.6.7',
            'version' => '1.6.7.0',
            'reference' => '29c0fbe96d0d4063ecd5c9a4644cb65a7fb7cc4e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/crypt_gpg',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/mail_mime' => array(
            'pretty_version' => '1.10.11',
            'version' => '1.10.11.0',
            'reference' => 'd4fb9ce61201593d0f8c6db629c45e29c3409c14',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/mail_mime',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/net_ldap2' => array(
            'pretty_version' => 'v2.2.0',
            'version' => '2.2.0.0',
            'reference' => '38f1b22a96dfbd7ec53852f0e1e7ec1a9a5eb0e8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/net_ldap2',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/net_sieve' => array(
            'pretty_version' => '1.4.5',
            'version' => '1.4.5.0',
            'reference' => '94763e0fc6f39a9ebcd01e5e7a8250292804a50e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/net_sieve',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/net_smtp' => array(
            'pretty_version' => '1.10.0',
            'version' => '1.10.0.0',
            'reference' => '51e5997b711fbd1e5a9a075634d4d682168537fa',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/net_smtp',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/net_socket' => array(
            'pretty_version' => 'v1.2.2',
            'version' => '1.2.2.0',
            'reference' => 'bbe6a12bb4f7059dba161f6ddd43f369c0ec8d09',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/net_socket',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/pear-core-minimal' => array(
            'pretty_version' => 'v1.10.11',
            'version' => '1.10.11.0',
            'reference' => '68d0d32ada737153b7e93b8d3c710ebe70ac867d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/pear-core-minimal',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/pear_exception' => array(
            'pretty_version' => 'v1.0.2',
            'version' => '1.0.2.0',
            'reference' => 'b14fbe2ddb0b9f94f5b24cf08783d599f776fff0',
            'type' => 'class',
            'install_path' => __DIR__ . '/../pear/pear_exception',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-client' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => '2dfb5f6c5eff0e91e20e913f8c5452ed95b86621',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-client',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-factory' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => '12ac7fcd07e5b077433f5f2bee95b3a771bf61be',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-factory',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-factory-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-message' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => 'f6561bf28d520154e4b0ec72be95418abe6d9363',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'ralouphie/getallheaders' => array(
            'pretty_version' => '3.0.3',
            'version' => '3.0.3.0',
            'reference' => '120b605dfeb996808c31b6477290a714d356e822',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ralouphie/getallheaders',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'roundcube/plugin-installer' => array(
            'pretty_version' => '0.3.2',
            'version' => '0.3.2.0',
            'reference' => 'c4335e20b86cfe3a184ccf24d675c6a0338a372a',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../roundcube/plugin-installer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'roundcube/roundcubemail' => array(
            'pretty_version' => 'dev-master',
            'version' => 'dev-master',
            'reference' => '39da42bacb746d323e00ce5e293fc0463db7baf0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'roundcube/rtf-html-php' => array(
            'pretty_version' => 'v2.1',
            'version' => '2.1.0.0',
            'reference' => '7b488113e6fe2fccd84643e5121070fe7f335cb2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../roundcube/rtf-html-php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'rsky/pear-core-min' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.10.11',
            ),
        ),
        'symfony/deprecation-contracts' => array(
            'pretty_version' => 'v2.2.0',
            'version' => '2.2.0.0',
            'reference' => '5fa56b4074d1ae755beb55617ddafe6f5d78f665',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/deprecation-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
