<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Dalīšanās';
$labels['myrights'] = 'Piekļuves tiesības';
$labels['username'] = 'Lietotājs:';
$labels['advanced'] = 'Paplašinātais režīms';
$labels['add'] = 'Pievienot';
$labels['newuser'] = 'Pievienot ierakstu';
$labels['editperms'] = 'Rediģēt piejas';
$labels['actions'] = 'Darbības ar piekļuves tiesībām...';
$labels['anyone'] = 'Visi lietotāji (ikviens)';
$labels['anonymous'] = 'Viesi (anonīmie)';
$labels['identifier'] = 'Identifikators';
$labels['acll'] = 'Atrast';
$labels['aclr'] = 'Lasīt ziņojumus';
$labels['acls'] = 'Paturēt "Redzētā" statusu';
$labels['aclw'] = 'Saglabāt atzīmes';
$labels['acli'] = 'Ievietot (Iekopēt)';
$labels['aclp'] = 'Nosūtīt';
$labels['aclc'] = 'Izveidot apakšmapes';
$labels['aclk'] = 'Izveidot apakšmapes';
$labels['acld'] = 'Dzēst ziņojumus';
$labels['aclt'] = 'Dzēst ziņojumus';
$labels['acle'] = 'Izdzēst';
$labels['aclx'] = 'Dzēst mapi';
$labels['acla'] = 'Pārvaldīt';
$labels['acln'] = 'Anotēt e-pastus';
$labels['aclfull'] = 'Pilna kontrole';
$labels['aclother'] = 'Cits';
$labels['aclread'] = 'Lasīt';
$labels['aclwrite'] = 'Rakstīt';
$labels['acldelete'] = 'Dzēst';
$labels['shortacll'] = 'Atrast';
$labels['shortaclr'] = 'Lasīt';
$labels['shortacls'] = 'Paturēt';
$labels['shortaclw'] = 'Rakstīt';
$labels['shortacli'] = 'Ievietot';
$labels['shortaclp'] = 'Nosūtīt';
$labels['shortaclc'] = 'Izveidot';
$labels['shortaclk'] = 'Izveidot';
$labels['shortacld'] = 'Dzēst';
$labels['shortaclt'] = 'Dzēst';
$labels['shortacle'] = 'Izdzēst';
$labels['shortaclx'] = 'Mapes dzēšana';
$labels['shortacla'] = 'Pārvaldīt';
$labels['shortacln'] = 'Anotēt';
$labels['shortaclother'] = 'Cits';
$labels['shortaclread'] = 'Lasīt';
$labels['shortaclwrite'] = 'Rakstīt';
$labels['shortacldelete'] = 'Dzēst';
$labels['longacll'] = 'Mape ir redzama kopējā mapju sarakstā un var tikt abonēta';
$labels['longaclr'] = 'Ši mape var tikt atvērta lasīšanai';
$labels['longacls'] = 'Ziņojumu "Redzēts" atzīme var tik mainīta';
$labels['longaclw'] = 'Ziņojumu atzīmes, izņemot "Redzēts" un "Dzēsts", un atslēgvārdi var tik mainīti';
$labels['longacli'] = 'Ziņojumi var tikt  ierakstīti vai pārkopēti uz šo mapi';
$labels['longaclp'] = 'Vēstules var tikt ievietotas šajā mapē';
$labels['longaclc'] = 'Zem šīs mapes pa tiešo var tikt izveidotas (vai pārsauktas) citas mapes';
$labels['longaclk'] = 'Zem šīs mapes pa tiešo var tikt izveidotas (vai pārsauktas) citas mapes';
$labels['longacld'] = 'Ziņojumu "Dzēst" atzīme var tikt mainīta';
$labels['longaclt'] = 'Ziņojumu "Dzēst" atzīme var tikt mainīta';
$labels['longacle'] = 'Vēstules var tikt izdzēstas';
$labels['longaclx'] = 'Mape var tikt gan dzēsta, gan pārdēvēta';
$labels['longacla'] = 'Mapes pieejas tiesības var tikt izmainītas';
$labels['longacln'] = 'E-pastu koplietotie meta dati (anotācijas) var tikt mainīti';
$labels['longaclfull'] = 'Pilna kontrole, iekļaujot arī mapju administrēšanu';
$labels['longaclread'] = 'Mape var tikt atvērta lasīšanai';
$labels['longaclwrite'] = 'Ziņojumi mapē var tikt gan atzīmēti, gan ierakstīti vai arī pārkopēti uz mapi';
$labels['longacldelete'] = 'Vēstules var tikt izdzēstas';
$labels['longaclother'] = 'Pieejas tiesības citiem';
$labels['ariasummaryacltable'] = 'Pieejas tiesību saraksts';
$labels['arialabelaclactions'] = 'Darbību saraksts';
$labels['arialabelaclform'] = 'Pieejas tiesību forma';
$messages['deleting'] = 'Dzēš piekļuves tiesības...';
$messages['saving'] = 'Saglabā piekļuves tiesības...';
$messages['updatesuccess'] = 'Piekļuves tiesības tika veiksmīgi samainītas';
$messages['deletesuccess'] = 'Piekļuves tiesības tika veiksmīgi izdzēstas';
$messages['createsuccess'] = 'Piekļuves tiesības tika veiksmīgi pievienotas';
$messages['updateerror'] = 'Pieejas tiesības nomainīt neizdevās';
$messages['deleteerror'] = 'Piekļuves tiesības izdzēst neizdevās';
$messages['createerror'] = 'Piekļuves tiesības pievienot neizdevās';
$messages['deleteconfirm'] = 'Vai tiešām atzīmētajiem lietotājiem noņemt piekļuves tiesības?';
$messages['norights'] = 'Netika norādītas tiesības!';
$messages['nouser'] = 'Netika norādīts lietotājvārds!';
