<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Mirë se erdhët te $product';
$labels['username'] = 'Emër përdoruesi';
$labels['password'] = 'Fjalëkalimi';
$labels['server'] = 'Shërbyes';
$labels['login'] = 'Hyrje';
$labels['oauthlogin'] = 'Hyrje me $provider';
$labels['menu'] = 'Menu';
$labels['logout'] = 'Dalje';
$labels['mail'] = 'Postë';
$labels['settings'] = 'Rregullime';
$labels['addressbook'] = 'Libër Adresash';
$labels['darkmode'] = 'Mënyrë e Errët';
$labels['lightmode'] = 'Mënyra e Çelët';
$labels['inbox'] = 'Të marrë';
$labels['drafts'] = 'Skica';
$labels['sent'] = 'Të dërguar';
$labels['trash'] = 'Hedhurina';
$labels['junk'] = 'Të pavlerë';
$labels['show_real_foldernames'] = 'Shfaqi emrat realë për dosjet speciale';
$labels['subject'] = 'Subjekt';
$labels['from'] = 'Nga';
$labels['sender'] = 'Dërguesi';
$labels['to'] = 'Për';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Përgjigju';
$labels['followupto'] = 'Ndiqe';
$labels['date'] = 'Datë';
$labels['size'] = 'Madhësi';
$labels['priority'] = 'Përparësi';
$labels['organization'] = 'Ent';
$labels['readstatus'] = 'Gjendje leximi';
$labels['listoptions'] = 'Mundësi liste…';
$labels['listoptionstitle'] = 'Mundësi liste';
$labels['mailboxlist'] = 'Dosje';
$labels['messagesfromto'] = 'Mesazhet nga $from deri në $to nga $count gjithsej';
$labels['threadsfromto'] = 'Rrjedhat nga $from deri në $to nga $count gjithsej';
$labels['messagenrof'] = 'Mesazhi $nr nga $count gjithsej';
$labels['fromtoshort'] = '$from – $to nga $count gjithsej';
$labels['copy'] = 'Kopjoje';
$labels['move'] = 'Lëvize';
$labels['moveto'] = 'Shpjere te...';
$labels['copyto'] = 'Kopjoje te...';
$labels['download'] = 'Shkarkoje';
$labels['open'] = 'Hape';
$labels['showattachment'] = 'Shfaqe';
$labels['showanyway'] = 'Shfaqe sido qoftë';
$labels['filename'] = 'Emër kartele';
$labels['filesize'] = 'Madhësi kartele';
$labels['addtoaddressbook'] = 'Shtoje në librin e adresave';
$labels['sun'] = 'E Die';
$labels['mon'] = 'Hën';
$labels['tue'] = 'Mar';
$labels['wed'] = 'Mër';
$labels['thu'] = 'Enj';
$labels['fri'] = 'Pre';
$labels['sat'] = 'Sht';
$labels['sunday'] = 'e Dielë';
$labels['monday'] = 'e Hënë';
$labels['tuesday'] = 'e Martë';
$labels['wednesday'] = 'e Mërkurë';
$labels['thursday'] = 'e Enjte';
$labels['friday'] = 'e Premte';
$labels['saturday'] = 'e Shtunë';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Shk';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Pri';
$labels['may'] = 'Maj';
$labels['jun'] = 'Qer';
$labels['jul'] = 'Kor';
$labels['aug'] = 'Gus';
$labels['sep'] = 'Sht';
$labels['oct'] = 'Tet';
$labels['nov'] = 'Nën';
$labels['dec'] = 'Dhj';
$labels['longjan'] = 'Janar';
$labels['longfeb'] = 'Shkurt';
$labels['longmar'] = 'Mars';
$labels['longapr'] = 'Prill';
$labels['longmay'] = 'Maj';
$labels['longjun'] = 'Qershor';
$labels['longjul'] = 'Korrik';
$labels['longaug'] = 'Gusht';
$labels['longsep'] = 'Shtator';
$labels['longoct'] = 'Tetor';
$labels['longnov'] = 'Nëntor';
$labels['longdec'] = 'Dhjetor';
$labels['today'] = 'Sot';
$labels['refresh'] = 'Rifreskoje';
$labels['checkmail'] = 'Kontrollo për mesazhe të reja';
$labels['compose'] = 'Hartoni';
$labels['writenewmessage'] = 'Krijoni një mesazh të ri';
$labels['reply'] = 'Përgjigju';
$labels['replytomessage'] = 'Përgjigjiu dërguesit';
$labels['replytoallmessage'] = 'Përgjigju te lista ose dërguesit dhe të gjithë marrësve';
$labels['replyall'] = 'Përgjigju të gjithëve';
$labels['replylist'] = 'Përgjigju listës';
$labels['forward'] = 'Përcille';
$labels['forwardinline'] = 'Përcille brendazi';
$labels['forwardattachment'] = 'Përcille si bashkëngjitje';
$labels['forwardmessage'] = 'Përcille mesazhin';
$labels['bouncemsg'] = 'Përpunim marrësi';
$labels['bounce'] = 'Ridërgoje';
$labels['deletemessage'] = 'Fshije mesazhin';
$labels['movemessagetotrash'] = 'Hidhe mesazhin në kosh';
$labels['printmessage'] = 'Shtype këtë mesazh';
$labels['previousmessage'] = 'Shfaq mesazhin e mëparshëm';
$labels['firstmessage'] = 'Shfaq mesazhin e parë';
$labels['nextmessage'] = 'Shfaq mesazhin pasardhës';
$labels['lastmessage'] = 'Shfaq mesazhin e fundit';
$labels['backtolist'] = 'Kthehu te lista e mesazheve';
$labels['viewsource'] = 'Shfaqi burimin';
$labels['mark'] = 'Vëri shenjë';
$labels['markmessages'] = 'Vëru shenjë mesazheve';
$labels['markread'] = 'Si të lexuara';
$labels['markunread'] = 'Si të palexuara';
$labels['markflagged'] = 'Si me shenjë';
$labels['markunflagged'] = 'Si me shenjë të hequr';
$labels['markundeleted'] = 'Si i pafshirë';
$labels['moreactions'] = 'Më tepër veprime…';
$labels['markallread'] = 'Vëru shenjë të tërëve si të lexuar';
$labels['folders-cur'] = 'Vetëm dosjes së përzgjedhur';
$labels['folders-sub'] = 'Dosjes së përzgjedhur dhe nëndosjeve të saj';
$labels['folders-all'] = 'Krejt dosjet';
$labels['more'] = 'Më tepër';
$labels['back'] = 'Mbrapsht';
$labels['options'] = 'Opsione';
$labels['composeoptions'] = 'Mundësi hartimi';
$labels['optionsandattachments'] = 'Mundësi dhe bashkëngjitje';
$labels['actions'] = 'Veprime';
$labels['first'] = 'I pari';
$labels['last'] = 'I fundit';
$labels['previous'] = 'I mëparshmi';
$labels['next'] = 'Pasuesi';
$labels['select'] = 'Përzgjidhni';
$labels['selection'] = 'Përzgjdhje';
$labels['all'] = 'Krejt';
$labels['none'] = 'Asnjë';
$labels['currpage'] = 'Faqja e tanishme';
$labels['isread'] = 'Të lexuar';
$labels['unread'] = 'Të palexuar';
$labels['flagged'] = 'Me Shenjë';
$labels['unflagged'] = 'Pa Shenjë';
$labels['unanswered'] = 'Pa përgjigje';
$labels['withattachment'] = 'Me bashkëngjitje';
$labels['deleted'] = 'Të fshirë';
$labels['undeleted'] = 'Të pafshirë';
$labels['replied'] = 'Me përgjigje';
$labels['forwarded'] = 'Të përcjellë';
$labels['invert'] = 'Përmbyse';
$labels['filter'] = 'Filtër';
$labels['list'] = 'Listë';
$labels['threads'] = 'Rrjedha';
$labels['expand-all'] = 'Zgjeroji Krejt';
$labels['expand-unread'] = 'Zgjero të Palexuarit';
$labels['collapse-all'] = 'Tkurri Krejt';
$labels['threaded'] = 'Me rrjedhë';
$labels['showunread'] = 'Shfaq mesazhe të palexuar';
$labels['autoexpand_threads'] = 'Zgjero rrjedha mesazhesh';
$labels['do_expand'] = 'krejt rrjedhat';
$labels['expand_only_unread'] = 'vetëm ato me mesazhe të palexuar';
$labels['fromto'] = 'Nga/Për';
$labels['flag'] = 'Shenjë';
$labels['attachment'] = 'Bashkëngjitje';
$labels['nonesort'] = 'Asnjë';
$labels['sentdate'] = 'Datë dërgimi';
$labels['arrival'] = 'Datë mbërritje';
$labels['asc'] = 'në rend rritës';
$labels['desc'] = 'në rend zbritës';
$labels['listcolumns'] = 'Paraqit shtylla';
$labels['listsorting'] = 'Shtyllë renditjeje';
$labels['listorder'] = 'Rend renditjeje';
$labels['listmode'] = 'Mënyra parje si listë';
$labels['lmode'] = 'Mënyra listë';
$labels['layout'] = 'Skemë';
$labels['layoutwidescreen'] = 'Me ekran të gjerë';
$labels['layoutdesktop'] = 'Desktop';
$labels['layoutlist'] = 'Listë';
$labels['layoutwidescreendesc'] = 'Me ekran të gjerë (pamje 3 shtylla)';
$labels['layoutdesktopdesc'] = 'Desktop (listë e gjerë dhe paraparje nën të )';
$labels['layoutlistdesc'] = 'Listë (pa paraparje poste)';
$labels['folderactions'] = 'Veprime mbi dosje…';
$labels['compact'] = 'Ngjeshe';
$labels['empty'] = 'Zbraze';
$labels['importmessages'] = 'Importo mesazhe';
$labels['mailimportdesc'] = 'Mund të ngarkoni postë duke përdorur kartela në formatin <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> ose <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>.';
$labels['mailimportzip'] = 'Një grup kartelash mund të ngjeshen në arkiva zip.';
$labels['quota'] = 'Përdorim disku';
$labels['unknown'] = 'i panjohur';
$labels['unlimited'] = 'i pakufizuar';
$labels['quotatype'] = 'Lloj thonjëzash';
$labels['quotatotal'] = 'Kufi';
$labels['quotaused'] = 'E përdorur';
$labels['quotastorage'] = 'Hapësirë disku';
$labels['quotamessage'] = 'Numër mesazhesh';
$labels['shortheaderdate'] = 'Më $date';
$labels['shortheaderto'] = 'Për $to më $date';
$labels['shortheaderfrom'] = 'Nga $from më $date';
$labels['quicksearch'] = 'Kërkim i shpejtë';
$labels['searchplaceholder'] = 'Kërkoni…';
$labels['resetsearch'] = 'Kërkim nga e para';
$labels['searchmod'] = 'Modifikues kërkimi';
$labels['msgtext'] = 'Krejt mesazhin';
$labels['body'] = 'Lëndë';
$labels['type'] = 'Lloj';
$labels['namex'] = 'Emër';
$labels['searchscope'] = 'Shtrirje';
$labels['currentfolder'] = 'Dosja e tanishme';
$labels['subfolders'] = 'Kjo dhe nëndosjet';
$labels['allfolders'] = 'Krejt dosjet';
$labels['searchinterval-1W'] = 'më të vjetër se një javë';
$labels['searchinterval-1M'] = 'më të vjetër se një muaj';
$labels['searchinterval-1Y'] = 'më të vjetër se një vit';
$labels['searchinterval1W'] = 'më të rinj se një javë';
$labels['searchinterval1M'] = 'më të rinj se një muaj';
$labels['searchinterval1Y'] = 'më të rinj se një vit';
$labels['openinextwin'] = 'Hape në dritare të re';
$labels['emlsave'] = 'Shkarkoje (.eml)';
$labels['changeformattext'] = 'Shfaqe në format tekst të thjeshtë';
$labels['changeformathtml'] = 'Shfaqe në format HTML';
$labels['editasnew'] = 'Përpunojeni si të ri';
$labels['send'] = 'Dërgoje';
$labels['sendmessage'] = 'Dërgoje mesazhin';
$labels['savemessage'] = 'Ruaje si skicë';
$labels['addattachment'] = 'Bashkëngjitni një kartelë';
$labels['charset'] = 'Bashkësi shkronjash';
$labels['editortype'] = 'Lloj përpunuesi';
$labels['returnreceipt'] = 'Dëftesë kthimi';
$labels['dsn'] = 'Njoftim gjendjeje dërgimi';
$labels['keepformatting'] = 'Mbaje formatimin';
$labels['mailreplyintro'] = 'Më $date, $sender shkroi:';
$labels['originalmessage'] = 'Mesazhi Origjinal';
$labels['selectimage'] = 'Përzgjidhni figurë';
$labels['addimage'] = 'Shtoni figurë';
$labels['selectmedia'] = 'Përzgjidhni film';
$labels['addmedia'] = 'Shtoni film';
$labels['encrypt'] = 'Fshehtëzoje';
$labels['encryptmessage'] = 'Fshehtëzoje mesazhin';
$labels['encryptmessagemailvelope'] = 'Fshehtëzoje mesazhin me Mailvelope';
$labels['importpubkeys'] = 'Importo kyçe publikë';
$labels['encryptedsendialog'] = 'Po dërgohet mesazh i fshehtëzuar';
$labels['encryptandsign'] = 'Fshehtëzoje dhe nënshkruaje';
$labels['keyid'] = 'ID Kyçi';
$labels['keylength'] = 'Bite';
$labels['keyexpired'] = 'I skaduar';
$labels['keyrevoked'] = 'I shfuqizuar';
$labels['bccinstead'] = 'Përdor Bcc';
$labels['addheader'] = 'Shtoni marrës (krye)';
$labels['insert'] = 'Fut';
$labels['insertcontact'] = 'Futni kontakt(e)';
$labels['recipient'] = 'Marrës';
$labels['recipientedit'] = 'Redaktimi i marrësit ose pranuesit';
$labels['editidents'] = 'Përpunoni identitete';
$labels['spellcheck'] = 'Drejtshkrim';
$labels['checkspelling'] = 'Kontrolloji drejtshkrimin';
$labels['resumeediting'] = 'Rikthejuni përpunimit';
$labels['revertto'] = 'Riktheje te';
$labels['restore'] = 'Rimerre';
$labels['restoremessage'] = 'Të rimerret mesazhi?';
$labels['ignore'] = 'Shpërfille';
$labels['responses'] = 'Përgjigje';
$labels['insertresponse'] = 'Futni një përgjigje';
$labels['manageresponses'] = 'Administroni përgjigje';
$labels['newresponse'] = 'Krijoni përgjigje të re';
$labels['addresponse'] = 'Shtoni përgjigje';
$labels['editresponse'] = 'Përpunoni përgjigje';
$labels['editresponses'] = 'Përpunoni përgjigje';
$labels['responsename'] = 'Emër';
$labels['responsetext'] = 'Tekst Përgjigjeje';
$labels['attach'] = 'Bashkëngjite';
$labels['attachments'] = 'Bashkëngjitje';
$labels['upload'] = 'Ngarko';
$labels['uploadprogress'] = '$percent ($current nga $total gjithsej)';
$labels['close'] = 'Mbylle';
$labels['messageoptions'] = 'Mundësi mesazhesh…';
$labels['togglecomposeoptions'] = 'Shfaq/fshih mundësi hartimi';
$labels['attachmentrename'] = 'Riemërtoni bashkëngjitjet';
$labels['low'] = 'E ulët';
$labels['lowest'] = 'Më e ulëta';
$labels['normal'] = 'Normale';
$labels['high'] = 'E lartë';
$labels['highest'] = 'Më e larta';
$labels['nosubject'] = '(pa subjekt)';
$labels['showimages'] = 'Shfaq figura';
$labels['allow'] = 'Lejoje';
$labels['alwaysshow'] = 'Shfaqi përherë figurat nga $sender';
$labels['alwaysallow'] = 'Lejo përherë nga $sender';
$labels['isdraft'] = 'Kjo është një skicë mesazhi.';
$labels['andnmore'] = '$nr të tjerë...';
$labels['details'] = 'Hollësi';
$labels['summary'] = 'Përmbledhje';
$labels['headers'] = 'Krye';
$labels['allheaders'] = 'Krejt kryet…';
$labels['togglemoreheaders'] = 'Shfaq më tepër krye mesazhi';
$labels['togglefullheaders'] = 'Shfaq/fshih krye të papërpunuar mesazhi';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Tekst i thjeshtë';
$labels['savesentmessagein'] = 'Ruaje mesazhin e dërguar te';
$labels['dontsave'] = 'mos e ruaj';
$labels['maxuploadsize'] = 'Maksimumi i lejuar për madhësi kartelash është $size';
$labels['addcc'] = 'Shto Cc';
$labels['addbcc'] = 'Shto Bcc';
$labels['addreplyto'] = 'Shtoni Përgjigjuni-Te';
$labels['addfollowupto'] = 'Shto Vazhdojeni-Te';
$labels['sendreceipt'] = 'Të dërgohet dëftesë leximi?';
$labels['mdnrequest'] = 'Dërguesi i këtij mesazhi ka kërkuar që të njoftohet kur të lexoni këtë mesazh. Dëshironi të njoftohet dërguesi?';
$labels['receiptread'] = 'Dëftesë Kthimi (u lexua)';
$labels['yourmessage'] = 'Kjo është një Dëftesë Kthimi për mesazhin tuaj';
$labels['receiptnote'] = 'Shënim: Kjo dëftesë dëshmon vetëm se mesazhi u shfaq në kompjuterin e marrësit. Nuk ka garanci se marrësi e ka lexuar ose e ka kuptuar përmbajtjen e mesazhit.';
$labels['sendalwaysto'] = 'Dërgoje përherë te $email';
$labels['zoomin'] = 'Zmadhim';
$labels['zoomout'] = 'Zvogëlim';
$labels['rotate'] = 'Rrotulloje';
$labels['increaseimage'] = 'Zmadhoni madhësi figure';
$labels['decreaseimage'] = 'Zvogëloni madhësi figure';
$labels['rotateimage'] = 'Rrotullojeni figurën';
$labels['showtools'] = 'Shfaq mjete figure';
$labels['hidetools'] = 'Fshihi mjetet e figurës';
$labels['name'] = 'Emër Në Ekran';
$labels['firstname'] = 'Emër';
$labels['surname'] = 'Mbiemër';
$labels['middlename'] = 'Emër i Dytë';
$labels['nameprefix'] = 'Parashtesë';
$labels['namesuffix'] = 'Prapashtesë';
$labels['nickname'] = 'Nofkë';
$labels['jobtitle'] = 'Pozicion';
$labels['department'] = 'Degë';
$labels['gender'] = 'Gjini';
$labels['maidenname'] = 'Emër në Vajzëri';
$labels['email'] = 'Email';
$labels['phone'] = 'Telefon';
$labels['address'] = 'Adresë';
$labels['street'] = 'Rrugë';
$labels['locality'] = 'Qytet';
$labels['zipcode'] = 'Kod ZIP';
$labels['region'] = 'Shtet/Provincë';
$labels['country'] = 'Vend';
$labels['birthday'] = 'Datëlindje';
$labels['anniversary'] = 'Përvjetor';
$labels['website'] = 'Sajt';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Shënime';
$labels['male'] = 'mashkull';
$labels['female'] = 'femër';
$labels['manager'] = 'Përgjegjës';
$labels['assistant'] = 'Asistent';
$labels['spouse'] = 'Bashkëshort';
$labels['allfields'] = 'Krejt fushat';
$labels['search'] = 'Kërkoni';
$labels['searchresult'] = 'Përfundime kërkimi';
$labels['advsearch'] = 'Kërkim i Thelluar';
$labels['advanced'] = 'I thelluar';
$labels['other'] = 'Tjetër';
$labels['printcontact'] = 'Shtype kontaktin';
$labels['qrcode'] = 'Kod QR';
$labels['typehome'] = 'Shtëpie';
$labels['typework'] = 'Pune';
$labels['typeother'] = 'Tjetër';
$labels['typemobile'] = 'Celular';
$labels['typemain'] = 'Kryesore';
$labels['typehomefax'] = 'Faks Shtëpie';
$labels['typeworkfax'] = 'Faks Pune';
$labels['typecar'] = 'Automjet';
$labels['typepager'] = 'Faques';
$labels['typevideo'] = 'Video';
$labels['typeassistant'] = 'Asistent';
$labels['typehomepage'] = 'Faqe Hyrëse';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Shtoni fushë…';
$labels['addcontact'] = 'Shtoni kontakt';
$labels['editcontact'] = 'Përpunoni kontakt';
$labels['contacts'] = 'Kontakte';
$labels['contactproperties'] = 'Veti kontaktesh';
$labels['contactnameandorg'] = 'Emër dhe Ent';
$labels['personalinfo'] = 'Të dhëna personale';
$labels['personal'] = 'Personale';
$labels['contactphoto'] = 'Foto kontakti';
$labels['edit'] = 'Përpunoni';
$labels['cancel'] = 'Anuloje';
$labels['save'] = 'Ruaje';
$labels['delete'] = 'Fshije';
$labels['discard'] = 'Hidhe tej';
$labels['continue'] = 'Vazhdo';
$labels['ok'] = 'OK';
$labels['rename'] = 'Riemërtojeni';
$labels['addphoto'] = 'Shtoni';
$labels['replacephoto'] = 'Zëvendësoje';
$labels['uploadphoto'] = 'Ngarkoni foto';
$labels['choosefile'] = 'Zgjidhni kartelë…';
$labels['choosefiles'] = 'Zgjidhni kartela…';
$labels['browse'] = 'Shfletoni';
$labels['newcontact'] = 'Krijoni kontakt të ri';
$labels['deletecontact'] = 'Fshiji kontaktet e përzgjedhur';
$labels['composeto'] = 'Hartoni email për';
$labels['contactsfromto'] = 'Kontaktet nga $from deri në $to nga $count gjithsej';
$labels['print'] = 'Shtype';
$labels['export'] = 'Eksporto';
$labels['exportall'] = 'Eksportoji krejt';
$labels['exportsel'] = 'Eksporto të përzgjedhurat';
$labels['exportvcards'] = 'Eksportoji kontaktet në format vCard';
$labels['newgroup'] = 'Krijoni grup të ri';
$labels['addgroup'] = 'Shtoni grup';
$labels['grouprename'] = 'Riemërtojeni grupin';
$labels['groupdelete'] = 'Fshije grupin';
$labels['groupassign'] = 'Caktojani një grupi…';
$labels['groupremove'] = 'Hiqeni prej grupi';
$labels['groupremoveselected'] = 'Hiqi nga grupi kontaktet e përzgjedhur';
$labels['uponelevel'] = 'Një nivel më sipër';
$labels['previouspage'] = 'Shfaq faqen e mëparshme';
$labels['firstpage'] = 'Shfaq faqen e parë';
$labels['nextpage'] = 'Shfaq faqen pasuese';
$labels['lastpage'] = 'Shfaq faqen e fundit';
$labels['group'] = 'Grup';
$labels['groups'] = 'Grupe';
$labels['listgroup'] = 'Paraqit anëtarë grupi';
$labels['personaladrbook'] = 'Adresa Personale';
$labels['searchsave'] = 'Ruaje kërkimin';
$labels['searchdelete'] = 'Fshije kërkimin';
$labels['import'] = 'Importo';
$labels['importcontacts'] = 'Importo kontaktet';
$labels['importfromfile'] = 'Importo prej kartele';
$labels['importtarget'] = 'Shtoni kontakte te';
$labels['importreplace'] = 'Zëvendëso krejt librin e adresave';
$labels['importgroups'] = 'Importo përshoqërime grupi';
$labels['importgroupsall'] = 'Krejt (krijo grupe, në u dashtë)';
$labels['importgroupsexisting'] = 'Vetëm për grupe ekzistues';
$labels['importdesc'] = 'Mund të ngarkoni kontakte nga një libër ekzistues adresash.<br/>Deri këtu mbulojmë importim adresash prej formati <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> ose CSV (comma-separated) të dhënash.';
$labels['importmapdesc'] = 'Përpara se të ecet më tej me importim të dhënash CSV (ndarë me presje), ripohoni më poshtë të dhënat mbi përshoqërim fushash.';
$labels['fieldnotmapped'] = 'Fushë e papërshoqëruar (mos e importo)';
$labels['skipheader'] = 'Mos importo rreshtin e parë (kryet)';
$labels['done'] = 'U bë';
$labels['settingsfor'] = 'Rregullime për';
$labels['about'] = 'Rreth';
$labels['preferences'] = 'Parapëlqime';
$labels['userpreferences'] = 'Parapëlqime përdoruesi';
$labels['editpreferences'] = 'Përpunoni parapëlqime përdoruesi';
$labels['identities'] = 'Identitete';
$labels['manageidentities'] = 'Administroni identitete';
$labels['newidentity'] = 'Krijoni identitet të ri';
$labels['addidentity'] = 'Shtoni identitet';
$labels['editidentity'] = 'Përpunoni identitet';
$labels['identityencryption'] = 'Fshehtëzim';
$labels['preferhtml'] = 'Shfaq HTML';
$labels['defaultcharset'] = 'Shkronja Parazgjedhje';
$labels['htmlmessage'] = 'Mesazh HTML';
$labels['messagepart'] = 'Pjesë';
$labels['digitalsig'] = 'Nënshkrim Dixhital';
$labels['dateformat'] = 'Format të dhënash';
$labels['timeformat'] = 'Format kohe';
$labels['prettydate'] = 'Data të hijshme';
$labels['setdefault'] = 'Caktoje si parazgjedhje';
$labels['autodetect'] = 'Auto';
$labels['language'] = 'Gjuhë';
$labels['timezone'] = 'Brez orar';
$labels['pagesize'] = 'Rreshta për faqe';
$labels['signature'] = 'Nënshkrim';
$labels['dstactive'] = 'Ndryshim ore';
$labels['showinextwin'] = 'Hape mesazhin në dritare të re';
$labels['composeextwin'] = 'Për hartim mesazhesh hap dritare të re';
$labels['htmleditor'] = 'Harto mesazhe HTML';
$labels['htmlonreply'] = 'kur i përgjigjeni mesazheve HTML';
$labels['htmlonreplyandforward'] = 'kur i përgjigjeni ose përcillni mesazh HTML';
$labels['htmlsignature'] = 'Nënshkrimi HTML';
$labels['showemail'] = 'Adresën email shfaqe me emrin për në ekran';
$labels['previewpane'] = 'Shfaq panel paraparjeje';
$labels['skin'] = 'Temë grafike për ndërfaqen';
$labels['logoutclear'] = 'Pastroji Hedhurinat gjatë daljes';
$labels['logoutcompact'] = 'Ngjeshi Të marrët në dalje e sipër';
$labels['uisettings'] = 'Ndërfaqe Përdoruesi';
$labels['serversettings'] = 'Rregullime Shërbyesi';
$labels['mailboxview'] = 'Shfaqje e Kutisë Postare';
$labels['mdnrequests'] = 'Kur kërkohet dëftesë kthimi';
$labels['askuser'] = 'pyetmë';
$labels['autosend'] = 'dërgo dëftesë';
$labels['autosendknown'] = 'dërgoju dëftesë kontakteve të mi, përndryshe pyetmë';
$labels['autosendknownignore'] = 'dërgoju dëftesë kontakteve të mi, përndryshe shpërfille';
$labels['autosendtrusted'] = 'dërgo dëftesë te dërgues të besuar, përndryshe pyetmë';
$labels['autosendtrustedignore'] = 'dërgoju dëftesë dërguesve të besuar, përndryshe shpërfille';
$labels['ignorerequest'] = 'shpërfille kërkesën';
$labels['readwhendeleted'] = 'Gjatë fshirjes shënoje mesazhin si të lexuar';
$labels['flagfordeletion'] = 'Vëri shenjë mesazhit për fshirje, në vend se ta fshish';
$labels['skipdeleted'] = 'Mos shfaq mesazhe të fshirë';
$labels['deletealways'] = 'Nëse shpënia te Hedhurinat dështon, fshiji';
$labels['deletejunk'] = 'Mesazhet te Të pavlerat fshiji drejtpërsëdrejti';
$labels['showremoteimages'] = 'Shfaqi figurat e largëta të trupëzuara në mesazh';
$labels['allowremoteresources'] = 'Lejo burime të largëta (figura, stile)';
$labels['fromknownsenders'] = 'prej dërguesish të njohur';
$labels['fromtrustedsenders'] = 'prej dërguesish të besuar';
$labels['frommycontacts'] = 'prej kontakteve të mi';
$labels['always'] = 'përherë';
$labels['alwaysbutplain'] = 'përherë, hiq rastin kur i përgjigjem teksti të thjeshtë';
$labels['showinlineimages'] = 'Figurat e bashkëngjitura shfaqi nën mesazh';
$labels['autosavedraft'] = 'Ruaje automatikisht si skicë';
$labels['everynminutes'] = 'çdo $n minutë(a)';
$labels['refreshinterval'] = 'Rifreskoje (kontrollo për mesazhe të rinj, etj)';
$labels['never'] = 'kurrë';
$labels['immediately'] = 'menjëherë';
$labels['messagesdisplaying'] = 'Shfaqje Mesazhesh';
$labels['messagescomposition'] = 'Hartim Mesazhesh';
$labels['mimeparamfolding'] = 'Emra bashkëngjitjesh';
$labels['2231folding'] = 'RFC 2231 i Plotë (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'RFC 2047 i Plotë (tjetër)';
$labels['force7bit'] = 'Për shenja 8-bitëshe përdor kodim MIME';
$labels['savelocalstorage'] = "Ruaji te depoja vendore e shfletuesit (përkohësisht)";
$labels['advancedoptions'] = 'Mundësi të mëtejshme';
$labels['toggleadvancedoptions'] = 'Shfaq/fshih mundësi të mëtejshme';
$labels['focusonnewmessage'] = 'Për mesazhe të rinj kaloje fokusin te dritarja e shfletuesit';
$labels['checkallfolders'] = 'Kontrollo krejt dosjet për mesazhe të rinj';
$labels['displaynext'] = 'Pas fshirjesh/lëvizjesh, shfaq zërin pasues në listë';
$labels['defaultfont'] = 'Shkronja parazgjedhje për mesazhe HTML';
$labels['mainoptions'] = 'Mundësitë Kryesore';
$labels['browseroptions'] = 'Mundësi Shfletuesi';
$labels['section'] = 'Seksion';
$labels['maintenance'] = 'Mirëmbajtje';
$labels['newmessage'] = 'Mesazh i Ri';
$labels['signatureoptions'] = 'Mundësi Nënshkrimesh';
$labels['whenreplying'] = 'Kur përgjigjem';
$labels['replyempty'] = 'mos e cito mesazhin origjinal';
$labels['replytopposting'] = 'filloje mesazhin e ri sipër citimit';
$labels['replytoppostingnoindent'] = 'nise mesazhin e ri sipër citimit (pa shmangie)';
$labels['replybottomposting'] = 'filloje mesazhin e ri poshtë citimit';
$labels['replyremovesignature'] = 'Kur përgjigjeni, hiqni nënshkrimin origjinal nga mesazhi';
$labels['autoaddsignature'] = 'Nënshkrimin shtoje vetvetiu';
$labels['newmessageonly'] = 'vetëm për mesazh të ri';
$labels['replyandforwardonly'] = 'vetëm për përgjigje dhe përcjellje';
$labels['insertsignature'] = 'Fut nënshkrim';
$labels['sigbelow'] = 'Nënshkrimin vendose nën mesazhin e cituar';
$labels['sigseparator'] = 'Në nënshkrime përdor detyrimisht ndarës standard';
$labels['automarkread'] = 'Vëru shenjë mesazheve si të lexuar';
$labels['afternseconds'] = 'pas $n sekondash';
$labels['reqmdn'] = 'Kërko përherë dëftesë kthimi';
$labels['reqdsn'] = 'Kërko përherë njoftim mbi gjendje dërgimi';
$labels['replysamefolder'] = 'Vendosi përgjigjet te dosja e mesazheve të cilit po i përgjigjeni';
$labels['defaultabook'] = 'Libër parazgjedhje adresash';
$labels['autocompletesingle'] = 'Gjatë vetëplotësimit anashkalo adresa email alternative';
$labels['listnamedisplay'] = 'Kontaktet paraqiti si';
$labels['contactformmode'] = 'Mënyrë formulari kontaktesh';
$labels['privatemode'] = 'Privat (Shtëpie)';
$labels['businessmode'] = 'Biznes (Pune)';
$labels['collectedaddresses'] = 'Adresa të grumbulluara';
$labels['collectedrecipients'] = 'Marrës të Grumbulluar';
$labels['collectedrecipientsopt'] = 'Marrës email-esh të dërguar depozitoji në';
$labels['collectedsendersopt'] = 'Dërguesit e besuar depozitoji në';
$labels['trustedsenders'] = 'Dërgues të Besuar';
$labels['spellcheckbeforesend'] = 'Kontrollo drejtshkrimin para dërgimit të një mesazhi';
$labels['spellcheckoptions'] = 'Mundësi Kontrolli Drejtshkrimi';
$labels['spellcheckignoresyms'] = 'Shpërfilli fjalët me simbole';
$labels['spellcheckignorenums'] = 'Shpërfilli fjalët me numra';
$labels['spellcheckignorecaps'] = 'Shpërfilli fjalët me krejt shkronjat me të madhe';
$labels['addtodict'] = 'Shtoje në fjalor';
$labels['mailtoprotohandler'] = 'Regjistro trajtues protokolli për lidhje mailto:';
$labels['standardwindows'] = 'Flluskat trajtoji si dritare standarde';
$labels['forwardmode'] = 'Përcjellje mesazhesh';
$labels['inline'] = 'brendazi';
$labels['asattachment'] = 'si bashkëngjitje';
$labels['replyallmode'] = 'Veprim parazgjedhje për butonin [Përgjigju krejt]';
$labels['replyalldefault'] = 'përgjigju të tërëve';
$labels['replyalllist'] = 'përgjigju vetëm te listë postimesh (nëse gjendet e tillë)';
$labels['allmessages'] = 'krejt mesazhet';
$labels['olderxdays'] = 'më i vjetër se $x ditë';
$labels['folder'] = 'Dosje';
$labels['folders'] = 'Dosje';
$labels['foldername'] = 'Emër dosjeje';
$labels['subscribed'] = 'Regjistruar';
$labels['messagecount'] = 'Mesazhe';
$labels['create'] = 'Krijoje';
$labels['createfolder'] = 'Krijo dosje të re';
$labels['managefolders'] = 'Administroni dosje';
$labels['specialfolders'] = 'Dosje Speciale';
$labels['properties'] = 'Veti';
$labels['folderproperties'] = 'Veti dosjeje';
$labels['parentfolder'] = 'Dosje mëmë';
$labels['location'] = 'Vendndodhje';
$labels['info'] = 'Informacion';
$labels['getfoldersize'] = 'Klikoni që të kini madhësinë e dosjes';
$labels['changesubscription'] = 'Klikoni që të ndryshoni pajtimin';
$labels['foldertype'] = 'Lloj Dosjeje';
$labels['personalfolder'] = 'Dosje Private';
$labels['otherfolder'] = 'Dosje Përdoruesi Tjetër';
$labels['sharedfolder'] = 'Dosje Publike';
$labels['findfolders'] = 'Gjeni dosje';
$labels['findcontacts'] = 'Gjej kontakte';
$labels['findmail'] = 'Gjej mesazhe poste';
$labels['namespace.personal'] = 'Personale';
$labels['namespace.other'] = 'Përdorues të tjerë';
$labels['namespace.shared'] = 'E përbashkët';
$labels['dualuselabel'] = 'Mund të përmbajë vetëm';
$labels['dualusemail'] = 'mesazhe';
$labels['dualusefolder'] = 'dosje';
$labels['generate'] = 'Prodhoje';
$labels['encryptioncreatekey'] = 'Krijoni një çift të ri kyçesh';
$labels['openmailvelopesettings'] = 'Hapni Rregullime për Mailvelope';
$labels['encryptionprivkeysinmailvelope'] = 'Keni $nr kyçe privatë me përputhje të depozituar në vargun tuaj të kyçeve Mailvelope:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Identiteti i këtij dërguesi ende s’ka ndonjë kyç privat PGP të depozituar në zgjerimin tuaj Mailvelope. Do të donit të krijoni një që të mund të aktivizohet shkëmbim mesazhesh të fshehtëzuar?';
$labels['encryption'] = 'Fshehtëzim';
$labels['mailvelopeoptions'] = 'Mundësi Mailvelope';
$labels['mailvelopemainkeyring'] = 'Përdor varg kyçesh kryesor Mailvelope';
$labels['mailvelopenotfound'] = 'Zgjerimi Mailvelope s’është aktivizuar/instaluar në shfletuesin tuaj.';
$labels['sortby'] = 'Renditi sipas';
$labels['sortasc'] = 'Në rend rritës';
$labels['sortdesc'] = 'Në rend zbritës';
$labels['undo'] = 'Zhbëje';
$labels['installedplugins'] = 'Shtojca të instaluara';
$labels['plugin'] = 'Shtojcë';
$labels['version'] = 'Version';
$labels['source'] = 'Burim';
$labels['destination'] = 'Vendmbërritje';
$labels['license'] = 'Licencë';
$labels['support'] = 'Merrni asistencë';
$labels['savedsearches'] = 'Kërkime të ruajtura';
$labels['dateformatY'] = 'YYYY';
$labels['dateformaty'] = 'YY';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unikod';
$labels['english'] = 'Anglisht';
$labels['westerneuropean'] = 'Europiano-perëndimore';
$labels['easterneuropean'] = 'Europiano-lindore';
$labels['southeasterneuropean'] = 'Europiano-juglindore';
$labels['baltic'] = 'Baltike';
$labels['cyrillic'] = 'Cirilike';
$labels['arabic'] = 'Arabike';
$labels['greek'] = 'Greke';
$labels['hebrew'] = 'Hebraike';
$labels['turkish'] = 'Turke';
$labels['nordic'] = 'Nordike';
$labels['thai'] = 'Tajlandeze';
$labels['celtic'] = 'Celtike';
$labels['vietnamese'] = 'Vietnameze';
$labels['japanese'] = 'Japoneze';
$labels['korean'] = 'Koreane';
$labels['chinese'] = 'Kineze';
$labels['arialabeltopnav'] = 'Kontroll dritareje';
$labels['arialabeltasknav'] = 'Akte aplikacioni';
$labels['arialabeltoolbar'] = 'Panel aplikacioni';
$labels['arialabellistnav'] = 'Lëvizje në listë';
$labels['arialabelactivetask'] = 'Akte aktive';
$labels['arialabelmessagessearchfilter'] = 'Filtri i listës së ePostës';
$labels['arialabelmailsearchform'] = 'Formular kërkimi mesazhi email';
$labels['arialabelcontactsearchform'] = 'Formular kërkimi kontaktesh';
$labels['arialabelmailquicksearchbox'] = 'Fushë kërkimi email-i';
$labels['arialabelquicksearchbox'] = 'Fushë kërkimi';
$labels['arialabelfoldersearchfilter'] = 'Filtër lënde dosjeje';
$labels['arialabelfoldersearchform'] = 'Formular kërkimi dosjesh';
$labels['arialabelfolderlist'] = 'Përzgjedhje dosje email';
$labels['arialabelmessagelist'] = 'Shfaqje Mesazhesh Email';
$labels['arialabelmailpreviewframe'] = 'Paraparje mesazhi';
$labels['arialabelmailboxmenu'] = 'Menu veprimesh mbi dosje';
$labels['arialabellistselectmenu'] = 'Menu përzgjedhjeje liste';
$labels['arialabelthreadselectmenu'] = 'Menu paraqitje rrjedhash';
$labels['arialabelmessagelistoptions'] = 'Mundësi mbi shfaqje dhe renditje listash mesazhesh';
$labels['arialabelmailimportdialog'] = 'Dialog importimi mesazhesh';
$labels['arialabelmessagenav'] = 'Lëvizje te mesazhi';
$labels['arialabelmessagebody'] = 'Lëndë Mesazhi';
$labels['arialabelmessageactions'] = 'Veprime mbi mesazhe';
$labels['arialabelcontactquicksearch'] = 'Formular kërkimi kontaktesh';
$labels['arialabelcontactsearchbox'] = 'Fushë kërkimi kontaktesh';
$labels['arialabelmessageheaders'] = 'Krye mesazhi';
$labels['arialabelforwardingoptions'] = 'Mundësi përcjelljesh';
$labels['arialabelreplyalloptions'] = 'Mundësi për Përgjigju-krejt';
$labels['arialabelmoremessageactions'] = 'Më tepër veprime mbi mesazhe';
$labels['arialabelmorecontactactions'] = 'Më tepër veprime mbi kontakte';
$labels['arialabelmarkmessagesas'] = 'Mesazheve të përzgjedhur vëru shenjë si…';
$labels['arialabelcomposeoptions'] = 'Mundësi hartimi';
$labels['arialabelresponsesmenu'] = 'Menuja e përgjigjeve të parapërgatitura';
$labels['arialabelattachmentuploadform'] = 'Formular ngarkimi bashkëngjitjesh';
$labels['arialabelattachmentmenu'] = 'Mundësi bashkëngjitjesh';
$labels['arialabelmailtomenu'] = 'Mundësi adresash email';
$labels['arialabelattachmentpreview'] = 'Paraparje bashkëngjitjesh';
$labels['ariasummarycomposecontacts'] = 'Listë kontaktesh dhe grupesh për t’u përzgjedhur si marrës';
$labels['arialabelcontactexportoptions'] = 'Mundësi eksportimi kontaktesh';
$labels['arialabelabookgroupoptions'] = 'Mundësi libri adresash/grupi';
$labels['arialabelpreferencesform'] = 'Formular parapëlqimesh';
$labels['arialabelidentityeditfrom'] = 'Formular përpunimi identitetesh';
$labels['arialabelresponseeditfrom'] = 'Formular përpunimi përgjigjesh';
$labels['arialabelsearchterms'] = 'Terma kërkimi';
$labels['arialabeldropactionmenu'] = 'Menu veprimi Merr-dhe-Vër';
$labels['arialabelheadersmenu'] = 'Menu shtimi marrësi (krye)';
$labels['arialabelimagetools'] = 'Mjete figure';
$labels['helplistnavigation'] = 'Lëvizje me tastierë në lista';
$labels['helplistkeyboardnavigation'] = "Shigjeta sipër/poshtë: Zhvendosni fokusin/përzgjedhjen në rreshta.
Space: Përzgjidhni rreshtin që ka fokusin.
Shift + up/down: Përzgjidhni rreshta shtesë sipër/poshtë.
Ctrl + Space: Shtojeni rreshtin që ka fokusin te përzgjedhja/heqja nga përzgjedhja.";
$labels['helplistkeyboardnavmessages'] = "Shigjetat majtas/djathtas: zgjeroni/tkurrni rrjedhë mesazhesh (e vlefshme vetëm nën mënyrën rrjedhë).
Enter: Hapni mesazhin e përzgjedhur/atë që ka fokusin.
Delete: Shpjereni mesazhin e përzgjedhur te Hedhurinat.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Hapni kontaktin e përzgjedhur/atë që ka fokusin.";
