<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-newmail_notifier/
*/

$labels['basic'] = 'Dangos hysbysiadau porwr ar neges newydd';
$labels['desktop'] = 'Dangos hysbysiadau penbwrdd ar neges newydd';
$labels['sound'] = 'Chwarae sŵn ar neges newydd';
$labels['test'] = 'Prawf';
$labels['title'] = 'Ebost Newydd!';
$labels['body'] = 'Rydych wedi derbyn neges newydd.';
$labels['testbody'] = 'Hysbysiad prawf yw hwn.';
$labels['desktopdisabled'] = 'Mae hysbysiadau penbwrdd wedi ei analluogi yn eich porwr';
$labels['desktopunsupported'] = 'Nid yw eich porwr yn cefnogi hysbysiadau penbwrdd.';
$labels['desktoptimeout'] = 'Cau hysbysiad penbwrdd';
