<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Partekatzen';
$labels['myrights'] = 'Sarbide-eskubideak';
$labels['username'] = 'Erabiltzailea:';
$labels['advanced'] = 'Modu aurreratua';
$labels['add'] = 'Gehitu';
$labels['newuser'] = 'Gehitu sarrera';
$labels['editperms'] = 'Editatu baimenak';
$labels['actions'] = 'Sarbide-eskubideen ekintzak...';
$labels['anyone'] = 'Erabiltzaile guztiak (edozein)';
$labels['anonymous'] = 'Gonbidatuak (anonimo)';
$labels['identifier'] = 'Identifikatzailea';
$labels['acll'] = 'Bilatu';
$labels['aclr'] = 'Irakurri mezuak';
$labels['acls'] = 'Mantendu ikusita egoera';
$labels['aclw'] = 'Idatzi banderak';
$labels['acli'] = 'Txertatu (kopiatu barnean)';
$labels['aclp'] = 'Posta';
$labels['aclc'] = 'Sortu azpikarpetak';
$labels['aclk'] = 'Sortu azpikarpetak';
$labels['acld'] = 'Ezabatu mezuak';
$labels['aclt'] = 'Ezabatu mezuak';
$labels['acle'] = 'Kendu';
$labels['aclx'] = 'Ezabatu karpeta';
$labels['acla'] = 'Administratu';
$labels['acln'] = 'Idatzi mezuak';
$labels['aclfull'] = 'Kontrol osoa';
$labels['aclother'] = 'Beste';
$labels['aclread'] = 'Irakurri';
$labels['aclwrite'] = 'Idatzi';
$labels['acldelete'] = 'Ezabatu';
$labels['shortacll'] = 'Bilatu';
$labels['shortaclr'] = 'Irakurri';
$labels['shortacls'] = 'Mantendu';
$labels['shortaclw'] = 'Idatzi';
$labels['shortacli'] = 'Txertatu';
$labels['shortaclp'] = 'Bidali';
$labels['shortaclc'] = 'Sortu';
$labels['shortaclk'] = 'Sortu';
$labels['shortacld'] = 'Ezabatu';
$labels['shortaclt'] = 'Ezabatu';
$labels['shortacle'] = 'Kendu';
$labels['shortaclx'] = 'Ezabatu karpeta';
$labels['shortacla'] = 'Administratu';
$labels['shortacln'] = 'Idatzi';
$labels['shortaclother'] = 'Beste';
$labels['shortaclread'] = 'Irakurri';
$labels['shortaclwrite'] = 'Idatzi';
$labels['shortacldelete'] = 'Ezabatu';
$labels['longacll'] = 'Karpeta hau zerrendan ikusgai dago eta harpidetzen ahal zara';
$labels['longaclr'] = 'Karpeta ireki daiteke irakurtzeko';
$labels['longacls'] = 'Mezuen ikusita bandera aldatu daiteke';
$labels['longaclw'] = 'Mezuen banderak eta gako-hitzak alda daitezke, ikusita eta ezabatuta salbu';
$labels['longacli'] = 'Mezuak karpetara idatzi edo kopiatu daitezke';
$labels['longaclp'] = 'Mezuak bidali daitezke karpeta honetara';
$labels['longaclc'] = 'Karpetak sor daitezke (edo berrizendatu) zuzenean karpeta honetan';
$labels['longaclk'] = 'Karpetak sor daitezke (edo berrizendatu) karpeta honetan';
$labels['longacld'] = 'Mezuen ezabatu bandera alda daiteke';
$labels['longaclt'] = 'Mezuen ezabatu bandera alda daiteke';
$labels['longacle'] = 'Mezuak betiko ezaba daitezke';
$labels['longaclx'] = 'Karpeta ezaba edo berrizenda daiteke';
$labels['longacla'] = 'Karpetaren sarbide eskubideak alda daitezke';
$labels['longacln'] = 'Partekatutatko mezuen metadatuak (oharrak) alda daitezke';
$labels['longaclfull'] = 'Kontrol osoa, karpetaren administrazioa barne';
$labels['longaclread'] = 'Karpeta ireki daiteke irakurtzeko';
$labels['longaclwrite'] = 'Mezuak marka, idatzi edo kopia daitezke karpetara';
$labels['longacldelete'] = 'Mezuak ezaba daitezke';
$labels['longaclother'] = 'Beste sarbide-eskubideak';
$labels['ariasummaryacltable'] = 'Sarbide-eskubideen zerrenda';
$labels['arialabelaclactions'] = 'Zerrendatu ekintzak';
$labels['arialabelaclform'] = 'Sarbide-eskubideen formularioa';
$messages['deleting'] = 'Sarbide-eskubideak ezabatzen...';
$messages['saving'] = 'Sarbide-eskubideak gordetzen...';
$messages['updatesuccess'] = 'Sarbide-eskubideak ongi aldatu dira';
$messages['deletesuccess'] = 'Sarbide-eskubideak ongi ezabatu dira';
$messages['createsuccess'] = 'Sarbide-eskubideak ongi gehitu dira';
$messages['updateerror'] = 'Ezin dira eguneratu sarbide-eskubideak';
$messages['deleteerror'] = 'Ezin dira ezabatu sarbide-eskubideak';
$messages['createerror'] = 'Ezin dira gehitu sarbide-eskubideak';
$messages['deleteconfirm'] = 'Seguru zaude hautatutako erabiltzaile(ar)en sarbide-eskubideak ezabatu nahi duzula?';
$messages['norights'] = 'Eskubideak ez dira zehaztu!';
$messages['nouser'] = 'Erabiltzaile-izana ez da zehaztu!';
