<?php

// autoload_namespaces.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Roundcube\\Composer' => array($vendorDir . '/roundcube/plugin-installer/src'),
    'Net' => array($vendorDir . '/pear/net_socket', $vendorDir . '/pear/net_smtp'),
    'Mail' => array($vendorDir . '/pear/mail_mime'),
    'Console' => array($vendorDir . '/pear/console_getopt', $vendorDir . '/pear/console_commandline'),
    'Auth' => array($vendorDir . '/pear/auth_sasl'),
    '' => array($vendorDir . '/pear/pear-core-minimal/src'),
);
