<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Witamy w $product';
$labels['username'] = 'Nazwa użytkownika';
$labels['password'] = 'Hasło';
$labels['server'] = 'Serwer';
$labels['login'] = 'Zaloguj';
$labels['oauthlogin'] = 'Zaloguj z $provider';
$labels['menu'] = 'Menu';
$labels['logout'] = 'Wyloguj';
$labels['mail'] = 'Poczta';
$labels['settings'] = 'Ustawienia';
$labels['addressbook'] = 'Książka adresowa';
$labels['darkmode'] = 'Tryb ciemny';
$labels['lightmode'] = 'Tryb jasny';
$labels['inbox'] = 'Odebrane';
$labels['drafts'] = 'Kopie robocze';
$labels['sent'] = 'Wysłane';
$labels['trash'] = 'Kosz';
$labels['junk'] = 'Spam';
$labels['show_real_foldernames'] = 'Pokaż prawdziwe nazwy dla folderów specjalnych';
$labels['subject'] = 'Temat';
$labels['from'] = 'Od';
$labels['sender'] = 'Nadawca';
$labels['to'] = 'Do';
$labels['cc'] = 'Kopia';
$labels['bcc'] = 'Ukryta kopia';
$labels['replyto'] = 'Odpowiedź do';
$labels['followupto'] = 'Kontynuacja do';
$labels['date'] = 'Data';
$labels['size'] = 'Rozmiar';
$labels['priority'] = 'Priorytet';
$labels['organization'] = 'Organizacja';
$labels['readstatus'] = 'Przeczytano';
$labels['listoptions'] = 'Opcje listy...';
$labels['listoptionstitle'] = 'Opcje listy';
$labels['mailboxlist'] = 'Foldery';
$labels['messagesfromto'] = 'Wiadomości od $from do $to z $count';
$labels['threadsfromto'] = 'Wątki od $from do $to z $count';
$labels['messagenrof'] = 'Wiadomość $nr z $count';
$labels['fromtoshort'] = '$from - $to z $count';
$labels['copy'] = 'Kopiuj';
$labels['move'] = 'Przenieś';
$labels['moveto'] = 'Przenieś do...';
$labels['copyto'] = 'Kopiuj do...';
$labels['download'] = 'Pobierz';
$labels['open'] = 'Otwórz';
$labels['showattachment'] = 'Pokaż';
$labels['showanyway'] = 'Pokaż';
$labels['filename'] = 'Nazwa pliku';
$labels['filesize'] = 'Rozmiar pliku';
$labels['addtoaddressbook'] = 'Dodaj do książki adresowej';
$labels['sun'] = 'Nd';
$labels['mon'] = 'Pn';
$labels['tue'] = 'Wt';
$labels['wed'] = 'Śr';
$labels['thu'] = 'Czw';
$labels['fri'] = 'Pt';
$labels['sat'] = 'Sb';
$labels['sunday'] = 'Niedziela';
$labels['monday'] = 'Poniedziałek';
$labels['tuesday'] = 'Wtorek';
$labels['wednesday'] = 'Środa';
$labels['thursday'] = 'Czwartek';
$labels['friday'] = 'Piątek';
$labels['saturday'] = 'Sobota';
$labels['jan'] = 'Sty';
$labels['feb'] = 'Lut';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Kwi';
$labels['may'] = 'Maj';
$labels['jun'] = 'Cze';
$labels['jul'] = 'Lip';
$labels['aug'] = 'Sie';
$labels['sep'] = 'Wrz';
$labels['oct'] = 'Paź';
$labels['nov'] = 'Lis';
$labels['dec'] = 'Gru';
$labels['longjan'] = 'styczeń';
$labels['longfeb'] = 'luty';
$labels['longmar'] = 'marzec';
$labels['longapr'] = 'kwiecień';
$labels['longmay'] = 'maj';
$labels['longjun'] = 'czerwiec';
$labels['longjul'] = 'lipiec';
$labels['longaug'] = 'sierpień';
$labels['longsep'] = 'wrzesień';
$labels['longoct'] = 'październik';
$labels['longnov'] = 'listopad';
$labels['longdec'] = 'grudzień';
$labels['today'] = 'Dzisiaj';
$labels['refresh'] = 'Odśwież';
$labels['checkmail'] = 'Sprawdź skrzynkę';
$labels['compose'] = 'Utwórz';
$labels['writenewmessage'] = 'Utwórz nową wiadomość';
$labels['reply'] = 'Odpowiedz';
$labels['replytomessage'] = 'Odpowiedz nadawcy';
$labels['replytoallmessage'] = 'Odpowiedz wszystkim';
$labels['replyall'] = 'Odpowiedz wszystkim';
$labels['replylist'] = 'Odpowiedz na listę';
$labels['forward'] = 'Przekaż';
$labels['forwardinline'] = 'Prześlij w treści';
$labels['forwardattachment'] = 'Prześlij jako załącznik';
$labels['forwardmessage'] = 'Prześlij dalej';
$labels['bouncemsg'] = 'Prześlij ponownie (odbij)';
$labels['bounce'] = 'Prześlij ponownie';
$labels['deletemessage'] = 'Usuń wiadomości';
$labels['movemessagetotrash'] = 'Przenieś wiadomości do Kosza';
$labels['printmessage'] = 'Drukuj wiadomość';
$labels['previousmessage'] = 'Poprzednia wiadomość';
$labels['firstmessage'] = 'Pierwsza wiadomość';
$labels['nextmessage'] = 'Następna wiadomość';
$labels['lastmessage'] = 'Ostatnia wiadomość';
$labels['backtolist'] = 'Pokaż listę wiadomości';
$labels['viewsource'] = 'Pokaż źródło';
$labels['mark'] = 'Oznacz';
$labels['markmessages'] = 'Oznacz wiadomości';
$labels['markread'] = 'Jako przeczytane';
$labels['markunread'] = 'Jako nieprzeczytane';
$labels['markflagged'] = 'Jako oflagowane';
$labels['markunflagged'] = 'Jako nieoflagowane';
$labels['moreactions'] = 'Więcej akcji...';
$labels['markallread'] = 'Oznacz wszystkie jako przeczytane';
$labels['folders-cur'] = 'Tylko wybrany folder';
$labels['folders-sub'] = 'Wybrany folder i podfoldery';
$labels['folders-all'] = 'Wszystkie foldery';
$labels['more'] = 'Więcej';
$labels['back'] = 'Wstecz';
$labels['options'] = 'Opcje';
$labels['composeoptions'] = 'Opcje';
$labels['optionsandattachments'] = 'Opcje i załączniki';
$labels['actions'] = 'Akcje';
$labels['first'] = 'Pierwsza';
$labels['last'] = 'Ostatnia';
$labels['previous'] = 'Poprzednia';
$labels['next'] = 'Następna';
$labels['select'] = 'Zaznacz';
$labels['selection'] = 'Zaznaczenie';
$labels['all'] = 'Wszystkie';
$labels['none'] = 'Brak';
$labels['currpage'] = 'Bieżąca strona';
$labels['isread'] = 'Przeczytane';
$labels['unread'] = 'Nieprzeczytane';
$labels['flagged'] = 'Oznaczone';
$labels['unflagged'] = 'Nieoznaczone';
$labels['unanswered'] = 'Bez odpowiedzi';
$labels['withattachment'] = 'Z załącznikiem';
$labels['deleted'] = 'Usunięte';
$labels['undeleted'] = 'Nieusunięte';
$labels['replied'] = 'Odpowiedziana';
$labels['forwarded'] = 'Przekazane';
$labels['invert'] = 'Odwróć';
$labels['filter'] = 'Filtr';
$labels['list'] = 'Lista';
$labels['threads'] = 'Wątki';
$labels['expand-all'] = 'Rozwiń wszystkie';
$labels['expand-unread'] = 'Rozwiń nieprzeczytane';
$labels['collapse-all'] = 'Zwiń wszystkie';
$labels['threaded'] = 'Powątkowane';
$labels['showunread'] = 'Pokaż nieprzeczytane';
$labels['autoexpand_threads'] = 'Rozwijaj wątki';
$labels['do_expand'] = 'wszystkie';
$labels['expand_only_unread'] = 'tylko nieprzeczytane';
$labels['fromto'] = 'Od/Do';
$labels['flag'] = 'Flaga';
$labels['attachment'] = 'Załącznik';
$labels['nonesort'] = 'Brak';
$labels['sentdate'] = 'Data wysyłki';
$labels['arrival'] = 'Data odbioru';
$labels['asc'] = 'rosnąco';
$labels['desc'] = 'malejąco';
$labels['listcolumns'] = 'Kolumny';
$labels['listsorting'] = 'Porządek sortowania';
$labels['listorder'] = 'Kierunek sortowania';
$labels['listmode'] = 'Typ listy';
$labels['lmode'] = 'Rodzaj listy';
$labels['layout'] = 'Układ';
$labels['layoutwidescreen'] = 'Szeroki ekran';
$labels['layoutdesktop'] = 'Pulpit';
$labels['layoutlist'] = 'Lista';
$labels['layoutwidescreendesc'] = 'Szeroki ekran (widok 3-kolumnowy)';
$labels['layoutdesktopdesc'] = 'Pulpit (szeroka lista i podgląd wiadomości poniżej)';
$labels['layoutlistdesc'] = 'Lista (bez podglądu wiadomości)';
$labels['folderactions'] = 'Działania na folderach...';
$labels['compact'] = 'Porządkuj';
$labels['empty'] = 'Opróżnij';
$labels['importmessages'] = 'Import wiadomości';
$labels['mailimportdesc'] = 'Możesz zaimportować pliki w formacie <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> lub <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>.';
$labels['mailimportzip'] = 'Wiele plików może być skompresowane przy użyciu archiwum zip.';
$labels['quota'] = 'Użyte miejsce';
$labels['unknown'] = 'nieznane';
$labels['unlimited'] = 'bez limitu';
$labels['quotatype'] = 'Typ limitu';
$labels['quotatotal'] = 'Ograniczenie';
$labels['quotaused'] = 'Używany';
$labels['quotastorage'] = 'Przestrzeń dyskowa';
$labels['quotamessage'] = 'Ilość wiadomości';
$labels['shortheaderdate'] = 'W dniu $date';
$labels['shortheaderto'] = 'Do $to w dniu $date';
$labels['shortheaderfrom'] = 'Od $from w dniu $date';
$labels['quicksearch'] = 'Szybkie wyszukiwanie';
$labels['searchplaceholder'] = 'Szukaj...';
$labels['resetsearch'] = 'Wyczyść filtr';
$labels['searchmod'] = 'Parametry wyszukiwania';
$labels['msgtext'] = 'Cała wiadomość';
$labels['body'] = 'Treść';
$labels['type'] = 'Typ';
$labels['namex'] = 'Nazwa';
$labels['searchscope'] = 'Zakres';
$labels['currentfolder'] = 'Bieżący folder';
$labels['subfolders'] = 'Ten i podfoldery';
$labels['allfolders'] = 'Wszystkie foldery';
$labels['searchinterval-1W'] = 'starsza niż tydzień';
$labels['searchinterval-1M'] = 'starsza niż miesiąc';
$labels['searchinterval-1Y'] = 'starsza niż rok';
$labels['searchinterval1W'] = 'młodsza niż tydzień';
$labels['searchinterval1M'] = 'młodsza niż miesiąc';
$labels['searchinterval1Y'] = 'młodsza niż rok';
$labels['openinextwin'] = 'Otwórz w nowym oknie';
$labels['emlsave'] = 'Pobierz (.eml)';
$labels['changeformattext'] = 'Wyświetl w formacie tekstowym';
$labels['changeformathtml'] = 'Wyświetl w formacie HTML';
$labels['editasnew'] = 'Edytuj jako nową';
$labels['send'] = 'Wyślij';
$labels['sendmessage'] = 'Wyślij teraz';
$labels['savemessage'] = 'Zapisz kopię roboczą';
$labels['addattachment'] = 'Dołącz plik';
$labels['charset'] = 'Kodowanie znaków';
$labels['editortype'] = 'Typ edytora';
$labels['returnreceipt'] = 'Potwierdzenie odbioru';
$labels['dsn'] = 'Status dostarczenia (DSN)';
$labels['mailreplyintro'] = 'W dniu $date, $sender napisał(a):';
$labels['originalmessage'] = 'Wiadomość oryginalna';
$labels['selectimage'] = 'Wybierz obraz';
$labels['addimage'] = 'Dodaj obraz';
$labels['selectmedia'] = 'Wybierz film';
$labels['addmedia'] = 'Dodaj film';
$labels['encrypt'] = 'Szyfrowanie';
$labels['encryptmessage'] = 'Szyfruj wiadomość';
$labels['encryptmessagemailvelope'] = 'Szyfruj wiadomość używając Mailvelope';
$labels['importpubkeys'] = 'Importuj klucze publiczne';
$labels['encryptedsendialog'] = 'Wysyłanie zaszyfrowanej wiadomości';
$labels['encryptandsign'] = 'Szyfruj i podpisz';
$labels['keyid'] = 'ID Klucza';
$labels['keylength'] = 'Bitów';
$labels['keyexpired'] = 'Przedawniony';
$labels['keyrevoked'] = 'Unieważniony';
$labels['bccinstead'] = 'Użyj Bcc';
$labels['addheader'] = 'Dodaj odbiorcę (nagłówek)';
$labels['insert'] = 'Wstaw';
$labels['insertcontact'] = 'Wstaw kontakt(y)';
$labels['recipient'] = 'Odbiorca';
$labels['recipientedit'] = 'Edycja odbiorcy';
$labels['editidents'] = 'Edytuj tożsamości';
$labels['spellcheck'] = 'Pisownia';
$labels['checkspelling'] = 'Sprawdź pisownię';
$labels['resumeediting'] = 'Zakończ sprawdzanie pisowni';
$labels['revertto'] = 'Powróć do';
$labels['restore'] = 'Przywróć';
$labels['restoremessage'] = 'Przyrócić wiadomość?';
$labels['ignore'] = 'Ignoruj';
$labels['responses'] = 'Odpowiedzi';
$labels['insertresponse'] = 'Wstaw odpowiedź';
$labels['manageresponses'] = 'Zarządzaj odpowiedziami';
$labels['newresponse'] = 'Utwórz nową odpowiedź';
$labels['addresponse'] = 'Dodaj odpowiedź';
$labels['editresponse'] = 'Edytuj odpowiedź';
$labels['editresponses'] = 'Edytuj odpowiedzi';
$labels['responsename'] = 'Nazwa';
$labels['responsetext'] = 'Tekst odpowiedzi';
$labels['attach'] = 'Załącz';
$labels['attachments'] = 'Załączniki';
$labels['upload'] = 'Prześlij';
$labels['uploadprogress'] = '$percent ($current z $total)';
$labels['close'] = 'Zamknij';
$labels['messageoptions'] = 'Opcje wiadomości...';
$labels['togglecomposeoptions'] = 'Przestaw opcje kompozycji';
$labels['attachmentrename'] = 'Zmiana nazwy załącznika';
$labels['low'] = 'Niski';
$labels['lowest'] = 'Bardzo niski';
$labels['normal'] = 'Normalny';
$labels['high'] = 'Wysoki';
$labels['highest'] = 'Bardzo wysoki';
$labels['nosubject'] = '(brak tematu)';
$labels['showimages'] = 'Wyświetl obrazki';
$labels['allow'] = 'Zezwól';
$labels['alwaysshow'] = 'Zawsze wyświetlaj obrazki od $sender';
$labels['alwaysallow'] = 'Zawsze zezwalaj od $sender';
$labels['isdraft'] = 'To jest kopia robocza wiadomości.';
$labels['andnmore'] = '$nr więcej...';
$labels['details'] = 'Szczegóły';
$labels['summary'] = 'Ogólne';
$labels['headers'] = 'Nagłówki';
$labels['allheaders'] = 'Wszystkie nagłówki...';
$labels['togglemoreheaders'] = 'Pokaż więcej nagłówków wiadomości';
$labels['togglefullheaders'] = 'Przełącz podgląd nagłówków wiadomości';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Zwykły tekst';
$labels['savesentmessagein'] = 'Zapisz wiadomość w';
$labels['dontsave'] = 'nie zapisuj';
$labels['maxuploadsize'] = 'Maksymalny rozmiar pliku to $size';
$labels['addcc'] = 'Dodaj Cc';
$labels['addbcc'] = 'Dodaj Bcc';
$labels['addreplyto'] = 'Dodaj Reply-To';
$labels['addfollowupto'] = 'Dodaj Followup-To';
$labels['sendreceipt'] = 'Wysłać potwierdzenie odbioru?';
$labels['mdnrequest'] = 'Nadawca zażądał potwierdzenia przeczytania tej wiadomości. Czy chcesz go powiadomić?';
$labels['receiptread'] = 'Potwierdzenie otrzymania';
$labels['yourmessage'] = 'To jest potwierdzenie dostarczenia Twojej wiadomości';
$labels['receiptnote'] = 'Uwaga: To potwierdzenie dostarczenia wiadomości oznacza tylko, że wiadomość została wyświetlona na komputerze adresata. Nie ma żadnej gwarancji, że odbiorca przeczytał czy też zrozumiał treść wiadomości.';
$labels['sendalwaysto'] = 'Zawsze wysyłaj do $email';
$labels['zoomin'] = 'Zwiększ';
$labels['zoomout'] = 'Zmniejsz';
$labels['rotate'] = 'Obróć';
$labels['increaseimage'] = 'Zwiększ rozmiar obrazu';
$labels['decreaseimage'] = 'Zmniejsz rozmiar obrazu';
$labels['rotateimage'] = 'Obróć obraz';
$labels['showtools'] = 'Pokaż narzędzia obrazu';
$labels['hidetools'] = 'Ukryj narzędzia obrazu';
$labels['name'] = 'Nazwa wyświetlana';
$labels['firstname'] = 'Imię';
$labels['surname'] = 'Nazwisko';
$labels['middlename'] = 'Drugie imię';
$labels['nameprefix'] = 'Prefiks';
$labels['namesuffix'] = 'Sufiks';
$labels['nickname'] = 'Pseudonim';
$labels['jobtitle'] = 'Zawód';
$labels['department'] = 'Oddział';
$labels['gender'] = 'Płeć';
$labels['maidenname'] = 'N. panieńskie';
$labels['email'] = 'E-Mail';
$labels['phone'] = 'Telefon';
$labels['address'] = 'Adres';
$labels['street'] = 'Ulica';
$labels['locality'] = 'Miasto';
$labels['zipcode'] = 'Kod';
$labels['region'] = 'Region';
$labels['country'] = 'Kraj';
$labels['birthday'] = 'Urodziny';
$labels['anniversary'] = 'Jubileusz';
$labels['website'] = 'Strona internetowa';
$labels['instantmessenger'] = 'Komunikator';
$labels['notes'] = 'Notatki';
$labels['male'] = 'mężczyzna';
$labels['female'] = 'kobieta';
$labels['manager'] = 'Kierownik';
$labels['assistant'] = 'Asystent';
$labels['spouse'] = 'Małżonek';
$labels['allfields'] = 'Wszystkie pola';
$labels['search'] = 'Szukaj';
$labels['searchresult'] = 'Wyniki wyszukiwania';
$labels['advsearch'] = 'Wyszukiwanie zaawansowane';
$labels['advanced'] = 'Zaawansowane';
$labels['other'] = 'Inne';
$labels['printcontact'] = 'Drukuj Kontakt';
$labels['qrcode'] = 'Kod QR';
$labels['typehome'] = 'Dom';
$labels['typework'] = 'Praca';
$labels['typeother'] = 'Inne';
$labels['typemobile'] = 'Komórkowy';
$labels['typemain'] = 'Główny';
$labels['typehomefax'] = 'Fax domowy';
$labels['typeworkfax'] = 'Fax firmowy';
$labels['typecar'] = 'Samochód';
$labels['typepager'] = 'Pager';
$labels['typevideo'] = 'Wideo';
$labels['typeassistant'] = 'Asystent';
$labels['typehomepage'] = 'Strona domowa';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Dodaj pole...';
$labels['addcontact'] = 'Dodaj kontakt';
$labels['editcontact'] = 'Edytuj kontakt';
$labels['contacts'] = 'Kontakty';
$labels['contactproperties'] = 'Właściwości';
$labels['contactnameandorg'] = 'Nazwa i organizacja';
$labels['personalinfo'] = 'Informacje osobiste';
$labels['personal'] = 'Osobiste';
$labels['contactphoto'] = 'Zdjęcie kontaktu';
$labels['edit'] = 'Edytuj';
$labels['cancel'] = 'Anuluj';
$labels['save'] = 'Zapisz';
$labels['delete'] = 'Usuń';
$labels['discard'] = 'Odrzuć';
$labels['continue'] = 'Kontynuuj';
$labels['ok'] = 'OK';
$labels['rename'] = 'Zmień nazwę';
$labels['addphoto'] = 'Dodaj';
$labels['replacephoto'] = 'Zamień';
$labels['uploadphoto'] = 'Wyślij zdjęcie';
$labels['choosefile'] = 'Wybierz plik...';
$labels['choosefiles'] = 'Wybierz pliki...';
$labels['browse'] = 'Przeglądaj';
$labels['newcontact'] = 'Dodaj nowy kontakt';
$labels['deletecontact'] = 'Usuń zaznaczone kontakty';
$labels['composeto'] = 'Utwórz wiadomość do wybranych kontaktów';
$labels['contactsfromto'] = 'Kontakty od $from do $to z $count';
$labels['print'] = 'Drukuj';
$labels['export'] = 'Eksportuj';
$labels['exportall'] = 'Eksportuj wszystkie';
$labels['exportsel'] = 'Eksportuj zaznaczone';
$labels['exportvcards'] = 'Eksport kontaktów w formacie vCard';
$labels['newgroup'] = 'Utwórz nową grupę';
$labels['addgroup'] = 'Dodaj grupę';
$labels['grouprename'] = 'Zmień nazwę grupy';
$labels['groupdelete'] = 'Usuń grupę';
$labels['groupassign'] = 'Przypisz do grupy...';
$labels['groupremove'] = 'Usuń z grupy';
$labels['groupremoveselected'] = 'Usuń wybrane kontakty z grupy';
$labels['uponelevel'] = 'Jeden poziom w górę';
$labels['previouspage'] = 'Poprzednia strona';
$labels['firstpage'] = 'Pierwsza strona';
$labels['nextpage'] = 'Następna strona';
$labels['lastpage'] = 'Ostatnia strona';
$labels['group'] = 'Grupa';
$labels['groups'] = 'Grupy';
$labels['listgroup'] = 'Członkowie grupy';
$labels['personaladrbook'] = 'Kontakty osobiste';
$labels['searchsave'] = 'Zapisz wyszukiwanie';
$labels['searchdelete'] = 'Usuń wyszukiwanie';
$labels['import'] = 'Importuj';
$labels['importcontacts'] = 'Import kontaktów';
$labels['importfromfile'] = 'Import z pliku';
$labels['importtarget'] = 'Dodaj kontakty do';
$labels['importreplace'] = 'Zastąp całą książkę adresową';
$labels['importgroups'] = 'Importuj powiązania z grupami';
$labels['importgroupsall'] = 'Wszystkie (utwórz grupy jeśli potrzeba)';
$labels['importgroupsexisting'] = 'Tylko do isniejących grup';
$labels['importdesc'] = 'Możesz zaimportować kontakty z istniejącej książki adresowej.<br/>Obecnie wspierany jest format <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> lub CSV (dane odzielone przecinkami).';
$labels['importmapdesc'] = 'Przed przystąpieniem do importu danych w formacie CSV potwierdź poprawność powiązania pól.';
$labels['fieldnotmapped'] = 'Pole niepowiązane (pomiń)';
$labels['skipheader'] = 'Nie importuj pierwszej linii (nagłówki)';
$labels['done'] = 'Wykonane';
$labels['settingsfor'] = 'Ustawienia dla';
$labels['about'] = 'O programie';
$labels['preferences'] = 'Preferencje';
$labels['userpreferences'] = 'Preferencje użytkownika';
$labels['editpreferences'] = 'Edytuj preferencje';
$labels['identities'] = 'Tożsamości';
$labels['manageidentities'] = 'Zarządzaj tożsamościami';
$labels['newidentity'] = 'Utwórz nową tożsamość';
$labels['addidentity'] = 'Dodaj tożsamość';
$labels['editidentity'] = 'Edytuj tożsamości';
$labels['identityencryption'] = 'Szyfrowanie';
$labels['preferhtml'] = 'Domyślny HTML';
$labels['defaultcharset'] = 'Domyślny zestaw znaków';
$labels['htmlmessage'] = 'Wiadomość HTML';
$labels['messagepart'] = 'Część';
$labels['digitalsig'] = 'Podpis cyfrowy';
$labels['dateformat'] = 'Format daty';
$labels['timeformat'] = 'Format czasu';
$labels['prettydate'] = 'Ładne daty';
$labels['setdefault'] = 'Domyślna';
$labels['autodetect'] = '- wybór automatyczny -';
$labels['language'] = 'Język';
$labels['timezone'] = 'Strefa czasowa';
$labels['pagesize'] = 'Liczba wierszy na stronie';
$labels['signature'] = 'Podpis';
$labels['dstactive'] = 'Czas letni';
$labels['showinextwin'] = 'Otwórz wiadomość w nowym oknie';
$labels['composeextwin'] = 'Twórz w nowym oknie';
$labels['htmleditor'] = 'Twórz wiadomości HTML';
$labels['htmlonreply'] = 'tylko w odpowiedzi na wiadomość HTML';
$labels['htmlonreplyandforward'] = 'podczas przesyłania dalej lub odpowiedzi na wiadomość HTML';
$labels['htmlsignature'] = 'Podpis w HTML';
$labels['showemail'] = 'Pokazuj adres e-mail wraz z nazwą/opisem';
$labels['previewpane'] = 'Pokaż podgląd wiadomości';
$labels['skin'] = 'Wygląd interfejsu';
$labels['logoutclear'] = 'Przy wylogowaniu opróżnij Kosz';
$labels['logoutcompact'] = 'Przy wylogowaniu porządkuj folder Odebrane';
$labels['uisettings'] = 'Interfejs użytkownika';
$labels['serversettings'] = 'Ustawienia serwera';
$labels['mailboxview'] = 'Widok skrzynki pocztowej';
$labels['mdnrequests'] = 'Na żądanie potwierdzenia odbioru';
$labels['askuser'] = 'pytaj mnie';
$labels['autosend'] = 'wyślij potwierdzenie';
$labels['autosendknown'] = 'wyślij potwierdzenie tylko do moich kontaktów, pytaj o pozostałe';
$labels['autosendknownignore'] = 'wyślij potwierdzenie tylko do moich kontaktów, pozostałe ignoruj';
$labels['autosendtrusted'] = 'wyślij do zaufanych nadawców, w innych przypadkach pytaj';
$labels['autosendtrustedignore'] = 'wyślij do zaufanych nadawców, w innych przypadkach ignoruj';
$labels['ignorerequest'] = 'ignoruj żądanie';
$labels['readwhendeleted'] = 'Podczas usuwania oznacz wiadomość jako przeczytaną';
$labels['flagfordeletion'] = 'Oznacz wiadomość do usunięcia zamiast ją usuwać';
$labels['skipdeleted'] = 'Ukryj wiadomości oznaczone do usunięcia';
$labels['deletealways'] = 'Usuń wiadomości, gdy przenoszenie do Kosza zawiedzie';
$labels['deletejunk'] = 'Kasuj wiadomości bezpośrednio w folderze Spam';
$labels['showremoteimages'] = 'Wyświetlaj obrazki w wiadomościach';
$labels['allowremoteresources'] = 'Zezwól na zdalne zasoby (obrazki, style)';
$labels['fromknownsenders'] = 'od znanych nadawców';
$labels['fromtrustedsenders'] = 'od zaufanych nadawców';
$labels['frommycontacts'] = 'od moich kontaktów';
$labels['always'] = 'zawsze';
$labels['alwaysbutplain'] = 'zawsze, za wyjątkiem odpowiedzi na zwykły tekst.';
$labels['showinlineimages'] = 'Wyświetlaj załączone obrazki pod treścią wiadomości';
$labels['autosavedraft'] = 'Automatycznie zapisuj tworzoną wiadomość';
$labels['everynminutes'] = 'co $n minut(y)';
$labels['refreshinterval'] = 'Odświeżanie (sprawdzanie nowych wiadomości, etc.)';
$labels['never'] = 'nigdy';
$labels['immediately'] = 'natychmiast';
$labels['messagesdisplaying'] = 'Wyświetlanie wiadomości';
$labels['messagescomposition'] = 'Tworzenie wiadomości';
$labels['mimeparamfolding'] = 'Stosuj nazwy załączników zgodne z';
$labels['2231folding'] = 'RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'RFC 2047 (przestarzałe)';
$labels['force7bit'] = 'Używaj kodowania MIME dla znaków 8-bitowych';
$labels['savelocalstorage'] = "Zapisz w lokalnej bazie przeglądarki (tymczasowo)";
$labels['advancedoptions'] = 'Opcje zaawansowane';
$labels['toggleadvancedoptions'] = 'Pokaż/ukryj opcje zaawansowane';
$labels['focusonnewmessage'] = 'Informuj przeglądarkę o nowej wiadomości';
$labels['checkallfolders'] = 'Sprawdzaj czy nadeszły nowe wiadomości we wszystkich folderach';
$labels['displaynext'] = 'Po usunięciu elementu listy wyświetl następny';
$labels['defaultfont'] = 'Czcionka wiadomości HTML';
$labels['mainoptions'] = 'Opcje główne';
$labels['browseroptions'] = 'Opcje przeglądarki';
$labels['section'] = 'Sekcja';
$labels['maintenance'] = 'Konserwacja';
$labels['newmessage'] = 'Nowa wiadomość';
$labels['signatureoptions'] = 'Opcje podpisów';
$labels['whenreplying'] = 'Podczas odpowiadania rozpocznij wiadomość';
$labels['replyempty'] = 'nie cytuj oryginalnej wiadomości';
$labels['replytopposting'] = 'powyżej cytowanej treści';
$labels['replytoppostingnoindent'] = 'Zacznij nową wiadomość ponad cytowaną treścią (brak wcięcia)';
$labels['replybottomposting'] = 'poniżej cytowanej treści';
$labels['replyremovesignature'] = 'Podczas odpowiedzi usuń podpis z cytowanej treści';
$labels['autoaddsignature'] = 'Automatycznie wstaw podpis';
$labels['newmessageonly'] = 'tylko dla nowych wiadomości';
$labels['replyandforwardonly'] = 'tylko dla przekazywania i odpowiedzi';
$labels['insertsignature'] = 'Wstaw podpis';
$labels['sigbelow'] = 'Umieść podpis poniżej cytowanej wiadomości';
$labels['sigseparator'] = 'Wymuś standardowy separator w podpisie';
$labels['automarkread'] = 'Oznacz wiadomości jako przeczytane';
$labels['afternseconds'] = 'po $n sekundach';
$labels['reqmdn'] = 'Zawsze żądaj potwierdzenia odbioru';
$labels['reqdsn'] = 'Zawsze żądaj statusu dostarczenia (DSN)';
$labels['replysamefolder'] = 'Umieszczaj odpowiedzi w folderze wiadomości, na którą odpowiadam';
$labels['defaultabook'] = 'Domyślna książka adresowa';
$labels['autocompletesingle'] = 'Nie pokazuj alternatywnych adresów przy autouzupełnianiu';
$labels['listnamedisplay'] = 'Wyświetl kontakty jako';
$labels['contactformmode'] = 'Tryb formularza kontaktu';
$labels['privatemode'] = 'Osobisty (Dom)';
$labels['businessmode'] = 'Firmowy (Praca)';
$labels['collectedaddresses'] = 'Zebrane adresy';
$labels['collectedrecipients'] = 'Zebrani adresaci';
$labels['collectedrecipientsopt'] = 'Zapisuj adresatów poczty do';
$labels['collectedsendersopt'] = 'Zapisuj zaufanych nadawców do';
$labels['trustedsenders'] = 'Zaufani nadawcy';
$labels['spellcheckbeforesend'] = 'Przed wysłaniem wiadomości sprawdzaj pisownię';
$labels['spellcheckoptions'] = 'Opcje sprawdzania pisowni';
$labels['spellcheckignoresyms'] = 'Ignoruj słowa zawierające symbole';
$labels['spellcheckignorenums'] = 'Ignoruj słowa zawierające cyfry';
$labels['spellcheckignorecaps'] = 'Ignoruj słowa pisane wielkimi literami';
$labels['addtodict'] = 'Dodaj do słownika';
$labels['mailtoprotohandler'] = 'Zainstaluj obsługę linków mailto:';
$labels['standardwindows'] = 'Traktuj okna wyskakujące jako standardowe okna';
$labels['forwardmode'] = 'Przekazywanie wiadomości';
$labels['inline'] = 'w treści';
$labels['asattachment'] = 'jako załącznik';
$labels['replyallmode'] = 'Domyśla akcja przycisku [Odpowiedz wszystkim]';
$labels['replyalldefault'] = 'odpowiedz wszystkim';
$labels['replyalllist'] = 'odpowiedz tylko do listy mailingowej (jeśli wykryto)';
$labels['allmessages'] = 'wszystkich';
$labels['folder'] = 'Folder';
$labels['folders'] = 'Foldery';
$labels['foldername'] = 'Nazwa folderu';
$labels['subscribed'] = 'Zasubskrybowany';
$labels['messagecount'] = 'Wiadomości';
$labels['create'] = 'Utwórz';
$labels['createfolder'] = 'Utwórz nowy folder';
$labels['managefolders'] = 'Zarządzaj folderami';
$labels['specialfolders'] = 'Foldery specjalne';
$labels['properties'] = 'Właściwości';
$labels['folderproperties'] = 'Właściwości folderu';
$labels['parentfolder'] = 'Folder nadrzędny';
$labels['location'] = 'Położenie';
$labels['info'] = 'Informacje';
$labels['getfoldersize'] = 'Kliknij aby pobrać rozmiar folderu';
$labels['changesubscription'] = 'Kliknij aby zmienić subskrypcję';
$labels['foldertype'] = 'Typ folderu';
$labels['personalfolder'] = 'Folder prywatny';
$labels['otherfolder'] = 'Folder innego użytkownika';
$labels['sharedfolder'] = 'Folder współdzielony';
$labels['findfolders'] = 'Szukaj folderów';
$labels['findcontacts'] = 'Znajdź kontakty';
$labels['findmail'] = 'Znajdź wiadomości pocztowe';
$labels['namespace.personal'] = 'Osobiste';
$labels['namespace.other'] = 'Innych użytkowników';
$labels['namespace.shared'] = 'Współdzielone';
$labels['dualuselabel'] = 'Może zawierać tylko';
$labels['dualusemail'] = 'wiadomości';
$labels['dualusefolder'] = 'foldery';
$labels['generate'] = 'Generuj';
$labels['encryptioncreatekey'] = 'Utwórz nową parę kluczy';
$labels['openmailvelopesettings'] = 'Otwórz ustawienia Mailvelope';
$labels['encryptionprivkeysinmailvelope'] = 'Znaleziono $nr pasujących kluczy prywatnych w bazie Mailvelope:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Wybrana tożsamość nadawcy nie posiada pasującego klucza prywatnego w bazie Mailvelope. Czy chcesz utworzyć klucz pozwalający szyfrować wiadomości?';
$labels['encryption'] = 'Szyfrowanie';
$labels['mailvelopeoptions'] = 'Opcje Mailvelope';
$labels['mailvelopemainkeyring'] = 'Korzystaj z głównego zasobu kluczy (keyring) Mailvelope';
$labels['mailvelopenotfound'] = 'Rozszerzenie Mailvelope nie jest włączone/zainstalowane w twojej przeglądarce.';
$labels['sortby'] = 'Sortuj wg';
$labels['sortasc'] = 'Rosnąco';
$labels['sortdesc'] = 'Malejąco';
$labels['undo'] = 'Cofnij';
$labels['installedplugins'] = 'Zainstalowane wtyczki';
$labels['plugin'] = 'Wtyczka';
$labels['version'] = 'Wersja';
$labels['source'] = 'Źródła';
$labels['destination'] = 'Cel';
$labels['license'] = 'Licencja';
$labels['support'] = 'Wsparcie techniczne';
$labels['savedsearches'] = 'Zapisane wyszukiwania';
$labels['dateformatY'] = 'RRRR';
$labels['dateformaty'] = 'RR';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'kB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'uniwersalny';
$labels['english'] = 'angielski';
$labels['westerneuropean'] = 'zachodnioeuropejski';
$labels['easterneuropean'] = 'wschodnioeuropejski';
$labels['southeasterneuropean'] = 'południowo-wschodnioeuropejski';
$labels['baltic'] = 'bałtycki';
$labels['cyrillic'] = 'cyrylica';
$labels['arabic'] = 'arabski';
$labels['greek'] = 'grecki';
$labels['hebrew'] = 'hebrajski';
$labels['turkish'] = 'turecki';
$labels['nordic'] = 'nordycki';
$labels['thai'] = 'tajski';
$labels['celtic'] = 'celtycki';
$labels['vietnamese'] = 'wietnamski';
$labels['japanese'] = 'japoński';
$labels['korean'] = 'koreański';
$labels['chinese'] = 'chiński';
$labels['arialabeltopnav'] = 'Kontrolki okna';
$labels['arialabeltasknav'] = 'Zadania aplikacji';
$labels['arialabeltoolbar'] = 'Narzędzia aplikacji';
$labels['arialabellistnav'] = 'Obsługa listy';
$labels['arialabelactivetask'] = 'Aktywne zadanie';
$labels['arialabelmessagessearchfilter'] = 'Filtr listy wiadomości';
$labels['arialabelmailsearchform'] = 'Formularz wyszukiwania wiadomości';
$labels['arialabelcontactsearchform'] = 'Formularz wyszukiwania kontaktów';
$labels['arialabelmailquicksearchbox'] = 'Wejście danych wyszukiwania';
$labels['arialabelquicksearchbox'] = 'Wejście danych wyszukiwania';
$labels['arialabelfoldersearchfilter'] = 'Filtr listy folderów';
$labels['arialabelfoldersearchform'] = 'Formularz wyszukiwania folderów';
$labels['arialabelfolderlist'] = 'Wybór folderu';
$labels['arialabelmessagelist'] = 'Lista wiadomości e-mail';
$labels['arialabelmailpreviewframe'] = 'Podgląd wiadomości';
$labels['arialabelmailboxmenu'] = 'Menu akcji folderów';
$labels['arialabellistselectmenu'] = 'Menu zaznaczenia listy';
$labels['arialabelthreadselectmenu'] = 'Menu wątków listy';
$labels['arialabelmessagelistoptions'] = 'Opcje wyświetlania i sortowania listy';
$labels['arialabelmailimportdialog'] = 'Dialog importu wiadomości';
$labels['arialabelmessagenav'] = 'Nawigacja wiadomości';
$labels['arialabelmessagebody'] = 'Treść wiadomości';
$labels['arialabelmessageactions'] = 'Akcje wiadomości';
$labels['arialabelcontactquicksearch'] = 'Formularz wyszukiwania kontaktów';
$labels['arialabelcontactsearchbox'] = 'Wejście danych wyszukiwania';
$labels['arialabelmessageheaders'] = 'Nagłówki wiadomości';
$labels['arialabelforwardingoptions'] = 'Opcje przekazywania wiadomości';
$labels['arialabelreplyalloptions'] = 'Opcje odpowiedzi do wszystkich';
$labels['arialabelmoremessageactions'] = 'Więcej akcji';
$labels['arialabelmorecontactactions'] = 'Więcej akcji';
$labels['arialabelmarkmessagesas'] = 'Oznacz wybrane wiadomości jako...';
$labels['arialabelcomposeoptions'] = 'Opcje kompozycji';
$labels['arialabelresponsesmenu'] = 'Menu zapisanych odpowiedzi';
$labels['arialabelattachmentuploadform'] = 'Formularz wysyłania załączników';
$labels['arialabelattachmentmenu'] = 'Opcje załączników';
$labels['arialabelmailtomenu'] = 'Opcje adresu email';
$labels['arialabelattachmentpreview'] = 'Podgląd załącznika';
$labels['ariasummarycomposecontacts'] = 'Lista wyboru kontaktów/grup jako odbiorców';
$labels['arialabelcontactexportoptions'] = 'Opcje eksportu kontaktów';
$labels['arialabelabookgroupoptions'] = 'Opcje książki adresowej i grup';
$labels['arialabelpreferencesform'] = 'Formularz ustawień';
$labels['arialabelidentityeditfrom'] = 'Formularz edycji tożsamości';
$labels['arialabelresponseeditfrom'] = 'Formularz edycji odpowiedzi';
$labels['arialabelsearchterms'] = 'Szukana fraza';
$labels['arialabeldropactionmenu'] = 'Menu Przeciągnij-i-upuść';
$labels['arialabelheadersmenu'] = 'Menu dodawania odbiorcy (nagłóweka)';
$labels['arialabelimagetools'] = 'Narzędzia obrazu';
$labels['helplistnavigation'] = 'Obsługa listy przy pomocy klawiatury';
$labels['helplistkeyboardnavigation'] = "Strzałki góra/dół: Oznaczanie/poruszanie się po wierszach.
Spacja: Wybór bieżącego wiersza.
SHIFT + góra/dół: Oznaczenie dodatkowych wierszy.
CTRL + Spacja: Zaznaczenie/odznaczenie bieżącego wiersza.";
$labels['helplistkeyboardnavmessages'] = "Strzałki prawo/lewo: Rozwiniecie/zwinięcie wątku (w trybie wątkowania).
ENTER: Otwarcie bieżącej wiadomości.
DELETE: Usunięcie/Przeniesienie wiadomości do Kosza.";
$labels['helplistkeyboardnavcontacts'] = "ENTER: Otwarcie bieżącego kontaktu.";
