<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'ተጓንፎ ጋዶ';
$messages['loginfailed']  = 'ከይዲ ምእታዎ ፈሺሉ';
$messages['cookiesdisabled'] = 'ጎስጓሲ ኢንተርኔት ዛላማላ አይቕበልን';
$messages['sessionerror'] = 'እዋኑ ዝሓለፎ ወይ ዋጋ ዘይብሉ ካርነ ምጥቃም ክልክል እዩ::';
$messages['storageerror'] = 'ናብ ውሃቢ ግልጋሉት ቆፎ ረኽቢ አይተኻለን::';
$messages['servererror'] = 'ጋዶ ውሃቢት ግልጋሉት';
