<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/csv2vcard.inc                                     |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Aleksander Machniak <alec@alec.pl>                            |
 +-----------------------------------------------------------------------+
*/
$map = array();
$map['anniversary'] = "Aniversário";
$map['assistants_name'] = "Nome do Assistente";
$map['assistants_phone'] = "Fone do Assistente";
$map['birthday'] = "Aniversário";
$map['business_city'] = "Cidade comercial";
$map['business_countryregion'] = "Região/País comercial";
$map['business_fax'] = "Fax comercial";
$map['business_phone'] = "Fone comercial";
$map['business_phone_2'] = "Fone comercial 2";
$map['business_postal_code'] = "Código postal comercial";
$map['business_state'] = "Estado comercial";
$map['business_street'] = "Rua comercial";
$map['car_phone'] = "Fone do carro";
$map['categories'] = "Categorias";
$map['company'] = "Empresa";
$map['department'] = "Departamento";
$map['email_address'] = "Endereço de E-mail";
$map['email_2_address'] = "Endereço de E-mail 2";
$map['email_3_address'] = "Endereço de E-mail 3";
$map['first_name'] = "Primeiro nome";
$map['gender'] = "Gênero";
$map['home_city'] = "Cidade de casa";
$map['home_countryregion'] = "Região/País de casa";
$map['home_fax'] = "Fax de casa";
$map['home_phone'] = "Fone de casa";
$map['home_phone_2'] = "Fone de casa 2";
$map['home_postal_code'] = "Código Postal de casa";
$map['home_state'] = "Estado de casa";
$map['home_street'] = "Rua de casa";
$map['job_title'] = "Cargo";
$map['last_name'] = "Último nome";
$map['managers_name'] = "Nome do gerente";
$map['middle_name'] = "Nome do meio";
$map['mobile_phone'] = "Celular";
$map['notes'] = "Notas";
$map['other_city'] = "Outra cidade";
$map['other_countryregion'] = "Outro País/Região";
$map['other_fax'] = "Outro Fax";
$map['other_phone'] = "Outro Fone";
$map['other_postal_code'] = "Outro Código Postal";
$map['other_state'] = "Outro Estado";
$map['other_street'] = "Outra Rua";
$map['pager'] = "Pager";
$map['primary_phone'] = "Fone Primario";
$map['spouse'] = "Spouse";
$map['suffix'] = "Sufixo";
$map['title'] = "Título";
$map['web_page'] = "Página Web";
$map['birth_day'] = "Dia de nascimento";
$map['birth_month'] = "Mês de nascimento";
$map['birth_year'] = "Ano de nascimento";
$map['display_name'] = "Mostrar nome";
$map['fax_number'] = "Número de Fax";
$map['home_address'] = "Endereço de casa";
$map['home_country'] = "País de casa";
$map['home_zipcode'] = "CEP de casa";
$map['mobile_number'] = "Celular";
$map['nickname'] = "Apelido";
$map['organization'] = "Organização";
$map['pager_number'] = "Número do Pager";
$map['primary_email'] = "E-mail primário";
$map['secondary_email'] = "E-mail secundário";
$map['web_page_1'] = "Web Page 1";
$map['web_page_2'] = "Web Page 2";
$map['work_phone'] = "Fone de trabalho";
$map['work_address'] = "Endereço de trabalho";
$map['work_country'] = "País de trabalho";
$map['work_zipcode'] = "CEP de trabalho";
$map['date_of_birth'] = "Data de nascimento";
$map['email'] = "E-mail";
$map['home_mobile'] = "Celular pessoal";
$map['home_zip'] = "CEP pessoal";
$map['info'] = "Informações";
$map['user_photo'] = "Foto do Usuário";
$map['url'] = "URL";
$map['work_city'] = "Cidade de trabalho";
$map['work_company'] = "Empresa";
$map['work_dept'] = "Departamento";
$map['work_fax'] = "Fax";
$map['work_mobile'] = "Celular de trabalho";
$map['work_state'] = "Estado";
$map['work_title'] = "Cargo";
$map['work_zip'] = "CEP";
