<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'ንኻልእ';
$labels['myrights'] = 'መሰላት በዓል ዋና';
$labels['username'] = 'በዓል ዋና';
$labels['newuser'] = 'እታዎ ክውስኽ';
$labels['actions'] = 'ንጥፈታት መብት ተጠቃማይነት';
$labels['anyone'] = 'ኩሉም በዓልቲ ዋናታት(ዝኾነ ሰብ)';
$labels['anonymous'] = 'ጋሻ(ሽም አልቦ)';
$labels['identifier'] = 'መለለዪ';
$labels['acll'] = 'አለሻ';
$labels['aclr'] = 'ዝተነበቡ መልእኽታት';
$labels['acls'] = 'ተራእዩ ብዝብል ይጽናሕ';
$labels['aclw'] = 'ምልክታት ምጽሓፍ';
$labels['acli'] = 'ሸጉጥ(አብ..መንጎ አቐምጥ)';
$labels['aclp'] = 'ጠቅዕ';
$labels['aclc'] = 'ማህደር ፍጠር';
$labels['aclk'] = 'ክፍለማህደር ፍጠር';
$labels['acld'] = 'መልእኽታት አጥፍእ';
$labels['aclt'] = 'መልእኽታት አጥፍእ';
$labels['acle'] = 'ንሓዋሩ አጥፍእ';
$labels['aclx'] = 'ማህደር አጥፍእ';
$labels['acla'] = 'ተቖፃፀር';
$labels['aclfull'] = 'ምሉእ ቑጽፅር';
$labels['aclother'] = 'ካሊእ';
$labels['aclread'] = 'ከንብብ';
$labels['aclwrite'] = 'ክጽሕፍ';
$labels['acldelete'] = 'ይጥፈአለይ';
$labels['shortacll'] = 'አለሻ';
$labels['shortaclr'] = 'ዝተነበበ';
$labels['shortacls'] = 'ይፅናሕ';
$labels['shortaclw'] = 'ይጽሓፍ';
$labels['shortacli'] = 'ይሸጎጥ';
$labels['shortaclp'] = 'ይጠቃዕ';
$labels['shortaclc'] = 'ይፈጠር';
$labels['shortaclk'] = 'ይፈጠር';
$labels['shortacld'] = 'ይጥፋእ';
$labels['shortaclt'] = 'ይጥፋእ';
$labels['shortacle'] = 'ንሓዋሩ ይጥፋእ';
$labels['shortaclx'] = 'ዝጠፍእ ማህደር';
$labels['shortacla'] = 'ክቆፃፀር';
$labels['shortaclother'] = 'ካሊእ';
$labels['shortaclread'] = 'ከንብብ';
$labels['shortaclwrite'] = 'ክጽሕፍ';
$labels['shortacldelete'] = 'ይጥፋእ';
$labels['longaclr'] = 'ማህደር ተኸፊቱ ክንበብ ይኽእል';
$labels['longacls'] = 'ተራእዩ ዝብል መልእኽቲ ዕላም ክለወጥ ይኽእል';
$labels['longaclw'] = 'ዕላማትን መፍትሕ ቃላትን መልኽትታት ክልወጡ ይኽእሉ, ብዘይካ ዝተረኣዩን ዝጠፍኡን';
$labels['longacli'] = 'መልእኽቲ ናብዚ ማህደር ክጽሓፍ ወይ ክቕዳሕ ይኽእል';
$labels['longaclp'] = 'መልእኽቲ ናብዚ ማህደር ክኣቱ ይኽእል';
$labels['longaclread'] = 'ማህደር ተኸፊቱ ክንበብ ይኽእል';
