<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'الأرشيف';
$labels['buttontitle'] = 'أرشفة هذه الرسالة';
$labels['archived'] = 'أُرشفت بنجاح';
$labels['archivedreload'] = 'تمت أرشفته بنجاح. أعد تحميل الصفحة لمشاهدة مجلدات الأرشيف الجديدة.';
$labels['archiveerror'] = 'لا يمكن أرشفة بعض الرسائل';
$labels['archivefolder'] = 'الأرشيف';
$labels['settingstitle'] = 'الأرشيف';
$labels['archivetype'] = 'تقسيم الأرشيف ب';
$labels['archivetypeyear'] = 'السنة (على سبيل المثال. الأرشيف / 2012)';
$labels['archivetypemonth'] = 'الشهر (على سبيل المثال. الأرشيف / 2012 / 06)';
$labels['archivetypetbmonth'] = 'الشهر - متوافق مع Thunderbird (على سبيل المثال أرشيف / 2012 / 2012-06)';
$labels['archivetypefolder'] = 'المجلد الاصلي';
$labels['archivetypefolderyear'] = 'السنة والمجلد الأصلي (على سبيل المثال. الأرشيف / 2012 / ...)';
$labels['archivetypefoldermonth'] = 'السنة والشهر والمجلد الأصلي (على سبيل المثال. الأرشيف / 2012 / 06 / ...)';
$labels['archivetypesender'] = 'البريد المرسل';
$labels['unkownsender'] = 'مجهول';
$labels['readonarchive'] = 'ضع علامة على الرسالة كمقروءة في الأرشيف';
