<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['messagedelete'] = 'Dit bericht verwijderen';
$labels['add'] = 'Toevoegen';
$labels['del'] = 'Verwijderen';
$labels['sender'] = 'Afzender';
$labels['flagdeleted'] = 'Verwijderd';
$labels['flagflagged'] = 'Geselecteerd';
$labels['notifymethodmailto'] = 'E-mailadres';
$labels['notifymethodtel'] = 'Telefoonnummer';
$labels['datetest'] = 'Datum';
$labels['advancedopts'] = 'Geavanceerde opties';
$labels['vacation.subject'] = 'Onderwerp';
