<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-password/
*/

$labels['changepasswd']  = 'Şîfreyê biguherîne';
$labels['curpasswd']  = 'Şîfreya niha:';
$labels['newpasswd']  = 'Şîfreya nû:';
$labels['confpasswd']  = 'Şîfreya nû bipejirîne:';
$messages['nopassword'] = 'Şîfreya nû binivîse.';
$messages['nocurpassword'] = 'Şîfreya niha binivîse.';
$messages['passwordincorrect'] = 'Şîfreya niha xelet e.';
$messages['passwordinconsistency'] = 'Şîfre hevdu nagirin, dîsa biceribîne.';
$messages['crypterror'] = 'Şîfreya nû nehat tomarkirin. Fonksiyona şîfrekirinê hat jibîrkirin.';
$messages['connecterror'] = 'Şîfreya nû nehat tomarkirin. Çewtiya girêdanê.';
$messages['internalerror'] = 'Şîfre nehat tomarkirin.';
$messages['passwordshort'] = 'Divê şîfre ji $length karakteran kêmtir nebe.';
$messages['passwordweak'] = 'Divê di şîfreyê de herî kêm hejmarek û karakterekî xalbendiyê hebe.';
$messages['passwordforbidden'] = 'Şîfre karakterên qedexe dihewîne.';
$messages['firstloginchange'] = 'Ev têketina te ya yekemîn e. Ji kerema xwe şîfreya xwe biguherîne.';
