<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Ett fel uppstod!';
$messages['loginfailed']  = 'Inloggningen misslyckades';
$messages['cookiesdisabled'] = 'Webbläsaren accepterar inte cookies.';
$messages['sessionerror'] = 'Din inloggning är felaktig eller har gått ut';
$messages['cookiesmismatch'] = 'Något är fel med webbläsarens cookie. Rensa bort den för att kunna fortsätta.';
$messages['storageerror'] = 'Anslutning till lagringsservern misslyckades.';
$messages['servererror'] = 'Serverfel!';
$messages['servererrormsg'] = 'Serverfel: $msg';
$messages['accountlocked'] = 'För många felaktiga inloggningar. Försök igen senare.';
$messages['connerror'] = 'Anslutningsfel (misslyckades att kontakta servern)!';
$messages['dberror'] = 'Databasfel!';
$messages['dbconnerror'] = 'Anslutning till serverns databas misslyckades!';
$messages['windowopenerror'] = 'Popup-fönstret blockerades!';
$messages['requesttimedout'] = 'Begäran tog för lång tid';
$messages['errorreadonly'] = 'Åtgärden kunde inte utföras. Mappen är skrivskyddad.';
$messages['errornoperm'] = 'Åtgärden kunde inte utföras. Otillräcklig befogenhet.';
$messages['erroroverquota'] = 'Åtgärden kunde inte utföras. Otillräckligt lagringsutrymme.';
$messages['erroroverquotadelete'] = 'Otillräckligt lagringsutrymme. Tryck på SHIFT och DEL för att ta bort ett meddelande.';
$messages['invalidrequest'] = 'Ogiltig begäran! Informationen sparades inte.';
$messages['invalidhost'] = 'Ogiltigt servernamn.';
$messages['nomessagesfound'] = 'Inga meddelanden.';
$messages['loggedout'] = 'Du är utloggad. Välkommen åter!';
$messages['mailboxempty'] = 'Brevlådan är tom';
$messages['nomessages'] = 'Inga meddelanden';
$messages['refreshing'] = 'Uppdaterar...';
$messages['loading'] = 'Läser in...';
$messages['uploading'] = 'Överför fil...';
$messages['attaching'] = 'Bifogar fil...';
$messages['uploadingmany'] = 'Överför filer...';
$messages['loadingdata'] = 'Läser in data...';
$messages['checkingmail'] = 'Hämtar nya meddelanden...';
$messages['sendingmessage'] = 'Skickar meddelande...';
$messages['messagesent'] = 'Meddelandet har skickats.';
$messages['savingmessage'] = 'Sparar meddelande...';
$messages['messagesaved'] = 'Meddelandet har sparats i Utkast';
$messages['successfullysaved'] = 'Sparat.';
$messages['savingresponse'] = 'Sparar responstext...';
$messages['deleteresponseconfirm'] = 'Vill du verkligen ta bort denna responstext?';
$messages['nocontactselected'] = 'Ingen kontakt är vald ännu.';
$messages['addedsuccessfully'] = 'Kontakten har lagts till i adressboken.';
$messages['contactexists'] = 'En kontakt med den här adressen finns redan.';
$messages['contactnameexists'] = 'En kontakt med det här namnet finns redan.';
$messages['blockedimages'] = 'Externt länkade bilder i meddelandet har blockerats.';
$messages['blockedresources'] = 'Externt länkade resurser i meddelandet har blockerats.';
$messages['suspiciousemail'] = 'Meddelandet innehåller mailadresser som kan vara försök till bedrägeri.';
$messages['bccemail'] = 'Vidarebefordrat meddelande innehåller dolda mottagare (Bcc).';
$messages['bouncehint'] = 'Meddelandet kommer att skickas utan modifieringar, dvs med ursprungligt innehåll, meddelandehuvud och ursprungliga mottagare.';
$messages['encryptedmessage'] = 'Meddelandet är krypterat och kan tyvärr inte visas.';
$messages['externalmessagedecryption'] = 'Meddelandet är krypterat och kan visas med ett tillägg i webbläsaren.';
$messages['nopubkeyfor'] = 'Ingen giltig offentlig nyckel hittades för $email';
$messages['nopubkeyforsender'] = 'Ingen giltig offentlig nyckel hittades för din avsändaradress. Vill du kryptera meddelandet enbart för mottagaren?';
$messages['encryptnoattachments'] = 'Redan uppladdade bilagor kan inte krypteras. Lägg till bilagorna i krypteringsredigeraren istället.';
$messages['searchpubkeyservers'] = 'Ska saknade nycklar sökas i offentliga nyckelservrar?';
$messages['encryptpubkeysfound'] = 'Följande offentliga nycklar hittades:';
$messages['keyservererror'] = 'Nyckeln kunde inte hämtas från nyckelservern.';
$messages['keyimportsuccess'] = 'Offentlig nyckel $key är tillagd i din nyckelring.';
$messages['nocontactsfound'] = 'Inga kontakter hittades.';
$messages['contactnotfound'] = 'Efterfrågad kontakt hittades inte.';
$messages['contactsearchonly'] = 'Ange sökord för att hitta kontakter i vald adressbok.';
$messages['sendingfailed'] = 'Meddelandet kunde inte skickas.';
$messages['senttooquickly'] = 'Vänta ytterligare $sec sekunder med att skicka meddelandet.';
$messages['errorsavingsent'] = 'Det skickade meddelandet kunde inte sparas.';
$messages['errorsaving'] = 'Meddelandet kunde inte sparas.';
$messages['errormoving'] = 'Meddelandet kunde inte flyttas.';
$messages['errorcopying'] = 'Meddelandet kunde inte kopieras.';
$messages['errordeleting'] = 'Meddelandet kunde inte tas bort.';
$messages['errormarking'] = 'Meddelandet kunde inte markeras.';
$messages['alerttitle'] = 'Uppmärksamhet';
$messages['confirmationtitle'] = 'Är du säker...';
$messages['deletecontactconfirm']  = 'Vill du verkligen ta bort valda kontakter?';
$messages['deletegroupconfirm']  = 'Vill du verkligen ta bort den valda gruppen?';
$messages['deletemessagesconfirm'] = 'Vill du verkligen ta bort valda meddelanden?';
$messages['deletefolderconfirm']  = 'Vill du verkligen ta bort den här mappen?';
$messages['movefolderconfirm']  = 'Vill du verkligen flytta den här mappen?';
$messages['purgefolderconfirm']  = 'Vill du verkligen ta bort alla meddelanden i den här mappen?';
$messages['contactdeleting'] = 'Tar bort kontakt...';
$messages['groupdeleting'] = 'Tar bort grupp...';
$messages['folderdeleting'] = 'Tar bort mapp...';
$messages['foldermoving'] = 'Flyttar mapp...';
$messages['foldersubscribing'] = 'Startar prenumeration på mapp...';
$messages['folderunsubscribing'] = 'Avslutar prenumeration på mapp...';
$messages['formincomplete'] = 'Formuläret var inte komplett ifyllt.';
$messages['noemailwarning'] = 'Ange en giltig adress.';
$messages['nonamewarning']  = 'Ange ett namn.';
$messages['nopagesizewarning'] = 'Ange en sidstorlek.';
$messages['nosenderwarning'] = 'Ange en avsändaradress.';
$messages['recipientsadded'] = 'Mottagare tillagda.';
$messages['norecipientwarning'] = 'Ange minst en mottagare.';
$messages['disclosedrecipwarning'] = 'Alla mottagare kommer att kunna se varandras adresser. Undvik detta genom att ange adresserna i fältet Dold kopia istället.';
$messages['disclosedreciptitle'] = 'Alltför många mottagaradresser';
$messages['nosubjectwarning']  = 'Ämnesraden är tom. Vill du ange ett ämne nu?';
$messages['nosubjecttitle']  = 'Inget ämne';
$messages['nobodywarning'] = 'Skicka det här meddelandet utan text?';
$messages['notsentwarning'] = 'Meddelandet har inte skickats ännu men har ändringar som inte är sparade. Vill du strunta i ändringarna?';
$messages['restoresavedcomposedata'] = 'Ett tidigare skrivet men inte skickat meddelande upptäcktes.\n\nÄmne: $subject\nSparat: $date\n\nVill du återskapa meddelandet?';
$messages['nosearchname'] = 'Ange ett kontaktnamn eller en adress.';
$messages['notuploadedwarning'] = 'Alla bilagor har inte överförts ännu. Vänta eller avbryt överföringen.';
$messages['searchsuccessful'] = '$nr meddelanden hittades.';
$messages['contactsearchsuccessful'] = '$nr kontakter hittades.';
$messages['searchnomatch'] = 'Sökningen gav inget resultat.';
$messages['searching'] = 'Söker...';
$messages['checking'] = 'Kontrollerar...';
$messages['stillsearching'] = 'Söker fortfarande...';
$messages['nospellerrors'] = 'Inget stavfel hittades.';
$messages['folderdeleted'] = 'Mappen togs bort.';
$messages['foldersubscribed'] = 'Prenumeration på mapp startad.';
$messages['folderunsubscribed'] = 'Prenumeration på mapp avslutad.';
$messages['folderpurged'] = 'Mappen är tömd.';
$messages['folderexpunged'] = 'Mappen är rensad.';
$messages['deletedsuccessfully'] = 'Borttaget.';
$messages['converting'] = 'Tar bort formatering...';
$messages['messageopenerror'] = 'Meddelandet kunde inte hämtas från servern.';
$messages['filelinkerror'] = 'Filen kunde inte bifogas.';
$messages['fileuploaderror'] = 'Filuppladdning misslyckades.';
$messages['csvfilemismatch'] = 'Import av flera CSV-filer med olika fält stöds inte.';
$messages['filesizeerror'] = 'Den uppladdade filens storlek överstiger högsta tillåtna $size.';
$messages['filecounterror'] = 'Högst $count filer kan laddas upp samtidigt.';
$messages['msgsizeerror'] = 'Filen kunde inte bifogas. Största tillåtna storlek ($size) överskreds.';
$messages['msgsizeerrorfwd'] = 'Tillåten storlek på meddelandet ($size) är överskriden. $num meddelanden har inte bifogats.';
$messages['copysuccess'] = '$nr kontakter har kopierats.';
$messages['movesuccess'] = '$nr kontakter har flyttats.';
$messages['copyerror'] = 'Några kontakter kunde inte kopieras.';
$messages['moveerror'] = 'Några kontakter kunde inte flyttas.';
$messages['sourceisreadonly'] = 'Denna adresskälla är skrivskyddad.';
$messages['errorsavingcontact'] = 'Kontaktadressen kunde inte sparas.';
$messages['movingmessage'] = 'Flyttar meddelande...';
$messages['copyingmessage'] = 'Kopierar meddelande...';
$messages['copyingcontact'] = 'Kopierar kontakter...';
$messages['movingcontact'] = 'Flyttar kontakter...';
$messages['deletingmessage'] = 'Tar bort meddelande...';
$messages['markingmessage'] = 'Markerar meddelande...';
$messages['addingmember'] = 'Lägger till kontakter i gruppen...';
$messages['removingmember'] = 'Tar bort kontakter från gruppen...';
$messages['receiptsent'] = 'Mottagarkvitto har skickats.';
$messages['errorsendingreceipt'] = 'Mottagarkvitto kunde inte skickas.';
$messages['deleteidentityconfirm'] = 'Vill du verkligen ta bort denna identitet?';
$messages['nodeletelastidentity'] = 'Du kan inte ta bort identiteten, den är din sista.';
$messages['forbiddencharacter'] = 'Mappnamnet innehåller otillåtna tecken.';
$messages['selectimportfile'] = 'Välj en fil att ladda upp.';
$messages['addresswriterror'] = 'Markerad adressbok är skrivskyddad.';
$messages['contactaddedtogroup'] = 'Kontakterna har lagts till i gruppen.';
$messages['contactremovedfromgroup'] = 'Kontakterna har tagits bort från gruppen.';
$messages['nogroupassignmentschanged'] = 'Ingen grupptillhörighet ändrades.';
$messages['importwait'] = 'Importerar, var god vänta...';
$messages['importformaterror'] = 'Importen misslyckades! Filen har inte korrekt dataformat.';
$messages['importconfirm'] = '<b>Lyckad import av $inserted kontakter</b>';
$messages['importconfirmskipped'] = '<b>Hoppade över $skipped befintliga poster</b>';
$messages['importmessagesuccess'] = '$nr meddelanden har importerats';
$messages['importmessageerror'] = 'Importen misslyckades! Filen är inte ett giltigt meddelande eller en brevlåda';
$messages['opnotpermitted'] = 'Otillåten operation!';
$messages['nofromaddress'] = 'Vald identitet saknar adress.';
$messages['editorwarning'] = 'Genom att byta textredigerare kan formateringen av texten gå förlorad. Vill du fortsätta?';
$messages['httpreceivedencrypterror'] = 'Ett irreparabelt fel har uppstått. Kontakta administratören omgående. <b>Meddelandet kan inte skickas.</b>';
$messages['smtpconnerror'] = 'SMTP-fel ($code): Anslutning till servern misslyckades.';
$messages['smtpautherror'] = 'SMTP-fel ($code): Inloggningen misslyckades.';
$messages['smtpfromerror'] = 'SMTP-fel ($code): Kan inte sätta avsändaradress till "$from" ($msg).';
$messages['smtptoerror'] = 'SMTP-fel ($code): Kan inte lägga till mottagaradress "$to" ($msg).';
$messages['smtprecipientserror'] = 'SMTP-fel: Felaktigt formaterad lista med mottagaradresser.';
$messages['smtputf8error'] = 'SMTP-fel: Servern klarar inte mailadresser med Unicode.';
$messages['smtpsizeerror'] = 'SMTP-fel: Meddelandet är för stort ($limit).';
$messages['smtperror'] = 'SMTP-fel: $msg';
$messages['emailformaterror'] = 'Ogiltig adress: $email';
$messages['toomanyrecipients'] = 'Förmånga mottagare. Minska antalet till högst $max.';
$messages['maxgroupmembersreached'] = 'Antalet gruppmedlemmar får inte överstiga $max.';
$messages['internalerror'] = 'Ett internt fel uppstod. Försök igen.';
$messages['contactdelerror'] = 'Kontakt kunde inte tas bort.';
$messages['contactdeleted'] = 'Kontakt borttagen.';
$messages['contactrestoreerror'] = 'Borttagna kontakter kunde inte återskapas.';
$messages['contactrestored'] = 'Kontakter återskapade.';
$messages['groupdeleted'] = 'Grupp borttagen.';
$messages['grouprenamed'] = 'Gruppnamn ändrat.';
$messages['groupcreated'] = 'Grupp skapad.';
$messages['savedsearchdeleted'] = 'Sparad sökning borttagen.';
$messages['savedsearchdeleteerror'] = 'Kunde inte ta bort sparad sökning.';
$messages['savedsearchcreated'] = 'Sparad sökning tillagd.';
$messages['savedsearchcreateerror'] = 'Kunde inte lägga till sparad sökning.';
$messages['messagedeleted'] = 'Meddelande borttaget.';
$messages['messagemoved'] = 'Meddelande flyttat.';
$messages['messagemovedtotrash'] = 'Meddelanden flyttade till Papperskorg.';
$messages['messagecopied'] = 'Meddelande kopierat.';
$messages['messagemarked'] = 'Meddelande markerat.';
$messages['autocompletechars'] = 'Ange minst $min tecken för automatisk komplettering.';
$messages['autocompletemore'] = 'Ytterligare passande poster funna. Skriv fler tecken.';
$messages['namecannotbeempty'] = 'Namnet får inte vara tomt.';
$messages['nametoolong'] = 'Namnet är för långt.';
$messages['namedotforbidden'] = 'Mappnamnet kan inte inledas med en punkt.';
$messages['folderupdated'] = 'Mappen är uppdaterad.';
$messages['foldercreated'] = 'Mappen är skapad.';
$messages['invalidimageformat'] = 'Ogiltigt bildfilsformat.';
$messages['mispellingsfound'] = 'Stavfel hittades i meddelandet.';
$messages['parentnotwritable'] = 'Mappen kunde inte skapas eller flyttas. Åtkomsträttighet saknas.';
$messages['messagetoobig'] = 'Meddelandet är alltför stort att behandla.';
$messages['attachmentvalidationerror'] = 'Den här bilagan är misstänkt eftersom dess typ inte överensstämmer med typen som anges i meddelandet. Om du inte litar på avsändaren ska du inte öppna bilagan i webbläsaren eftersom innehållet kan vara skadligt.<br/><br/><em>Förväntad: $expected; Funnen: $detected</em>';
$messages['noscriptwarning'] = 'Varning: Denna webbmailtjänst fungerar inte utan Javascript! Aktivera Javascript i webbläsarens inställningar.';
$messages['messageissent'] = 'Meddelandet är skickat men har inte sparats ännu. Vill du spara meddelandet nu?';
$messages['errnotfound'] = 'Filen hittades inte';
$messages['errnotfoundexplain'] = 'Efterfrågad resurs hittades inte!';
$messages['errfailedrequest'] = 'Begäran misslyckades';
$messages['errauthorizationfailed'] = 'Autentiseringen misslyckades';
$messages['errunauthorizedexplain'] = 'Din behörighet till den här tjänsten kunde inte bekräftas!';
$messages['errrequestcheckfailed'] = 'Kontroll av begäran misslyckades';
$messages['errcsrfprotectionexplain'] = "Åtkomst till den här resursen är skyddad mot CSRF.\nDetta visas därför att utloggning från tjänsten inte gjordes korrekt.\n\nEn aktiv handling krävs nu för att fortsätta.";
$messages['errcontactserveradmin'] = 'Kontakta administratören.';
$messages['clicktoresumesession'] = 'Klicka här för att återuppta föregående session';
$messages['errcomposesession'] = 'Fel i påbörjat meddelande';
$messages['errcomposesessionexplain'] = 'Det påbörjade meddelandet hittades inte.';
$messages['clicktocompose'] = 'Klicka här för att skriva ett nytt meddelande';
$messages['nosupporterror'] = 'Funktionen finns inte i webbläsaren.';
$messages['siginserted'] = 'Signatur infogad.';
$messages['responseinserted'] = 'Respons infogad.';
$messages['noresponsesavailable'] = 'Ingen respons tillgänglig';
$messages['listempty'] = 'Listan är tom.';
$messages['listusebutton'] = 'Använd Skapa-knappen för att lägga till information.';
$messages['keypaircreatesuccess'] = 'Ett nytt nyckelpar har skapats för $identity.';
$messages['emptyattachment'] = 'Bilagan verkar vara tom.<br>Kontakta avsändaren.';
$messages['oauthloginfailed'] = 'OAuth-inloggningen misslyckades. Vänligen försök igen.';
