<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Хуваалцах';
$labels['myrights'] = 'Нэвтрэлтийн зөвшөөрлүүд';
$labels['username'] = 'Хэрэглэгч:';
$labels['advanced'] = 'Дэлгэрэнгүй горим';
$labels['newuser'] = 'Нэмэх';
$labels['editperms'] = 'Зөвшөөрлүүдийг засах';
$labels['actions'] = 'Нэвтрэлтийн зөвшөөрлийн үйлдлүүд...';
$labels['anyone'] = 'Бүх хэрэглэгч (хүн бүр)';
$labels['anonymous'] = '(Үл таних) зочин';
$labels['identifier'] = 'Таних мэдээлэл';
$labels['acll'] = 'Хайх';
$labels['aclr'] = 'Зурвас унших';
$labels['acls'] = 'Харсан төлөвт хадгалах';
$labels['aclw'] = 'Тэмдэглэгээ хийх';
$labels['acli'] = 'Оруулах (хуулж)';
$labels['aclp'] = 'Бичлэг';
$labels['aclc'] = 'Дэд хавтас үүсгэх';
$labels['aclk'] = 'Дэд хавтас үүсгэх';
$labels['acld'] = 'Захиануудыг устгах';
$labels['aclt'] = 'Захиануудыг устгах';
$labels['acle'] = 'Устгах';
$labels['aclx'] = 'Хавтас устгах';
$labels['acla'] = 'Зохицуулагч';
$labels['acln'] = 'Тайлбар зурвас';
$labels['aclfull'] = 'Бүрэн удирдлага';
$labels['aclother'] = 'Бусад';
$labels['aclread'] = 'Уншсан';
$labels['aclwrite'] = 'Бичих';
$labels['acldelete'] = 'Устгах';
$labels['shortacll'] = 'Хайх';
$labels['shortaclr'] = 'Унших';
$labels['shortaclw'] = 'Бичих';
$labels['shortaclp'] = 'Бичлэг';
$labels['shortacld'] = 'Устгах';
$labels['shortaclt'] = 'Устгах';
$labels['shortacle'] = 'Устгах';
$labels['shortacla'] = 'Зохицуулагч';
$labels['shortaclother'] = 'Бусад';
$labels['shortaclread'] = 'Унших';
$labels['shortaclwrite'] = 'Бичих';
$labels['shortacldelete'] = 'Устгах';
