<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'चाळण्या';
$labels['moveup'] = 'वर हलवा';
$labels['movedown'] = 'खाली हलवा';
$labels['filterallof'] = 'खालील सर्व नियम जुळत आहेत';
$labels['filterany'] = 'सर्व संदेश';
$labels['filteris'] = 'च्या बरोबर आहे';
$labels['filterisnot'] = 'च्या बरोबर नाही';
$labels['filterexists'] = 'अस्तित्वात आहे';
$labels['filternotexists'] = 'अस्तित्वात नाही';
$labels['filterunder'] = 'खाली';
$labels['filterover'] = 'वरती';
$labels['messagedelete'] = 'संदेश काढून टाका';
$labels['messagesactions'] = 'खालील कृती आमलात आणा :';
$labels['add'] = 'समावेश करा';
$labels['del'] = 'नष्ट करा';
$labels['sender'] = 'प्रेषक';
$labels['flagdeleted'] = 'काढून टाकलेला(ले)';
$labels['flagflagged'] = 'खूण लावलेले';
$labels['notifymethodmailto'] = 'इ-मेल्';
$labels['notifymethodtel'] = 'दूरध्वनी';
$labels['datetest'] = 'दिनांक';
$labels['advancedopts'] = 'अधिक पर्याय';
$labels['spamtestequals'] = 'च्या बरोबर आहे';
$labels['spamtestnotequals'] = 'च्या बरोबर नाही';
$labels['vacation.subject'] = 'विषय';
