<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-password/
*/

$labels['changepasswd']  = 'گۆڕینی تێپەڕەوشە';
$labels['curpasswd']  = 'تێپەڕەوشەی ئێستا:';
$labels['newpasswd']  = 'تێپەڕەوشەی نوێ:';
$labels['confpasswd']  = 'پشتڕاستکردنەوەی تێپەڕەوشەی نوێ:';
$messages['nopassword'] = 'تکایە تێپەڕەوشەی نوێ بنووسە.';
$messages['nocurpassword'] = 'تکایە تێپەڕەوشەی ئێستا بنووسە.';
$messages['passwordincorrect'] = 'تێپەڕەوشەی ئێستا نادروستە.';
$messages['passwordinconsistency'] = 'تێپەڕەوشەکان هاویەک نین، تکایە دووبارە هەوڵبدەوە.';
$messages['connecterror'] = 'نەتوانرا تێپەڕەوشەی نوێ پاشەکەوت بکرێت. هەڵەی پەیوەندیکردن.';
$messages['internalerror'] = 'نەتوانرا تێپەڕەوشەی نوێ پاشەکەوت بکرێت.';
$messages['passwordforbidden'] = 'تێپەڕەوشە نووسەی ڕێپێنەدراوی تێدایە.';
$messages['firstloginchange'] = 'ئەمە یەکەم چوونەژوورەوەتە. تکایە تێپەڕەوشەکەت بگۆڕە.';
