<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Filter';
$labels['managefilters'] = 'Atur filter email masuk';
$labels['filtername'] = 'Nama filter';
$labels['newfilter'] = 'Filter baru';
$labels['filteradd'] = 'Tambah filter';
$labels['filterdel'] = 'Hapus filter';
$labels['rules'] = 'Peraturan';
$labels['actions'] = 'Tindakan';
$labels['scope'] = 'Jangkauan';
$labels['moveup'] = 'Pindah ke atas';
$labels['movedown'] = 'Pindah ke bawah';
$labels['filterallof'] = 'cocok dengan semua aturan berikut ini';
$labels['filteranyof'] = 'cocok dengan aturan manapun';
$labels['filterany'] = 'semua pesan';
$labels['filtercontains'] = 'berisi';
$labels['filternotcontains'] = 'tidak berisi';
$labels['filteris'] = 'sama dengan';
$labels['filterisnot'] = 'tidak sama dengan';
$labels['filterexists'] = 'ada';
$labels['filternotexists'] = 'tidak ada';
$labels['filtermatches'] = 'ekspresi yg cocok';
$labels['filternotmatches'] = 'ekspresi yg tidak cocok';
$labels['filterregex'] = 'cocok dengan ekspresi reguler';
$labels['filternotregex'] = 'tidak cocok dengan ekspresi reguler';
$labels['filterunder'] = 'di bawah';
$labels['filterover'] = 'di atas';
$labels['mime'] = 'MIME';
$labels['mimepart'] = 'MIME part:';
$labels['mime-message'] = 'Pesan';
$labels['mime-anychild'] = 'Apapun';
$labels['mime-type'] = 'Tipe';
$labels['mime-subtype'] = 'Sub tipe';
$labels['mime-contenttype'] = 'Konten tipe';
$labels['mime-param'] = 'Parameter';
$labels['addrule'] = 'Tambah aturan';
$labels['delrule'] = 'Hapus aturan';
$labels['messagemoveto'] = 'Pindah pesan ke';
$labels['messageredirect'] = 'Alihkan pesan ke';
$labels['messagecopyto'] = 'Salin pesan ke';
$labels['messagesendcopy'] = 'Kirim salinan pesan ke';
$labels['messagereply'] = 'balas dengan pesan';
$labels['messagedelete'] = 'Hapus pesan';
$labels['messagediscard'] = 'Buang dengan pesan';
$labels['messagekeep'] = 'Biarkan pesan tetap didalam kotak surat';
$labels['messagesrules'] = 'Untuk email masuk:';
$labels['messagesactions'] = '...lakukan tindakan berikut';
$labels['add'] = 'Tambah';
$labels['del'] = 'Hapus';
$labels['sender'] = 'Pengirim';
$labels['recipient'] = 'Penerima';
$labels['vacationaddr'] = 'Alamat email saya:';
$labels['vacationdays'] = 'Seberapa sering mengirim pesan (dalam hari):';
$labels['vacationinterval'] = 'Seberapa sering untuk pengiriman pesan:';
$labels['vacationreason'] = 'Isi pesan (alasan liburan):';
$labels['vacationfrom'] = 'Alamat pengirim balasan:';
$labels['vacationsubject'] = 'Judul pesan:';
$labels['days'] = 'hari';
$labels['seconds'] = 'detik';
$labels['rulestop'] = 'Berhenti mengevaluasi aturan';
$labels['enable'] = 'Aktifkan/Non-Aktifkan';
$labels['filterset'] = 'Set tapis';
$labels['filtersets'] = 'Himpunan banyak filter';
$labels['filtersetadd'] = 'Tambahkan set tapis';
$labels['filtersetdel'] = 'Hapus set tapis';
$labels['filtersetact'] = 'Aktifkan set tapis saat ini';
$labels['filtersetdeact'] = 'Nonaktifkan set tapis saat ini';
$labels['filterseteditraw'] = 'Sunting set penyaring';
$labels['filterdef'] = 'Definisi filter';
$labels['filtersetname'] = 'Nama set tapis';
$labels['newfilterset'] = 'Set tapis baru';
$labels['active'] = 'aktif';
$labels['none'] = 'nihil';
$labels['fromset'] = 'dari himpunan';
$labels['fromfile'] = 'dari berkas';
$labels['filterdisabled'] = 'Filter dimatikan';
$labels['countisgreaterthan'] = 'penghitungan lebih besar dari';
$labels['countisgreaterthanequal'] = 'penghitungan lebih besa dari atau sama dengan';
$labels['countislessthan'] = 'penghitungan lebih kecil dari';
$labels['countislessthanequal'] = 'penghitungan lebih kecil dari atau sama dengan';
$labels['countequals'] = 'penghitungan sama dengan';
$labels['countnotequals'] = 'penghitungan tidak sama dengan';
$labels['valueisgreaterthan'] = 'nilai lebih besar dari';
$labels['valueisgreaterthanequal'] = 'nilai lebih besar dari atau sama dengan';
$labels['valueislessthan'] = 'nilai lebih kecil dari';
$labels['valueislessthanequal'] = 'nilai lebih kecil dari atau sama dengan';
$labels['valueequals'] = 'nilai sama dengan';
$labels['valuenotequals'] = 'nilai tidak sadengan';
$labels['setflags'] = 'Atur tanda pada pesan';
$labels['addflags'] = 'Berikan tanda pada pesan';
$labels['removeflags'] = 'Cabut tanda dari pesan';
$labels['flagread'] = 'Baca';
$labels['flagdeleted'] = 'Terhapus';
$labels['flaganswered'] = 'Terjawab';
$labels['flagflagged'] = 'Ditandai';
$labels['flagdraft'] = 'Konsep';
$labels['setvariable'] = 'Set variabel';
$labels['setvarname'] = 'Nama variabel:';
$labels['setvarvalue'] = 'Nilai variabel';
$labels['setvarmodifiers'] = 'Pengubah';
$labels['varlower'] = 'huruf kecil';
$labels['varupper'] = 'huruf besar';
$labels['varlowerfirst'] = 'karakter pertama huruf kecil';
$labels['varupperfirst'] = 'karakter pertama huruf besar';
$labels['varquotewildcard'] = 'kutip karakter khusus';
$labels['varlength'] = 'panjang';
$labels['notify'] = 'Kirim pemberitahuan';
$labels['notifytarget'] = 'Pemberitahuan yang dituju:';
$labels['notifymessage'] = 'Pemberitahuan pesan (pilihan):';
$labels['notifyoptions'] = 'Pemberitahuan untuk beberapa pilihan (pilihan):';
$labels['notifyfrom'] = 'Pemberitahuan ke pengirim (tidak harus):';
$labels['notifyimportance'] = 'Tingkat kepentingan:';
$labels['notifyimportancelow'] = 'rendah';
$labels['notifyimportancenormal'] = 'normal';
$labels['notifyimportancehigh'] = 'tinggi';
$labels['notifymethodmailto'] = 'Surat Elektronik / Email';
$labels['notifymethodtel'] = 'Telepon';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Buat filter';
$labels['usedata'] = 'Gunakan data berikut dalam filter:';
$labels['nextstep'] = 'Langkah Selanjutnya';
$labels['...'] = '...';
$labels['string'] = 'String';
$labels['currdate'] = 'Tanggal sekarang';
$labels['datetest'] = 'Tanggal';
$labels['dateheader'] = 'header / tajuk:';
$labels['year'] = 'tahun';
$labels['month'] = 'bulan';
$labels['day'] = 'hari';
$labels['date'] = 'tanggal (yyyy-mm-dd)';
$labels['julian'] = 'tanggal (kalender julian)';
$labels['hour'] = 'jam';
$labels['minute'] = 'menit';
$labels['second'] = 'detik';
$labels['time'] = 'waktu :(hh:mm:ss)';
$labels['iso8601'] = 'tanggal (ISO8601)';
$labels['std11'] = 'tanggal (RFC2822)';
$labels['zone'] = 'zona-waktu';
$labels['weekday'] = 'hari kerja (0-6)';
$labels['advancedopts'] = 'Pilihan lanjutan';
$labels['body'] = 'Isi';
$labels['address'] = 'alamat';
$labels['envelope'] = 'amplop';
$labels['modifier'] = 'peubah:';
$labels['text'] = 'teks';
$labels['undecoded'] = 'praterjemahan (mentah)';
$labels['contenttype'] = 'tipe isi';
$labels['modtype'] = 'tipe:';
$labels['allparts'] = 'semua';
$labels['domain'] = 'domain';
$labels['localpart'] = 'bagian lokal';
$labels['user'] = 'pengguna';
$labels['detail'] = 'rinci';
$labels['comparator'] = 'pembanding:';
$labels['default'] = 'standar';
$labels['octet'] = 'ketat (oktet)';
$labels['asciicasemap'] = 'case insensitive (ascii-casemap)';
$labels['asciinumeric'] = 'numeric (ascii-numeric)';
$labels['index'] = 'indeks:';
$labels['indexlast'] = 'mundur:';
$labels['spamtestequals'] = 'sama dengan';
$labels['spamtestnotequals'] = 'tidak sama dengan';
$labels['vacation'] = 'Di Luar Kantor';
$labels['vacation.reply'] = 'Balas pesan';
$labels['vacation.advanced'] = 'Pengaturan Lanjutan';
$labels['vacation.from'] = 'Alamat pengirim balasan';
$labels['vacation.subject'] = 'Judul';
$labels['vacation.body'] = 'Isi';
$labels['vacation.start'] = 'Waktu mulai';
$labels['vacation.end'] = 'Waktu berakhir';
$labels['vacation.status'] = 'Status';
$labels['vacation.on'] = 'Nyala';
$labels['vacation.off'] = 'Mati';
$labels['vacation.addresses'] = 'Alamat email saya';
$labels['vacation.interval'] = 'Balas secara interval';
$labels['vacation.after'] = 'Pasang aturan di-luar-kantor setelah';
$labels['vacation.saving'] = 'Menyimpan data...';
$labels['vacation.action'] = 'Tindakan untuk pesan masuk';
$labels['vacation.keep'] = 'Simpan';
$labels['vacation.discard'] = 'Buang';
$labels['vacation.redirect'] = 'Alihkan ke';
$labels['vacation.copy'] = 'Kirim salinan ke';
$labels['forward'] = 'Diteruskan / Meneruskan';
$labels['forward.redirect'] = 'Alihkan ke';
$labels['forward.copy'] = 'Kirim salinan ke';
$labels['forward.on'] = 'Nyala';
$labels['forward.off'] = 'Mati';
$labels['forward.status'] = 'Status:';
$labels['forward.action'] = 'Tindakan untuk eksekusi masuknya surat';
$labels['forward.saving'] = 'Menyimpan data...';
$labels['filladdresses'] = 'Isi dengan semua alamat saya';
$labels['arialabelfiltersetactions'] = 'Tindakan untuk penyaringan';
$labels['arialabelfilteractions'] = 'Tindakan penyaringan';
$labels['arialabelfilterform'] = 'Properti untuk penyaringan';
$labels['ariasummaryfilterslist'] = 'Daftar penyaringan';
$labels['ariasummaryfiltersetslist'] = 'Daftar penyaringan yang telah di set';
$labels['filterstitle'] = 'Ubah penyaringan untuk email masuk';
$labels['vacationtitle'] = 'Ubah aturan untuk sedang-diluar-kantor';
$labels['forwardtitle'] = 'Edit peraturan untuk meneruskan surat';
$labels['message'] = 'Pesan';
$labels['duplicate'] = 'duplikat';
$labels['notduplicate'] = 'tidak duplikat';
$labels['duplicate.handle'] = 'handle:';
$labels['duplicate.header'] = 'header:';
$labels['duplicate.uniqueid'] = 'identifier:';
$labels['duplicate.seconds'] = 'tenggat waktu (detik):';
$labels['duplicate.last'] = 'relatif terhadap eksekusi terakhir';
$messages['filterunknownerror'] = 'Error pada server tak dikenali.';
$messages['filterconnerror'] = 'Tidak dapat menyambung ke server.';
$messages['filterdeleteerror'] = 'Tidak dapat menghapus penyaringan. Terjadi kesalahan pada server.';
$messages['filterdeleted'] = 'Penyaringan berhasil dihapus.';
$messages['filtersaved'] = 'Penyaringan berhasil disimpan.';
$messages['filtersaveerror'] = 'Tidak dapat menyimpan penyaringan. Terjadi kesalahan pada server.';
$messages['filterformerror'] = 'Formulir penyaring memuat kesalahan.';
$messages['filterdeleteconfirm'] = 'Yakin untuk menghapus penyaringan terpilih?';
$messages['ruledeleteconfirm'] = 'Yakin untuk menghapus aturan terpilih?';
$messages['actiondeleteconfirm'] = 'Yakin untuk menghapus tindakan terpilih?';
$messages['forbiddenchars'] = 'Karakter terlarang pada isian.';
$messages['cannotbeempty'] = 'Isian tidak bisa kosong.';
$messages['ruleexist'] = 'Penyaringan dengan nama tersebut sudah ada.';
$messages['setactivateerror'] = 'Tidak bisa mengaktifkan set tapis yang dipilih. Terjadi kesalahan server.';
$messages['setdeactivateerror'] = 'Tidak bisa menonaktifkan set tapis yang dipilih. Terjadi kesalahan server.';
$messages['setdeleteerror'] = 'Tidak bisa menghapus set tapis yang dipilih. Terjadi kesalahan server.';
$messages['setactivated'] = 'Set tapis sukses diaktifkan.';
$messages['setdeactivated'] = 'Set tapis sukses dinonaktifkan.';
$messages['setdeleted'] = 'Set tapis sukses dihapus.';
$messages['setupdated'] = 'Set tapis sukses diperbarui';
$messages['setdeleteconfirm'] = 'Anda yakin hendak menghapus set tapis yang dipilih?';
$messages['setcreateerror'] = 'Tidak bisa membuat set tapis. Terjadi kesalahan server.';
$messages['setcreated'] = 'Set tapis sukses dibuat.';
$messages['activateerror'] = 'Tidak dapat mengaktifkan penyaringan terpilih. Terjadi kesalahan pada server';
$messages['deactivateerror'] = 'Tidak dapat mematikan penyaringan terpilih. Terjadi kesalahan pada server';
$messages['deactivated'] = 'Berhasil menghidupkan penyaringan.';
$messages['activated'] = 'Berhasil mematikan penyaringan.';
$messages['moved'] = 'Berhasil memindahkan penyaringan.';
$messages['moveerror'] = 'Tidak bisa memindahkan penyaringan terpilih. Ada kesalahan di server.';
$messages['nametoolong'] = 'Nama terlalu panjang.';
$messages['namereserved'] = 'Nama sudah terpesan.';
$messages['setexist'] = 'Kumpulan sudah ada.';
$messages['nodata'] = 'Setidaknya satu posisi harus dipilih!';
$messages['invaliddateformat'] = 'Format tanggal atau bagian dari tanggal salah';
$messages['saveerror'] = 'Tidak dapat menyimpan data. Terjadi kesalahan pada server.';
$messages['vacationsaved'] = 'Data di-luar-kantor sukses disimpan';
$messages['forwardsaved'] = 'Meneruskan data sukses tersimpan';
$messages['emptyvacationbody'] = 'Tubuh pesan liburan diperlukan!';
$messages['duplicate.conflict.err'] = 'Header dan identifier unik keduanya tidak diijinkan.';
$messages['disabledaction'] = 'Tindakan tidak di izinkan';
