<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'Arkistoi';
$labels['buttontitle'] = 'Arkistoi viesti';
$labels['archived'] = 'Arkistoitu onnistuneesti';
$labels['archivedreload'] = 'Arkistointi onnistui. Päivitä sivu nähdäksesi uudet arkistokansiot.';
$labels['archiveerror'] = 'Joidenkin viestien arkistointi epäonnistui';
$labels['archivefolder'] = 'Arkisto';
$labels['settingstitle'] = 'Arkistointi';
$labels['archivetype'] = 'Jaa arkisto';
$labels['archivetypeyear'] = 'Vuodella (esim. Arkisto/2012)';
$labels['archivetypemonth'] = 'Kuukaudella (esim. Arkisto/2012/06)';
$labels['archivetypetbmonth'] = 'Kuukausi - Thunderbird-yhteensopiva (esim. Archive/2012/2012-06)';
$labels['archivetypefolder'] = 'Alkuperäinen kansio';
$labels['archivetypefolderyear'] = 'Vuosi ja alkuperäinen kansio (esim. Arkisto/2012/…)';
$labels['archivetypefoldermonth'] = 'Vuosi, kuukausi ja alkuperäinen kansio (esim. Arkisto/2012/06/…)';
$labels['archivetypesender'] = 'Lähettäjän osoite';
$labels['unkownsender'] = 'tuntematon';
$labels['readonarchive'] = 'Merkitse viesti luetuksi arkistoon';
