<?php

/*
 +-----------------------------------------------------------------------+
 | localization/zh_TW/csv2vcard.inc                                      |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2012, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Aleksander Machniak <alec@alec.pl>                            |
 +-----------------------------------------------------------------------+
*/
$map = array();
$map['anniversary'] = "紀念日";
$map['assistants_name'] = "助理";
$map['assistants_phone'] = "助理電話";
$map['birthday'] = "生日";
$map['business_city'] = "商務 - 市/鎮";
$map['business_countryregion'] = "商務 - 國家/地區";
$map['business_fax'] = "商務傳真";
$map['business_phone'] = "商務電話";
$map['business_phone_2'] = "商務電話 2";
$map['business_postal_code'] = "商務 - 郵遞區號";
$map['business_state'] = "商務 - 縣市";
$map['business_street'] = "商務 - 街";
$map['car_phone'] = "汽車電話";
$map['categories'] = "類別";
$map['company'] = "公司";
$map['department'] = "部門";
$map['email_address'] = "電子郵件地址";
$map['first_name'] = "名字";
$map['gender'] = "性別";
$map['home_city'] = "住家 - 市/鎮";
$map['home_countryregion'] = "住家 - 國家/地區";
$map['home_fax'] = "住家傳真";
$map['home_phone'] = "住家電話";
$map['home_phone_2'] = "住家電話 2";
$map['home_postal_code'] = "住家 - 郵遞區號";
$map['home_state'] = "住家 - 縣/市";
$map['home_street'] = "住家 - 街";
$map['job_title'] = "職稱";
$map['last_name'] = "姓氏";
$map['managers_name'] = "主管名稱";
$map['middle_name'] = "中間名";
$map['mobile_phone'] = "行動電話";
$map['notes'] = "記事";
$map['other_city'] = "其他 - 市/鎮";
$map['other_countryregion'] = "其他 - 國家/地區";
$map['other_fax'] = "其他傳真";
$map['other_phone'] = "其他電話";
$map['other_postal_code'] = "其他 - 郵遞區號";
$map['other_state'] = "其他 - 縣/市";
$map['other_street'] = "其他 - 街";
$map['pager'] = "呼叫器";
$map['primary_phone'] = "代表電話";
$map['spouse'] = "配偶";
$map['suffix'] = "稱謂";
$map['title'] = "頭銜";
$map['web_page'] = "網頁";
$map['last'] = "姓";
$map['first'] = "名";
$map['birth_day'] = "生日 (日)";
$map['birth_month'] = "生日 (月)";
$map['birth_year'] = "生日 (年)";
$map['display_name'] = "顯示名稱";
$map['fax_number'] = "傳真號碼";
$map['home_address'] = "住家住址";
$map['home_country'] = "居住國家";
$map['home_zipcode'] = "住址郵遞區號";
$map['mobile_number'] = "手機號碼";
$map['nickname'] = "暱稱";
$map['organization'] = "Organization";
$map['pager_number'] = "呼叫器號碼";
$map['primary_email'] = "主要 Email";
$map['secondary_email'] = "次要 Email";
$map['web_page_1'] = "網頁 1";
$map['web_page_2'] = "網頁 2";
$map['work_phone'] = "商務電話";
$map['work_address'] = "商務地址";
$map['work_country'] = "商務國家";
$map['work_zipcode'] = "商務郵遞區號";
$map['work_city'] = "商務市鎮";
$map['work_state'] = "商務縣市";
$map['home_city_short'] = "居住市鎮";
$map['home_state_short'] = "居住縣市";
