<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Welkom bij $product';
$labels['username'] = 'Gebruikersnaam';
$labels['password'] = 'Wachtwoord';
$labels['server'] = 'Server';
$labels['login'] = 'Inloggen';
$labels['menu'] = 'Menu';
$labels['logout'] = 'Uitloggen';
$labels['mail'] = 'E-mail';
$labels['settings'] = 'Instellingen';
$labels['addressbook'] = 'Adresboek';
$labels['inbox'] = 'Postvak In';
$labels['drafts'] = 'Concepten';
$labels['sent'] = 'Verzonden';
$labels['trash'] = 'Prullenbak';
$labels['junk'] = 'Spam';
$labels['show_real_foldernames'] = 'Toon echte namen voor speciale mappen';
$labels['subject'] = 'Onderwerp';
$labels['from'] = 'Afzender';
$labels['sender'] = 'Afzender';
$labels['to'] = 'Ontvanger';
$labels['cc'] = 'Kopie';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Antwoord-aan';
$labels['followupto'] = 'Followup-Aan';
$labels['date'] = 'Datum';
$labels['size'] = 'Grootte';
$labels['priority'] = 'Prioriteit';
$labels['organization'] = 'Organisatie';
$labels['readstatus'] = 'Gelezen?';
$labels['listoptions'] = 'Lijstopties...';
$labels['listoptionstitle'] = 'Lijst Opties';
$labels['mailboxlist'] = 'Mappen';
$labels['messagesfromto'] = 'Bericht $from t/m $to van $count';
$labels['threadsfromto'] = 'Conversatie $from t/m $to van $count';
$labels['messagenrof'] = 'Bericht $nr van $count';
$labels['fromtoshort'] = '$from – $to van $count';
$labels['copy'] = 'Kopiëren';
$labels['move'] = 'Verplaats';
$labels['moveto'] = 'Verplaats naar...';
$labels['copyto'] = 'Kopiëren naar...';
$labels['download'] = 'Download';
$labels['open'] = 'Openen';
$labels['showattachment'] = 'Toon';
$labels['showanyway'] = 'Laat toch zien';
$labels['filename'] = 'Bestandsnaam';
$labels['filesize'] = 'Bestandsgrootte';
$labels['addtoaddressbook'] = 'Toevoegen aan adresboek';
$labels['sun'] = 'Zo';
$labels['mon'] = 'Ma';
$labels['tue'] = 'Di';
$labels['wed'] = 'Wo';
$labels['thu'] = 'Do';
$labels['fri'] = 'Vr';
$labels['sat'] = 'Za';
$labels['sunday'] = 'zondag';
$labels['monday'] = 'maandag';
$labels['tuesday'] = 'dinsdag';
$labels['wednesday'] = 'woensdag';
$labels['thursday'] = 'donderdag';
$labels['friday'] = 'vrijdag';
$labels['saturday'] = 'zaterdag';
$labels['jan'] = 'jan';
$labels['feb'] = 'feb';
$labels['mar'] = 'mrt';
$labels['apr'] = 'apr';
$labels['may'] = 'mei';
$labels['jun'] = 'jun';
$labels['jul'] = 'jul';
$labels['aug'] = 'aug';
$labels['sep'] = 'sep';
$labels['oct'] = 'okt';
$labels['nov'] = 'nov';
$labels['dec'] = 'dec';
$labels['longjan'] = 'januari';
$labels['longfeb'] = 'februari';
$labels['longmar'] = 'maart';
$labels['longapr'] = 'april';
$labels['longmay'] = 'mei';
$labels['longjun'] = 'juni';
$labels['longjul'] = 'juli';
$labels['longaug'] = 'augustus';
$labels['longsep'] = 'september';
$labels['longoct'] = 'oktober';
$labels['longnov'] = 'november';
$labels['longdec'] = 'december';
$labels['today'] = 'Vandaag';
$labels['refresh'] = 'Vernieuwen';
$labels['checkmail'] = 'Controleer op nieuwe berichten';
$labels['compose'] = 'Opstellen';
$labels['writenewmessage'] = 'Maak een nieuw bericht';
$labels['reply'] = 'Beantwoorden';
$labels['replytomessage'] = 'Beantwoord het bericht';
$labels['replytoallmessage'] = 'Beantwoord lijst of afzender en alle ontvangers';
$labels['replyall'] = 'Beantwoord iedereen';
$labels['replylist'] = 'Beantwoord lijst';
$labels['forward'] = 'Doorsturen';
$labels['forwardinline'] = 'Doorsturen in bericht';
$labels['forwardattachment'] = 'Doorsturen als bijlage';
$labels['forwardmessage'] = 'Bericht doorsturen';
$labels['bouncemsg'] = 'Opnieuw verzenden (kaatsen)';
$labels['bounce'] = 'Opnieuw verzenden';
$labels['deletemessage'] = 'Verwijder het bericht';
$labels['movemessagetotrash'] = 'Verplaats het bericht naar de prullenbak';
$labels['printmessage'] = 'Dit bericht afdrukken';
$labels['previousmessage'] = 'Toon het vorige bericht';
$labels['firstmessage'] = 'Toon het eerste bericht';
$labels['nextmessage'] = 'Toon het volgende bericht';
$labels['lastmessage'] = 'Toon het laatste bericht';
$labels['backtolist'] = 'Terug naar berichtenoverzicht';
$labels['viewsource'] = 'Toon bron';
$labels['mark'] = 'Markeren';
$labels['markmessages'] = 'Markeer berichten';
$labels['markread'] = 'Gelezen';
$labels['markunread'] = 'Ongelezen';
$labels['markflagged'] = 'Gemarkeerd';
$labels['markunflagged'] = 'Niet-gemarkeerd';
$labels['moreactions'] = 'Meer acties...';
$labels['markallread'] = 'Markeer alles als gelezen';
$labels['folders-cur'] = 'Alleen geselecteerde map ';
$labels['folders-sub'] = 'Geselecteerde map en sub-mapppen';
$labels['folders-all'] = 'Alle mappen';
$labels['more'] = 'Meer';
$labels['back'] = 'Terug';
$labels['options'] = 'Opties';
$labels['composeoptions'] = 'Opties voor opstellen';
$labels['optionsandattachments'] = 'Opties en bijlages';
$labels['actions'] = 'Acties';
$labels['first'] = 'Eerste';
$labels['last'] = 'Laatste';
$labels['previous'] = 'Vorige';
$labels['next'] = 'Volgende';
$labels['select'] = 'Selecteer';
$labels['selection'] = 'Selectie';
$labels['all'] = 'Allemaal';
$labels['none'] = 'Geen';
$labels['currpage'] = 'Huidige pagina';
$labels['isread'] = 'Gelezen';
$labels['unread'] = 'Ongelezen';
$labels['flagged'] = 'Gemarkeerd';
$labels['unflagged'] = 'Ongemarkeerd';
$labels['unanswered'] = 'Onbeantwoord';
$labels['withattachment'] = 'Met bijlage';
$labels['deleted'] = 'Verwijderd';
$labels['undeleted'] = 'Niet verwijderd';
$labels['replied'] = 'Beantwoord';
$labels['forwarded'] = 'Doorgestuurd';
$labels['invert'] = 'Selectie omkeren';
$labels['filter'] = 'Filter';
$labels['list'] = 'Lijst';
$labels['threads'] = 'Conversaties';
$labels['expand-all'] = 'Alles uitklappen';
$labels['expand-unread'] = 'Ongelezen uitklappen';
$labels['collapse-all'] = 'Alles inklappen';
$labels['threaded'] = 'Conversaties';
$labels['showunread'] = 'Toon ongelezen berichten';
$labels['autoexpand_threads'] = 'Klap alle conversaties uit';
$labels['do_expand'] = 'alle conversaties';
$labels['expand_only_unread'] = 'alleen met ongelezen berichten';
$labels['fromto'] = 'Afzender/Ontvanger';
$labels['flag'] = 'Markeer';
$labels['attachment'] = 'Bijlage';
$labels['nonesort'] = 'Geen';
$labels['sentdate'] = 'Verzenddatum';
$labels['arrival'] = 'Ontvangstdatum';
$labels['asc'] = 'oplopend';
$labels['desc'] = 'aflopend';
$labels['listcolumns'] = 'Kolommen';
$labels['listsorting'] = 'Sorteer op kolom';
$labels['listorder'] = 'Sorteervolgorde';
$labels['listmode'] = 'Lijstweergave';
$labels['lmode'] = 'Lijst modus';
$labels['layout'] = 'Indeling';
$labels['layoutwidescreen'] = 'Breedbeeld';
$labels['layoutdesktop'] = 'Bureaublad';
$labels['layoutlist'] = 'Lijst';
$labels['layoutwidescreendesc'] = 'Breedbeeld (3 kolommen)';
$labels['layoutdesktopdesc'] = 'Bureaublad (Brede lijst en voorbeeld van bericht onder)';
$labels['layoutlistdesc'] = 'Lijst (geen voorbeeld van bericht)';
$labels['folderactions'] = 'Mapacties...';
$labels['compact'] = 'Opschonen';
$labels['empty'] = 'Legen';
$labels['importmessages'] = 'Berichten importeren';
$labels['mailimportdesc'] = 'U kunt e-mail uploaden met bestanden in <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME-</a> of <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>-formaat.';
$labels['mailimportzip'] = 'Meerdere bestanden kunnen gecomprimeerd worden in zip-bestanden.';
$labels['quota'] = 'Opslagverbruik';
$labels['unknown'] = 'onbekend';
$labels['unlimited'] = 'onbeperkt';
$labels['quotatype'] = 'Soort quotum';
$labels['quotatotal'] = 'Limiet';
$labels['quotaused'] = 'Gebruikt';
$labels['quotastorage'] = 'Schijfruimte';
$labels['quotamessage'] = 'Aantal berichten';
$labels['shortheaderdate'] = 'Op $date';
$labels['shortheaderto'] = 'Naar $to op $date';
$labels['shortheaderfrom'] = 'Van $from op $date';
$labels['quicksearch'] = 'Snel zoeken';
$labels['searchplaceholder'] = 'Zoeken...';
$labels['resetsearch'] = 'Wis zoekopdracht';
$labels['searchmod'] = 'Zoekopties';
$labels['msgtext'] = 'Gehele bericht';
$labels['body'] = 'Inhoud';
$labels['type'] = 'Type';
$labels['namex'] = 'Naam';
$labels['searchscope'] = 'Zoekbereik';
$labels['currentfolder'] = 'Huidige map';
$labels['subfolders'] = 'Deze en onderliggende mappen';
$labels['allfolders'] = 'Alle mappen';
$labels['searchinterval-1W'] = 'ouder dan een week';
$labels['searchinterval-1M'] = 'ouder dan een maand';
$labels['searchinterval-1Y'] = 'ouder dan een jaar';
$labels['searchinterval1W'] = 'nieuwer dan een week';
$labels['searchinterval1M'] = 'nieuwer dan een maand';
$labels['searchinterval1Y'] = 'nieuwer dan een jaar';
$labels['openinextwin'] = 'Openen in een nieuw venster';
$labels['emlsave'] = 'Opslaan (.eml)';
$labels['changeformattext'] = 'Weergeven als platte tekst';
$labels['changeformathtml'] = 'Weergeven als opgemaakte tekst (HTML)';
$labels['editasnew'] = 'Als nieuw bewerken';
$labels['send'] = 'Verzenden';
$labels['sendmessage'] = 'Verstuur bericht';
$labels['savemessage'] = 'Bewaar als concept';
$labels['addattachment'] = 'Bijlage toevoegen';
$labels['charset'] = 'Tekenset';
$labels['editortype'] = 'Soort tekstverwerker';
$labels['returnreceipt'] = 'Ontvangstbevestiging';
$labels['dsn'] = 'Afleveringsbericht (DSN)';
$labels['mailreplyintro'] = '$sender schreef op $date:';
$labels['originalmessage'] = 'Oorspronkelijke bericht';
$labels['selectimage'] = 'Selecteer afbeelding';
$labels['addimage'] = 'Afbeelding toevoegen';
$labels['selectmedia'] = 'Video selecteren';
$labels['addmedia'] = 'Film toevoegen';
$labels['encrypt'] = 'Versleutel';
$labels['encryptmessage'] = 'Versleutel bericht';
$labels['encryptmessagemailvelope'] = 'Versleutel bericht met Mailvelope';
$labels['importpubkeys'] = 'Publieke sleutels importeren';
$labels['encryptedsendialog'] = 'Versleuteld bericht versturen';
$labels['encryptandsign'] = 'Versleutelen en ondertekenen';
$labels['keyid'] = 'Sleutel ID';
$labels['keylength'] = 'Bits';
$labels['keyexpired'] = 'Verlopen';
$labels['keyrevoked'] = 'Ingetrokken';
$labels['bccinstead'] = 'Bcc gebruiken';
$labels['addheader'] = 'Ontvanger toevoegen (header)';
$labels['insert'] = 'Invoegen';
$labels['insertcontact'] = 'Contact(en) invoegen';
$labels['recipient'] = 'Ontvanger';
$labels['recipientedit'] = 'Ontvanger aanpassen';
$labels['editidents'] = 'Identiteiten bewerken';
$labels['spellcheck'] = 'Spelling';
$labels['checkspelling'] = 'Controleer spelling';
$labels['resumeediting'] = 'Doorgaan met opstellen';
$labels['revertto'] = 'Terugwijzigen in';
$labels['restore'] = 'Herstellen';
$labels['restoremessage'] = 'Bericht herstellen?';
$labels['ignore'] = 'Negeren';
$labels['responses'] = 'Reacties';
$labels['insertresponse'] = 'Reactie invoegen';
$labels['manageresponses'] = 'Reacties beheren';
$labels['newresponse'] = 'Nieuw antwoord aanmaken';
$labels['addresponse'] = 'Antwoord toevoegen';
$labels['editresponse'] = 'Bewerk reactie';
$labels['editresponses'] = 'Bewerk reactie';
$labels['responsename'] = 'Naam';
$labels['responsetext'] = 'Reactie';
$labels['attach'] = 'Bijvoegen';
$labels['attachments'] = 'Bijlagen';
$labels['upload'] = 'Toevoegen';
$labels['uploadprogress'] = '$percent ($current van $total)';
$labels['close'] = 'Sluit';
$labels['messageoptions'] = 'Berichtopties...';
$labels['togglecomposeoptions'] = 'Wissel opties voor opstellen';
$labels['attachmentrename'] = 'Hernoem bijlage';
$labels['low'] = 'Laag';
$labels['lowest'] = 'Laagste';
$labels['normal'] = 'Normaal';
$labels['high'] = 'Hoog';
$labels['highest'] = 'Hoogste';
$labels['nosubject'] = '(geen onderwerp)';
$labels['showimages'] = 'Toon afbeeldingen';
$labels['allow'] = 'Toestaan';
$labels['alwaysshow'] = 'Afbeeldingen van $sender altijd tonen';
$labels['alwaysallow'] = 'Altijd van $sender toestaan';
$labels['isdraft'] = 'Dit is een conceptbericht.';
$labels['andnmore'] = '$nr meer...';
$labels['details'] = 'Details';
$labels['headers'] = 'Headers';
$labels['allheaders'] = 'Alle headers...';
$labels['togglemoreheaders'] = 'Toon meer berichtheaders';
$labels['togglefullheaders'] = 'Originele berichtheaders aan/uit';
$labels['htmltoggle'] = 'Opgemaakt (HTML)';
$labels['plaintoggle'] = 'Platte tekst';
$labels['savesentmessagein'] = 'Bewaar verzonden bericht in';
$labels['dontsave'] = 'niet bewaren';
$labels['maxuploadsize'] = 'Maximum toegestane bestandsgrootte is $size';
$labels['addcc'] = 'Cc toevoegen';
$labels['addbcc'] = 'Bcc toevoegen';
$labels['addreplyto'] = 'Antwoord-aan toevoegen';
$labels['addfollowupto'] = 'Followup-To toevoegen';
$labels['mdnrequest'] = 'De afzender van dit bericht heeft gevraagd een melding te ontvangen wanneer u dit bericht heeft gelezen. Wilt u deze melding verzenden?';
$labels['receiptread'] = 'Ontvangstbevestiging (gelezen)';
$labels['yourmessage'] = 'Dit is een ontvangstbevestiging voor uw bericht';
$labels['receiptnote'] = 'Let op: Dit bevestigt alleen dat uw bericht bij de geadresseerde is weergegeven. Er is geen garantie dat de geadresseerde het bericht daadwerkelijk heeft gelezen of de inhoud ervan heeft begrepen.';
$labels['zoomin'] = 'Inzoomen';
$labels['zoomout'] = 'Uitzoomen';
$labels['rotate'] = 'Draaien';
$labels['increaseimage'] = 'Afbeelding vergroten';
$labels['decreaseimage'] = 'Afbeelding verkleinen';
$labels['rotateimage'] = 'Afbeelding draaien';
$labels['showtools'] = 'Afbeelding opties weergeven';
$labels['hidetools'] = 'Afbeelding opties verbergen';
$labels['name'] = 'Weergavenaam';
$labels['firstname'] = 'Voornaam';
$labels['surname'] = 'Achternaam';
$labels['middlename'] = 'Tweede naam';
$labels['nameprefix'] = 'Voorvoegsel';
$labels['namesuffix'] = 'Achtervoegsel';
$labels['nickname'] = 'Bijnaam';
$labels['jobtitle'] = 'Functietitel';
$labels['department'] = 'Afdeling';
$labels['gender'] = 'Geslacht';
$labels['maidenname'] = 'Meisjesnaam';
$labels['email'] = 'E-mail';
$labels['phone'] = 'Telefoon';
$labels['address'] = 'Adres';
$labels['street'] = 'Straat';
$labels['locality'] = 'Stad';
$labels['zipcode'] = 'Postcode';
$labels['region'] = 'Provincie/staat';
$labels['country'] = 'Land';
$labels['birthday'] = 'Geboortedatum';
$labels['anniversary'] = 'Gedenkdatum';
$labels['website'] = 'Website';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Opmerkingen';
$labels['male'] = 'Man';
$labels['female'] = 'Vrouw';
$labels['manager'] = 'Leidinggevende';
$labels['assistant'] = 'Assistent';
$labels['spouse'] = 'Echtgenoot';
$labels['allfields'] = 'Alle velden';
$labels['search'] = 'Zoeken';
$labels['searchresult'] = 'Zoekresultaat';
$labels['advsearch'] = 'Geavanceerd zoeken';
$labels['advanced'] = 'Geavanceerd';
$labels['other'] = 'Anders';
$labels['printcontact'] = 'Contactpersoon printen';
$labels['qrcode'] = 'QR-code';
$labels['typehome'] = 'Thuis';
$labels['typework'] = 'Werk';
$labels['typeother'] = 'Anders';
$labels['typemobile'] = 'Mobiel';
$labels['typemain'] = 'Belangrijkste';
$labels['typehomefax'] = 'Fax thuis';
$labels['typeworkfax'] = 'Fax werk';
$labels['typecar'] = 'Auto';
$labels['typepager'] = 'Pieper';
$labels['typevideo'] = 'Video';
$labels['typeassistant'] = 'Assistent';
$labels['typehomepage'] = 'Website';
$labels['typeblog'] = 'Weblog';
$labels['typeprofile'] = 'Profiel';
$labels['addfield'] = 'Veld toevoegen...';
$labels['addcontact'] = 'Contact toevoegen';
$labels['editcontact'] = 'Contactpersoon wijzigen';
$labels['contacts'] = 'Contactpersonen';
$labels['contactproperties'] = 'Gegevens van contactpersoon';
$labels['contactnameandorg'] = 'Naam en organisatie';
$labels['personalinfo'] = 'Persoonlijke informatie';
$labels['personal'] = 'Persoonlijk';
$labels['contactphoto'] = 'Contactfoto';
$labels['edit'] = 'Wijzig';
$labels['cancel'] = 'Annuleren';
$labels['save'] = 'Opslaan';
$labels['delete'] = 'Verwijder';
$labels['discard'] = 'Weggooien';
$labels['continue'] = 'Doorgaan';
$labels['ok'] = 'OK';
$labels['rename'] = 'Hernoemen';
$labels['addphoto'] = 'Toevoegen';
$labels['replacephoto'] = 'Vervangen';
$labels['uploadphoto'] = 'Foto uploaden';
$labels['choosefile'] = 'Kies bestand...';
$labels['choosefiles'] = 'Kies bestanden...';
$labels['browse'] = 'Blader';
$labels['newcontact'] = 'Nieuw contact aanmaken';
$labels['deletecontact'] = 'Verwijder geselecteerde contactpersonen';
$labels['composeto'] = 'Stuur een bericht naar';
$labels['contactsfromto'] = 'Contactpersonen $from t/m $to van $count';
$labels['print'] = 'Afdrukken';
$labels['export'] = 'Exporteren';
$labels['exportall'] = 'Alles exporteren';
$labels['exportsel'] = 'Selectie exporteren';
$labels['exportvcards'] = 'Exporteer contactpersonen in vCard-formaat';
$labels['newgroup'] = 'Nieuwe groep maken';
$labels['addgroup'] = 'Groep toevoegen';
$labels['grouprename'] = 'Groep hernoemen';
$labels['groupdelete'] = 'Groep verwijderen';
$labels['groupassign'] = 'Aan groep toevoegen...';
$labels['groupremove'] = 'Van groep verwijderen...';
$labels['groupremoveselected'] = 'Verwijder geselecteerde contactpersonen van groep';
$labels['uponelevel'] = 'Een niveau omhoog';
$labels['previouspage'] = 'Vorige pagina';
$labels['firstpage'] = 'Eerste pagina';
$labels['nextpage'] = 'Volgende pagina';
$labels['lastpage'] = 'Laatste pagina';
$labels['group'] = 'Groep';
$labels['groups'] = 'Groepen';
$labels['listgroup'] = 'Toon groepsleden';
$labels['personaladrbook'] = 'Persoonlijk adresboek';
$labels['searchsave'] = 'Zoekopdracht opslaan';
$labels['searchdelete'] = 'Zoekopdracht verwijderen';
$labels['import'] = 'Importeren';
$labels['importcontacts'] = 'Contactpersonen importeren';
$labels['importfromfile'] = 'Importeer van bestand';
$labels['importtarget'] = 'Contacten toevoegen aan';
$labels['importreplace'] = 'Vervang het complete adresboek';
$labels['importgroups'] = 'Importeer groepstoewijzingen';
$labels['importgroupsall'] = 'Allemaal (maak groepen aan indien nodig)';
$labels['importgroupsexisting'] = 'Alleen voor bestaande groepen';
$labels['importdesc'] = 'U kunt contactpersonen uploaden van een bestaand adresboek.<br/>Op dit moment ondersteunen we het importeren van adresboeken in <a href="https://en.wikipedia.org/wiki/VCard">vCard-</a>en CSV-formaat (kommagescheiden tekstbestand).';
$labels['done'] = 'Klaar';
$labels['settingsfor'] = 'Instellingen voor';
$labels['about'] = 'Over';
$labels['preferences'] = 'Instellingen';
$labels['userpreferences'] = 'Gebruikersinstellingen';
$labels['editpreferences'] = 'Wijzig gebruikersinstellingen';
$labels['identities'] = 'Identiteiten';
$labels['manageidentities'] = 'Identiteiten beheren';
$labels['newidentity'] = 'Nieuwe identiteit';
$labels['addidentity'] = 'Identiteit toevoegen';
$labels['editidentity'] = 'Identiteit bewerken';
$labels['identityencryption'] = 'Versleuteling';
$labels['preferhtml'] = 'Toon berichten in HTML-opmaak';
$labels['defaultcharset'] = 'Standaard tekenset';
$labels['htmlmessage'] = 'HTML-bericht';
$labels['messagepart'] = 'Gedeelte';
$labels['digitalsig'] = 'Digitale handtekening';
$labels['dateformat'] = 'Datumnotatie';
$labels['timeformat'] = 'Tijdweergave';
$labels['prettydate'] = 'Leesbare datums';
$labels['setdefault'] = 'Stel in als standaard';
$labels['autodetect'] = 'Automatisch';
$labels['language'] = 'Taal';
$labels['timezone'] = 'Tijdzone';
$labels['pagesize'] = 'Aantal berichten per pagina';
$labels['signature'] = 'Ondertekening';
$labels['dstactive'] = 'Zomertijd';
$labels['showinextwin'] = 'Bericht in een nieuw venster openen';
$labels['composeextwin'] = 'In een nieuw venster bewerken';
$labels['htmleditor'] = 'Berichten opstellen in HTML-opmaak';
$labels['htmlonreply'] = 'alleen bij beantwoorden van HTML-berichten';
$labels['htmlonreplyandforward'] = 'bij doorsturen of beantwoorden van een HTML-bericht';
$labels['htmlsignature'] = 'HTML-ondertekening';
$labels['showemail'] = 'Toon e-mailadressen met weergavenaam';
$labels['previewpane'] = 'Toon voorbeeldvenster';
$labels['skin'] = 'Interfacestijl';
$labels['logoutclear'] = 'Prullenbak legen bij uitloggen';
$labels['logoutcompact'] = 'Postvak In opschonen bij uitloggen';
$labels['uisettings'] = 'Gebruikersinterface';
$labels['serversettings'] = 'Serverinstellingen';
$labels['mailboxview'] = 'Mailboxweergave';
$labels['mdnrequests'] = 'Ontvangstmeldingen';
$labels['askuser'] = 'altijd aan mij vragen';
$labels['autosend'] = 'stuur automatisch';
$labels['autosendknown'] = 'stuur automatisch naar mijn contactpersonen,  anders vragen';
$labels['autosendknownignore'] = 'stuur automatisch naar mijn contactpersonen,  anders negeren';
$labels['ignorerequest'] = 'negeer verzoek';
$labels['readwhendeleted'] = 'Bericht na verwijderen als gelezen markeren';
$labels['flagfordeletion'] = 'Bericht niet verwijderen maar als \'te verwijderen\' markeren';
$labels['skipdeleted'] = 'Verwijderde berichten niet tonen';
$labels['deletealways'] = 'Verwijder bericht wanneer verplaatsen naar Prullenbak mislukt';
$labels['deletejunk'] = 'Verwijder direct berichten in Spam';
$labels['showremoteimages'] = 'Externe afbeeldingen weergeven';
$labels['allowremoteresources'] = 'Externe bronnen toestaan (afbeeldingen, stijlen)';
$labels['fromknownsenders'] = 'van bekende afzenders';
$labels['always'] = 'altijd';
$labels['alwaysbutplain'] = 'altijd, behalve bij antwoord in tekst zonder opmaak';
$labels['showinlineimages'] = 'Bijgevoegde afbeeldingen onder het bericht weergeven';
$labels['autosavedraft'] = 'Concept automatisch opslaan';
$labels['everynminutes'] = 'iedere $n minuten';
$labels['refreshinterval'] = 'Vernieuwen (controleer op nieuwe berichten, etc.)';
$labels['never'] = 'nooit';
$labels['immediately'] = 'onmiddellijk';
$labels['messagesdisplaying'] = 'Berichtenweergave';
$labels['messagescomposition'] = 'Berichten opstellen';
$labels['mimeparamfolding'] = 'Namen van bijlagen';
$labels['2231folding'] = 'Volledig RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Volledig RFC 2047 (andere)';
$labels['force7bit'] = 'Gebruik MIME-codering voor 8-bit karakters';
$labels['savelocalstorage'] = "Opslaan in de lokale opslag van de browser (tijdelijk)";
$labels['advancedoptions'] = 'Geavanceerde opties';
$labels['toggleadvancedoptions'] = 'Geavanceerde opties inschakelen';
$labels['focusonnewmessage'] = 'Focus browserscherm bij nieuw bericht';
$labels['checkallfolders'] = 'In alle mappen op nieuwe berichten controleren';
$labels['displaynext'] = 'Laat volgende item in lijst zien na wissen/verplaatsen';
$labels['defaultfont'] = 'Standaardlettertype voor HTML-berichten';
$labels['mainoptions'] = 'Hoofdopties';
$labels['browseroptions'] = 'Browserinstellingen';
$labels['section'] = 'Sectie';
$labels['maintenance'] = 'Onderhoud';
$labels['newmessage'] = 'Nieuw bericht';
$labels['signatureoptions'] = 'Instellingen voor ondertekening';
$labels['whenreplying'] = 'Bij antwoorden';
$labels['replyempty'] = 'het oorspronkelijke bericht niet citeren';
$labels['replytopposting'] = 'begin bericht boven het origineel';
$labels['replytoppostingnoindent'] = 'begin nieuw bericht boven het origineel (geen inspringing)';
$labels['replybottomposting'] = 'begin bericht onder het origineel';
$labels['replyremovesignature'] = 'Verwijder oorspronkelijke ondertekening van bericht bij beantwoorden';
$labels['autoaddsignature'] = 'Ondertekening automatisch toevoegen';
$labels['newmessageonly'] = 'alleen bij nieuwe berichten';
$labels['replyandforwardonly'] = 'alleen bij antwoorden en doorsturen';
$labels['insertsignature'] = 'Ondertekening invoegen';
$labels['sigbelow'] = 'Plaats ondertekening onder het geciteerde bericht';
$labels['sigseparator'] = 'Forceer standaard scheidingsteken in ondertekeningen';
$labels['automarkread'] = 'Markeer berichten als gelezen';
$labels['afternseconds'] = 'na $n seconden';
$labels['reqmdn'] = 'Vraag altijd een ontvangstbevestiging';
$labels['reqdsn'] = 'Vraag altijd om een afleveringsbericht';
$labels['replysamefolder'] = 'Bewaar reacties in de map van het beantwoorde bericht';
$labels['defaultabook'] = 'Standaard adresboek';
$labels['autocompletesingle'] = 'Alternatieve e-mailadressen niet gebruiken bij automatisch aanvullen';
$labels['listnamedisplay'] = 'Contactpersonen weergeven als';
$labels['spellcheckbeforesend'] = 'Controleer spelling voor het versturen van een bericht';
$labels['spellcheckoptions'] = 'Instellingen spellingscontrole';
$labels['spellcheckignoresyms'] = 'Negeer woorden met symbolen';
$labels['spellcheckignorenums'] = 'Negeer woorden met cijfers';
$labels['spellcheckignorecaps'] = 'Negeer woorden welke volledig uit hoofdletters bestaan';
$labels['addtodict'] = 'Voeg toe aan woordenboek';
$labels['mailtoprotohandler'] = 'Registreer protocolhandler voor mailto: links';
$labels['standardwindows'] = 'Behandel pop-ups als normale vensters';
$labels['forwardmode'] = 'Berichten doorsturen';
$labels['inline'] = 'invoegen';
$labels['asattachment'] = 'als bijlage';
$labels['replyallmode'] = 'Standaardactie van [Beantwoord iedereen]-knop';
$labels['replyalldefault'] = 'iedereen beantwoorden';
$labels['replyalllist'] = 'alleen maillijst beantwoorden (indien gevonden)';
$labels['allmessages'] = 'alle berichten';
$labels['folder'] = 'Map';
$labels['folders'] = 'Mappen';
$labels['foldername'] = 'Mapnaam';
$labels['subscribed'] = 'Geabonneerd';
$labels['messagecount'] = 'Berichten';
$labels['create'] = 'Nieuw';
$labels['createfolder'] = 'Nieuwe map maken';
$labels['managefolders'] = 'Beheer mappen';
$labels['specialfolders'] = 'Speciale mappen';
$labels['properties'] = 'Eigenschappen';
$labels['folderproperties'] = 'Mapeigenschappen';
$labels['parentfolder'] = 'Bovenliggende map';
$labels['location'] = 'Locatie';
$labels['info'] = 'Informatie';
$labels['getfoldersize'] = 'Klik om de omvang van de map te berekenen';
$labels['changesubscription'] = 'Klik om abonnering te wijzigen';
$labels['foldertype'] = 'Maptype';
$labels['personalfolder'] = 'Privémap';
$labels['otherfolder'] = 'Map van andere gebruiker';
$labels['sharedfolder'] = 'Publieke map';
$labels['findfolders'] = 'Zoek mappen';
$labels['findcontacts'] = 'Zoek contactpersonen';
$labels['findmail'] = 'Zoek berichten';
$labels['namespace.personal'] = 'Persoonlijk';
$labels['namespace.other'] = 'Andere gebruikers';
$labels['namespace.shared'] = 'Gedeeld';
$labels['dualuselabel'] = 'Bevat alleen';
$labels['dualusemail'] = 'berichten';
$labels['dualusefolder'] = 'mappen';
$labels['generate'] = 'Aanmaken';
$labels['encryptioncreatekey'] = 'Maak een nieuw sleutelpaar aan';
$labels['openmailvelopesettings'] = 'open Mailvelope Instellingen';
$labels['encryptionprivkeysinmailvelope'] = 'U heeft $nr overeenkomende privésleutels opgeslagen in Mailvelope';
$labels['encryptionnoprivkeysinmailvelope'] = 'Deze afzender zijn indentiteit heeft (nog) geen PGP-privésleutels opgeslagen in uw Mailvelope extensie. Wilt u deze aanmaken om versleuteling van berichten in te kunnen schakelen?';
$labels['encryption'] = 'Versleuteling';
$labels['sortby'] = 'Sorteer op';
$labels['sortasc'] = 'Sorteer oplopend';
$labels['sortdesc'] = 'Sorteer aflopend';
$labels['undo'] = 'Ongedaan maken';
$labels['installedplugins'] = 'Geïnstalleerde plug-ins';
$labels['plugin'] = 'Invoegtoepassing';
$labels['version'] = 'Versie';
$labels['source'] = 'Broncode';
$labels['license'] = 'Licentie';
$labels['support'] = 'Hulp nodig?';
$labels['savedsearches'] = 'Opgeslagen zoekacties';
$labels['dateformatY'] = 'JJJJ';
$labels['dateformaty'] = 'JJ';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Engels';
$labels['westerneuropean'] = 'West-Europees';
$labels['easterneuropean'] = 'Oost-Europees';
$labels['southeasterneuropean'] = 'Zuidoost Europees';
$labels['baltic'] = 'Baltisch';
$labels['cyrillic'] = 'Cyrillisch';
$labels['arabic'] = 'Arabisch';
$labels['greek'] = 'Grieks';
$labels['hebrew'] = 'Hebreeuws';
$labels['turkish'] = 'Turks';
$labels['nordic'] = 'Noord-Germaans';
$labels['thai'] = 'Thais';
$labels['celtic'] = 'Keltisch';
$labels['vietnamese'] = 'Vietnamees';
$labels['japanese'] = 'Japans';
$labels['korean'] = 'Koreaans';
$labels['chinese'] = 'Chinees';
$labels['arialabeltopnav'] = 'Vensterinstellingen';
$labels['arialabeltasknav'] = 'Applicatietaken';
$labels['arialabeltoolbar'] = 'Applicatiewerkbalk';
$labels['arialabelactivetask'] = 'Actieve taak';
$labels['arialabelmessagessearchfilter'] = 'Filter voor e-maillijst';
$labels['arialabelmailsearchform'] = 'Formulier voor berichten zoeken';
$labels['arialabelcontactsearchform'] = 'Zoekformulier voor contacten';
$labels['arialabelmailquicksearchbox'] = 'Zoekinvoer voor e-mail';
$labels['arialabelquicksearchbox'] = 'Zoekinvoer';
$labels['arialabelfoldersearchfilter'] = 'Zoekfilter voor mappenlijst';
$labels['arialabelfoldersearchform'] = 'Zoekformulier voor mappen';
$labels['arialabelfolderlist'] = 'Selectie van e-mailmap';
$labels['arialabelmessagelist'] = 'Lijst van e-mailberichten';
$labels['arialabelmailpreviewframe'] = 'Berichtweergave';
$labels['arialabelmailboxmenu'] = 'Menu voor mapacties';
$labels['arialabellistselectmenu'] = 'Menu voor lijstselectie';
$labels['arialabelthreadselectmenu'] = 'Menu voor conversatie-overzicht';
$labels['arialabelmessagelistoptions'] = 'Weergave- en sorteeropties voor berichtenlijst';
$labels['arialabelmailimportdialog'] = 'Dialoogvenster voor berichten importeren';
$labels['arialabelmessagenav'] = 'Berichtnavigatie';
$labels['arialabelmessagebody'] = 'Berichtinhoud';
$labels['arialabelmessageactions'] = 'Berichtacties';
$labels['arialabelcontactquicksearch'] = 'Zoekformulier voor contacten';
$labels['arialabelcontactsearchbox'] = 'Zoekinvoer voor contacten';
$labels['arialabelmessageheaders'] = 'Berichtheaders';
$labels['arialabelforwardingoptions'] = 'Opties voor doorsturen';
$labels['arialabelreplyalloptions'] = 'Opties voor iedereen beantwoorden';
$labels['arialabelmoremessageactions'] = 'Meer berichtacties';
$labels['arialabelmorecontactactions'] = 'Meer contacten acties';
$labels['arialabelmarkmessagesas'] = 'Geselecteerde berichten markeren als...';
$labels['arialabelcomposeoptions'] = 'Opties voor opstellen';
$labels['arialabelresponsesmenu'] = 'Menu voor standaardreacties';
$labels['arialabelattachmentuploadform'] = 'Uploadformulier voor bijlagen';
$labels['arialabelattachmentmenu'] = 'Opties voor bijlagen';
$labels['arialabelmailtomenu'] = 'opties voor email adressen';
$labels['arialabelattachmentpreview'] = 'Voorbeeldweergave van bijlagen';
$labels['ariasummarycomposecontacts'] = 'Lijst van contacten en groepen om als ontvanger te selecteren';
$labels['arialabelcontactexportoptions'] = 'Opties voor contacten exporteren';
$labels['arialabelabookgroupoptions'] = 'Adresboek-/groepopties';
$labels['arialabelpreferencesform'] = 'Formulier voor instellingen';
$labels['arialabelidentityeditfrom'] = 'Formulier voor identiteit bewerken';
$labels['arialabelresponseeditfrom'] = 'Formulier voor bewerken antwoord';
$labels['arialabelsearchterms'] = 'Zoekwoorden';
$labels['arialabeldropactionmenu'] = 'Sleep actie menu';
$labels['arialabelheadersmenu'] = 'Ontvanger (header) toevoegen menu';
$labels['arialabelimagetools'] = 'Afbeelding opties';
$labels['helplistnavigation'] = 'Overzicht met sneltoetsen';
$labels['helplistkeyboardnavigation'] = "Pijl omhoog/omlaag: Verander actieve rij of selectie.
Spatiebalk: Selecteer actieve rij.
Shift + omhoog/omlaag: Selecteer aanvullende rij boven/onder.
Ctrl + spatiebalk: Voeg actieve rij toe aan selectie of verwijder van selectie.";
$labels['helplistkeyboardnavmessages'] = "Pijl links/rechts: conversaties in- of uitklappen (alleen in conversatiemodus).
Enter: Open geselecteerd of actief bericht.
Delete: Verwijder geselecteerde berichten naar Prullenbak.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Open geselecteerd of actief contact.";
