<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-newmail_notifier/
*/

$labels['basic'] = 'Yangi xat kelganda brauzer eslatmalarini tasvirlash';
$labels['desktop'] = 'Yangi xat kelganda ish stoli eslatmalarini tasvirlash';
$labels['sound'] = 'Yangi xat kelganda ovoz xabari berish';
$labels['test'] = 'Test';
$labels['title'] = 'Yangi xat!';
$labels['body'] = 'Siz yangi xat qabul qildingiz.';
$labels['testbody'] = 'Bu tekshirish maqsadida yuborilgan eslatma.';
$labels['desktopdisabled'] = 'Sizning brauzeringizda eslatmalar o‘chirilgan.';
$labels['desktopunsupported'] = 'Sizning brauzeringiz ish stoli eslatmalarini qo‘llab-quvvatla olmaydi.';
$labels['desktoptimeout'] = 'Ish stoli eslatmalarini yopish';
