tinymce.addI18n('az',{
"Redo": "\u0130r\u0259li",
"Undo": "Geriy\u0259",
"Cut": "K\u0259s",
"Copy": "K\u00f6\u00e7\u00fcr",
"Paste": "\u018flav\u0259 et",
"Select all": "Ham\u0131s\u0131n\u0131 se\u00e7",
"New document": "Yeni s\u0259n\u0259d",
"Ok": "Oldu",
"Cancel": "L\u0259\u011fv et",
"Visual aids": "Konturlar\u0131 g\u00f6st\u0259r",
"Bold": "Qal\u0131n",
"Italic": "Maili",
"Underline": "Alt x\u0259ttli",
"Strikethrough": "Silinmi\u015f",
"Superscript": "Yuxar\u0131 indeks",
"Subscript": "A\u015fa\u011f\u0131 indeks",
"Clear formatting": "Format\u0131 t\u0259mizl\u0259",
"Align left": "Sol t\u0259r\u0259f \u00fczr\u0259",
"Align center": "M\u0259rk\u0259z \u00fczr\u0259",
"Align right": "Sa\u011f t\u0259r\u0259f \u00fczr\u0259",
"Justify": "H\u0259r iki t\u0259r\u0259f \u00fczr\u0259",
"Bullet list": "S\u0131ras\u0131z siyah\u0131",
"Numbered list": "N\u00f6mr\u0259l\u0259nmi\u015f siyah\u0131",
"Decrease indent": "Bo\u015flu\u011fu azalt",
"Increase indent": "Bo\u015flu\u011fu art\u0131r",
"Close": "Ba\u011fla",
"Formats": "Formatlar",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Sizin brauzeriniz m\u00fcbadil\u0259 buferin\u0259 birba\u015fa yolu d\u0259st\u0259kl\u0259mir. Z\u0259hm\u0259t olmasa, bunun yerin\u0259 klaviaturan\u0131n Ctrl+X\/C\/V d\u00fcym\u0259l\u0259rind\u0259n istifad\u0259 edin.",
"Headers": "Ba\u015fl\u0131qlar",
"Header 1": "Ba\u015fl\u0131q 1",
"Header 2": "Ba\u015fl\u0131q 2",
"Header 3": "Ba\u015fl\u0131q 3",
"Header 4": "Ba\u015fl\u0131q 4",
"Header 5": "Ba\u015fl\u0131q 5",
"Header 6": "Ba\u015fl\u0131q 6",
"Headings": "Ba\u015fl\u0131qlar",
"Heading 1": "Ba\u015fl\u0131q 1",
"Heading 2": "Ba\u015fl\u0131q 2",
"Heading 3": "Ba\u015fl\u0131q 3",
"Heading 4": "Ba\u015fl\u0131q 4",
"Heading 5": "Ba\u015fl\u0131q 5",
"Heading 6": "Ba\u015fl\u0131q 6",
"Preformatted": "\u018fvv\u0259lc\u0259d\u0259n formatland\u0131r\u0131lm\u0131\u015f",
"Div": "Div",
"Pre": "Pre",
"Code": "Kod",
"Paragraph": "Paraqraf",
"Blockquote": "Sitat",
"Inline": "S\u0259tir i\u00e7i",
"Blocks": "Bloklar",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Hal-haz\u0131rda adi m\u0259tn rejimind\u0259 yerl\u0259\u015fdirilir. M\u0259zmun sad\u0259 m\u0259tn \u015f\u0259klind\u0259 yerl\u0259\u015fdiril\u0259c\u0259k, h\u0259l\u0259 bu se\u00e7imi d\u0259yi\u015fdirm\u0259.",
"Font Family": "Font stili",
"Font Sizes": "Font \u00f6l\u00e7\u00fcl\u0259ri",
"Class": "Sinif",
"Browse for an image": "\u015e\u0259kil se\u00e7",
"OR": "V\u018f YA",
"Drop an image here": "\u015e\u0259kli buraya s\u00fcr\u00fckl\u0259yin",
"Upload": "Y\u00fckl\u0259",
"Block": "Blokla",
"Align": "D\u00fczl\u0259ndir",
"Default": "Susmaya g\u00f6r\u0259",
"Circle": "Dair\u0259",
"Disc": "Disk",
"Square": "Sah\u0259",
"Lower Alpha": "Ki\u00e7ik Alfa \u0259lifbas\u0131",
"Lower Greek": "Ki\u00e7ik Yunan \u0259lifbas\u0131",
"Lower Roman": "Ki\u00e7ik Roma \u0259lifbas\u0131",
"Upper Alpha": "B\u00f6y\u00fck Alfa \u0259lifbas\u0131",
"Upper Roman": "B\u00f6y\u00fck Roma \u0259lifbas\u0131",
"Anchor": "L\u00f6vb\u0259r",
"Name": "Ad",
"Id": "ID",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "\u0130D h\u0259rfl\u0259 ba\u015flamal\u0131d\u0131r. Daha sonra is\u0259 h\u0259rf, r\u0259q\u0259m, tire, n\u00f6qt\u0259, qo\u015fan\u00f6qt\u0259, v\u0259 altx\u0259tt kimi simvollardan istifad\u0259 oluna bil\u0259r.",
"You have unsaved changes are you sure you want to navigate away?": "Sizd\u0259 yadda saxlan\u0131lmayan d\u0259yi\u015fiklikl\u0259r var \u0259minsiniz ki, getm\u0259k ist\u0259yirsiniz?",
"Restore last draft": "Son layih\u0259nin b\u0259rpas\u0131",
"Special character": "X\u00fcsusi simvollar",
"Source code": "M\u0259nb\u0259 kodu",
"Insert\/Edit code sample": "Kod n\u00fcmun\u0259sin\u0259 \u0259lav\u0259\/d\u00fcz\u0259li\u015f et",
"Language": "Dil",
"Code sample": "Kod n\u00fcmun\u0259si",
"Color": "R\u0259ng",
"R": "R",
"G": "G",
"B": "B",
"Left to right": "Soldan sa\u011fa",
"Right to left": "Sa\u011fdan sola",
"Emoticons": "Emosiyalar",
"Document properties": "S\u0259n\u0259din x\u00fcsusiyy\u0259tl\u0259ri",
"Title": "Ba\u015fl\u0131q",
"Keywords": "A\u00e7ar s\u00f6zl\u0259r",
"Description": "T\u0259sviri",
"Robots": "Robotlar",
"Author": "M\u00fc\u0259llif",
"Encoding": "Kodla\u015fd\u0131rma",
"Fullscreen": "Tam ekran rejimi",
"Action": "\u018fmr",
"Shortcut": "Q\u0131sayol",
"Help": "K\u00f6m\u0259k",
"Address": "Adres",
"Focus to menubar": "Menyu \u00e7ubu\u011funa diqq\u0259t et",
"Focus to toolbar": "Al\u0259tl\u0259r \u00e7ubu\u011funa diqq\u0259t et",
"Focus to element path": "Elementin m\u0259nb\u0259yin\u0259 diqq\u0259t et",
"Focus to contextual toolbar": "Kontekst menyuya diqq\u0259t et",
"Insert link (if link plugin activated)": "Link \u0259lav\u0259 et (\u0259g\u0259r link \u0259lav\u0259si aktivdirs\u0259)",
"Save (if save plugin activated)": "Yadda\u015fa yaz (\u0259g\u0259r yadda\u015fa yaz \u0259lav\u0259si aktivdirs\u0259)",
"Find (if searchreplace plugin activated)": "Tap (\u0259g\u0259r axtar\u0131\u015f \u0259lav\u0259si aktivdirs\u0259)",
"Plugins installed ({0}):": "\u018flav\u0259l\u0259r y\u00fckl\u0259ndi ({0}):",
"Premium plugins:": "Premium \u0259lav\u0259l\u0259r",
"Learn more...": "Daha \u00e7ox \u00f6yr\u0259n...",
"You are using {0}": "Siz {0} istifad\u0259 edirsiniz",
"Plugins": "\u018flav\u0259l\u0259r",
"Handy Shortcuts": "Laz\u0131ml\u0131 q\u0131sayollar",
"Horizontal line": "Horizontal x\u0259tt",
"Insert\/edit image": "\u015e\u0259kilin \u0259lav\u0259\/redakt\u0259 edilm\u0259si",
"Image description": "\u015e\u0259kilin t\u0259sviri",
"Source": "M\u0259nb\u0259",
"Dimensions": "\u00d6l\u00e7\u00fcl\u0259r",
"Constrain proportions": "Nisb\u0259tl\u0259rin saxlan\u0131lmas\u0131",
"General": "\u00dcmumi",
"Advanced": "Geni\u015fl\u0259nmi\u015f",
"Style": "Stil",
"Vertical space": "Vertikal sah\u0259",
"Horizontal space": "Horizontal sah\u0259",
"Border": "\u00c7\u0259r\u00e7iv\u0259",
"Insert image": "\u015e\u0259kil yerl\u0259\u015fdir",
"Image": "\u015e\u0259kil",
"Image list": "\u015e\u0259kil listi",
"Rotate counterclockwise": "Saat \u0259qr\u0259binin \u0259ksin\u0259 f\u0131rlat",
"Rotate clockwise": "Saat \u0259qr\u0259bi istiqam\u0259tind\u0259 f\u0131rlat",
"Flip vertically": "\u015eaquli \u00e7evir",
"Flip horizontally": "\u00dcfiqi \u00e7evir",
"Edit image": "\u015e\u0259kili redakt\u0259 et",
"Image options": "\u015e\u0259kil parametrl\u0259ri",
"Zoom in": "Yax\u0131nla\u015fd\u0131r",
"Zoom out": "Uzaqla\u015fd\u0131r",
"Crop": "K\u0259s",
"Resize": "\u00d6l\u00e7\u00fcl\u0259ri d\u0259yi\u015f",
"Orientation": "Oriyentasiya",
"Brightness": "Parlaql\u0131q",
"Sharpen": "K\u0259skinl\u0259\u015fdir",
"Contrast": "Ziddiyy\u0259t",
"Color levels": "R\u0259ng s\u0259viyy\u0259l\u0259ri",
"Gamma": "Qamma",
"Invert": "T\u0259rsin\u0259 \u00e7evir",
"Apply": "T\u0259tbiq et",
"Back": "Geri",
"Insert date\/time": "G\u00fcn\/tarix \u0259lav\u0259 et",
"Date\/time": "Tarix\/saat",
"Insert link": "Linkin \u0259lav\u0259 edilm\u0259si",
"Insert\/edit link": "Linkin \u0259lav\u0259\/redakt\u0259 edilm\u0259si",
"Text to display": "G\u00f6r\u00fcn\u0259n yaz\u0131n\u0131n t\u0259sviri",
"Url": "Linkin \u00fcnvan\u0131",
"Target": "H\u0259d\u0259f",
"None": "Yoxdur",
"New window": "Yeni p\u0259nc\u0259r\u0259d\u0259 a\u00e7\u0131ls\u0131n",
"Remove link": "Linki sil",
"Anchors": "L\u00f6vb\u0259rl\u0259r",
"Link": "Ke\u00e7id",
"Paste or type a link": "Ke\u00e7idi yerl\u0259\u015fdirin v\u0259 ya yaz\u0131n",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Daxil etdiyiniz URL bir e-mail kimi g\u00f6r\u00fcn\u00fcr. \u018fg\u0259r t\u0259l\u0259b olunan mailto: prefix \u0259lav\u0259 etm\u0259k ist\u0259yirsiniz?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Daxil etdiyiniz URL bir e-mail kimi g\u00f6r\u00fcn\u00fcr. \u018fg\u0259r t\u0259l\u0259b olunan mailto: prefix \u0259lav\u0259 etm\u0259k ist\u0259yirsiniz?",
"Link list": "Ke\u00e7id listi",
"Insert video": "Videonun \u0259lav\u0259 edilm\u0259si",
"Insert\/edit video": "Videonun \u0259lav\u0259\/redakt\u0259 edilm\u0259si",
"Insert\/edit media": "Media \u0259lav\u0259\/d\u00fcz\u0259li\u015f et",
"Alternative source": "Alternativ m\u0259nb\u0259",
"Poster": "Poster",
"Paste your embed code below:": "\u00d6z kodunuzu a\u015fa\u011f\u0131 \u0259lav\u0259 edin:",
"Embed": "\u018flav\u0259 etm\u0259k \u00fc\u00e7\u00fcn kod",
"Media": "Media",
"Nonbreaking space": "Q\u0131r\u0131lmaz sah\u0259",
"Page break": "S\u0259hif\u0259nin q\u0131r\u0131lmas\u0131",
"Paste as text": "M\u0259tn kimi \u0259lav\u0259 et",
"Preview": "\u0130lkinbax\u0131\u015f",
"Print": "\u00c7ap et",
"Save": "Yadda saxla",
"Find": "Tap",
"Replace with": "Bununla d\u0259yi\u015fdir",
"Replace": "D\u0259yi\u015fdir",
"Replace all": "Ham\u0131s\u0131n\u0131 d\u0259yi\u015fdir",
"Prev": "\u018fvv\u0259lki",
"Next": "N\u00f6vb\u0259ti",
"Find and replace": "Tap v\u0259 d\u0259yi\u015fdir",
"Could not find the specified string.": "G\u00f6st\u0259ril\u0259n s\u0259tiri tapmaq olmur",
"Match case": "Registri n\u0259z\u0259r\u0259 al",
"Whole words": "Tam s\u00f6zl\u0259r",
"Spellcheck": "Orfoqrafiyan\u0131 yoxla",
"Ignore": "\u0130qnorla",
"Ignore all": "Ham\u0131s\u0131n\u0131 iqnorla",
"Finish": "Bitir",
"Add to Dictionary": "L\u00fc\u011f\u0259t\u0259 \u0259lav\u0259 edilsin",
"Insert table": "S\u0259tir \u0259lav\u0259 et",
"Table properties": "C\u0259dv\u0259lin x\u00fcsusiyy\u0259tl\u0259ri",
"Delete table": "C\u0259dv\u0259li sil",
"Cell": "H\u00fccr\u0259",
"Row": "S\u0259tir",
"Column": "S\u00fctun",
"Cell properties": "H\u00fccr\u0259nin x\u00fcsusiyy\u0259tl\u0259ri",
"Merge cells": "H\u00fccr\u0259l\u0259ri birl\u0259\u015ftir",
"Split cell": "H\u00fccr\u0259l\u0259rin say\u0131",
"Insert row before": "\u018fvv\u0259lin\u0259 s\u0259tir \u0259lav\u0259 et",
"Insert row after": "Sonras\u0131na s\u0259tir \u0259lav\u0259 et",
"Delete row": "S\u0259tri sil",
"Row properties": "S\u0259trin x\u00fcsusiyy\u0259tl\u0259ri",
"Cut row": "S\u0259tiri k\u0259s",
"Copy row": "S\u0259tiri k\u00f6\u00e7\u00fcr",
"Paste row before": "\u018fvv\u0259lin\u0259 s\u0259tir \u0259lav\u0259 et",
"Paste row after": "Sonras\u0131na s\u0259tir \u0259lav\u0259 et",
"Insert column before": "\u018fvv\u0259lin\u0259 s\u0259tir \u0259lav\u0259 et",
"Insert column after": "\u018fvv\u0259lin\u0259 s\u00fctun \u0259lav\u0259 et",
"Delete column": "S\u00fctunu sil",
"Cols": "S\u00fctunlar",
"Rows": "S\u0259tirl\u0259r",
"Width": "Eni",
"Height": "H\u00fcnd\u00fcrl\u00fcy\u00fc",
"Cell spacing": "H\u00fccr\u0259l\u0259rin aras\u0131nda m\u0259saf\u0259",
"Cell padding": "H\u00fccr\u0259l\u0259rin sah\u0259l\u0259ri",
"Caption": "Ba\u015flan\u011f\u0131c",
"Left": "Sol t\u0259r\u0259f \u00fczr\u0259",
"Center": "M\u0259rk\u0259z \u00fczr\u0259",
"Right": "Sa\u011f t\u0259r\u0259f \u00fczr\u0259",
"Cell type": "H\u00fccr\u0259nin tipi",
"Scope": "Sfera",
"Alignment": "D\u00fczl\u0259ndirm\u0259",
"H Align": "H D\u00fczl\u0259ndir",
"V Align": "V D\u00fczl\u0259ndir",
"Top": "Yuxar\u0131",
"Middle": "Orta",
"Bottom": "A\u015fa\u011f\u0131",
"Header cell": "H\u00fccr\u0259nin ba\u015fl\u0131\u011f\u0131",
"Row group": "S\u0259tirin qrupu",
"Column group": "S\u00fctunun qrupu",
"Row type": "S\u0259tirin tipi",
"Header": "Ba\u015fl\u0131q",
"Body": "K\u00fctl\u0259",
"Footer": "\u018fn a\u015fa\u011f\u0131",
"Border color": "\u00c7\u0259r\u00e7iv\u0259 r\u0259ngi",
"Insert template": "\u015eablon \u0259lav\u0259 et",
"Templates": "\u015eablonlar",
"Template": "\u015eablon",
"Text color": "M\u0259tnin r\u0259ngi",
"Background color": "Arxafon r\u0259ngi",
"Custom...": "\u00c7\u0259kilm\u0259...",
"Custom color": "\u00c7\u0259kilm\u0259 r\u0259ng",
"No color": "R\u0259ngsiz",
"Table of Contents": "M\u00fcnd\u0259ricat",
"Show blocks": "Bloklar\u0131 g\u00f6st\u0259r",
"Show invisible characters": "G\u00f6r\u00fcnm\u0259y\u0259n simvollar\u0131 g\u00f6st\u0259r",
"Words: {0}": "S\u00f6zl\u0259r: {0}",
"{0} words": "{0} s\u00f6z",
"File": "Fayl",
"Edit": "Redakt\u0259 et",
"Insert": "\u018flav\u0259 et",
"View": "G\u00f6r\u00fcn\u00fc\u015f",
"Format": "Format",
"Table": "C\u0259dv\u0259l",
"Tools": "Al\u0259tl\u0259r",
"Powered by {0}": "{0} t\u0259r\u0259find\u0259n t\u0259chiz edilib",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "B\u00f6y\u00fck m\u0259tn sah\u0259si \u0259lav\u0259 edilib. Menyu \u00fc\u00e7\u00fcn ALT-F9 d\u00fcym\u0259sini bas\u0131n. Al\u0259tl\u0259r paneli \u00fc\u00e7\u00fcn ALT-F10 d\u00fcym\u0259sini bas\u0131n. K\u00f6m\u0259k \u00fc\u00e7\u00fcn ALT-0 d\u00fcym\u0259l\u0259rin bas\u0131n."
});