<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'काहीतरी चूक झाली';
$messages['loginfailed']  = 'प्रवेश करता आला नाही';
$messages['cookiesdisabled'] = 'तुमचा ब्राऊझर कुकीज घेऊ शकत नाही';
$messages['sessionerror'] = 'तुम्ही प्रवेश केल्यानंतर बराच वेळ काही न करता गेला म्हणून तुमचा कालावधी संपला किंवा तुमच्या कालावधीच्या नोंदेत काही चूक झाली आहे.';
$messages['storageerror'] = 'आयमॅप सर्व्हरशी संपर्क होवू शकला नाही.';
$messages['servererror'] = 'सर्व्‍हर चूक !';
$messages['servererrormsg'] = 'सर्व्हर चूक : $msg';
$messages['dberror'] = 'माहितीसाठा चूक !';
$messages['errorreadonly'] = 'कृती करण्यास असमर्थ, फोल्डर फक्त बघण्यासाठी';
$messages['errornoperm'] = 'कृती करण्यास असमर्थ, परवानगी अमान्य';
$messages['invalidrequest'] = 'अवैध विनंती! माहिती साठवलेली नाही.';
$messages['nomessagesfound'] = 'या खात्यामधे कोणताही संदेश आलेला नाही';
$messages['loading'] = 'संदेश आणत आहे';
$messages['uploading'] = 'फाईल चढवली जात आहे...';
$messages['loadingdata'] = 'माहिती आणत आहे';
$messages['checkingmail'] = 'नवीन संदेश आले आहेत का हे पहात आहे';
$messages['sendingmessage'] = 'संदेश पाठवत आहे';
$messages['messagesent'] = 'संदेश यशस्वीरित्या पाठवण्यात आला आहे';
$messages['savingmessage'] = 'संदेश जतन करुन ठेवत आहे';
$messages['messagesaved'] = 'संदेश मसुदा फोल्डरमधे ठेवत आहे';
$messages['successfullysaved'] = 'यशस्वीरित्या ठेवला';
$messages['addedsuccessfully'] = 'नवीन नाव पत्तां नोंदवहीत व्यवस्थित ठेवला';
$messages['contactnameexists'] = 'सारख्या नावाची नोंद आधीच आहे';
$messages['blockedimages'] = 'तुमची गोपनीयता पाळण्यासाठी या संदेशातील दुसर्‍या सर्व्हरवरील चित्रे दिसणे थांबवले आहे.';
$messages['encryptedmessage'] = 'हा गुप्त व सांकेतिक संदेश आहे. तो तुम्हाला असा दाखवता येणार नाही.';
$messages['nocontactsfound'] = 'कोणताच पत्ता नोंदवहीत नाही.';
$messages['contactnotfound'] = 'या नावाचा कोणताच पत्ता नोंदवहीत नाही.';
$messages['sendingfailed'] = 'संदेश पाठवता आला नाही.';
$messages['senttooquickly'] = 'कृपया हा संदेश पाठवण्यापूर्वी $sec थांबा';
$messages['errormoving'] = 'संदेश तेथे ठेवता आला नाही.';
$messages['errorcopying'] = 'संदेशांची नक्‍कल करता आली नाही';
$messages['errordeleting'] = 'संदेश काढून टाकता आला नाही.';
$messages['errormarking'] = 'संदेशांवर खूण करता आली नाही.';
$messages['deletecontactconfirm']  = 'खूण केलेले सर्व पत्ते खरोखरच तुम्हाला काढून टाकायचे आहेत का?';
$messages['deletegroupconfirm']  = 'निवडलेला गट तुम्हाला नक्की नष्ट करायचा आहे का?';
$messages['deletemessagesconfirm'] = 'खूण केलेले सर्व संदेश खरोखरच तुम्हाला काढून टाकायचे आहेत का?';
$messages['deletefolderconfirm']  = 'हा फोल्डर खरोखरच तुम्हाला काढून टाकायचा आहेत का?';
$messages['purgefolderconfirm']  = 'या फोल्डरमधिल सर्व संदेश खरोखरच तुम्हाला काढून टाकायचे आहेत का?';
$messages['folderdeleting'] = 'फोल्डर काढून टाकत आहे';
$messages['foldermoving'] = 'फोल्डर हलवत आहे.';
$messages['formincomplete'] = 'फॉर्म पूर्णपणे भरलेला  नाही.';
$messages['noemailwarning'] = 'योग्य, बरोबर, आणि वैध इमेल पत्ता द्या.';
$messages['nonamewarning']  = 'नाव द्या';
$messages['nopagesizewarning'] = 'पानाचा आकार द्या';
$messages['norecipientwarning'] = 'किमान एकतरी पत्ता द्या ज्यांना तुम्हाला संदेश पाठवावयाचा आहे.';
$messages['nosubjectwarning']  = 'विषय दिलेला नाही. तुम्हाला विषय द्यायचा आहे का?';
$messages['nobodywarning'] = 'संदेशामधे कोणताही मजकूर नाही. तुम्हाला तसाच संदेश पाठवावयाचा आहे का?';
$messages['nosearchname'] = 'कृपया ज्यांना तुम्हाला संदेश पाठवावयाचा आहे त्यांचे नाव किंवा इमेल पत्ता द्या.';
$messages['notuploadedwarning'] = 'सर्व फाईल अजून चढवल्‍या गेलेल्‍या नाहीत. कृपया वाट पहा किंवा मागे फिरा';
$messages['searchsuccessful'] = '$nr संदेष मिळाले.';
$messages['searchnomatch'] = 'शोध घेतल्यानंतर एकही संदेश मिळाला नाही';
$messages['searching'] = 'शोधत आहे......';
$messages['checking'] = 'तपासत आहे.....';
$messages['nospellerrors'] = 'शुध्दलेखनाची चूक सापडली नाही';
$messages['folderdeleted'] = 'फोल्डर यशस्वी रित्या काढून टाकण्यात आला आहे.';
$messages['deletedsuccessfully'] = 'यशस्वी रित्या काढून टाकण्यात आला आहे.';
$messages['converting'] = 'दृष्य स्वरुप काढून टाकण्यात येत आहे.';
$messages['messageopenerror'] = 'सर्व्हरवरुन संदेश आणता आला नाही.';
$messages['fileuploaderror'] = 'फाईल चढवता आली नाही';
$messages['filesizeerror'] = 'तुम्ही चढवलेली फाईल क्षमतेपेक्षा जास्त मोठी आहे.';
$messages['sourceisreadonly'] = 'पत्ता फक्त वाचण्यासाठी आहे.';
$messages['errorsavingcontact'] = 'पत्ता नोंदवहीत ठेवता आला नाही.';
$messages['movingmessage'] = 'संदेश हलवत आहे..';
$messages['copyingmessage'] = 'संदेशाची नक्‍कल करत आहे...';
$messages['receiptsent'] = 'पोचपावती यशस्वीरित्या पाठवण्यात आली आहे.';
$messages['errorsendingreceipt'] = 'पोचपावती पाठवता आली नाही.';
$messages['deleteidentityconfirm'] = 'तुम्हाला ही ओळख नक्की नष्ट करायची आहे का?';
$messages['nodeletelastidentity'] = 'तुम्ही हे खाते काढून टाकू शकत नाही कारण हे तुमचे शेवटचे खाते आहे.';
$messages['forbiddencharacter'] = 'फोल्डरच्या नावात न चालणारी अक्षरे किंवा खूणा आहेत.';
$messages['selectimportfile'] = 'चढवण्यासाठी फाईल निवडा';
$messages['addresswriterror'] = 'निवडलेल्या पत्ता नोंदवहीत नोंद करता येत नाही.';
$messages['contactaddedtogroup'] = 'पत्‍ते यशस्‍वीरित्‍या हया गटात वाढवण्‍यात आले.';
$messages['contactremovedfromgroup'] = 'पत्‍ते यशस्‍वीरित्‍या हया गटातून काढून टाकले.';
$messages['importwait'] = 'आयात करत आहे, कृपया वाट पहा.....';
$messages['importconfirm'] = '<b>$inserted पत्ते यशस्वीरित्या आयात केल, $skipped आधिच असलेल्या नोंदी केल्या नाहीत</b>:<p><em>$names</em></p>';
$messages['opnotpermitted'] = 'ही क्रिया करण्यास परवानगी नाही.';
$messages['httpreceivedencrypterror'] = 'हानीकारक चूक झाली. व्‍यवस्‍थापकाशी तात्‍काळ संपर्क साधा. <b> तुमचा संदेश पाठवला नाही </b>';
$messages['smtpconnerror'] = 'SMTP चूक ($code): सर्व्‍हरशी संपर्क साधता येत नाही';
$messages['smtpautherror'] = 'SMTP चूक ($code): ओळख पटवता येत नाही';
$messages['smtpfromerror'] = 'SMTP चूक ($code): "$from" पाठवणार्‍याचे नाव टाकता आले नाही';
$messages['smtptoerror'] = 'SMTP चूक ($code): प्राप्‍तकर्ता "$to" टाकता आला नाही';
$messages['smtprecipientserror'] = 'SMTP चूक : प्राप्‍तकर्त्‍यांची यादी चालू करता आली नाही';
$messages['smtperror'] = 'SMTP चूक : $msg';
$messages['toomanyrecipients'] = 'खूप जास्‍त प्राप्‍तकर्ते. प्राप्‍तकर्त्‍यांची संख्‍या $max पर्यंत कमी करा';
$messages['maxgroupmembersreached'] = 'गट सभासद संख्‍या $max पेक्षा जास्‍त झाली आहे';
