<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'Archiv';
$labels['buttontitle'] = 'Nachricht(en) archivieren';
$labels['archived'] = 'Nachricht(en) erfolgreich archiviert';
$labels['archivedreload'] = 'Nachrichten wurden archiviert. Laden Sie die Seite neu, um die neuen Archivordner zu sehen.';
$labels['archiveerror'] = 'Einige Nachrichten konnten nicht archiviert werden';
$labels['archivefolder'] = 'Archiv';
$labels['settingstitle'] = 'Archiv';
$labels['archivetype'] = 'Erstelle Unterordner nach';
$labels['archivetypeyear'] = 'Jahr (z.B. Archiv/2012)';
$labels['archivetypemonth'] = 'Monat (z.B. Archiv/2012/06)';
$labels['archivetypetbmonth'] = 'Monat - Kompatibel mit Thunderbird (z.B. Archive/2012/2012-06)';
$labels['archivetypefolder'] = 'Originalordner';
$labels['archivetypefolderyear'] = 'Jahr und Originalordner (z.B. Archiv/2012/Yxz)';
$labels['archivetypefoldermonth'] = ' Jahr, Monat und Originalordner (z.B. Archiv/2012/06/Xyz)';
$labels['archivetypesender'] = 'Absender';
$labels['unkownsender'] = 'unbekannt';
$labels['readonarchive'] = 'Nachrichten beim Archivieren als gelesen markieren';
