<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'Crypt_GPG' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG.php',
    'Crypt_GPGAbstract' => $vendorDir . '/pear/crypt_gpg/Crypt/GPGAbstract.php',
    'Crypt_GPG_BadPassphraseException' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
    'Crypt_GPG_DeletePrivateKeyException' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
    'Crypt_GPG_Engine' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/Engine.php',
    'Crypt_GPG_Exception' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
    'Crypt_GPG_FileException' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
    'Crypt_GPG_InvalidKeyParamsException' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
    'Crypt_GPG_InvalidOperationException' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
    'Crypt_GPG_Key' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/Key.php',
    'Crypt_GPG_KeyGenerator' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/KeyGenerator.php',
    'Crypt_GPG_KeyNotCreatedException' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
    'Crypt_GPG_KeyNotFoundException' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
    'Crypt_GPG_NoDataException' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
    'Crypt_GPG_OpenSubprocessException' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
    'Crypt_GPG_PinEntry' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/PinEntry.php',
    'Crypt_GPG_ProcessControl' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/ProcessControl.php',
    'Crypt_GPG_ProcessHandler' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/ProcessHandler.php',
    'Crypt_GPG_Signature' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/Signature.php',
    'Crypt_GPG_SignatureCreationInfo' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/SignatureCreationInfo.php',
    'Crypt_GPG_SubKey' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/SubKey.php',
    'Crypt_GPG_UserId' => $vendorDir . '/pear/crypt_gpg/Crypt/GPG/UserId.php',
    'Net_LDAP2' => $vendorDir . '/pear/net_ldap2/Net/LDAP2.php',
    'Net_LDAP2_Entry' => $vendorDir . '/pear/net_ldap2/Net/LDAP2/Entry.php',
    'Net_LDAP2_Error' => $vendorDir . '/pear/net_ldap2/Net/LDAP2.php',
    'Net_LDAP2_Filter' => $vendorDir . '/pear/net_ldap2/Net/LDAP2/Filter.php',
    'Net_LDAP2_LDIF' => $vendorDir . '/pear/net_ldap2/Net/LDAP2/LDIF.php',
    'Net_LDAP2_RootDSE' => $vendorDir . '/pear/net_ldap2/Net/LDAP2/RootDSE.php',
    'Net_LDAP2_Schema' => $vendorDir . '/pear/net_ldap2/Net/LDAP2/Schema.php',
    'Net_LDAP2_SchemaCache' => $vendorDir . '/pear/net_ldap2/Net/LDAP2/SchemaCache.interface.php',
    'Net_LDAP2_Search' => $vendorDir . '/pear/net_ldap2/Net/LDAP2/Search.php',
    'Net_LDAP2_SimpleFileSchemaCache' => $vendorDir . '/pear/net_ldap2/Net/LDAP2/SimpleFileSchemaCache.php',
    'Net_LDAP2_Util' => $vendorDir . '/pear/net_ldap2/Net/LDAP2/Util.php',
    'Net_LDAP3' => $vendorDir . '/kolab/net_ldap3/lib/Net/LDAP3.php',
    'Net_LDAP3_Result' => $vendorDir . '/kolab/net_ldap3/lib/Net/LDAP3/Result.php',
    'Net_Sieve' => $vendorDir . '/pear/net_sieve/Sieve.php',
    'PEAR_Exception' => $vendorDir . '/pear/pear_exception/PEAR/Exception.php',
    'SieveTest' => $vendorDir . '/pear/net_sieve/tests/SieveTest.php',
);
