<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'Arkivoje';
$labels['buttontitle'] = 'Arkivoje këtë mesazh';
$labels['archived'] = 'U arkivua me sukses';
$labels['archivedreload'] = 'U arkivua me sukses. Ringarkoni faqen që të shihni dosjet e reja arkiv.';
$labels['archiveerror'] = 'Ca nga mesazhet s’u arkivuan dot';
$labels['archivefolder'] = 'Arkivoje';
$labels['settingstitle'] = 'Arkivoje';
$labels['archivetype'] = 'Ndaje arkivin sipas';
$labels['archivetypeyear'] = 'Vit (p.sh. Arkiv/2012)';
$labels['archivetypemonth'] = 'Muaj (p.sh. Arkiv/2012/06)';
$labels['archivetypetbmonth'] = 'Muaj - i përputhshëm me Thunderbird-in (p.sh. Arkiv/2012/2012-06)';
$labels['archivetypefolder'] = 'Dosje origjinale';
$labels['archivetypefolderyear'] = 'Viti dhe dosja origjinale (p.sh., Arkiv/2012/…)';
$labels['archivetypefoldermonth'] = 'Viti, muaji, dhe dosja origjinale (p.sh., Arkivi/2012/06/…)';
$labels['archivetypesender'] = 'Email dërguesi';
$labels['unkownsender'] = 'e panjohur';
$labels['readonarchive'] = 'I vini shenjë si të lexuar mesazhit në arkiv';
