<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-password/
*/

$labels['changepasswd']  = 'Нууц үг солих';
$labels['curpasswd']  = 'Одоогийн нууц үг:';
$labels['newpasswd']  = 'Шинэ нууц үг:';
$labels['confpasswd']  = 'Шинэ нууц үгийг батлах';
$messages['nopassword'] = 'Шинэ нууц үгээ оруулна уу.';
$messages['nocurpassword'] = 'Одоогийн нууц үгээ оруулна уу.';
$messages['passwordincorrect'] = 'Одоогийн нууц үг таарахгүй байна.';
$messages['passwordinconsistency'] = 'Нууц үгнүүд хоорондоо таарахгүй байна, дахин оролдоно уу.';
$messages['crypterror'] = 'Шинэ нууц үгийг хадгалж чадсангүй. Шифрлэлтийн функц олдоогүй.';
$messages['connecterror'] = 'Шинэ нууц үгийг хадгалж чадсангүй. Холболтын алдаа.';
$messages['internalerror'] = 'Шинэ нууц үгийг хадгалж чадахгүй байна.';
$messages['passwordshort'] = 'Нууц үг хамгийн богинодоо $length урттай байх ёстой.';
$messages['passwordweak'] = 'Нууц үг дор хаяж нэг тоо ба нэг цэг, таслал зэрэг тэмдэгт агуулах ёстой.';
$messages['passwordforbidden'] = 'Нууц үг зөвшөөрөгдөөгүй тэмдэгт агуулж байна.';
$messages['firstloginchange'] = 'Энэ бол таны анхны нэвтрэлт. Нууц үгээ солино уу.';
