<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'تصفية';
$labels['managefilters'] = 'ادارة تصفية البريد الوارد';
$labels['filtername'] = 'اسم التصفية';
$labels['newfilter'] = 'تصفية جديدة';
$labels['filteradd'] = 'اضافة تصفية';
$labels['filterdel'] = 'حذف تصفية';
$labels['actions'] = 'الإجراءات';
$labels['scope'] = 'مجال';
$labels['moveup'] = 'نقل الى الاعلى ';
$labels['movedown'] = 'نقل الى الاسفل';
$labels['filterallof'] = 'مطابقة جميع القواعد التالية';
$labels['filteranyof'] = 'مطابقة اي القواعد التالية';
$labels['filterany'] = 'كل الرسائل';
$labels['filtercontains'] = 'محتوى';
$labels['filternotcontains'] = 'بدون محتوى';
$labels['filteris'] = 'مساوي الى';
$labels['filterisnot'] = 'لا يساوي';
$labels['filterexists'] = 'موجود';
$labels['filternotexists'] = 'غير موجود';
$labels['filtermatches'] = 'يطابق التعبير';
$labels['filternotmatches'] = 'لا يطابق التعبير';
$labels['filterregex'] = 'يطابق التعبير العادي';
$labels['filternotregex'] = 'لا يطابق التعبير العادي';
$labels['filterunder'] = 'تحت';
$labels['filterover'] = 'خلال';
$labels['addrule'] = 'اضافة قاعدة';
$labels['delrule'] = 'حذف قاعدة';
$labels['messagemoveto'] = 'نقل الرساله الى ';
$labels['messageredirect'] = 'إعادة توجيه الرسالة الى ';
$labels['messagecopyto'] = 'نسخ الرسالة الى ';
$labels['messagesendcopy'] = 'ارسال نسخة من الرسالة الى ';
$labels['messagereply'] = 'الرد مع رسالة';
$labels['messagedelete'] = 'حذف الرسالة';
$labels['messagediscard'] = 'تجاهل مع الرسالة';
$labels['messagekeep'] = 'إبقاء الرسالة في علبة الوارد';
$labels['messagesrules'] = 'للبريد الوارد:';
$labels['messagesactions'] = '...تنفيذ المهام التالية:';
$labels['add'] = 'إضافة';
$labels['del'] = 'حذف';
$labels['sender'] = 'المرسل';
$labels['recipient'] = 'مستلم';
$labels['vacationdays'] = 'في الغالب كم رسالة ترسل (بالايام):';
$labels['vacationinterval'] = 'كم عدد الرسائل المرسلة عادةً:';
$labels['vacationreason'] = 'نص الرسالة (بسبب الاجازة):';
$labels['vacationsubject'] = 'موضوع الرسالة:';
$labels['days'] = 'ايام';
$labels['seconds'] = 'ثواني';
$labels['rulestop'] = 'ايقاف تقييم القواعد';
$labels['enable'] = 'تفعيل/تعطيل';
$labels['filtersets'] = 'مجموعة تصفية';
$labels['filterdef'] = 'تعريف التصفية ';
$labels['active'] = 'نشط';
$labels['none'] = 'لاشيء';
$labels['fromset'] = 'من مجموعة';
$labels['fromfile'] = 'من ملف';
$labels['filterdisabled'] = 'تعطيل التصفية';
$labels['countisgreaterthan'] = 'العدد اكبر من ';
$labels['countisgreaterthanequal'] = 'العدد اكبر من او يساوي ';
$labels['countislessthan'] = 'العدد اقل من ';
$labels['countislessthanequal'] = 'العدد اقل من او يساوي';
$labels['countequals'] = 'العدد يساوي ';
$labels['countnotequals'] = 'العدد لا يساوي';
$labels['valueisgreaterthan'] = 'القيمة اكبر من ';
$labels['valueisgreaterthanequal'] = 'القيمة اكبر من او تساوي';
$labels['valueislessthan'] = 'القيمة اقل من ';
$labels['valueislessthanequal'] = 'القيمة اقل من او يساوي';
$labels['valueequals'] = 'القيمة تساوي';
$labels['valuenotequals'] = 'القيمة لا تساوي';
$labels['setflags'] = 'ضع وسم على هذه الرسالة ';
$labels['addflags'] = 'اضف وسم على هذه الرسالة ';
$labels['removeflags'] = 'احذف الوسم الموجود على هذه الرسالة ';
$labels['flagread'] = 'قراءة ';
$labels['flagdeleted'] = 'محذوف';
$labels['flaganswered'] = 'مجابة';
$labels['flagflagged'] = 'موسوم';
$labels['flagdraft'] = 'مسودة';
$labels['setvariable'] = 'تعيين متغير';
$labels['setvarname'] = 'اسم المتغير:';
$labels['setvarvalue'] = 'قيمة المتغير:';
$labels['setvarmodifiers'] = 'تعديلات:';
$labels['varquotewildcard'] = 'أقتبس أحرف خاصة';
$labels['varlength'] = 'الطول';
$labels['notify'] = 'ارسل تنبية';
$labels['notifyimportance'] = 'اهمية:';
$labels['notifyimportancelow'] = 'منخفض';
$labels['notifyimportancenormal'] = 'عادي';
$labels['notifyimportancehigh'] = 'مرتفع';
$labels['notifymethodmailto'] = 'البريد الإلكتروني';
$labels['notifymethodtel'] = 'الهاتف';
$labels['filtercreate'] = 'انشئ تصفية';
$labels['usedata'] = 'استخدم البيانات التالية في الفلتر:';
$labels['nextstep'] = 'الخطوة التالية';
$labels['...'] = '...';
$labels['currdate'] = 'التاريخ الحالي';
$labels['datetest'] = 'التاريخ';
$labels['dateheader'] = 'الراس:';
$labels['year'] = 'السنة';
$labels['month'] = 'شهر';
$labels['day'] = 'يوم';
$labels['date'] = 'التاريخ (yyyy-mm-dd)';
$labels['julian'] = 'التاريخ (يوليان)';
$labels['hour'] = 'ساعات';
$labels['minute'] = 'دقائق';
$labels['second'] = 'ثواني';
$labels['time'] = 'الوقت (hh:mm:ss)';
$labels['iso8601'] = 'التاريخ (ISO8601)';
$labels['std11'] = 'التاريخ (RFC2822)';
$labels['zone'] = 'المنطقة الزمنية';
$labels['weekday'] = 'ايام العمل (0-6)';
$labels['advancedopts'] = 'خيارات متقدّمة';
$labels['body'] = 'نص';
$labels['address'] = 'العنوان';
$labels['modifier'] = 'تعديل:';
$labels['text'] = 'نص';
$labels['contenttype'] = 'نوع المحتوى';
$labels['modtype'] = 'نوع:';
$labels['allparts'] = 'الكل';
$labels['domain'] = 'المجال';
$labels['localpart'] = 'الجزء المحلي';
$labels['user'] = 'مستخدم';
$labels['detail'] = 'تفاصيل';
$labels['default'] = 'افتراضي';
$labels['index'] = 'الوارد:';
$labels['indexlast'] = 'تراجع';
$labels['spamtestequals'] = 'مساوي الى';
$labels['spamtestnotequals'] = 'لا يساوي';
$labels['vacation'] = 'خارج المكتب';
$labels['vacation.advanced'] = 'اعدادات متقدمة';
$labels['vacation.from'] = 'الرد على عنوان المرسل';
$labels['vacation.subject'] = 'موضوع';
$labels['vacation.body'] = 'محتوى ';
$labels['vacation.status'] = 'الحالة ';
$labels['vacation.on'] = 'تشغيل';
$labels['vacation.off'] = 'ايقاف';
$labels['vacation.after'] = 'ضع قاعدة الخروج من المنصب بعد ذلك';
$labels['vacation.saving'] = 'يتم حفظ البيانات...';
$labels['vacation.keep'] = 'ابقاء';
$labels['forward.on'] = 'تشغيل';
$labels['forward.off'] = 'ايقاف';
$labels['forward.saving'] = 'يتم حفظ البيانات...';
$labels['duplicate.header'] = 'الراس:';
$messages['filterunknownerror'] = 'خطا غير معروف من الخادم.';
$messages['filterconnerror'] = 'لا يمكن الاتصال بالخادم.';
$messages['filterdeleteerror'] = 'لا يمكن حذف التصفية.خطا في الخادم.';
$messages['filterdeleted'] = 'تم حذف التصفية بنجاح.';
$messages['filtersaved'] = 'تم حفظ التصفية بنجاح.';
$messages['filtersaveerror'] = 'لا يمكن حفظ التصفية.خطا في الخادم.';
$messages['filterdeleteconfirm'] = 'هل تريد فعلاً حذف التصفية المحددة؟';
$messages['ruledeleteconfirm'] = 'هل تريد فعلاً حذف القواعد المحددة؟';
$messages['actiondeleteconfirm'] = 'هل تريد فعلاً حذف الاجراءات المحددة؟';
$messages['forbiddenchars'] = 'احرف محظورة في هذا الحقل.';
$messages['cannotbeempty'] = 'لا يمكن ترك الحقل فارغاً';
$messages['ruleexist'] = 'اسم هذة التصفية موجود مسبقاً';
$messages['setactivateerror'] = 'تعذر تنشيط مجموعة التصفية المحددة. حدث خطأ في الخادم.';
$messages['setdeactivateerror'] = 'تعذر إلغاء تنشيط مجموعة التصفية المحددة. حدث خطأ في الخادم.';
$messages['activateerror'] = 'لا يمكن تمكين التصفية(ـات) المحددة .خطا في الخادم.';
$messages['deactivateerror'] = 'لا يمكن تعطيل التصفية(ـات) المحددة .خطا في الخادم.';
$messages['deactivated'] = 'تم تعطيل المصفيـ(ـاة) بنجاح.';
$messages['activated'] = 'تم تفعيل المصفيـ(ـاة) بنجاح.';
$messages['moved'] = 'تم نقل التصفية بنجاح.';
$messages['moveerror'] = 'لا يمكن نقل التصفياة المحددة.خطا في الخادم.';
$messages['nametoolong'] = 'الإسم طويل جداً';
$messages['setexist'] = 'المجموعة موجودة مسبقا.';
$messages['nodata'] = 'يجب تحديد موضع واحد على الأقل!';
$messages['invaliddateformat'] = 'تاريخ غير صحيح او يوجد خطا في تنسق اجزاء التاريخ';
$messages['saveerror'] = 'لا يمكن حفظ البيانات. خطا في الخادم.';
