<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-password/
*/

$labels['changepasswd']  = 'Athraigh an focal faire';
$labels['curpasswd']  = 'An focal faire reatha:';
$labels['newpasswd']  = 'An focal faire nua:';
$labels['confpasswd']  = 'Deimhnigh an focal faire nua:';
$messages['nopassword'] = 'Cuir isteach focal faire nua.';
$messages['nocurpassword'] = 'Cuir isteach d\'fhocal faire reatha.';
$messages['passwordincorrect'] = 'Níl an focal faire reatha ceart.';
$messages['passwordinconsistency'] = 'Ní hionann na focail faire. Déan arís é.';
$messages['crypterror'] = 'Níorbh fhéidir an focal faire nua a chur i dtaisce. Tá an fheidhm chriptiúcháin in easnamh.';
$messages['connecterror'] = 'Níorbh fhéidir an focal faire nua a chur i dtaisce. Tharla earráid leis an gceangal.';
$messages['internalerror'] = 'Níorbh fhéidir an focal faire nua a chur i dtaisce.';
$messages['passwordshort'] = 'Ní mór $length gcarachtar ar a laghad a bheith sa bhfocal faire.';
$messages['passwordweak'] = 'Ní mór aon uimhir amháin agus aon chomhartha poncaíochta amháin a bheith sa bhfocal faire.';
$messages['passwordtooweak'] = 'Tá an focal faire rólag.';
$messages['passwordnoseq'] = 'Níor cheart don bhfocal faire a bheith ina sraith amhail 123456 nó QWERTY.';
$messages['passwordnocommon'] = 'Níor cheart focal nó ainm coitianta a roghnú mar fhocal faire.';
$messages['passwordforbidden'] = 'Tá carachtair nach gceadaítear san fhocal faire.';
$messages['firstloginchange'] = 'Is é seo an chéad uair duit síniú isteach. Athraigh d\'fhocal faire.';
$messages['disablednotice'] = 'Tá an córas á chothabháil faoi láthair agus ní féidir an focal faire a athrú ag an am seo. Ba cheart go mbeadh gach rud mar is gnách sula i bhfad. Is dona linn aon mhíchaoithiúlacht.';
$messages['passwinhistory'] = 'Baineadh feidhm as an bhfocal faire seo cheana.';
$messages['samepasswd'] = 'Ní mór don bhfocal faire nua bheith éagsúil ón seanfhocal faire.';
$messages['passwdexpirewarning'] = 'Rabhadh! Rachaidh d\'fhocal faire in éag go luath. Athraigh é roimh $expirationdatetime.';
$messages['passwdexpired'] = 'D\'éag d\'fhocal faire. Ní mór duit é a athrú anois!';
$messages['passwdconstraintviolation'] = 'Sárú ar na rialacha do na focail faire. Is dócha go bhfuil an focal faire rólag.';
$messages['pwned_isdisclosed'] = 'Tá fios ag an iomarca daoine ar an bhfocal faire sin.';
$messages['pwned_fetcherror'] = 'Theip ar an gcóras a fhíorú cé chomh láidir is atá an focal faire.';
