<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Bộ lọc';
$labels['managefilters'] = 'Quản lý bộ lọc thư đến';
$labels['filtername'] = 'Lọc tên';
$labels['newfilter'] = 'Bộ lọc mới';
$labels['filteradd'] = 'Thêm bộ lọc';
$labels['filterdel'] = 'Xóa bộ lọc';
$labels['scope'] = 'Phạm vi';
$labels['moveup'] = 'Chuyển lên';
$labels['movedown'] = 'Chuyển xuống';
$labels['filterallof'] = 'Phù hợp với tất cả các qui luật sau đây';
$labels['filteranyof'] = 'Phù hợp với bất kỳ qui luật nào sau đây';
$labels['filterany'] = 'Tất cả tin nhắn';
$labels['filtercontains'] = 'Bao gồm';
$labels['filternotcontains'] = 'Không bao gồm';
$labels['filteris'] = 'Bằng với';
$labels['filterisnot'] = 'Không bằng với';
$labels['filterexists'] = 'Tồn tại';
$labels['filternotexists'] = 'Không tồn tại';
$labels['filtermatches'] = 'Tương ứng với cách diễn đạt';
$labels['filternotmatches'] = 'Không tương ứng với cách diễn đạt';
$labels['filterregex'] = 'Tương ứng với cách diễn đạt thông thường';
$labels['filternotregex'] = 'Không phù  hợp với cách diễn đạt thông thường';
$labels['filterunder'] = 'Dưới';
$labels['filterover'] = 'Hơn';
$labels['addrule'] = 'Thêm qui luật';
$labels['delrule'] = 'Xóa qui luật';
$labels['messagemoveto'] = 'Chuyển tin nhắn tới';
$labels['messageredirect'] = 'Gửi lại tin nhắn tới';
$labels['messagecopyto'] = 'Sao chép tin nhắn tới';
$labels['messagesendcopy'] = 'Gửi bản sao chép tin nhắn tới';
$labels['messagereply'] = 'Trả lời tin nhắn';
$labels['messagedelete'] = 'Xóa thư';
$labels['messagediscard'] = 'Loại bỏ với tin nhắn';
$labels['messagekeep'] = 'Giữ thư ở Hộp thư chính';
$labels['messagesrules'] = 'Với thư đến';
$labels['messagesactions'] = 'Thực hiện các hành động sau:';
$labels['add'] = 'Thêm';
$labels['del'] = 'Xoá';
$labels['sender'] = 'Người gửi';
$labels['recipient'] = 'Người nhận';
$labels['vacationdays'] = 'Số lần gửi thư (trong ngày)';
$labels['vacationinterval'] = 'Tần suất gửi thư:';
$labels['vacationreason'] = 'Nội dung chính';
$labels['vacationsubject'] = 'Tiêu đề thư';
$labels['days'] = 'ngày';
$labels['seconds'] = 'giây';
$labels['rulestop'] = 'Ngừng đánh giá qui luật';
$labels['enable'] = 'Kích hoạt/Không kích hoạt';
$labels['filtersets'] = 'Thiết lập bộ lọc';
$labels['filterdef'] = 'Định nghĩa bộ lọc';
$labels['active'] = 'Kích hoạt';
$labels['none'] = 'Không có';
$labels['fromset'] = 'Từ thiết lập';
$labels['fromfile'] = 'Từ hồ sơ';
$labels['filterdisabled'] = 'Bộ lọc được ngừng hoạt động';
$labels['countisgreaterthan'] = 'Đếm lớn hơn';
$labels['countisgreaterthanequal'] = 'Đếm lớn hơn hoặc bằng';
$labels['countislessthan'] = 'Đếm ít hơn';
$labels['countislessthanequal'] = 'Đếm ít hơn hoặc bằng';
$labels['countequals'] = 'Đếm bằng';
$labels['countnotequals'] = 'đếm không bằng với';
$labels['valueisgreaterthan'] = 'Giá trị lớn hơn';
$labels['valueisgreaterthanequal'] = 'Giá trị lớn hơn hoặc bằng';
$labels['valueislessthan'] = 'Giá trị nhỏ hơn';
$labels['valueislessthanequal'] = 'Giá trị nhỏ hơn hoặc bằng';
$labels['valueequals'] = 'Giá trị bằng';
$labels['valuenotequals'] = 'giá trị không bằng với';
$labels['setflags'] = 'Thiết lập đánh dấu cho thư';
$labels['addflags'] = 'Thêm đánh dấu cho thư';
$labels['removeflags'] = 'Bỏ đánh dấu khỏi thư';
$labels['flagread'] = 'Đọc';
$labels['flagdeleted'] = 'Đã được xóa';
$labels['flaganswered'] = 'Đã trả lời';
$labels['flagflagged'] = 'Đã đánh dấu';
$labels['flagdraft'] = 'Nháp';
$labels['setvariable'] = 'Đặt biến';
$labels['setvarname'] = 'Tên biến:';
$labels['setvarvalue'] = 'Giá trị biến:';
$labels['setvarmodifiers'] = 'Bộ chia:';
$labels['varlower'] = 'viết thường';
$labels['varupper'] = 'viết hoa';
$labels['varlowerfirst'] = 'chữ cái đầu viết thường';
$labels['varupperfirst'] = 'chữ cái đầu viết hoa';
$labels['varquotewildcard'] = 'trích dẫn ký tự đặc biệt';
$labels['varlength'] = 'độ dài';
$labels['notify'] = 'Gửi thông báo';
$labels['notifytarget'] = 'Mục tiêu thông báo:';
$labels['notifymessage'] = 'Nội dung thông báo (tuỳ chọn):';
$labels['notifyoptions'] = 'Lựa chọn thông báo (tuỳ chọn):';
$labels['notifyfrom'] = 'Người gửi thông báo (tuỳ chọn):';
$labels['notifyimportance'] = 'Mức độ quan trọng:';
$labels['notifyimportancelow'] = 'thấp';
$labels['notifyimportancenormal'] = 'vừa phải';
$labels['notifyimportancehigh'] = 'cao';
$labels['notifymethodmailto'] = 'Thư điện tử';
$labels['notifymethodtel'] = 'Điện thoại';
$labels['notifymethodsms'] = 'Tin nhắn';
$labels['filtercreate'] = 'Tạo bộ lọc';
$labels['usedata'] = 'Dùng dữ liệu trong bộ lọc sau:';
$labels['nextstep'] = 'Bước tiếp theo';
$labels['...'] = '…';
$labels['currdate'] = 'Ngày hiện tại';
$labels['datetest'] = 'Ngày';
$labels['dateheader'] = 'tiêu đề:';
$labels['year'] = 'năm';
$labels['month'] = 'tháng';
$labels['day'] = 'ngày';
$labels['date'] = 'ngày (cú pháp: năm-tháng-ngày)';
$labels['julian'] = 'ngày (theo kiểu Julian)';
$labels['hour'] = 'giờ';
$labels['minute'] = 'phút';
$labels['second'] = 'giây';
$labels['time'] = 'giờ (cú pháp: giờ:phút:giây)';
$labels['iso8601'] = 'ngày (theo chuẩn ISO 8601)';
$labels['std11'] = 'ngày (theo chuẩn RFC 2822)';
$labels['zone'] = 'vùng thời gian';
$labels['weekday'] = 'ngày trog tuần (0-6)';
$labels['advancedopts'] = 'Tùy chọn tính năng cao hơn';
$labels['body'] = 'Nội dung';
$labels['address'] = 'Địa chỉ';
$labels['envelope'] = 'Phong bì';
$labels['modifier'] = 'Bổ nghĩa';
$labels['text'] = 'Văn bản';
$labels['undecoded'] = 'Chưa được giải mã (nguyên bản)';
$labels['contenttype'] = 'Kiểu mẫu nội dung';
$labels['modtype'] = 'Kiểu:';
$labels['allparts'] = 'Tất cả';
$labels['domain'] = 'Phạm vi';
$labels['localpart'] = 'Phần nội bộ';
$labels['user'] = 'Người dùng';
$labels['detail'] = 'Chi tiết';
$labels['comparator'] = 'Vật so sánh';
$labels['default'] = 'Mặc định';
$labels['octet'] = 'Khắt khe';
$labels['asciicasemap'] = 'Không phân biệt chữ hoa chữ thường';
$labels['asciinumeric'] = 'Bảng mã ASCII';
$labels['index'] = 'chỉ mục:';
$labels['indexlast'] = 'ngược';
$labels['spamtestequals'] = 'Bằng với';
$labels['spamtestnotequals'] = 'Không bằng với';
$labels['vacation.reply'] = 'Trả lời thư';
$labels['vacation.advanced'] = 'Tùy chọn tính năng cao hơn';
$labels['vacation.subject'] = 'Tiêu đề';
$labels['vacation.body'] = 'Nội dung thư';
$labels['vacation.status'] = 'Trạng thái';
$labels['vacation.on'] = 'Bật';
$labels['vacation.off'] = 'Tắt';
$labels['vacation.interval'] = 'Khoảng thời gian trả lời';
$labels['vacation.saving'] = 'Lưu lại dữ liệu...';
$labels['vacation.keep'] = 'Giữ';
$labels['forward.on'] = 'Bật';
$labels['forward.off'] = 'Tắt';
$labels['forward.saving'] = 'Lưu lại dữ liệu...';
$labels['duplicate.header'] = 'tiêu đề:';
$messages['filterunknownerror'] = 'Không tìm được lỗi máy chủ';
$messages['filterconnerror'] = 'Không kết nối được với máy chủ.';
$messages['filterdeleteerror'] = 'Không thể xóa bộ lọc. Xuất hiện lỗi ở máy chủ';
$messages['filterdeleted'] = 'Xóa bộ lọc thành công';
$messages['filtersaved'] = 'Lưu bộ lọc thành công';
$messages['filtersaveerror'] = 'Không thể lưu bộ lọc. Xuất hiện lỗi ở máy chủ';
$messages['filterdeleteconfirm'] = 'Bạn có thực sự muốn xóa bộ lọc được chọn?';
$messages['ruledeleteconfirm'] = 'Bạn có chắc chắn muốn xóa qui luật được chọn?';
$messages['actiondeleteconfirm'] = 'Bạn có chắc chắn muốn xóa hành động được chọn?';
$messages['forbiddenchars'] = 'Ký tự bị cấm trong ô';
$messages['cannotbeempty'] = 'Ô không thể bị bỏ trống';
$messages['ruleexist'] = 'Đã tồn tại bộ lọc với tên cụ thế';
$messages['activateerror'] = 'Không thể khởi động (các) bộ lọc được chọn. Có lỗi xuất hiện ở máy chủ';
$messages['deactivateerror'] = 'Không thể tắt (các) bộ lọc đã chọn. Có lỗi xuất hiện ở máy chủ';
$messages['deactivated'] = 'Bộ lọc được khởi động thành công';
$messages['activated'] = 'Bộ lọc được tắt thành công';
$messages['moved'] = 'Bộ lọc được chuyển đi thành công';
$messages['moveerror'] = 'Không thể chuyển bộ lọc đã chọn. Có lỗi xuất hiện ở máy chủ.';
$messages['nametoolong'] = 'Tên quá dài';
$messages['namereserved'] = 'Tên đã được bảo vệ';
$messages['setexist'] = 'Thiết lập đã tồn tại';
$messages['nodata'] = 'Ít nhất một vị trí phải được chọn';
$messages['invaliddateformat'] = 'Lỗi không đúng cú pháp ngày hoặc nhập ngày sai';
$messages['saveerror'] = 'Không thể lưu trữ dữ liệu. Xuất hiện lỗi ở máy chủ.';
