<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'ഒരു പിഴവ് സംഭവിച്ചിരിക്കുന്നു';
$messages['loginfailed']  = 'പ്രവേശനം പരാജയപ്പെട്ടിയിക്കുന്നു';
$messages['cookiesdisabled'] = 'താങ്കളുടെ ബ്രൗസർ കുക്കികൾ സ്വീകരിക്കുന്നതല്ല';
$messages['sessionerror'] = 'താങ്കളുടെ സെഷൻ അസാധുവാണ് അല്ലെങ്കിൽ കാലഹരണപ്പെട്ടിരിക്കുന്നു';
$messages['storageerror'] = 'സൂക്ഷിക്കുന്നതിനുള്ള സെർവറുമായി ബന്ധിപ്പിക്കാൻ സാധിച്ചില്ല';
$messages['servererror'] = 'സെർവർ പിഴവ്!';
$messages['servererrormsg'] = 'സെർവർ പിഴവ്: $msg';
$messages['connerror'] = 'ബന്ധിപ്പിക്കുന്നതിൽ പിഴവ് (സെർവറിൽ എത്താനായില്ല)!';
$messages['dberror'] = 'ഡാറ്റാബേസ് പിഴവ്';
$messages['windowopenerror'] = 'പോപ്പപ്പ് ജാലകം തടയപ്പെട്ടിരുന്നു';
$messages['requesttimedout'] = 'അപേക്ഷയുടെ കാലാവധി കഴിഞ്ഞു';
$messages['errorreadonly'] = 'പ്രവൃത്തി നടത്താനായില്ല. ഫോൾഡർ വായിക്കാൻ മാത്രമുള്ളതാണ്';
$messages['errornoperm'] = 'പ്രവര്‍ത്തനം നടത്താനായില്ല . അനുമതി നിഷേധിക്കപെട്ടിരിക്കുന്നു.';
$messages['erroroverquota'] = 'പ്രവര്‍ത്തനം നടത്താനായില്ല . ഡിസ്കിൽ സ്ഥലമില്ല.';
$messages['erroroverquotadelete'] = 'ഡിസ്കിൽ സ്ഥലമില്ല. ഒരു സന്ദേശം നീക്കം ചെയ്യാൻ SHIFT+DEL ഉപയോഗിക്കുക';
$messages['invalidrequest'] = 'അസാധുവായ അപേക്ഷ ! ഒരു ഡാറ്റയും സൂക്ഷിച്ചിട്ടില്ല.';
$messages['invalidhost'] = 'അസാധുവായ സെർവർ നാമം';
$messages['nomessagesfound'] = 'ഈ മെയിൽബോക്സിൽ സന്ദേശമൊന്നും കണ്ടെത്തിയില്ല';
$messages['loading'] = 'തുറക്കുന്നു...';
$messages['checkingmail'] = 'പുതിയ സന്ദേസങ്ങള്‍കുവേണ്ടി തിരയുന്നു...';
$messages['sendingmessage'] = 'സന്ദേശം അയക്കുന്നു...';
$messages['sendingfailed'] = 'സന്ദേശം അയക്കാന്‍ സാധിച്ചില്ല.';
$messages['senttooquickly'] = 'സന്ദേശം അയക്കുന്നതിനു മുന്പു ദയവായ്  $sec കാത്തിരിക്കൂ';
