<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Κοινή χρήση';
$labels['myrights'] = 'Δικαιώματα Πρόσβασης ';
$labels['username'] = 'Χρήστης:';
$labels['advanced'] = 'Προηγμένη λειτουργία';
$labels['add'] = 'Προσθήκη';
$labels['newuser'] = 'Προσθήκη καταχώρησης ';
$labels['editperms'] = 'Μεταβολή δικαιωμάτων';
$labels['actions'] = 'Ενέργειες δικαιωμάτων πρόσβασης...';
$labels['anyone'] = 'Όλοι οι χρήστες (οποιοσδήποτε)';
$labels['anonymous'] = 'Επισκέπτες (ανώνυμοι)';
$labels['identifier'] = 'Αναγνωριστικό';
$labels['acll'] = 'Αναζήτηση';
$labels['aclr'] = 'Διαβάστε τα μηνύματα ';
$labels['acls'] = 'Διατήρηση κατάστασης ανάγνωσης';
$labels['aclw'] = 'Ρυθμίσεις εγγραφής';
$labels['acli'] = 'Εισάγωγη (Αντιγραφή σε) ';
$labels['aclp'] = 'Καταχώρηση';
$labels['aclc'] = 'Δημιουργία υποφακέλων';
$labels['aclk'] = 'Δημιουργία υποφακέλων';
$labels['acld'] = 'Διαγραφή μηνυμάτων';
$labels['aclt'] = 'Διαγραφή μηνυμάτων';
$labels['acle'] = 'Απαλοιφή';
$labels['aclx'] = 'Διαγραφή φακέλου';
$labels['acla'] = 'Διαχείριση';
$labels['acln'] = 'Προσθήκη υπομνήματος στα μηνύματα';
$labels['aclfull'] = 'Πλήρης πρόσβαση';
$labels['aclother'] = 'Άλλο';
$labels['aclread'] = 'Ανάγνωση';
$labels['aclwrite'] = 'Εγγραφή';
$labels['acldelete'] = 'Διαγραφή';
$labels['shortacll'] = 'Αναζήτηση';
$labels['shortaclr'] = 'Ανάγνωση';
$labels['shortacls'] = 'Τήρηση';
$labels['shortaclw'] = 'Εγγραφή';
$labels['shortacli'] = 'Εισαγωγή';
$labels['shortaclp'] = 'Καταχώρηση';
$labels['shortaclc'] = 'Δημιουργία';
$labels['shortaclk'] = 'Δημιουργία';
$labels['shortacld'] = 'Διαγραφή';
$labels['shortaclt'] = 'Διαγραφή';
$labels['shortacle'] = 'Απαλοιφή';
$labels['shortaclx'] = 'Διαγραφή φακέλου';
$labels['shortacla'] = 'Διαχείριση';
$labels['shortacln'] = 'Προσθήκη υπομνήματος';
$labels['shortaclother'] = 'Άλλο';
$labels['shortaclread'] = 'Ανάγνωση';
$labels['shortaclwrite'] = 'Εγγραφή';
$labels['shortacldelete'] = 'Διαγραφή';
$labels['longacll'] = 'Ο φάκελος είναι ορατός στους καταλόγους και μπορείτε να εγγραφείτε σε αυτόν';
$labels['longaclr'] = 'Ο φάκελος μπορεί να προσπελαστεί για ανάγνωση ';
$labels['longacls'] = 'Η κατάσταση ανάγνωσης μηνυμάτων μπορεί να αλλαχθεί';
$labels['longaclw'] = 'Μπορούν να μεταβληθούν οι καταστάσεις μηνυμάτων και οι λέξεις κλειδιά, εκτός από τις καταστάσεις Ανάγνωσης και Διαγραφής';
$labels['longacli'] = 'Τα μηνύματα μπορούν να εγγραφούν ή να αντιγραφούν στον φάκελο ';
$labels['longaclp'] = 'Τα μηνύματα μπορούν να τοποθετηθούν σε αυτόν το φάκελο ';
$labels['longaclc'] = 'Μπορούν να δημιουργηθούν (ή να μετονομαστούν) φάκελοι ακριβώς κάτω από αυτόν τον φάκελο ';
$labels['longaclk'] = 'Μπορούν να δημιουργηθούν (ή να μετονομαστούν) φάκελοι ακριβώς κάτω από αυτόν τον φάκελο ';
$labels['longacld'] = 'Η κατάσταση διαγραφής μηνυμάτων μπορεί να μεταβληθεί';
$labels['longaclt'] = 'Η κατάσταση διαγραφής μηνυμάτων μπορεί να μεταβληθεί';
$labels['longacle'] = 'Τα μηνύματα μπορούν να απαλειφθούν';
$labels['longaclx'] = 'Ο φάκελος μπορεί να μετονομασθεί ή να διαγραφεί';
$labels['longacla'] = 'Τα δικαιώματα πρόσβασης στον φάκελο μπορούν να μεταβληθούν';
$labels['longacln'] = 'Το διαμοιραζόμενο υπόμνημα των μηνυμάτων είναι δυνατό να μεταβληθεί';
$labels['longaclfull'] = 'Πλήρης έλεγχος συμπεριλαμβανόμενης της διαχείρισης φακέλων';
$labels['longaclread'] = 'Ο φάκελος είναι δυνατό να προσπελαστεί για ανάγνωση';
$labels['longaclwrite'] = 'Τα μηνύματα μπορούν να σημαδεύονται, να εγγράφονται ή να αντιγράφονται στον φάκελο';
$labels['longacldelete'] = 'Τα μηνύματα μπορούν να διαγραφούν';
$labels['longaclother'] = 'Άλλα δικαιώματα πρόσβασης';
$labels['ariasummaryacltable'] = 'Λίστα δικαιωμάτων πρόσβασης';
$labels['arialabelaclactions'] = 'Λίστα ενεργειών';
$labels['arialabelaclform'] = 'Φόρμα δικαιωμάτων πρόσβασης';
$messages['deleting'] = 'Διαγραφή των δικαιωμάτων πρόσβασης...';
$messages['saving'] = 'Αποθήκευση δικαιώματων πρόσβασης...';
$messages['updatesuccess'] = 'Επιτυχής μεταβολή των δικαιωμάτων πρόσβασης';
$messages['deletesuccess'] = 'Επιτυχής διαγραφή των δικαιωμάτων πρόσβασης';
$messages['createsuccess'] = 'Επιτυχής προσθήκη δικαιωμάτων πρόσβασης';
$messages['updateerror'] = 'Δεν είναι δυνατή η ενημέρωση των δικαιωμάτων πρόσβασης';
$messages['deleteerror'] = 'Δεν είναι δυνατή η διαγραφή των δικαιωμάτων πρόσβασης ';
$messages['createerror'] = 'Δεν είναι δυνατή η προσθήκη δικαιωμάτων πρόσβασης ';
$messages['deleteconfirm'] = 'Είστε βέβαιοι ότι θέλετε να καταργήσετε τα δικαιώματα πρόσβασης του επιλεγμένου(ων) χρήστη(ών);';
$messages['norights'] = 'Κανένα δικαίωμα δεν έχει καθοριστεί!';
$messages['nouser'] = 'Το όνομα χρήστη δεν έχει καθοριστεί! ';
