<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Вітаем у $product';
$labels['username'] = 'Імя карыстальніка';
$labels['password'] = 'Пароль';
$labels['server'] = 'Сервер';
$labels['login'] = 'Увайсці';
$labels['oauthlogin'] = 'Увайсці з дапамогай $provider';
$labels['menu'] = 'Меню';
$labels['logout'] = 'Выйсці';
$labels['mail'] = 'Пошта';
$labels['settings'] = 'Налады';
$labels['addressbook'] = 'Адрасная кніга';
$labels['darkmode'] = 'Цёмны рэжым';
$labels['lightmode'] = 'Сціслы рэжым';
$labels['inbox'] = 'Атрыманыя';
$labels['drafts'] = 'Чарнавікі';
$labels['sent'] = 'Адпраўленыя';
$labels['trash'] = 'Сметніца';
$labels['junk'] = 'Спам';
$labels['show_real_foldernames'] = 'Паказваць арыгінальныя назвы адмысловых каталогаў';
$labels['subject'] = 'Тэма';
$labels['from'] = 'Ад';
$labels['sender'] = 'Адпраўнік';
$labels['to'] = 'Каму';
$labels['cc'] = 'Копія';
$labels['bcc'] = 'Схаваная копія';
$labels['replyto'] = 'Адказаць-на';
$labels['followupto'] = 'Групавы-адказ-на';
$labels['date'] = 'Дата';
$labels['size'] = 'Памер';
$labels['priority'] = 'Прыярытэт';
$labels['organization'] = 'Кампанія';
$labels['readstatus'] = 'Прачытана';
$labels['listoptions'] = 'Параметры спіса...';
$labels['listoptionstitle'] = 'Параметры спіса';
$labels['mailboxlist'] = 'Каталогі';
$labels['messagesfromto'] = 'Паведамленні $from—$to з $count';
$labels['threadsfromto'] = 'Абмеркаванні $from—$to з $count';
$labels['messagenrof'] = 'Паведамленне $nr з $count';
$labels['fromtoshort'] = '$from—$to з $count';
$labels['copy'] = 'Капіяваць';
$labels['move'] = 'Перамясціць';
$labels['moveto'] = 'Перамясціць у...';
$labels['copyto'] = 'Скапіяваць у...';
$labels['download'] = 'Спампаваць';
$labels['open'] = 'Адкрыць';
$labels['showattachment'] = 'Паказаць';
$labels['showanyway'] = 'Усё адно паказваць';
$labels['filename'] = 'Назва файла';
$labels['filesize'] = 'Памер файла';
$labels['addtoaddressbook'] = 'Дадаць у адрасную кнігу';
$labels['sun'] = 'Ндз';
$labels['mon'] = 'Пн';
$labels['tue'] = 'Аў';
$labels['wed'] = 'Ср';
$labels['thu'] = 'Чц';
$labels['fri'] = 'Пт';
$labels['sat'] = 'Сб';
$labels['sunday'] = 'Нядзеля';
$labels['monday'] = 'Панядзелак';
$labels['tuesday'] = 'Аўторак';
$labels['wednesday'] = 'Серада';
$labels['thursday'] = 'Чацвер';
$labels['friday'] = 'Пятніца';
$labels['saturday'] = 'Субота';
$labels['jan'] = 'Сту';
$labels['feb'] = 'Лют';
$labels['mar'] = 'Сак';
$labels['apr'] = 'Кра';
$labels['may'] = 'Травень';
$labels['jun'] = 'Чэр';
$labels['jul'] = 'Ліп';
$labels['aug'] = 'Жні';
$labels['sep'] = 'Вер';
$labels['oct'] = 'Кас';
$labels['nov'] = 'Ліс';
$labels['dec'] = 'Сне';
$labels['longjan'] = 'Студзень';
$labels['longfeb'] = 'Люты';
$labels['longmar'] = 'Сакавік';
$labels['longapr'] = 'Красавік';
$labels['longmay'] = 'Травень';
$labels['longjun'] = 'Чэрвень';
$labels['longjul'] = 'Ліпень';
$labels['longaug'] = 'Жнівень';
$labels['longsep'] = 'Верасень';
$labels['longoct'] = 'Кастрычнік';
$labels['longnov'] = 'Лістапад';
$labels['longdec'] = 'Снежань';
$labels['today'] = 'Сёння';
$labels['refresh'] = 'Абнавіць';
$labels['checkmail'] = 'Праверыць наяўнасць новых лістоў';
$labels['compose'] = 'Напісаць';
$labels['writenewmessage'] = 'Стварыць новы ліст';
$labels['reply'] = 'Адказаць';
$labels['replytomessage'] = 'Адказаць адпраўніку';
$labels['replytoallmessage'] = 'Адказаць па спісе альбо адпраўніку і ўсім атрымальнікам';
$labels['replyall'] = 'Адказаць усім';
$labels['replylist'] = 'Адказаць па спісе';
$labels['forward'] = 'Пераслаць';
$labels['forwardinline'] = 'Пераслаць унутры ліста';
$labels['forwardattachment'] = 'Пераслаць як далучаны файл';
$labels['forwardmessage'] = 'Пераслаць гэты ліст';
$labels['bouncemsg'] = 'Адправіць паўторна';
$labels['bounce'] = 'Адправіць паўторна';
$labels['deletemessage'] = 'Выдаліць ліст';
$labels['movemessagetotrash'] = 'Перамясціць ліст у сметніцу';
$labels['printmessage'] = 'Надрукаваць гэты ліст';
$labels['previousmessage'] = 'Паказаць папярэдні ліст';
$labels['firstmessage'] = 'Паказаць першы ліст';
$labels['nextmessage'] = 'Паказаць наступны ліст';
$labels['lastmessage'] = 'Паказаць апошні ліст';
$labels['backtolist'] = 'Назад да спіса';
$labels['viewsource'] = 'Зыходны тэкст';
$labels['mark'] = 'Пазначыць';
$labels['markmessages'] = 'Пазначыць лісты';
$labels['markread'] = 'Як прачытаныя';
$labels['markunread'] = 'Як непрачытаныя';
$labels['markflagged'] = 'Пазначыць сцягам';
$labels['markunflagged'] = 'Прыбраць сцяг';
$labels['markundeleted'] = 'Не выдаленыя';
$labels['moreactions'] = 'Больш дзеянняў...';
$labels['markallread'] = 'Пазначыць усё як прачытанае';
$labels['folders-cur'] = 'Толькі абраныя каталогі';
$labels['folders-sub'] = 'Абраныя каталогі і каталогі ў іх';
$labels['folders-all'] = 'Усе каталогі';
$labels['more'] = 'Яшчэ';
$labels['back'] = 'Назад';
$labels['options'] = 'Параметры';
$labels['composeoptions'] = 'Параметры стварэння';
$labels['optionsandattachments'] = 'Параметры і далучаныя файлы';
$labels['actions'] = 'Дзеянні';
$labels['first'] = 'У пачатак';
$labels['last'] = 'У канец';
$labels['previous'] = 'Назад';
$labels['next'] = 'Далей';
$labels['select'] = 'Абраць';
$labels['selection'] = 'Вылучэнне';
$labels['all'] = 'Усе';
$labels['none'] = 'Нічога';
$labels['currpage'] = 'Бягучая старонка';
$labels['isread'] = 'Прачытаныя';
$labels['unread'] = 'Непрачытаныя';
$labels['flagged'] = 'Са сцягам';
$labels['unflagged'] = 'Без сцяга';
$labels['unanswered'] = 'Не было адказу';
$labels['withattachment'] = 'З далучанымі файламі';
$labels['deleted'] = 'Выдаленыя';
$labels['undeleted'] = 'Не выдаленыя';
$labels['replied'] = 'Быў адказ';
$labels['forwarded'] = 'Перасланыя';
$labels['invert'] = 'Інвертаваць';
$labels['filter'] = 'Фільтр';
$labels['list'] = 'Спіс';
$labels['threads'] = 'Ліставанні';
$labels['expand-all'] = 'Разгарнуць усё';
$labels['expand-unread'] = 'Разгарнуць непрачытаныя';
$labels['collapse-all'] = 'Згарнуць усё';
$labels['threaded'] = 'Threaded';
$labels['showunread'] = 'Паказваць непрачытаныя лісты';
$labels['autoexpand_threads'] = 'Разгортванне ліставанняў';
$labels['do_expand'] = 'усе ліставанні';
$labels['expand_only_unread'] = 'толькі з непрачытанымі лістамі';
$labels['fromto'] = 'Ад/Да';
$labels['flag'] = 'Сцяг';
$labels['attachment'] = 'Далучаныя файлы';
$labels['nonesort'] = 'Няма';
$labels['sentdate'] = 'Дата адпраўлення';
$labels['arrival'] = 'Дата атрымання';
$labels['asc'] = 'па павелічэнні';
$labels['desc'] = 'па памяншэнні';
$labels['listcolumns'] = 'Слупкі';
$labels['listsorting'] = 'Сартаванне паводле';
$labels['listorder'] = 'Парадак сартавання';
$labels['listmode'] = 'Рэжым спіса';
$labels['lmode'] = 'Рэжым спіса';
$labels['layout'] = 'Размяшчэнне';
$labels['layoutwidescreen'] = '16:9';
$labels['layoutdesktop'] = 'Працоўны стол';
$labels['layoutlist'] = 'Спіс';
$labels['layoutwidescreendesc'] = 'Шырокаэкранны (3 слупкі)';
$labels['layoutdesktopdesc'] = 'Для камп\'ютара (шырокі спіс і папярэдні прагляд ліста ніжэй спіса)';
$labels['layoutlistdesc'] = 'Спіс (без папярэдняга прагляду)';
$labels['folderactions'] = 'Дзеянні з каталогам...';
$labels['compact'] = 'Сціснуць';
$labels['empty'] = 'Ачысціць';
$labels['importmessages'] = 'Імпартаваць лісты';
$labels['mailimportdesc'] = 'Вы можаце запампаваць лісты ў фарматах <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> або <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>.';
$labels['mailimportzip'] = 'Некалькі файлаў можна сціснуць у zip-архівы.';
$labels['quota'] = 'Выкарыстанне сховішча';
$labels['unknown'] = 'невядома';
$labels['unlimited'] = 'без абмежаванняў';
$labels['quotatype'] = 'Тып ліміту';
$labels['quotatotal'] = 'Ліміт';
$labels['quotaused'] = 'Выкарыстоўваецца';
$labels['quotastorage'] = 'Месца на дыску';
$labels['quotamessage'] = 'Колькасць лістоў';
$labels['shortheaderdate'] = '$date';
$labels['shortheaderto'] = 'Да $to $date';
$labels['shortheaderfrom'] = 'Ад $from $date';
$labels['quicksearch'] = 'Хуткі пошук';
$labels['searchplaceholder'] = 'Пошук...';
$labels['resetsearch'] = 'Скінуць пошук';
$labels['searchmod'] = 'Мадыфікатары пошуку';
$labels['msgtext'] = 'Entire message';
$labels['body'] = 'Цела';
$labels['type'] = 'Тып';
$labels['namex'] = 'Імя';
$labels['searchscope'] = 'Размяшчэнне';
$labels['currentfolder'] = 'Бягучы каталог';
$labels['subfolders'] = 'Гэты і ўкладзеныя каталогі';
$labels['allfolders'] = 'Усе каталогі';
$labels['searchinterval-1W'] = 'больш за тыдзень';
$labels['searchinterval-1M'] = 'больш за месяц';
$labels['searchinterval-1Y'] = 'больш за год';
$labels['searchinterval1W'] = 'менш за тыдзень';
$labels['searchinterval1M'] = 'менш за месяц';
$labels['searchinterval1Y'] = 'менш за год';
$labels['openinextwin'] = 'Адкрыць у новым акне';
$labels['emlsave'] = 'Спампаваць (.eml)';
$labels['changeformattext'] = 'Паказаць як просты тэкст';
$labels['changeformathtml'] = 'Паказаць як HTML';
$labels['editasnew'] = 'Рэдагаваць як новы ліст';
$labels['send'] = 'Адправіць';
$labels['sendmessage'] = 'Адправіць зараз';
$labels['savemessage'] = 'Захаваць як чарнавік';
$labels['addattachment'] = 'Далучыць файл';
$labels['charset'] = 'Кадаванне';
$labels['editortype'] = 'Тып рэдактара';
$labels['returnreceipt'] = 'Апавяшчэнне пра прачытанне';
$labels['dsn'] = 'Апавяшчэнне пра атрыманне';
$labels['keepformatting'] = 'Захоўваць фарматаванне';
$labels['mailreplyintro'] = '$sender напісаў $date:';
$labels['originalmessage'] = 'Арыгінальнае паведамленне';
$labels['selectimage'] = 'Абраць выяву';
$labels['addimage'] = 'Дадаць выяву';
$labels['selectmedia'] = 'Абраць відэа';
$labels['addmedia'] = 'Дадаць відэа';
$labels['encrypt'] = 'Зашыфраваць';
$labels['encryptmessage'] = 'Зашыфраваць ліст';
$labels['encryptmessagemailvelope'] = 'Зашыфраваць ліст з дапамогай Mailvelope';
$labels['importpubkeys'] = 'Імпартаваць публічны ключ';
$labels['encryptedsendialog'] = 'Адпраўленне зашыфраванага ліста';
$labels['encryptandsign'] = 'Зашыфраваць і падпісаць';
$labels['keyid'] = 'ID ключа';
$labels['keylength'] = 'Біты';
$labels['keyexpired'] = 'Састарэлы';
$labels['keyrevoked'] = 'Адкліканы';
$labels['bccinstead'] = 'Выкарыстоўваць схаваную копію';
$labels['addheader'] = 'Дадаць атрымальніка (загаловак)';
$labels['insert'] = 'Уставіць';
$labels['insertcontact'] = 'Уставіць кантакт(ы)';
$labels['recipient'] = 'Атрымальнік';
$labels['recipientedit'] = 'Рэдагаванне атрымальніка';
$labels['editidents'] = 'Рэдагаваць асабовыя звесткі';
$labels['spellcheck'] = 'Правапіс';
$labels['checkspelling'] = 'Праверыць правапіс';
$labels['resumeediting'] = 'Працягнуць рэдагаванне';
$labels['revertto'] = 'Вярнуцца да';
$labels['restore'] = 'Аднавіць';
$labels['restoremessage'] = 'Аднавіць ліст?';
$labels['ignore'] = 'Не зважаць';
$labels['responses'] = 'Адказы';
$labels['insertresponse'] = 'Уставіць адказ';
$labels['manageresponses'] = 'Кіраванне адказамі';
$labels['newresponse'] = 'Стварыць новы адказ';
$labels['addresponse'] = 'Дадаць адказ';
$labels['editresponse'] = 'Рэдагаваць адказ';
$labels['editresponses'] = 'Рэдагаваць адказы';
$labels['responsename'] = 'Назва';
$labels['responsetext'] = 'Тэкст адказу';
$labels['attach'] = 'Далучыць';
$labels['attachments'] = 'Далучаныя файлы';
$labels['upload'] = 'Запампаваць';
$labels['uploadprogress'] = '$percent ($current з $total)';
$labels['close'] = 'Закрыць';
$labels['messageoptions'] = 'Параметры ліста...';
$labels['togglecomposeoptions'] = 'Пераключыць параметры стварэння';
$labels['attachmentrename'] = 'Змяніць назву далучанага файла';
$labels['low'] = 'Нізкі';
$labels['lowest'] = 'Найніжэйшы';
$labels['normal'] = 'Звычайны';
$labels['high'] = 'Высокі';
$labels['highest'] = 'Найвышэйшы';
$labels['nosubject'] = '(без тэмы)';
$labels['showimages'] = 'Паказваць выявы';
$labels['allow'] = 'Дазволіць';
$labels['alwaysshow'] = 'Заўсёды паказваць выявы ад $sender';
$labels['alwaysallow'] = 'Заўсёды дазваляць ад $sender';
$labels['isdraft'] = 'Гэта чарнавік.';
$labels['andnmore'] = 'яшчэ $nr...';
$labels['details'] = 'Падрабязнасці';
$labels['summary'] = 'Агулам';
$labels['headers'] = 'Загалоўкі';
$labels['allheaders'] = 'Усе загалоўкі...';
$labels['togglemoreheaders'] = 'Паказаць больш загалоўкаў';
$labels['togglefullheaders'] = 'Паказаць неапрацаваныя загалоўкі';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Звычайны тэкст';
$labels['savesentmessagein'] = 'Захаваць ліст у';
$labels['dontsave'] = 'не захоўваць';
$labels['maxuploadsize'] = 'Максімальны памер файла — $size';
$labels['addcc'] = 'Копія';
$labels['addbcc'] = 'Схаваная копія';
$labels['addreplyto'] = 'Адказ-на';
$labels['addfollowupto'] = 'Групавы-адказ-на';
$labels['sendreceipt'] = 'Адправіць апавяшчэнне пра прачытанне?';
$labels['mdnrequest'] = 'Адпраўнік хоча даведацца пра прачытанне гэтага ліста. Апавясціць адпраўніка?';
$labels['receiptread'] = 'Пацвярджэнне атрымання (прачытання)';
$labels['yourmessage'] = 'Гэта пацвярджэнне атрымання вашага ліста';
$labels['receiptnote'] = 'Заўвага: гэтае пацвярджэнне азначае, што ліст быў адлюстраваны на экране камп\'ютара адрасата. Няма гарантыі, што атрымальнік прачытаў альбо зразумеў змесціва ліста.';
$labels['sendalwaysto'] = 'Заўсёды адпраўляць $email';
$labels['zoomin'] = 'Наблізіць';
$labels['zoomout'] = 'Аддаліць';
$labels['rotate'] = 'Павярнуць';
$labels['increaseimage'] = 'Павялічыць памер выявы';
$labels['decreaseimage'] = 'Паменшыць памер выявы';
$labels['rotateimage'] = 'Павярнуць выяву';
$labels['showtools'] = 'Паказаць інструменты для працы з выявамі';
$labels['hidetools'] = 'Схаваць інструменты для працы з выявамі';
$labels['name'] = 'Імя кантакта';
$labels['firstname'] = 'Імя';
$labels['surname'] = 'Прозвішча';
$labels['middlename'] = 'Імя па бацьку (другое імя)';
$labels['nameprefix'] = 'Назва';
$labels['namesuffix'] = 'Суфікс';
$labels['nickname'] = 'Мянушка';
$labels['jobtitle'] = 'Пасада';
$labels['department'] = 'Аддзел';
$labels['gender'] = 'Пол';
$labels['maidenname'] = 'Дзявоцкае прозвішча';
$labels['email'] = 'Эл. пошта';
$labels['phone'] = 'Тэлефон';
$labels['address'] = 'Адрас';
$labels['street'] = 'Вуліца';
$labels['locality'] = 'Горад';
$labels['zipcode'] = 'Індэкс';
$labels['region'] = 'Вобласць / Правінцыя';
$labels['country'] = 'Краіна';
$labels['birthday'] = 'Дзень народзінаў';
$labels['anniversary'] = 'Юбілей';
$labels['website'] = 'Вэб-сайт';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Нататкі';
$labels['male'] = 'мужчына';
$labels['female'] = 'жанчына';
$labels['manager'] = 'Кіраўнік';
$labels['assistant'] = 'Асістэнт';
$labels['spouse'] = 'Жонка';
$labels['allfields'] = 'Усе палі';
$labels['search'] = 'Пошук';
$labels['searchresult'] = 'Вынік пошуку';
$labels['advsearch'] = 'Пашыраны пошук';
$labels['advanced'] = 'Дадаткова';
$labels['other'] = 'Іншае';
$labels['printcontact'] = 'Надрукаваць кантакт';
$labels['qrcode'] = 'QR-код';
$labels['typehome'] = 'Дом';
$labels['typework'] = 'Праца';
$labels['typeother'] = 'Іншае';
$labels['typemobile'] = 'Мабільны';
$labels['typemain'] = 'Асноўны';
$labels['typehomefax'] = 'Хатні факс';
$labels['typeworkfax'] = 'Працоўны факс';
$labels['typecar'] = 'Аўтамабіль';
$labels['typepager'] = 'Пэйджар';
$labels['typevideo'] = 'Відэа';
$labels['typeassistant'] = 'Асістэнт';
$labels['typehomepage'] = 'Хатняя старонка';
$labels['typeblog'] = 'Блог';
$labels['typeprofile'] = 'Профіль';
$labels['addfield'] = 'Дадаць поле...';
$labels['addcontact'] = 'Дадаць кантакт';
$labels['editcontact'] = 'Рэдагаваць кантакт';
$labels['contacts'] = 'Кантакты';
$labels['contactproperties'] = 'Уласцівасці кантакта';
$labels['contactnameandorg'] = 'Імя і арганізацыя';
$labels['personalinfo'] = 'Асабістыя звесткі';
$labels['personal'] = 'Асабістыя';
$labels['contactphoto'] = 'Асабістае фота';
$labels['edit'] = 'Рэдагаваць';
$labels['cancel'] = 'Скасаваць';
$labels['save'] = 'Захаваць';
$labels['delete'] = 'Выдаліць';
$labels['discard'] = 'Адкінуць';
$labels['continue'] = 'Працягнуць';
$labels['ok'] = 'Добра';
$labels['rename'] = 'Змяніць назву';
$labels['addphoto'] = 'Дадаць';
$labels['replacephoto'] = 'Замяніць';
$labels['uploadphoto'] = 'Запампаваць фота';
$labels['choosefile'] = 'Абраць файл...';
$labels['choosefiles'] = 'Абраць файлы...';
$labels['browse'] = 'Агляд';
$labels['newcontact'] = 'Стварыць новы кантакт';
$labels['deletecontact'] = 'Выдаліць абраныя кантакты';
$labels['composeto'] = 'Напісаць ліст';
$labels['contactsfromto'] = 'Кантакты $from—$to з $count';
$labels['print'] = 'Друкаваць';
$labels['export'] = 'Экспарт';
$labels['exportall'] = 'Экспартаваць усё';
$labels['exportsel'] = 'Экспартаваць абранае';
$labels['exportvcards'] = 'Экспартаваць кантакты ў фармаце vCard';
$labels['newgroup'] = 'Стварыць новую групу';
$labels['addgroup'] = 'Дадаць групу';
$labels['grouprename'] = 'Змяніць назву групы';
$labels['groupdelete'] = 'Выдаліць групу';
$labels['groupassign'] = 'Прызначыць у групу...';
$labels['groupremove'] = 'Выдаліць з групы';
$labels['groupremoveselected'] = 'Выдаліць абраныя кантакты з групы';
$labels['uponelevel'] = 'На адзін узровень уверх';
$labels['previouspage'] = 'Папярэдняя старонка';
$labels['firstpage'] = 'Першая старонка';
$labels['nextpage'] = 'Наступная старонка';
$labels['lastpage'] = 'Апошняя старонка';
$labels['group'] = 'Група';
$labels['groups'] = 'Групы';
$labels['listgroup'] = 'Паказаць кантакты групы';
$labels['personaladrbook'] = 'Асабістыя адрасы';
$labels['searchsave'] = 'Захаваць запыт';
$labels['searchdelete'] = 'Выдаліць запыт';
$labels['import'] = 'Імпарт';
$labels['importcontacts'] = 'Імпартаваць кантакты';
$labels['importfromfile'] = 'Імпартаваць з файла';
$labels['importtarget'] = 'Дадаць канакты ў';
$labels['importreplace'] = 'Замяніць адрасную кнігу цалкам';
$labels['importgroups'] = 'Імпартаваць прызначэнні групы';
$labels['importgroupsall'] = 'Усе (стварыць групы пры неабходнасці)';
$labels['importgroupsexisting'] = 'Толькі для існых групаў';
$labels['importdesc'] = 'Вы можаце запампаваць кантакты з наяўнай адраснай кнігі.<br/>Цяпер мы падтрымліваем імпарт з файлаў фарматаў <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> і CSV (comma-separated).';
$labels['importmapdesc'] = 'Перш чым пачаць імпартаванне даных з файла фармату CSV (comma-separated), пераканайцеся, што палі ніжэй паказваюцца правільна.';
$labels['fieldnotmapped'] = 'Поле не паказана (не імпартаваць)';
$labels['skipheader'] = 'Не імпартаваць першы радок (загалоўкі)';
$labels['done'] = 'Завершана';
$labels['settingsfor'] = 'Налады для';
$labels['about'] = 'Інфармацыя';
$labels['preferences'] = 'Налады';
$labels['userpreferences'] = 'Налады карыстальніка';
$labels['editpreferences'] = 'Рэдагаваць налады карыстальніка';
$labels['identities'] = 'Асабовыя звесткі';
$labels['manageidentities'] = 'Кіраванне асабовымі звесткамі';
$labels['newidentity'] = 'Стварыць новыя асабовыя звесткі';
$labels['addidentity'] = 'Дадаць асабовыя звесткі';
$labels['editidentity'] = 'Рэдагаванне асабовых звестак';
$labels['identityencryption'] = 'Шыфраванне';
$labels['preferhtml'] = 'Паказаць HTML';
$labels['defaultcharset'] = 'Прадвызначанае кадаванне';
$labels['htmlmessage'] = 'Ліст ў фармаце HTML';
$labels['messagepart'] = 'Частка';
$labels['digitalsig'] = 'Электронны подпіс';
$labels['dateformat'] = 'Фармат даты';
$labels['timeformat'] = 'Фармат часу';
$labels['prettydate'] = 'Даты ў зручным фармаце';
$labels['setdefault'] = 'Зрабіць прадвызначаным';
$labels['autodetect'] = 'Аўтаматычна';
$labels['language'] = 'Мова';
$labels['timezone'] = 'Часавы пояс';
$labels['pagesize'] = 'Радкоў на старонцы';
$labels['signature'] = 'Подпіс';
$labels['dstactive'] = 'Летні/зімовы час';
$labels['showinextwin'] = 'Адкрываць лісты ў новым акне';
$labels['composeextwin'] = 'Ствараць лісты ў новым акне';
$labels['htmleditor'] = 'Ствараць лісты ў фармаце HTML';
$labels['htmlonreply'] = 'толькі ў адказ на лісты ў фармаце HTML';
$labels['htmlonreplyandforward'] = 'пры перасылцы альбо ў адказ на лісты ў фармаце HTML';
$labels['htmlsignature'] = 'Подпіс у HTML';
$labels['showemail'] = 'Паказваць адрас электроннай пошты разам з імем кантакта';
$labels['previewpane'] = 'Панэль прагляду';
$labels['skin'] = 'Абалонка інтэрфейсу';
$labels['logoutclear'] = 'Ачышчаць сметніцу пры выхадзе';
$labels['logoutcompact'] = 'Сціскаць атрыманыя пры выхадзе';
$labels['uisettings'] = 'Інтэрфейс карыстальніка';
$labels['serversettings'] = 'Налады сервера';
$labels['mailboxview'] = 'Выгляд скрыні';
$labels['mdnrequests'] = 'Пры запытванні пацвярджэння пра атрыманне';
$labels['askuser'] = 'пытацца мяне';
$labels['autosend'] = 'адпраўляць пацвярджэнне';
$labels['autosendknown'] = 'адпраўляць пацвярджэнне маім кантактам, інакш спытаць';
$labels['autosendknownignore'] = 'адпраўляць пацвярджэнне маім кантактам, інакш ігнараваць';
$labels['autosendtrusted'] = 'адпраўляць пацвярджэнне давераным адпраўнікам, інакш спытаць';
$labels['autosendtrustedignore'] = 'адпраўляць пацвярджэнне давераным адпраўнікам, інакш ігнараваць';
$labels['ignorerequest'] = 'ігнараваць запыт';
$labels['readwhendeleted'] = 'Пазначаць ліст як прачытаны пры выдаленні';
$labels['flagfordeletion'] = 'Пазначаць ліст для выдалення, не выдаляць';
$labels['skipdeleted'] = 'Не паказваць выдаленыя паведамленні';
$labels['deletealways'] = 'Калі не ўдалося перамясціць лісты ў сметніцу, выдаліць іх';
$labels['deletejunk'] = 'Назаўсёды выдаляць лісты ў каталозе спаму';
$labels['showremoteimages'] = 'Паказ адлеглых выяў';
$labels['allowremoteresources'] = 'Дазволіць адлеглыя рэсурсы (выявы, стылі)';
$labels['fromknownsenders'] = 'ад вядомых адпраўнікоў';
$labels['fromtrustedsenders'] = 'ад давераных адпраўнікоў';
$labels['frommycontacts'] = 'ад маіх кантактаў';
$labels['always'] = 'заўсёды';
$labels['alwaysbutplain'] = 'заўсёды, за выключэннем адказаў на просты тэкст';
$labels['showinlineimages'] = 'Паказваць далучаныя выявы пад лістом';
$labels['autosavedraft'] = 'Аўтаматычна захоўваць чарнавікі';
$labels['everynminutes'] = 'кожныя $n хвілін(ы)';
$labels['refreshinterval'] = 'Абнаўленне (праверка новых лістоў і г. д.)';
$labels['never'] = 'ніколі';
$labels['immediately'] = 'неадкладна';
$labels['messagesdisplaying'] = 'Адлюстраванне лістоў';
$labels['messagescomposition'] = 'Напісанне лістоў';
$labels['mimeparamfolding'] = 'Назвы далучаных файлаў';
$labels['2231folding'] = 'Поўныя RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Поўныя RFC 2047 (інш.)';
$labels['force7bit'] = 'Выкарыстоўваць MIME-кадаванне для 8-бітных знакаў';
$labels['savelocalstorage'] = "Захоўваць у лакальным сховішчы браўзера (часова)";
$labels['advancedoptions'] = 'Дадатковыя параметры';
$labels['toggleadvancedoptions'] = 'Паказаць/Схаваць дадатковыя параметры';
$labels['focusonnewmessage'] = 'Актываваць акно браўзера пры атрыманні новага ліста';
$labels['checkallfolders'] = 'Правяраць усе каталогі на наяўнасць новых лістоў';
$labels['displaynext'] = 'Паказваць наступны запіс у спісе пасля выдалення/перамяшчэння';
$labels['defaultfont'] = 'Прадвызначаны шрыфт лістоў у фармаце HTML';
$labels['mainoptions'] = 'Асноўныя параметры';
$labels['browseroptions'] = 'Параметры браўзера';
$labels['section'] = 'Раздзел';
$labels['maintenance'] = 'Абслугоўванне';
$labels['newmessage'] = 'Новы ліст';
$labels['signatureoptions'] = 'Параметры подпісу';
$labels['whenreplying'] = 'Пры адказе';
$labels['replyempty'] = 'не цытаваць зыходны ліст';
$labels['replytopposting'] = 'пачынаць новы ліст над цытаваным';
$labels['replytoppostingnoindent'] = 'пачынаць новы ліст над цытаваным (без водступу)';
$labels['replybottomposting'] = 'пачынаць новы ліст пад цытаваным';
$labels['replyremovesignature'] = 'Адказваючы, выдаліць стары подпіс';
$labels['autoaddsignature'] = 'Аўтаматычна дадаваць подпіс';
$labels['newmessageonly'] = 'толькі ў новых лістах';
$labels['replyandforwardonly'] = 'толькі ў адказах і перасланых';
$labels['insertsignature'] = 'Уставіць подпіс';
$labels['sigbelow'] = 'Размяшчаць подпіс пад цытаваным лістом';
$labels['sigseparator'] = 'Прымусова выкарыстоўваць стандартны падзяляльнік ў подпісах';
$labels['automarkread'] = 'Пазначыць прачытаным';
$labels['afternseconds'] = 'пасля $n секунд';
$labels['reqmdn'] = 'Заўсёды запытваць пацвярджэнне атрымання';
$labels['reqdsn'] = 'Заўсёды запытваць апавяшчэнне пра дастаўку';
$labels['replysamefolder'] = 'Размяшчаць адказы ў каталог зыходнага ліста';
$labels['defaultabook'] = 'Прадвызначаная адрасная кніга';
$labels['autocompletesingle'] = 'Прапускаць альтэрнатыўныя адрасы пры аўтаматычным дапаўненні';
$labels['listnamedisplay'] = 'Паказваць спіс кантактаў як';
$labels['contactformmode'] = 'Рэжым формы кантакта';
$labels['privatemode'] = 'Прыватны';
$labels['businessmode'] = 'Працоўны';
$labels['collectedaddresses'] = 'Сабраныя адрасы';
$labels['collectedrecipients'] = 'Сабраныя атрымальнікі';
$labels['collectedrecipientsopt'] = 'Захоўвайць атрымальнікаў выходных лістоў у';
$labels['collectedsendersopt'] = 'Захоўваць давераных адпраўнікоў у';
$labels['trustedsenders'] = 'Давераныя адпраўнікі';
$labels['spellcheckbeforesend'] = 'Правяраць правапіс перад адпраўленнем';
$labels['spellcheckoptions'] = 'Параметры праверкі правапісу';
$labels['spellcheckignoresyms'] = 'Ігнараваць словы з сімваламі';
$labels['spellcheckignorenums'] = 'Ігнараваць словы з лікамі';
$labels['spellcheckignorecaps'] = 'Ігнараваць словы з усімі літарамі ў верхнім рэгістры';
$labels['addtodict'] = 'Дадаць у слоўнік';
$labels['mailtoprotohandler'] = 'Зарэгістраваць пратакол апрацоўвання для спасылак mailto';
$labels['standardwindows'] = 'Апрацоўваць выплыўныя вокны як звычайныя вокны';
$labels['forwardmode'] = 'Перасылка лістоў';
$labels['inline'] = 'у тэксце';
$labels['asattachment'] = 'як далучаны файл';
$labels['replyallmode'] = 'Прадвызначанае дзеянне кнопкі [Адказаць усім]';
$labels['replyalldefault'] = 'адказаць усім';
$labels['replyalllist'] = 'адказаць толькі ў спіс рассылкі (калі знойдзены)';
$labels['allmessages'] = 'усе паведамленні';
$labels['olderxdays'] = 'больш за $x дзён';
$labels['folder'] = 'Каталог';
$labels['folders'] = 'Каталогі';
$labels['foldername'] = 'Назва каталога';
$labels['subscribed'] = 'Subscribed';
$labels['messagecount'] = 'Лісты';
$labels['create'] = 'Стварыць';
$labels['createfolder'] = 'Стварыць новы каталог';
$labels['managefolders'] = 'Кіраванне каталогамі';
$labels['specialfolders'] = 'Адмысловыя каталогі';
$labels['properties'] = 'Уласцівасці';
$labels['folderproperties'] = 'Уласцівасці каталога';
$labels['parentfolder'] = 'Бацькоўскі каталог';
$labels['location'] = 'Размяшчэнне';
$labels['info'] = 'Звесткі';
$labels['getfoldersize'] = 'Пстрыкніце, каб даведацца памер каталога';
$labels['changesubscription'] = 'Пстрыкніце, каб змяніць падпіску';
$labels['foldertype'] = 'Тып каталога';
$labels['personalfolder'] = 'Асабісты каталог';
$labels['otherfolder'] = 'Каталог іншага карыстальніка';
$labels['sharedfolder'] = 'Публічны каталог';
$labels['findfolders'] = 'Пошук каталогаў';
$labels['findcontacts'] = 'Пошук кантактаў';
$labels['findmail'] = 'Пошук лістоў';
$labels['namespace.personal'] = 'Асабістыя';
$labels['namespace.other'] = 'Iншыя карыстальнікi';
$labels['namespace.shared'] = 'Адпраўлена';
$labels['dualuselabel'] = 'Могуць змяшчаць толькі';
$labels['dualusemail'] = 'лісты';
$labels['dualusefolder'] = 'каталогі';
$labels['generate'] = 'Згенераваць';
$labels['encryptioncreatekey'] = 'Стварыць новую пару ключоў';
$labels['openmailvelopesettings'] = 'Адкрыць налады Mailvelope';
$labels['encryptionprivkeysinmailvelope'] = 'Вы маеце $nr адпаведных прыватных ключоў, якія захоўваюцца ў вашай вязцы Mailvelope:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Гэтыя асабовыя звесткі адпраўніка яшчэ не маюць прыватнага ключа PGP, захаванага ў пашырэнні Mailvelope. Хоочаце стварыць яго, каб уключыць зашыфраванае ліставанне?';
$labels['encryption'] = 'Шыфраванне';
$labels['mailvelopeoptions'] = 'Параметры Mailvelope';
$labels['mailvelopemainkeyring'] = 'Выкарыстоўваць галоўную вязку Mailvelope';
$labels['mailvelopenotfound'] = 'Пашырэнне Mailvelope не ўсталявана (або не ўключана) у вашым браўзеры.';
$labels['sortby'] = 'Сартаваць па';
$labels['sortasc'] = 'Па павелічэнні';
$labels['sortdesc'] = 'Па памяншэнні';
$labels['undo'] = 'Адрабіць';
$labels['installedplugins'] = 'Усталяваныя убудовы';
$labels['plugin'] = 'Убудова';
$labels['version'] = 'Версія';
$labels['source'] = 'Крыніца';
$labels['destination'] = 'Прызначэнне';
$labels['license'] = 'Ліцэнзія';
$labels['support'] = 'Падтрымка';
$labels['savedsearches'] = 'Захаваныя запыты пошуку';
$labels['dateformatY'] = 'ГГГГ';
$labels['dateformaty'] = 'ГГ';
$labels['dateformatm'] = 'ММ';
$labels['dateformatd'] = 'ДзДз';
$labels['dateformatj'] = 'Д';
$labels['dateformatn'] = 'М';
$labels['B'] = 'Б';
$labels['KB'] = 'КБ';
$labels['MB'] = 'МБ';
$labels['GB'] = 'ГБ';
$labels['unicode'] = 'Юнікод';
$labels['english'] = 'Англійскае';
$labels['westerneuropean'] = 'Заходне-Еўрапейскае';
$labels['easterneuropean'] = 'Усходне-Еўрапейскае';
$labels['southeasterneuropean'] = 'Паўднёва-Еўрапейскае';
$labels['baltic'] = 'Балтыйскае';
$labels['cyrillic'] = 'Кірыліца';
$labels['arabic'] = 'Арабскае';
$labels['greek'] = 'Грэчаскае';
$labels['hebrew'] = 'Іўрыт';
$labels['turkish'] = 'Турэцкае';
$labels['nordic'] = 'Скандынаўскае';
$labels['thai'] = 'Тайскае';
$labels['celtic'] = 'Кельцкае';
$labels['vietnamese'] = 'В\'етнамскае';
$labels['japanese'] = 'Японскае';
$labels['korean'] = 'Карэйскае';
$labels['chinese'] = 'Кітайскае';
$labels['arialabeltopnav'] = 'Кіраванне акном';
$labels['arialabeltasknav'] = 'Задачы праграмы';
$labels['arialabeltoolbar'] = 'Панэль інструментаў праграмы';
$labels['arialabellistnav'] = 'Навігацыя па спісах';
$labels['arialabelactivetask'] = 'Актыўная задача';
$labels['arialabelmessagessearchfilter'] = 'Фільтр спіса пошты';
$labels['arialabelmailsearchform'] = 'Форма пошуку лістоў';
$labels['arialabelcontactsearchform'] = 'Форма пошуку кантактаў';
$labels['arialabelmailquicksearchbox'] = 'Увод для пошуку лістоў';
$labels['arialabelquicksearchbox'] = 'Увод для пошуку';
$labels['arialabelfoldersearchfilter'] = 'Фільтр спіса каталогаў';
$labels['arialabelfoldersearchform'] = 'Форма пошуку каталогаў';
$labels['arialabelfolderlist'] = 'Выбар каталогаў';
$labels['arialabelmessagelist'] = 'Спіс лістоў';
$labels['arialabelmailpreviewframe'] = 'Папярэдні прагляд лістоў';
$labels['arialabelmailboxmenu'] = 'Меню дзеянняў з каталогам';
$labels['arialabellistselectmenu'] = 'Меню выбару спіса';
$labels['arialabelthreadselectmenu'] = 'Меню спіса ліставанняў';
$labels['arialabelmessagelistoptions'] = 'Параметры паказу і сартавання лістоў';
$labels['arialabelmailimportdialog'] = 'Дыялог імпартавання лістоў';
$labels['arialabelmessagenav'] = 'Навігацыя па лістах';
$labels['arialabelmessagebody'] = 'Цела ліста';
$labels['arialabelmessageactions'] = 'Дзеянні для лістоў';
$labels['arialabelcontactquicksearch'] = 'Форма пошуку кантактаў';
$labels['arialabelcontactsearchbox'] = 'Увод для пошуку кантактаў';
$labels['arialabelmessageheaders'] = 'Загалоўкі лістоў';
$labels['arialabelforwardingoptions'] = 'Параметры перасылання';
$labels['arialabelreplyalloptions'] = 'Параметры адказу ўсім';
$labels['arialabelmoremessageactions'] = 'Дадатковыя дзеянні для лістоў';
$labels['arialabelmorecontactactions'] = 'Дадатковыя дзеянні для кантактаў';
$labels['arialabelmarkmessagesas'] = 'Пазначыць абраныя лісты як...';
$labels['arialabelcomposeoptions'] = 'Параметры стварэння';
$labels['arialabelresponsesmenu'] = 'Меню падрыхтаваных адказаў';
$labels['arialabelattachmentuploadform'] = 'Форма запампоўвання далучаных файлаў';
$labels['arialabelattachmentmenu'] = 'Параметры далучэння файлаў';
$labels['arialabelmailtomenu'] = 'Параметры адрасоў электроннай пошты';
$labels['arialabelattachmentpreview'] = 'Папярэдні прагляд далучаных файлаў';
$labels['ariasummarycomposecontacts'] = 'Спіс кантактаў і групаў для выбару атрымальнікаў';
$labels['arialabelcontactexportoptions'] = 'Параметры экспартавання кантактаў';
$labels['arialabelabookgroupoptions'] = 'Параметры адраснай кнігі і групаў';
$labels['arialabelpreferencesform'] = 'Форма налад';
$labels['arialabelidentityeditfrom'] = 'Форма рэдагавання асабовых звестак';
$labels['arialabelresponseeditfrom'] = 'Форма рэдагавання адказу';
$labels['arialabelsearchterms'] = 'Пошук тэрмінаў';
$labels['arialabeldropactionmenu'] = 'Меню дзеянняў выплыўнога меню';
$labels['arialabelheadersmenu'] = 'Меню дадання атрымальніка (загаловак)';
$labels['arialabelimagetools'] = 'Інструменты для працы з выявамі';
$labels['helplistnavigation'] = 'Навігацыя клавіятурай па спісе';
$labels['helplistkeyboardnavigation'] = "Стрэлкі ўверх/уніз: перамясціць фокус/вылучэнне радка.
Прагал: абраць радок у фокусе.
Shift + уверх/уніз: абраць дадатковы радок ніжэй/вышэй.
Ctrl + прагал: дадаць/прыбраць радок у фокусе з абранага.";
$labels['helplistkeyboardnavmessages'] = "Стрэлкі ўправа/улева: разгарнуць/згарнуць ліставанне (толькі ў рэжыме ліставання).
Enter: адкрыць абраны ліст/ліст у фокусе.
Delete: перамясціць абраныя лісты ў кошык.";
$labels['helplistkeyboardnavcontacts'] = "Enter: адкрыць абраны кантакт / кантакт у фокусе.";
