<roundcube:include file="includes/layout.html" />

<h1 class="voice"><roundcube:label name="addressbook" /> : <roundcube:label name="importcontacts" /></h1>

<div class="formcontent">
	<roundcube:object name="importstep" class="propform" table-header-class="form-group row d-none d-sm-flex" table-col-source-class="col-sm-4" table-col-destination-class="col-sm-8" />
</div>

<roundcube:include file="includes/footer.html" />
