<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'දෝෂයක් මතුවිය!';
$messages['loginfailed']  = 'ඇතුල්වීම අසාර්ථකයි.';
$messages['cookiesdisabled'] = 'ඔබේ බෞසරය කුකී බාර ගන්නේ නැත';
$messages['sessionerror'] = 'ඔබේ වාරය අවලංගු හෝ කාලය ඉකුත් වී ඇත';
$messages['dberror'] = 'දත්ත ගබඩාවේ දෝෂය!';
$messages['nomessagesfound'] = 'ලියුම් පෙට්ටියේ පනිවුඩ නැත';
$messages['loading'] = 'පූරනය...';
$messages['loadingdata'] = 'දත්ත පූරනය...';
$messages['checkingmail'] = 'අලුත් පණිවිඩ පරීක්ෂා කරමින්...';
$messages['sendingmessage'] = 'පණිවිඩය යවමින්...';
$messages['messagesent'] = 'පණිවිඩය සාර්ථකව යවන ලදී.';
$messages['savingmessage'] = 'පණිවිඩය සුරකිමින්...';
$messages['messagesaved'] = 'පනිවුඩය කටු සටහනේ තැන්පත් විය';
$messages['successfullysaved'] = 'සුරැකීම සාර්ථකයි.';
$messages['addedsuccessfully'] = 'ලිපිනය සාර්ථකව ලිපින පොතට එකතු කරන ලදී.';
$messages['blockedimages'] = 'ඔබගෙ පොද්ගලිකත්වය හේතුවෙන්, දුරස්ථ රූප අවහිර කර ඇත.';
$messages['encryptedmessage'] = 'මෙම පනිවුඩය රහස් කේතනය කර ඇති බැවින් පෙන්විය නොහැක. සමාවන්න!';
$messages['nocontactsfound'] = 'ලිපින සොයා ගත නොහැක';
$messages['contactnotfound'] = 'ඉල්ලූ ලිපිනය සොයාගත නොහැක';
$messages['sendingfailed'] = 'පණිවිඩය යැවීම අසාර්ථකයි.';
$messages['senttooquickly'] = 'කරුණාකර මෙම පණිවිඩය යැවීමට පෙර තත්පර $secක් රැදී සිටින්න.';
$messages['errormoving'] = 'පනිවුඩය ගෙන යාමට නොහැක';
$messages['errorcopying'] = 'පණිවිඩ(ය) පිටපත් කල නොහැක.';
$messages['errordeleting'] = 'පණිවිඩ(ය) මකා දැමීමට නොහැක.';
$messages['errormarking'] = 'පණිවිඩ(ය) සලකුණු කල නොහැක.';
$messages['deletecontactconfirm']  = 'තෝරා ඇති ලිපින ඔබට මකා දැමීමට සැබවින්ම වුවමනාද?';
$messages['deletemessagesconfirm'] = 'තෝරා ඇති පණිවිඩ(ය) ඔබට මකා දැමීමට සැබවින්ම වුවමනාද?';
$messages['deletefolderconfirm']  = 'ඔබට මෙම බහාලුම මකා දැමීමට සැබවින්ම වුවමනාද?';
$messages['purgefolderconfirm']  = 'මෙම බහාලමේ ඇති සියලුම පණිවිඩ ඔබට මකා දැමීමට සැබවින්ම වුවමනාද?';
$messages['folderdeleting'] = 'බහාලුම මකාදමමින්...';
$messages['formincomplete'] = 'පෝරමය සම්පූර්ණයෙන් පුරවා නොමැත.';
$messages['noemailwarning'] = 'කරුණාකර වලංගු විද්යුත් ලිපිනයක් ඇතුලත් කරන්න.';
$messages['nonamewarning']  = 'කරුණාකර නම ඇතුලත් කරන්න.';
$messages['nopagesizewarning'] = 'කරුණාකර පිටුවේ ප්‍රමාණය ඇතුලත් කරන්න.';
$messages['norecipientwarning'] = 'කරුණාකර යටත් පිරිසෙයින් එක් ලබන්නෙකු හෝ ඇතුලත් කරන්න';
$messages['nosubjectwarning']  = '"මාතෘකාව" හිස්. මාතෘකාවක් ඇතුලත් කිරීමට ඔබ කැමතිද?';
$messages['nobodywarning'] = 'මෙම හිස් පනිවුඩය යවන්නද?';
$messages['nosearchname'] = 'කරුණාකර ලිපිනයෙහි නම හෝ විද්යුත් තැපැල් ලිපිනය ඇතුලත් කරන්න';
$messages['searchsuccessful'] = '$nr පනිවුඩය හමු විය';
$messages['searchnomatch'] = 'සෙවුමට අදාල ගැලපීමක් නොමැත.';
$messages['searching'] = 'සොයමින්...';
$messages['checking'] = 'පරික්‍ෂාකරමින්...';
$messages['nospellerrors'] = 'වියාකරන දොෂ නොමැත';
$messages['folderdeleted'] = 'බහාලුම සාර්ථකව මකා දමන ලදී.';
$messages['deletedsuccessfully'] = 'සාර්ථකව මකාදමන ලදී.';
$messages['converting'] = 'පනිවුඩයෙන් ආකෘතීකරණය ඉවත් කිරීම';
$messages['messageopenerror'] = 'පනිවුඩය පූරනය කිරීමට නොහැක';
$messages['fileuploaderror'] = 'ගොනුව ඇතුලත් කිරීමට නොහැක';
$messages['filesizeerror'] = 'ඇතුලත් කල ගොනුවෙ ප්රමාණය උපරිම අගය $size ඉක්මවා ඇත';
$messages['sourceisreadonly'] = 'මෙම ලිපින මූලාශ්රය කියවීම සඳහා පමනි';
$messages['errorsavingcontact'] = 'ලිපිනය තැන්පත් කීරීමට නොහැක';
$messages['movingmessage'] = 'පණිවිඩ(ය) ගෙනයමින්...';
$messages['copyingmessage'] = 'පණිවිඩ(ය) පිටපත් කරමින්...';
$messages['deletingmessage'] = 'පණිවිඩ(ය) මකා දමමින්...';
$messages['markingmessage'] = 'පණිවිඩ(ය) සලකුණු කරමින්...';
$messages['errorsendingreceipt'] = 'කියවීම් භාර ගැනීම යැවීමට නොහැක';
$messages['nodeletelastidentity'] = 'අවසාන අනන්‍යතාවය මකා දැමිය නොහැක';
$messages['importwait'] = 'ආනයනය කරමින්, කරුණාකර රැදී සිටින්න...';
$messages['messagedeleted'] = 'පණිවිඩ(ය) මකා දැමීම සාර්ථකයි.';
$messages['messagemoved'] = 'පණිවිඩ(ය) ගෙනයෑම සාර්ථකයි.';
$messages['messagecopied'] = 'පණිවිඩ(ය) පිටපත් කිරීම සාර්ථකයි.';
$messages['messagemarked'] = 'පණිවිඩ(ය) සලකුණු කිරීම සාර්ථකයි.';
$messages['namecannotbeempty'] = 'නම හිස්ව තැබිය නොහැක.';
$messages['nametoolong'] = 'නම දිග වැඩිය.';
