tinymce.addI18n('is_IS',{
"Redo": "Endurkalla",
"Undo": "Afturkalla",
"Cut": "Skera",
"Copy": "Afrita",
"Paste": "L\u00edma",
"Select all": "Velja allt",
"New document": "N\u00fdtt skjal",
"Ok": "Sta\u00f0festa",
"Cancel": "H\u00e6tta vi\u00f0",
"Visual aids": "Sj\u00f3nr\u00e6n hj\u00e1lp",
"Bold": "Feitletra\u00f0",
"Italic": "Skr\u00e1letra\u00f0",
"Underline": "Undirstrika\u00f0",
"Strikethrough": "Yfirstrika\u00f0",
"Superscript": "Uppskrift",
"Subscript": "Ni\u00f0urskrifa\u00f0",
"Clear formatting": "Hreinsa sni\u00f0",
"Align left": "Vinstrijafna",
"Align center": "Mi\u00f0jujafna",
"Align right": "H\u00e6grijafna",
"Justify": "Jafna",
"Bullet list": "K\u00falu listi",
"Numbered list": "N\u00famera\u00f0ur listi",
"Decrease indent": "Minnka inndr\u00e1tt",
"Increase indent": "Auka inndr\u00e1tt",
"Close": "Loka",
"Formats": "Sni\u00f0m\u00e1t",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Vafrinn \u00feinn sty\u00f0ur ekki beinann a\u00f0gang a\u00f0 klippibor\u00f0inu.  Nota\u00f0u Ctrl-X\/C\/V \u00e1 lyklabor\u00f0inu \u00ed sta\u00f0inn.",
"Headers": "Fyrirsagnir",
"Header 1": "Fyrirs\u00f6gn 1",
"Header 2": "Fyrirs\u00f6gn 2",
"Header 3": "Fyrirs\u00f6gn 3",
"Header 4": "Fyrirs\u00f6gn 4",
"Header 5": "Fyrirs\u00f6gn 5",
"Header 6": "Fyrirs\u00f6gn 6",
"Headings": "Fyrirsagnir",
"Heading 1": "Fyrirs\u00f6gn 1",
"Heading 2": "Fyrirs\u00f6gn 2",
"Heading 3": "Fyrirs\u00f6gn 3",
"Heading 4": "Fyrirs\u00f6gn 4",
"Heading 5": "Fyrirs\u00f6gn 5",
"Heading 6": "Fyrirs\u00f6gn 6",
"Preformatted": "Preformatted",
"Div": "Div",
"Pre": "\u00d3st\u00edla\u00f0",
"Code": "K\u00f3\u00f0i",
"Paragraph": "M\u00e1lsgrein",
"Blockquote": "Blokk",
"Inline": "Inndregi\u00f0",
"Blocks": "Blokkir",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "L\u00edming er \u00ed l\u00e1tlausum ham.  Innihald ver\u00f0ur l\u00edmt sem l\u00e1tlaus texti \u00feanga\u00f0 til \u00fe\u00fa afvirkjar \u00feennan m\u00f6guleika.",
"Fonts": "Leturger\u00f0ir",
"Font Sizes": "Leturst\u00e6r\u00f0",
"Class": "Tegund",
"Browse for an image": "Finna mynd \u00ed t\u00f6lvunni",
"OR": "E\u00d0A",
"Drop an image here": "Settu inn mynd h\u00e9r",
"Upload": "Hla\u00f0a upp",
"Block": "Blokka",
"Align": "Stilla",
"Default": "Sj\u00e1lfgefi\u00f0",
"Circle": "Hringur",
"Disc": "Diskur",
"Square": "Ferningur",
"Lower Alpha": "L\u00e1gstafir Alpha",
"Lower Greek": "L\u00e1gstafir Gr\u00edskir",
"Lower Roman": "L\u00e1gstafir R\u00f3mverskir",
"Upper Alpha": "H\u00e1stafir Alpha",
"Upper Roman": "H\u00e1stafir R\u00f3mverskir",
"Anchor...": "Anchor...",
"Name": "Nafn",
"Id": "Id",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "Id \u00e6tti a\u00f0 byrja \u00e1 b\u00f3kstaf, og skal einungis innihalda b\u00f3kstafi, t\u00f6lustafi, bandstrik, punkta, kommur e\u00f0a strik ni\u00f0ri.",
"You have unsaved changes are you sure you want to navigate away?": "\u00dea\u00f0 eru \u00f3vista\u00f0ar breytingar, ertu viss um a\u00f0 \u00fe\u00fa viljir vafra \u00ed burtu?",
"Restore last draft": "Endurkalla s\u00ed\u00f0asta uppkast",
"Special character...": "S\u00e9rstakur stafur...",
"Source code": "Frumk\u00f3\u00f0i",
"Insert\/Edit code sample": "Setja inn\/breyta k\u00f3\u00f0ad\u00e6mi",
"Language": "Tungum\u00e1l",
"Code sample...": "K\u00f3\u00f0ad\u00e6mi...",
"Color Picker": "Litaval",
"R": "R",
"G": "G",
"B": "B",
"Left to right": "Vinstri til h\u00e6gri",
"Right to left": "H\u00e6gri til vinstri",
"Emoticons...": "Tilfinningat\u00e1kn...",
"Metadata and Document Properties": "Metadata- og skjaleiginleikar",
"Title": "Titill",
"Keywords": "Lykilor\u00f0",
"Description": "L\u00fdsing",
"Robots": "Leitarv\u00e9lar",
"Author": "H\u00f6fundur",
"Encoding": "Umbreyting",
"Fullscreen": "Fylla skj\u00e1",
"Action": "A\u00f0ger\u00f0",
"Shortcut": "Fl\u00fdtilei\u00f0",
"Help": "Hj\u00e1lp",
"Address": "Address",
"Focus to menubar": "F\u00f3kus \u00e1 menubar",
"Focus to toolbar": "F\u00f3kus \u00e1 t\u00e6kjastiku",
"Focus to element path": "F\u00f3kus \u00e1 element path",
"Focus to contextual toolbar": "F\u00f3kus \u00e1 contextual toolbar",
"Insert link (if link plugin activated)": "Setja inn hlekk (ef link vi\u00f0b\u00f3t er virk)",
"Save (if save plugin activated)": "Vista (ef vistunar vi\u00f0b\u00f3t er virk)",
"Find (if searchreplace plugin activated)": "Leita (ef searchreplace vi\u00f0b\u00f3t er virk)",
"Plugins installed ({0}):": "Uppsettar vi\u00f0b\u00f3tir ({0}):",
"Premium plugins:": "Premium vi\u00f0b\u00e6tur:",
"Learn more...": "Sj\u00e1 meira...",
"You are using {0}": "\u00de\u00fa ert a\u00f0 nota {0}",
"Plugins": "Vi\u00f0b\u00e6tur",
"Handy Shortcuts": "Sni\u00f0ugar fl\u00fdtilei\u00f0ir",
"Horizontal line": "L\u00e1r\u00e9tt l\u00edna",
"Insert\/edit image": "Setja inn\/breyta mynd",
"Image description": "L\u00fdsing myndar",
"Source": "Sl\u00f3\u00f0i",
"Dimensions": "Hlutf\u00f6ll",
"Constrain proportions": "Halda hlutf\u00f6llum",
"General": "Almennt",
"Advanced": "\u00cdtarlegt",
"Style": "St\u00edll",
"Vertical space": "L\u00f3\u00f0r\u00e9tt bil",
"Horizontal space": "L\u00e1r\u00e9tt bil",
"Border": "Rammi",
"Insert image": "Setja inn mynd",
"Image...": "Mynd...",
"Image list": "Myndalisti",
"Rotate counterclockwise": "Sn\u00faa rangs\u00e6lis",
"Rotate clockwise": "Sn\u00faa r\u00e9tts\u00e6lis",
"Flip vertically": "Sn\u00faa l\u00f3\u00f0r\u00e9tt",
"Flip horizontally": "Sn\u00faa l\u00f3\u00f0r\u00e9tt",
"Edit image": "Breyta mynd",
"Image options": "Valm\u00f6guleikar myndar",
"Zoom in": "\u00deysja inn",
"Zoom out": "\u00deysja \u00fat",
"Crop": "Crop",
"Resize": "Breyta st\u00e6r\u00f0",
"Orientation": "Orientation",
"Brightness": "Birtustig",
"Sharpen": "Skerpa",
"Contrast": "Contrast",
"Color levels": "Litastu\u00f0lar",
"Gamma": "Gamma",
"Invert": "Invert",
"Apply": "Sta\u00f0festa",
"Back": "Til baka",
"Insert date\/time": "Setja inn dagsetningu\/t\u00edma",
"Date\/time": "Dagur\/t\u00edmi",
"Insert\/Edit Link": "Setja inn\/Breyta hlekk",
"Insert\/edit link": "Setja inn\/breyta hlekk",
"Text to display": "Texti til a\u00f0 s\u00fdna",
"Url": "Veffang",
"Open link in...": "Opna hlekk \u00ed...",
"Current window": "N\u00faverandi gluggi",
"None": "Ekkert",
"New window": "N\u00fdr gluggi",
"Remove link": "Fjarl\u00e6gja hlekk",
"Anchors": "Akkeri",
"Link...": "Hlekkur...",
"Paste or type a link": "L\u00edma e\u00f0a sl\u00e1 inn hlekk",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Hlekkurinn sem \u00fe\u00fa rita\u00f0ir inn l\u00fdtur \u00fat fyrir a\u00f0 vera netfang. Viltu b\u00e6ta vi\u00f0 forskeytinu mailto: ?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Hlekkurinn sem \u00fe\u00fa rita\u00f0ir inn l\u00fdtur \u00fat fyrir a\u00f0 vera ytri hlekkur. Viltu b\u00e6ta vi\u00f0 forskeytinu http:\/\/ ?",
"Link list": "Listi hlekkja",
"Insert video": "Setja inn myndband",
"Insert\/edit video": "Setja inn\/fjarl\u00e6gja myndband",
"Insert\/edit media": "Setja inn\/breyta myndefni",
"Alternative source": "Valkv\u00e6\u00f0ur frumk\u00f3\u00f0i",
"Alternative source URL": "Alternative source URL",
"Media poster (Image URL)": "Media poster (mynd URL)",
"Paste your embed code below:": "L\u00edma frumk\u00f3\u00f0a fyrir ne\u00f0an:",
"Embed": "Hengja vi\u00f0",
"Media...": "Media...",
"Nonbreaking space": "Bil sem brotnar ekki",
"Page break": "S\u00ed\u00f0ubrot",
"Paste as text": "L\u00edma sem texta",
"Preview": "Forsko\u00f0un",
"Print...": "Prenta...",
"Save": "Vista",
"Find": "Finna",
"Replace with": "Skipta \u00fat me\u00f0",
"Replace": "Skipta \u00fat",
"Replace all": "Skipta \u00f6llum \u00fat",
"Previous": "Fyrri",
"Next": "N\u00e6sti",
"Find and replace...": "Find and replace...",
"Could not find the specified string.": "Fann ekki umbe\u00f0inn streng.",
"Match case": "Samanbur\u00f0ur",
"Find whole words only": "Finna einungis heil or\u00f0",
"Spell check": "Stafsetning",
"Ignore": "Hunsa",
"Ignore all": "Hunsa allt",
"Finish": "Lj\u00faka",
"Add to Dictionary": "B\u00e6ta vi\u00f0 or\u00f0ab\u00f3k",
"Insert table": "Setja inn t\u00f6flu",
"Table properties": "Stillingar t\u00f6flu",
"Delete table": "Ey\u00f0a t\u00f6flu",
"Cell": "Reitur",
"Row": "R\u00f6\u00f0",
"Column": "D\u00e1lkur",
"Cell properties": "Stillingar reits",
"Merge cells": "Sameina reiti",
"Split cell": "Deila reiti",
"Insert row before": "Setja inn r\u00f6\u00f0 fyrir framan",
"Insert row after": "Setja inn r\u00f6\u00f0 fyrir aftan",
"Delete row": "Ey\u00f0a r\u00f6\u00f0",
"Row properties": "Stillingar ra\u00f0ar",
"Cut row": "Klippa r\u00f6\u00f0",
"Copy row": "Afrita r\u00f6\u00f0",
"Paste row before": "L\u00edma r\u00f6\u00f0 fyrir framan",
"Paste row after": "L\u00edma r\u00f6\u00f0 fyrir aftan",
"Insert column before": "Setja inn d\u00e1lk fyrir framan",
"Insert column after": "Setja inn d\u00e1lk fyrir aftan",
"Delete column": "Ey\u00f0a d\u00e1lki",
"Cols": "D\u00e1lkar",
"Rows": "Ra\u00f0ir",
"Width": "Breidd",
"Height": "H\u00e6\u00f0",
"Cell spacing": "Bil \u00ed reit",
"Cell padding": "R\u00fdmi reits",
"Show caption": "S\u00fdna myndatexta",
"Left": "Vinstri",
"Center": "Mi\u00f0ja",
"Right": "H\u00e6gri",
"Cell type": "Tegund reits",
"Scope": "Gildissvi\u00f0",
"Alignment": "J\u00f6fnun",
"H Align": "L\u00e1r\u00e9tt j\u00f6fnun",
"V Align": "L\u00f3\u00f0r\u00e9tt j\u00f6fnun",
"Top": "Efst",
"Middle": "Mi\u00f0ja",
"Bottom": "Ne\u00f0st",
"Header cell": "Reitarhaus",
"Row group": "H\u00f3pur ra\u00f0ar",
"Column group": "H\u00f3pur d\u00e1lks",
"Row type": "Tegund ra\u00f0ar",
"Header": "Fyrirs\u00f6gn",
"Body": "Innihald",
"Footer": "Ne\u00f0anm\u00e1l",
"Border color": "Litur \u00e1 ramma",
"Insert template...": "Setja inn sni\u00f0m\u00e1t...",
"Templates": "Sni\u00f0m\u00e1t",
"Template": "Sni\u00f0m\u00e1t",
"Text color": "Litur texta",
"Background color": "Bakgrunnslitur",
"Custom...": "S\u00e9rsni\u00f0i\u00f0...",
"Custom color": "S\u00e9rsni\u00f0in litur",
"No color": "Enginn litur",
"Remove color": "Fjarl\u00e6gja lit",
"Table of Contents": "Efnisyfirlit",
"Show blocks": "S\u00fdna kubba",
"Show invisible characters": "S\u00fdna \u00f3s\u00fdnilega stafi",
"Word count": "Or\u00f0afj\u00f6ldi",
"Count": "Fj\u00f6ldi",
"Document": "Skjal",
"Selection": "Val",
"Words": "Or\u00f0",
"Words: {0}": "Or\u00f0:  {0}",
"{0} words": "{0} or\u00f0",
"File": "Skjal",
"Edit": "Breyta",
"Insert": "Setja inn",
"View": "Sko\u00f0a",
"Format": "Sni\u00f0",
"Table": "Tafla",
"Tools": "T\u00f3l",
"Powered by {0}": "Keyrt af {0}",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Textasv\u00e6\u00f0i \u00ed \u00edtarham.  \u00ddttu \u00e1 ALT-F9 fyrir valmynd.  \u00ddttu \u00e1 ALT-F10 fyrir t\u00f3lastiku.  \u00ddttu \u00e1 ALT-0 fyrir a\u00f0sto\u00f0.",
"Image title": "Titill myndar",
"Border width": "Border width",
"Border style": "Border style",
"Error": "Villa",
"Warn": "A\u00f0vara",
"Valid": "Gilt",
"To open the popup, press Shift+Enter": "\u00ddttu \u00e1 Shift+Enter til a\u00f0 opna sprettiglugga",
"Rich Text Area. Press ALT-0 for help.": "Rich Text sv\u00e6\u00f0i. Smelltu \u00e1 Alt-0 fyrir hj\u00e1lp",
"System Font": "Kerfis leturger\u00f0",
"Failed to upload image: {0}": "Gat ekki hala\u00f0 upp mynd: {0}",
"Failed to load plugin: {0} from url {1}": "Gat ekki hla\u00f0i\u00f0 vi\u00f0b\u00f3t: {0} fr\u00e1 urli {1}",
"Failed to load plugin url: {0}": "Gat ekki hla\u00f0i\u00f0 vi\u00f0b\u00f3t url: {0}",
"Failed to initialize plugin: {0}": "Val",
"example": "d\u00e6mi",
"Search": "Leita",
"All": "Allt",
"Currency": "Gjaldmi\u00f0ill",
"Text": "Texti",
"Quotations": "Tilvitnanir",
"Mathematical": "St\u00e6r\u00f0fr\u00e6\u00f0i",
"Extended Latin": "Extended Latin",
"Symbols": "T\u00e1kn",
"Arrows": "\u00d6rvar",
"User Defined": "Stillt af notanda",
"dollar sign": "dollar t\u00e1kn",
"currency sign": "gjaldmi\u00f0ils t\u00e1kn",
"euro-currency sign": "evru-gjaldmi\u00f0ils t\u00e1kn",
"colon sign": "kommu t\u00e1kn",
"cruzeiro sign": "cruzeiro t\u00e1kn",
"french franc sign": "franskur franki t\u00e1kn",
"lira sign": "lira t\u00e1kn",
"mill sign": "mill t\u00e1kn",
"naira sign": "naira t\u00e1kn",
"peseta sign": "peseta t\u00e1kn",
"rupee sign": "rupee t\u00e1kn",
"won sign": "won t\u00e1kn",
"new sheqel sign": "new sheqel t\u00e1kn",
"dong sign": "dong t\u00e1kn",
"kip sign": "kip t\u00e1kn",
"tugrik sign": "tugrik t\u00e1kn",
"drachma sign": "drachma t\u00e1kn",
"german penny symbol": "german penny t\u00e1kn",
"peso sign": "peso t\u00e1kn",
"guarani sign": "guarani t\u00e1kn",
"austral sign": "austral t\u00e1kn",
"hryvnia sign": "hryvnia t\u00e1kn",
"cedi sign": "cedi t\u00e1kn",
"livre tournois sign": "livre tournois t\u00e1kn",
"spesmilo sign": "spesmilo t\u00e1kn",
"tenge sign": "tenge t\u00e1kn",
"indian rupee sign": "indverskt rupee t\u00e1kn",
"turkish lira sign": "tyrknesk l\u00edra t\u00e1kn",
"nordic mark sign": "nordic mark t\u00e1kn",
"manat sign": "manat t\u00e1kn",
"ruble sign": "ruble t\u00e1kn",
"yen character": "yen stafur",
"yuan character": "yuan stafur",
"yuan character, in hong kong and taiwan": "yuan stafur, \u00ed Hong Kong og Ta\u00edvan",
"yen\/yuan character variant one": "yen\/yuan t\u00e1kn afbrig\u00f0i eitt",
"Loading emoticons...": "Hle\u00f0 tilfinningat\u00e1kn...",
"Could not load emoticons": "Gat ekki hla\u00f0i\u00f0 tilfinningat\u00e1kn",
"People": "F\u00f3lk",
"Animals and Nature": "D\u00fdr og n\u00e1tt\u00fara",
"Food and Drink": "Matur og drykkur",
"Activity": "Virkni",
"Travel and Places": "Fer\u00f0al\u00f6g og sta\u00f0ir",
"Objects": "Hlutir",
"Flags": "F\u00e1nar",
"Characters": "Stafabil",
"Characters (no spaces)": "Stafabil (engin bil)",
"{0} characters": "{0} stafabil",
"Error: Form submit field collision.": "Villa: Form submit field collision.",
"Error: No form element found.": "Villa: Ekkert form element fannst.",
"Update": "Uppf\u00e6ra",
"Color swatch": "Litaval",
"Turquoise": "Gr\u00e6nbl\u00e1r",
"Green": "Gr\u00e6nn",
"Blue": "Bl\u00e1r",
"Purple": "Fj\u00f3lubl\u00e1r",
"Navy Blue": "D\u00f6kkbl\u00e1r",
"Dark Turquoise": "D\u00f6kk gr\u00e6nbl\u00e1r",
"Dark Green": "D\u00f6kkgr\u00e6nn",
"Medium Blue": "Mi\u00f0lungs bl\u00e1r",
"Medium Purple": "Mi\u00f0lungs fj\u00f3lubl\u00e1r",
"Midnight Blue": "N\u00e6turbl\u00e1r",
"Yellow": "Gulur",
"Orange": "Appels\u00ednugulur",
"Red": "Rau\u00f0ur",
"Light Gray": "Lj\u00f3sgr\u00e1r",
"Gray": "Gr\u00e1r",
"Dark Yellow": "D\u00f6kkgulur",
"Dark Orange": "D\u00f6kk appels\u00ednugulur",
"Dark Red": "D\u00f6kkrau\u00f0ur",
"Medium Gray": "Mi\u00f0lungs gr\u00e1r",
"Dark Gray": "D\u00f6kkgr\u00e1r",
"Light Green": "Lj\u00f3sgr\u00e6nn",
"Light Yellow": "Lj\u00f3sgulur",
"Light Red": "Lj\u00f3srau\u00f0ur",
"Light Purple": "Lj\u00f3s fj\u00f3lubl\u00e1r",
"Light Blue": "Lj\u00f3sbl\u00e1r",
"Dark Purple": "D\u00f6kk fj\u00f3lubl\u00e1r",
"Dark Blue": "D\u00f6kkbl\u00e1r",
"Black": "Svartur",
"White": "Hv\u00edtur",
"Switch to or from fullscreen mode": "Skipta \u00ed e\u00f0a \u00far fullum skj\u00e1",
"Open help dialog": "Opna hj\u00e1lparkassa",
"history": "saga",
"styles": "st\u00edlar",
"formatting": "formatting",
"alignment": "textastilling",
"indentation": "inndr\u00e1ttur",
"permanent pen": "varanlegur penni",
"comments": "umm\u00e6li",
"Format Painter": "Format Painter",
"Insert\/edit iframe": "Setja inn\/breyta iframe",
"Capitalization": "H\u00e1stafir",
"lowercase": "l\u00e1gstafir",
"UPPERCASE": "H\u00c1STAFIR",
"Title Case": "Title Case",
"Permanent Pen Properties": "Varanlegur penni stillingar",
"Permanent pen properties...": "Varanlegur penni stillingar...",
"Font": "Leturger\u00f0",
"Size": "St\u00e6r\u00f0",
"More...": "Meira...",
"Spellcheck Language": "Stafsetning tungum\u00e1ls",
"Select...": "Velja...",
"Preferences": "Stillingar",
"Yes": "J\u00e1",
"No": "Nei",
"Keyboard Navigation": "Lyklabor\u00f0 Navigation",
"Version": "\u00datg\u00e1fa",
"Anchor": "Akkeri",
"Special character": "S\u00e9rstakir stafir",
"Color": "Litur",
"Emoticons": "Tilfinningar",
"Document properties": "Eigindi skjals",
"Insert link": "Setja inn hlekk",
"Target": "Mi\u00f0",
"Poster": "Plakat",
"Print": "Prenta",
"Whole words": "Heil or\u00f0",
"Find and replace": "Finna og skipta \u00fat",
"Prev": "Fyrri",
"Spellcheck": "Villuleit",
"Caption": "Titill",
"Insert template": "Setja inn sni\u00f0m\u00e1t"
});