<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Bienllegáu a $product';
$labels['username'] = 'Usuariu';
$labels['password'] = 'Contraseña';
$labels['server'] = 'Sirvidor';
$labels['login'] = 'Aniciar sesión';
$labels['logout'] = 'Zarrar sesión';
$labels['mail'] = 'Corréu';
$labels['settings'] = 'Axustes';
$labels['addressbook'] = 'Llibreta de direiciones';
$labels['inbox'] = 'Bandexa d\'entrada';
$labels['drafts'] = 'Borradores';
$labels['sent'] = 'Unviaos';
$labels['trash'] = 'Papelera';
$labels['junk'] = 'Puxarra';
$labels['show_real_foldernames'] = 'Amosar nomes reales pa carpetes especiales';
$labels['subject'] = 'Asuntu';
$labels['from'] = 'De';
$labels['sender'] = 'Remitente';
$labels['to'] = 'Pa';
$labels['cc'] = 'Copia';
$labels['bcc'] = 'Cct';
$labels['replyto'] = 'Contestar a';
$labels['followupto'] = 'Responder-a';
$labels['date'] = 'Data';
$labels['size'] = 'Tamañu';
$labels['priority'] = 'Prioridá';
$labels['organization'] = 'Organización';
$labels['readstatus'] = 'Lleer estáu';
$labels['listoptions'] = 'Llista d\'opciones...';
$labels['mailboxlist'] = 'Carpetes';
$labels['messagesfromto'] = 'Mensaxes $from a $to de $count';
$labels['threadsfromto'] = 'Filos $from a $to de $count';
$labels['messagenrof'] = 'Mensaxe $nr de $count';
$labels['fromtoshort'] = '$from – $to de $count';
$labels['copy'] = 'Copia';
$labels['move'] = 'Mover';
$labels['moveto'] = 'mover a...';
$labels['copyto'] = 'Copiar a...';
$labels['download'] = 'Descargar';
$labels['open'] = 'Abrir';
$labels['showattachment'] = 'Amosar';
$labels['showanyway'] = 'Amosar de toes formes';
$labels['filename'] = 'Nome del ficheru';
$labels['filesize'] = 'Tamañu del ficheru';
$labels['addtoaddressbook'] = 'Amestar a la llibreta de direiciones';
$labels['sun'] = 'Dom';
$labels['mon'] = 'Llu';
$labels['tue'] = 'Mar';
$labels['wed'] = 'Mie';
$labels['thu'] = 'Xue';
$labels['fri'] = 'Vie';
$labels['sat'] = 'Sab';
$labels['sunday'] = 'Domingu';
$labels['monday'] = 'Llunes';
$labels['tuesday'] = 'Martes';
$labels['wednesday'] = 'Miércoles';
$labels['thursday'] = 'Xueves';
$labels['friday'] = 'Vienres';
$labels['saturday'] = 'Sábadu';
$labels['jan'] = 'Xin';
$labels['feb'] = 'Feb';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Abr';
$labels['may'] = 'Mayu';
$labels['jun'] = 'Xun';
$labels['jul'] = 'Xnt';
$labels['aug'] = 'Ago';
$labels['sep'] = 'Set';
$labels['oct'] = 'Och';
$labels['nov'] = 'Pay';
$labels['dec'] = 'Avi';
$labels['longjan'] = 'Xineru';
$labels['longfeb'] = 'Febreru';
$labels['longmar'] = 'Marzu';
$labels['longapr'] = 'Abril';
$labels['longmay'] = 'Mayu';
$labels['longjun'] = 'Xunu';
$labels['longjul'] = 'Xunetu';
$labels['longaug'] = 'Agostu';
$labels['longsep'] = 'Setiembre';
$labels['longoct'] = 'Ochobre';
$labels['longnov'] = 'Payares';
$labels['longdec'] = 'Avientu';
$labels['today'] = 'Güei';
$labels['refresh'] = 'Refrescar';
$labels['checkmail'] = 'Comprobar mensaxes nuevos';
$labels['compose'] = 'Redactar';
$labels['writenewmessage'] = 'Redactar un mensaxe nuevu';
$labels['reply'] = 'Responder';
$labels['replytomessage'] = 'Responder al remitente';
$labels['replytoallmessage'] = 'Responder a la llista o al remitente y tolos destinatarios';
$labels['replyall'] = 'Responder a toos';
$labels['replylist'] = 'Responder a la llista';
$labels['forward'] = 'Reunviar';
$labels['forwardinline'] = 'Reunviar direutamente';
$labels['forwardattachment'] = 'Reunviar como axuntu';
$labels['forwardmessage'] = 'Reunviar el mensaxe';
$labels['deletemessage'] = 'Desaniciar mensaxe';
$labels['movemessagetotrash'] = 'Mover mensaxe a la papelera';
$labels['printmessage'] = 'Imprentar esti mensaxe';
$labels['previousmessage'] = 'Amosar el mensaxe anterior';
$labels['firstmessage'] = 'Amosar primer mensaxe';
$labels['nextmessage'] = 'Amosar mensaxe siguiente';
$labels['lastmessage'] = 'Amosar mensaxe caberu';
$labels['backtolist'] = 'Tornar a la llista de mensaxes';
$labels['viewsource'] = 'Amosar fonte';
$labels['mark'] = 'Conseñar';
$labels['markmessages'] = 'Conseñar mensaxes';
$labels['markread'] = 'Como lleíu';
$labels['markunread'] = 'Como non lleíu';
$labels['markflagged'] = 'Como etiquetáu';
$labels['markunflagged'] = 'Como non etiquetáu';
$labels['moreactions'] = 'Más aiciones...';
$labels['folders-all'] = 'Toles carpetes';
$labels['more'] = 'Más';
$labels['back'] = 'Tornar';
$labels['options'] = 'Opciones';
$labels['first'] = 'Primeru';
$labels['last'] = 'Caberu';
$labels['previous'] = 'Postreru';
$labels['next'] = 'Siguiente';
$labels['select'] = 'Esbillar';
$labels['all'] = 'Toos';
$labels['none'] = 'Dengún';
$labels['currpage'] = 'Páxina actual';
$labels['isread'] = 'Lleer';
$labels['unread'] = 'Ensin lleer';
$labels['flagged'] = 'Etiquetaos';
$labels['unanswered'] = 'Ensin contestar';
$labels['withattachment'] = 'Con axuntu';
$labels['deleted'] = 'Desaniciáu';
$labels['undeleted'] = 'Non desaniciáu';
$labels['replied'] = 'Respondíu';
$labels['forwarded'] = 'Reunviáu';
$labels['invert'] = 'Invertir';
$labels['filter'] = 'Filtru';
$labels['list'] = 'Llista';
$labels['threads'] = 'Filos';
$labels['expand-all'] = 'Espander toos';
$labels['expand-unread'] = 'Espander non lleíos';
$labels['collapse-all'] = 'Contrayer toos';
$labels['threaded'] = 'Encadenaos';
$labels['autoexpand_threads'] = 'Espander filos de mensaxes';
$labels['do_expand'] = 'tolos filos';
$labels['expand_only_unread'] = 'namái con mensaxes non lleíos';
$labels['fromto'] = 'De/a';
$labels['flag'] = 'Bandera';
$labels['attachment'] = 'Axuntu';
$labels['nonesort'] = 'Dengún';
$labels['sentdate'] = 'Data d\'unviu';
$labels['arrival'] = 'Data de llegada';
$labels['asc'] = 'ascendente';
$labels['desc'] = 'descendente';
$labels['listcolumns'] = 'Llistar columnes';
$labels['listsorting'] = 'Columna de llistáu';
$labels['listorder'] = 'Orde de llistáu';
$labels['listmode'] = 'Mou de vista de llista';
$labels['layoutlist'] = 'Llista';
$labels['folderactions'] = 'Aiciones de carpeta...';
$labels['compact'] = 'Compautar';
$labels['empty'] = 'Vaciar';
$labels['importmessages'] = 'Importar mensaxes';
$labels['quota'] = 'Usu de discu';
$labels['unknown'] = 'desconocíu';
$labels['unlimited'] = 'ensin llende';
$labels['quotatotal'] = 'Llímite';
$labels['quotaused'] = 'Usáu';
$labels['quotastorage'] = 'Espaciu en discu';
$labels['quicksearch'] = 'Gueta rápida';
$labels['resetsearch'] = 'Reaniciar la gueta';
$labels['searchmod'] = 'Guetar modificadores';
$labels['msgtext'] = 'Mensaxe enteru';
$labels['body'] = 'Cuerpu';
$labels['type'] = 'Triba';
$labels['namex'] = 'Nome';
$labels['searchscope'] = 'Algame';
$labels['currentfolder'] = 'Carpeta actual';
$labels['subfolders'] = 'Esta y les subcarpetes';
$labels['allfolders'] = 'Toles carpetes';
$labels['openinextwin'] = 'Abrir nuna ventana nueva';
$labels['emlsave'] = 'Descargar (.eml)';
$labels['changeformattext'] = 'Amosar en formatu de testu planu';
$labels['changeformathtml'] = 'Amosar en formatu HTML';
$labels['editasnew'] = 'Editar como nuevu';
$labels['send'] = 'Unviar';
$labels['sendmessage'] = 'Unviar el mensaxe yá';
$labels['savemessage'] = 'Guardar como borrador';
$labels['addattachment'] = 'Axuntar un ficheru';
$labels['charset'] = 'Codificación';
$labels['editortype'] = 'Triba d\'editor';
$labels['returnreceipt'] = 'Devolver avisu de recibu';
$labels['dsn'] = 'Notificación d\'estáu d\'entrega';
$labels['mailreplyintro'] = 'El $date, $sender escribió:';
$labels['originalmessage'] = 'Mensaxe orixinal';
$labels['selectimage'] = 'Esbillar imaxe';
$labels['addimage'] = 'Amestar imaxe';
$labels['selectmedia'] = 'Esbillar película';
$labels['addmedia'] = 'Amestar película';
$labels['insert'] = 'Inxertar';
$labels['editidents'] = 'Editar identidaes';
$labels['spellcheck'] = 'Correutor ortográficu';
$labels['checkspelling'] = 'Revisar ortografía';
$labels['resumeediting'] = 'Siguir cola edición';
$labels['revertto'] = 'Revertir a';
$labels['restore'] = 'Restaurar';
$labels['restoremessage'] = '¿Restaurar mensaxe?';
$labels['responses'] = 'Rempuestes';
$labels['insertresponse'] = 'Inxertar una rempuesta';
$labels['manageresponses'] = 'Alministrar rempuestes';
$labels['newresponse'] = 'Crear resmpuesta nueva';
$labels['addresponse'] = 'Amestar rempuesta';
$labels['editresponse'] = 'Editar rempuesta';
$labels['editresponses'] = 'Editar rempuestes';
$labels['responsename'] = 'Nome';
$labels['responsetext'] = 'Testu de la rempuesta';
$labels['attach'] = 'Axuntar';
$labels['attachments'] = 'Axuntos';
$labels['upload'] = 'Xubir';
$labels['close'] = 'Zarrar';
$labels['messageoptions'] = 'Opciones de mensaxe...';
$labels['togglecomposeoptions'] = 'Camudar opciones de composición';
$labels['low'] = 'Baxu';
$labels['lowest'] = 'Mui baxu';
$labels['normal'] = 'Normal';
$labels['high'] = 'Altu';
$labels['highest'] = 'Mui altu';
$labels['nosubject'] = '(ensin asuntu)';
$labels['showimages'] = 'Amosar imáxenes';
$labels['alwaysshow'] = 'Amosar siempres les imáxenes de $sender';
$labels['isdraft'] = 'Esti mensaxe ye un borrador.';
$labels['andnmore'] = '$nr más...';
$labels['togglemoreheaders'] = 'Amosar más testeres del mensaxe';
$labels['togglefullheaders'] = 'Amosar o anubrir testeres de mensaxes';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Testu planu';
$labels['savesentmessagein'] = 'Guardar mensaxe unviáu en';
$labels['dontsave'] = 'nun guardar';
$labels['maxuploadsize'] = 'El tamañu másimu pa un ficheru ye $size';
$labels['addcc'] = 'Amestar Cc';
$labels['addbcc'] = 'Amestar Cct';
$labels['addreplyto'] = 'Amestar Rempuesta pa';
$labels['addfollowupto'] = 'Amestar Siguir a';
$labels['mdnrequest'] = 'El remitente d\'esti mensaxe entrugó pa ser notificáu cuando lleas esti mensaxe. ¿Deseyes notificá-ylo al remitente?';
$labels['receiptread'] = 'Devolver avisu de recibu (lleíu)';
$labels['yourmessage'] = 'Esto ye una devolución del avisu de recibu pal to mensaxe';
$labels['receiptnote'] = 'Nota: Esti avisu de recibu namái reconoz que\'l mensaxe amosóse nel ordenador del destinatariu. Nun hai garantía de que\'l destinatariu lleera o entendiera\'l conteníu del mensaxe.';
$labels['name'] = 'Nome completu';
$labels['firstname'] = 'Nome';
$labels['surname'] = 'Apellíu';
$labels['middlename'] = 'Segundu nome';
$labels['nameprefix'] = 'Prefixu';
$labels['namesuffix'] = 'Sufixu';
$labels['nickname'] = 'Nomatu';
$labels['jobtitle'] = 'Tratamientu';
$labels['department'] = 'Departamentu';
$labels['gender'] = 'Xéneru';
$labels['maidenname'] = 'Apellíu de soltera';
$labels['email'] = 'Corréu';
$labels['phone'] = 'Teléfonu';
$labels['address'] = 'Direición';
$labels['street'] = 'Cai';
$labels['locality'] = 'Ciudá';
$labels['zipcode'] = 'Códigu postal';
$labels['region'] = 'Estáu/Provincia';
$labels['country'] = 'País';
$labels['birthday'] = 'Cumpleaños';
$labels['anniversary'] = 'Aniversariu';
$labels['website'] = 'Páxina web';
$labels['instantmessenger'] = 'Mensaxería nel intre';
$labels['notes'] = 'Notes';
$labels['male'] = 'home';
$labels['female'] = 'muyer';
$labels['manager'] = 'Alministrador';
$labels['assistant'] = 'Auxiliar';
$labels['spouse'] = 'Casáu con';
$labels['allfields'] = 'Tolos campos';
$labels['search'] = 'Guetar';
$labels['advsearch'] = 'Gueta avanzada';
$labels['advanced'] = 'Avanzáu';
$labels['other'] = 'Otru';
$labels['typehome'] = 'Casa';
$labels['typework'] = 'Trabayu';
$labels['typeother'] = 'Otru';
$labels['typemobile'] = 'Móvil';
$labels['typemain'] = 'Principal';
$labels['typehomefax'] = 'Fax de casa';
$labels['typeworkfax'] = 'Fax del trabayu';
$labels['typecar'] = 'Coche';
$labels['typepager'] = 'Buscapersones';
$labels['typevideo'] = 'Videu';
$labels['typeassistant'] = 'Auxiliar';
$labels['typehomepage'] = 'Páxina d\'aniciu';
$labels['typeblog'] = 'Blogue';
$labels['typeprofile'] = 'Perfil';
$labels['addfield'] = 'Amestar campu...';
$labels['addcontact'] = 'Amestar contautu';
$labels['editcontact'] = 'Editar contautu';
$labels['contacts'] = 'Contautos';
$labels['contactproperties'] = 'Propiedaes del contautu';
$labels['contactnameandorg'] = 'Nome y organización';
$labels['personalinfo'] = 'Información personal';
$labels['contactphoto'] = 'Semeya de contautu';
$labels['edit'] = 'Editar';
$labels['cancel'] = 'Encaboxar';
$labels['save'] = 'Guardar';
$labels['delete'] = 'Desaniciar';
$labels['rename'] = 'Renomar';
$labels['addphoto'] = 'Amestar';
$labels['replacephoto'] = 'Trocar';
$labels['uploadphoto'] = 'Xubir semeya';
$labels['newcontact'] = 'Crear contautu nuevu';
$labels['deletecontact'] = 'Desaniciar los contautos esbillaos';
$labels['composeto'] = 'Redactar mensaxe a';
$labels['contactsfromto'] = 'Contautos $from a $to de $count';
$labels['print'] = 'Imprentar';
$labels['export'] = 'Esportar';
$labels['exportall'] = 'Esportar too';
$labels['exportsel'] = 'Esportar lo esbillao';
$labels['exportvcards'] = 'Esportar contautos en formatu vCard';
$labels['newgroup'] = 'Crear grupu nuevu';
$labels['grouprename'] = 'Renomar grupu';
$labels['groupdelete'] = 'Desaniciar grupu';
$labels['groupremoveselected'] = 'Desaniciar los contautos esbillaos del grupu';
$labels['uponelevel'] = 'Xunir un nivel';
$labels['previouspage'] = 'Amosar páxina postrera';
$labels['firstpage'] = 'Amosar primer páxina';
$labels['nextpage'] = 'Amosar páxina siguiente';
$labels['lastpage'] = 'Amosar páxina cabera';
$labels['group'] = 'Grupu';
$labels['groups'] = 'Grupos';
$labels['listgroup'] = 'Llistar miembros del grupu';
$labels['personaladrbook'] = 'Direiciones personales';
$labels['searchsave'] = 'Guardar gueta';
$labels['searchdelete'] = 'Desaniciar gueta';
$labels['import'] = 'Importar';
$labels['importcontacts'] = 'Importar contautos';
$labels['importtarget'] = 'Amestar contautos a';
$labels['importreplace'] = 'Trocar el llibru de direiciones enteru';
$labels['importgroups'] = 'Importar asignaciones de grupu';
$labels['importgroupsall'] = 'Toos (crear grupos si ye necesario)';
$labels['importgroupsexisting'] = 'Namái pa los grupos esistentes';
$labels['done'] = 'Fecho';
$labels['settingsfor'] = 'Axustes pa';
$labels['about'] = 'Tocante a';
$labels['preferences'] = 'Preferencies';
$labels['userpreferences'] = 'Preferencies d\'usuariu';
$labels['editpreferences'] = 'Editar preferencies d\'usuariu';
$labels['identities'] = 'Identidaes';
$labels['manageidentities'] = 'Almisnitrar identidaes';
$labels['newidentity'] = 'Crear identidá nueva';
$labels['addidentity'] = 'Amestar identidça';
$labels['editidentity'] = 'Editar identidá';
$labels['preferhtml'] = 'Amosar HTML';
$labels['defaultcharset'] = 'Xuegu de caráuteres predetermináu';
$labels['htmlmessage'] = 'Mensaxe HTML';
$labels['messagepart'] = 'Parte';
$labels['digitalsig'] = 'Robla dixital';
$labels['dateformat'] = 'Formatu de data';
$labels['timeformat'] = 'Formatu d\'hora';
$labels['prettydate'] = 'Dates prestoses';
$labels['setdefault'] = 'Reafitar';
$labels['autodetect'] = 'Auto';
$labels['language'] = 'Llingua';
$labels['timezone'] = 'Estaya horaria';
$labels['pagesize'] = 'Fileres per páxina';
$labels['signature'] = 'Robla';
$labels['dstactive'] = 'Cambéu horariu';
$labels['showinextwin'] = 'Abrir mensaxe nuna ventana nueva';
$labels['composeextwin'] = 'Redactar nuna ventana nueva';
$labels['htmleditor'] = 'Redactar el mensaxe en HTML';
$labels['htmlonreply'] = 'en rempuesta a mensaxe HTML';
$labels['htmlonreplyandforward'] = 'en reunviu o rempuesta al mensaxe HTML';
$labels['htmlsignature'] = 'Robla HTML';
$labels['showemail'] = 'Amosar direición de corréu-e al amosar el nome';
$labels['previewpane'] = 'Amosar panel de previsualización';
$labels['skin'] = 'Tema de la interfaz';
$labels['logoutclear'] = 'Vaciar la papelera al zarrar la sesión';
$labels['logoutcompact'] = 'Compautar la bandexa d\'entrada al zarrar la sesión';
$labels['uisettings'] = 'Interfaz d\'usuariu';
$labels['serversettings'] = 'Axustes del sirvidor';
$labels['mailboxview'] = 'Vista del buzón';
$labels['mdnrequests'] = 'En petición de devolución del recibíu';
$labels['askuser'] = 'entrúgame';
$labels['autosend'] = 'unviar recibu';
$labels['autosendknown'] = 'unviar recibu a los mios contautos, d\'otramiente entrúgame';
$labels['autosendknownignore'] = 'unviar recibu a los mios contautos, d\'otramiente inorar';
$labels['readwhendeleted'] = 'Conseñar el mensaxe como lleíu al desanicialu';
$labels['flagfordeletion'] = 'Conseñar el mensaxe pal desaniu en cuantes de desanicialu';
$labels['skipdeleted'] = 'Nun amosar los mensaxes desaniciaos';
$labels['deletealways'] = 'Si falla\'l treslláu de los mensaxes a la Papelera, desanicialos';
$labels['deletejunk'] = 'Desaniciar direutamente el correú en Puxarra';
$labels['showremoteimages'] = 'Amosar imáxenes en llinia remotes';
$labels['fromknownsenders'] = 'de remitentes conocíos';
$labels['always'] = 'siempres';
$labels['showinlineimages'] = 'Amosar les imáxenes axuntaes embaxo\'l mensaxe';
$labels['autosavedraft'] = 'Guardar borrador automáticamente';
$labels['everynminutes'] = 'cada $n minutu/os';
$labels['refreshinterval'] = 'Refrescar (comprobación de mensaxes nuevos, etc.)';
$labels['never'] = 'nunca';
$labels['immediately'] = 'de secute';
$labels['messagesdisplaying'] = 'Vista de mensaxes';
$labels['messagescomposition'] = 'Redaición de mensaxes';
$labels['mimeparamfolding'] = 'Nomes d\'axuntos';
$labels['2231folding'] = 'RFC 2231 completu (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'RFC 2047 completu (otros)';
$labels['force7bit'] = 'Usar codificación MIME pa caráuteres de 8 bits';
$labels['advancedoptions'] = 'Opciones avanzaes';
$labels['toggleadvancedoptions'] = 'Camudar opciones avanzaes';
$labels['focusonnewmessage'] = 'Enfocar la ventana de restolación en mensaxes nuevos';
$labels['checkallfolders'] = 'Comprobar en toles carpetes mensaxes nuevos';
$labels['defaultfont'] = 'Triba de fonte por defeutu del mensaxe HTML';
$labels['mainoptions'] = 'Opciones principales';
$labels['browseroptions'] = 'Opciones del restolador';
$labels['section'] = 'Seición';
$labels['maintenance'] = 'Caltenimientu';
$labels['newmessage'] = 'Mensaxe nuevu';
$labels['signatureoptions'] = 'Opciones de robla';
$labels['whenreplying'] = 'Cuando se respuenda';
$labels['replyempty'] = 'nun citar el mensaxe orixinal';
$labels['replytopposting'] = 'aniciar un mensaxe nuevu enriba l\'orixinal';
$labels['replybottomposting'] = 'aniciar un mensaxe nuevu embaxo l\'orixinal';
$labels['replyremovesignature'] = 'Desaniciar la robla orixinal del mensaxe cuando se respuenda';
$labels['autoaddsignature'] = 'Amestar robla automáticamente';
$labels['newmessageonly'] = 'namái mensaxe nuevu';
$labels['replyandforwardonly'] = 'namái rempuestes y reunvios';
$labels['insertsignature'] = 'Inxertar robla';
$labels['afternseconds'] = 'dempués de $n segundos';
$labels['reqmdn'] = 'Solicitar siempres un recibu';
$labels['reqdsn'] = 'Solicitar siempres la notificación d\'estáu d\'entrega';
$labels['replysamefolder'] = 'Allugar les rempuestes na carpeta del mensaxe que tea respondiéndose';
$labels['defaultabook'] = 'Llibreta de direiciones por defeutu';
$labels['autocompletesingle'] = 'Saltar direiciones de corréu alternatives nel autocompletáu';
$labels['listnamedisplay'] = 'Llistar contautos como';
$labels['spellcheckbeforesend'] = 'Comprobar ortografía enantes d\'unviar un mensaxe';
$labels['spellcheckoptions'] = 'Opciones d\'ortografía';
$labels['spellcheckignoresyms'] = 'Inorar pallabres con símbolos';
$labels['spellcheckignorenums'] = 'Inorar pallabres con númberos';
$labels['spellcheckignorecaps'] = 'Inorar pallabres con too mayúscules';
$labels['addtodict'] = 'Amestar al diccionariu';
$labels['mailtoprotohandler'] = 'Rexistrar xestor de protocolu pa enllaces \'mailto:\'';
$labels['standardwindows'] = 'Remanar ventanos emerxentes como ventanes estándar';
$labels['forwardmode'] = 'Reunviu de mensaxes';
$labels['inline'] = 'en llinia';
$labels['asattachment'] = 'como axuntu';
$labels['replyallmode'] = 'Aición por defeutu del botón [Responder too]';
$labels['replyalldefault'] = 'responder a toos';
$labels['replyalllist'] = 'responder namái a la llista de Corréu (si s\'alcuentra)';
$labels['allmessages'] = 'tolos mensaxes';
$labels['folder'] = 'Carpeta';
$labels['folders'] = 'Carpetes';
$labels['foldername'] = 'Nome de carpeta';
$labels['subscribed'] = 'Soscrita';
$labels['messagecount'] = 'Mensaxes';
$labels['create'] = 'Crear';
$labels['createfolder'] = 'Crear una carpeta nueva';
$labels['managefolders'] = 'Alministrar carpetes';
$labels['specialfolders'] = 'Carpetes especiales';
$labels['properties'] = 'Propiedaes';
$labels['folderproperties'] = 'Propiedaes de la carpeta';
$labels['parentfolder'] = 'Carpeta pá';
$labels['location'] = 'Llocalización';
$labels['info'] = 'Información';
$labels['getfoldersize'] = 'Primi pa saber el tamañu de la carpeta';
$labels['changesubscription'] = 'Primi pa camudar la soscripción';
$labels['foldertype'] = 'Triba de carpeta';
$labels['personalfolder'] = 'Carpeta privada';
$labels['otherfolder'] = 'Carpeta d\'otru usuariu';
$labels['sharedfolder'] = 'Carpeta pública';
$labels['sortby'] = 'Ordenar per';
$labels['sortasc'] = 'Orde ascendente';
$labels['sortdesc'] = 'Orde descendente';
$labels['undo'] = 'Desfacer';
$labels['installedplugins'] = 'Complementos instalaos';
$labels['plugin'] = 'Complementu';
$labels['version'] = 'Versión';
$labels['source'] = 'Fonte';
$labels['license'] = 'Llicencia';
$labels['support'] = 'Consiguir sofitu';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Inglés';
$labels['westerneuropean'] = 'Européu occidental';
$labels['easterneuropean'] = 'Européu oriental';
$labels['southeasterneuropean'] = 'Européu suroriental';
$labels['baltic'] = 'Bálticu';
$labels['cyrillic'] = 'Cirílicu';
$labels['arabic'] = 'Árabe';
$labels['greek'] = 'Griegu';
$labels['hebrew'] = 'Hebréu';
$labels['turkish'] = 'Turcu';
$labels['nordic'] = 'Nórdicu';
$labels['thai'] = 'Tailandés';
$labels['celtic'] = 'Celta';
$labels['vietnamese'] = 'Vietnamita';
$labels['japanese'] = 'Xaponés';
$labels['korean'] = 'Coreanu';
$labels['chinese'] = 'Chinu';
$labels['arialabeltopnav'] = 'Control de ventana';
$labels['arialabeltasknav'] = 'Xeres d\'aplicación';
$labels['arialabeltoolbar'] = 'Barra de ferramientes d\'aplicación';
$labels['arialabelactivetask'] = 'Xera activa';
$labels['arialabelmessagessearchfilter'] = 'Flitru de llistáy de correos';
$labels['arialabelmailsearchform'] = 'Formulariu de gueta de mensaxe de corréu';
$labels['arialabelcontactsearchform'] = 'Formulariu de gueta de contautos';
$labels['arialabelmailquicksearchbox'] = 'Entrada de gueta de correos';
$labels['arialabelquicksearchbox'] = 'Entrada de gueta';
$labels['arialabelfolderlist'] = 'Esbilla de carpeta de corréu';
$labels['arialabelmessagelist'] = 'Llistáu de mensaxes de corréu';
$labels['arialabelmailpreviewframe'] = 'Vista previa de mensaxe';
$labels['arialabelmailboxmenu'] = 'Menú d\'aiciones de carpeta';
$labels['arialabellistselectmenu'] = 'Menú d\'esbilla de llista';
$labels['arialabelthreadselectmenu'] = 'Menú de llistáu de filos';
$labels['arialabelmailimportdialog'] = 'Diálogu d\'impotación de mensaxe';
$labels['arialabelmessagenav'] = 'Restolación de mensaxe';
$labels['arialabelmessagebody'] = 'Cuerpu de mensaxe';
$labels['arialabelmessageactions'] = 'Aiciones de mensaxe';
$labels['arialabelcontactquicksearch'] = 'Formulariu de gueta de contautos';
$labels['arialabelcontactsearchbox'] = 'Entrada de gueta de contautu';
$labels['arialabelmessageheaders'] = 'Testeres de mensaxe';
$labels['arialabelforwardingoptions'] = 'Opciones de reunviu';
$labels['arialabelreplyalloptions'] = 'Opciones de responder a toos';
$labels['arialabelmoremessageactions'] = 'Aiciones de más mensaxes';
$labels['arialabelmarkmessagesas'] = 'Conseñar los mensaxes esbillaos como...';
$labels['arialabelcomposeoptions'] = 'Opciones de redaición';
$labels['arialabelresponsesmenu'] = 'Menú de rempuestes conservaes';
$labels['arialabelattachmentuploadform'] = 'Formulariu de xuba d\'axuntu';
$labels['arialabelattachmentpreview'] = 'Vista previa d\'axuntu';
$labels['ariasummarycomposecontacts'] = 'Llista de contutos y grupos pa esbillar como destinatarios';
$labels['arialabelcontactexportoptions'] = 'Opciones d\'esportación de contautu';
$labels['arialabelabookgroupoptions'] = 'Opciones de llibru de direiciones/grupu';
$labels['arialabelpreferencesform'] = 'Formulariu de preferencies';
$labels['arialabelidentityeditfrom'] = 'Formulariu d\'edición d\'identidá';
$labels['arialabelresponseeditfrom'] = 'Formulariu d\'edición de rempuesta';
$labels['helplistnavigation'] = 'Restolación de tecláu de llista';
$labels['helplistkeyboardnavcontacts'] = "Enter: Abrir el contautu esbilláu/enfocáu.";
