<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Filtre';
$labels['managefilters'] = 'Administrer indgående mail filtrering';
$labels['filtername'] = 'Filter navn';
$labels['newfilter'] = 'Nyt filter';
$labels['filteradd'] = 'Tilføj filter';
$labels['filterdel'] = 'Slet filter';
$labels['rules'] = 'Regler';
$labels['actions'] = 'Handlinger';
$labels['scope'] = 'Omfang';
$labels['moveup'] = 'Flyt op';
$labels['movedown'] = 'Flyt ned';
$labels['filterallof'] = 'matcher alle af de følgende regler';
$labels['filteranyof'] = 'matcher en af følgende regler';
$labels['filterany'] = 'alle meddelelser';
$labels['filtercontains'] = 'indeholder';
$labels['filternotcontains'] = 'indeholder ikke';
$labels['filteris'] = 'er ens med';
$labels['filterisnot'] = 'er ikke ens med';
$labels['filterexists'] = 'findes';
$labels['filternotexists'] = 'ikke eksisterer';
$labels['filtermatches'] = 'matcher udtryk';
$labels['filternotmatches'] = 'matcher ikke udtryk';
$labels['filterregex'] = 'matcher regulært udtryk';
$labels['filternotregex'] = 'matcher ikke regulært udtryk';
$labels['filterunder'] = 'under';
$labels['filterover'] = 'over';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'MIME del:';
$labels['mime-message'] = 'besked';
$labels['mime-anychild'] = 'vilkårlig';
$labels['mime-type'] = 'type';
$labels['mime-subtype'] = 'undertype';
$labels['mime-contenttype'] = 'content-type';
$labels['mime-param'] = 'parameter';
$labels['addrule'] = 'Tilføj regel';
$labels['delrule'] = 'Slet regel';
$labels['messagemoveto'] = 'Flyt besked til';
$labels['messageredirect'] = 'Omdiriger mail til';
$labels['messagecopyto'] = 'Kopier besked til';
$labels['messagesendcopy'] = 'Send kopi af besked til';
$labels['messagereply'] = 'Svar med besked';
$labels['messagedelete'] = 'Slet besked';
$labels['messagediscard'] = 'Slet med besked';
$labels['messagekeep'] = 'Behold besked i Inbox';
$labels['messagesrules'] = 'For indgående mails:';
$labels['messagesactions'] = '...udfør følgende handlinger:';
$labels['add'] = 'Tilføje';
$labels['del'] = 'Fjern';
$labels['sender'] = 'Afsender';
$labels['recipient'] = 'Modtager';
$labels['vacationaddr'] = 'Min e-mail adresse:';
$labels['vacationdays'] = 'Hvor tit skal besked sendes (i dage):';
$labels['vacationinterval'] = 'Hvor tit skal besked sendes:';
$labels['vacationreason'] = 'Besked (ved ferie):';
$labels['vacationfrom'] = 'Svar afsender adresse:';
$labels['vacationsubject'] = 'Besked emne:';
$labels['days'] = 'dage';
$labels['seconds'] = 'sekunder';
$labels['rulestop'] = 'Stop behandling af regler';
$labels['enable'] = 'Aktivér/Deaktivér';
$labels['filterset'] = 'Filtersæt';
$labels['filtersets'] = 'Filtersæt';
$labels['filtersetadd'] = 'Tilføj filtersæt';
$labels['filtersetdel'] = 'Slet filtersæt';
$labels['filtersetact'] = 'Aktiver nuværende filtersæt';
$labels['filtersetdeact'] = 'Deaktiver nuværende filtersæt';
$labels['filterseteditraw'] = 'Rediger filtersæt';
$labels['filtersetswitch'] = 'Aktivér/Deaktivér filtersæt';
$labels['filterdef'] = 'Filter definition';
$labels['filtersetname'] = 'Filtersæt navn';
$labels['newfilterset'] = 'Nyt filtersæt';
$labels['active'] = 'aktiv';
$labels['none'] = 'ingen';
$labels['fromset'] = 'fra sæt';
$labels['fromfile'] = 'fra fil';
$labels['filterdisabled'] = 'Filter deaktiveret';
$labels['filterenabled'] = 'Filter aktiveret';
$labels['countisgreaterthan'] = 'antal er større end';
$labels['countisgreaterthanequal'] = 'antal er større end eller lig med';
$labels['countislessthan'] = 'antal er mindre end';
$labels['countislessthanequal'] = 'antal er mindre end eller lig med';
$labels['countequals'] = 'antal er lig med';
$labels['countnotequals'] = 'antal er ikke lig med';
$labels['valueisgreaterthan'] = 'værdi er større end';
$labels['valueisgreaterthanequal'] = 'værdi er større end eller lig med';
$labels['valueislessthan'] = 'værdi er mindre end';
$labels['valueislessthanequal'] = 'værdi er mindre end eller lig med';
$labels['valueequals'] = 'værdi er lig med';
$labels['valuenotequals'] = 'værdi er ikke lig med';
$labels['setflags'] = 'Sæt flag i beskeden';
$labels['addflags'] = 'Tilføj flag til beskeden';
$labels['removeflags'] = 'Fjern flag fra beskeden';
$labels['flagread'] = 'Læs';
$labels['flagdeleted'] = 'Slettede';
$labels['flaganswered'] = 'Besvaret';
$labels['flagflagged'] = 'Markeret';
$labels['flagdraft'] = 'Kladde';
$labels['addheader'] = 'Tilføj header til beskeden';
$labels['deleteheader'] = 'Fjern header fra beskeden';
$labels['headername'] = 'Headernavn';
$labels['headervalue'] = 'Headerværdi';
$labels['headerpos'] = 'Headerposition';
$labels['headeratstart'] = 'i begyndelsen';
$labels['headeratend'] = 'i slutningen';
$labels['headerfromstart'] = 'Fra start';
$labels['headerfromend'] = 'Fra slut';
$labels['setvariable'] = 'Skriv variablen';
$labels['setvarname'] = 'Variabel navn:';
$labels['setvarvalue'] = 'Variabel værdi:';
$labels['setvarmodifiers'] = 'Modifikator';
$labels['varlower'] = 'små bogstaver';
$labels['varupper'] = 'store bogstaver';
$labels['varlowerfirst'] = 'første bogstav lille';
$labels['varupperfirst'] = 'Første bogstav stort';
$labels['varquotewildcard'] = 'Sæt specialle tegn i citationstegn ';
$labels['varlength'] = 'længde';
$labels['notify'] = 'Send meddelelse';
$labels['notifytarget'] = 'Meddelelse mål:';
$labels['notifyimportance'] = 'Vigtighed:';
$labels['notifyimportancelow'] = 'lav';
$labels['notifyimportancenormal'] = 'normal';
$labels['notifyimportancehigh'] = 'høj';
$labels['notifymethodmailto'] = 'Email';
$labels['notifymethodtel'] = 'Telefon';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Opret filter';
$labels['usedata'] = 'Brug følgende data i filteret:';
$labels['nextstep'] = 'Næste trin';
$labels['...'] = '...';
$labels['string'] = 'Streng';
$labels['currdate'] = 'Aktuel dato';
$labels['datetest'] = 'Dato';
$labels['dateheader'] = 'header:';
$labels['year'] = 'år';
$labels['month'] = 'måned';
$labels['day'] = 'dag';
$labels['date'] = 'dato (åååå-mm-dd)';
$labels['julian'] = 'dato (juliansk)';
$labels['hour'] = 'time';
$labels['minute'] = 'minut';
$labels['second'] = 'sekund';
$labels['time'] = 'tid (tt:mm:ss)';
$labels['iso8601'] = 'dato (ISO8601)';
$labels['std11'] = 'dato (RFC2822)';
$labels['zone'] = 'tidszone';
$labels['weekday'] = 'ugedag (0-6)';
$labels['advancedopts'] = 'Avancerede muligheder';
$labels['body'] = 'Brødtekst';
$labels['address'] = 'adresse';
$labels['envelope'] = 'kuvert';
$labels['modifier'] = 'modificerer:';
$labels['text'] = 'tekst';
$labels['undecoded'] = 'udekodet (råt):';
$labels['contenttype'] = 'indholdstype';
$labels['modtype'] = 'type:';
$labels['allparts'] = 'alle';
$labels['domain'] = 'domæne';
$labels['localpart'] = 'lokal del';
$labels['user'] = 'bruger';
$labels['detail'] = 'detalje';
$labels['comparator'] = 'sammenligner:';
$labels['default'] = 'standard';
$labels['octet'] = 'præcis (oktet)';
$labels['asciicasemap'] = 'store og små bogstaver (ascii-bogstaver)';
$labels['asciinumeric'] = 'numerisk (ascii-numerisk)';
$labels['index'] = 'indeks:';
$labels['indexlast'] = 'baglends';
$labels['spamtest'] = 'Spam score ';
$labels['spamtestisgreaterthan'] = 'er større end';
$labels['spamtestisgreaterthanequal'] = 'er større end eller lig med';
$labels['spamtestislessthan'] = 'er mindre end';
$labels['spamtestislessthanequal'] = 'er mindre end eller lig med';
$labels['spamtestequals'] = 'er ens med';
$labels['spamtestnotequals'] = 'er ikke ens med';
$labels['spamtestisunknown'] = 'er ukendt';
$labels['vacation'] = 'Ikke tilstede';
$labels['vacation.reply'] = 'Svar besked';
$labels['vacation.advanced'] = 'Avancerede indstillinger ';
$labels['vacation.subject'] = 'Emne';
$labels['vacation.body'] = 'Body';
$labels['vacation.start'] = 'Start tid';
$labels['vacation.end'] = 'Slut tid';
$labels['vacation.status'] = 'Status';
$labels['vacation.on'] = 'Tænd';
$labels['vacation.off'] = 'Sluk';
$labels['vacation.addresses'] = 'Mine e-mail adresser';
$labels['vacation.saving'] = 'Gemmer data...';
$labels['vacation.keep'] = 'Behold';
$labels['vacation.discard'] = 'Kasser';
$labels['vacation.redirect'] = 'Omdiriger til ';
$labels['vacation.copy'] = 'Send kopi til';
$labels['forward.redirect'] = 'Omdiriger til ';
$labels['forward.copy'] = 'Send kopi til';
$labels['forward.on'] = 'Tænd';
$labels['forward.off'] = 'Sluk';
$labels['forward.status'] = 'Status:';
$labels['forward.saving'] = 'Gemmer data...';
$labels['ariasummaryfilterslist'] = 'Liste over filtre';
$labels['ariasummaryfiltersetslist'] = 'Liste over filtre indstillinger';
$labels['filterstitle'] = 'Rediger filter for indkommende mails';
$labels['vacationtitle'] = 'Rediger out-of-office regel';
$labels['message'] = 'Besked';
$labels['duplicate.header'] = 'header:';
$messages['filterunknownerror'] = 'Ukendt server fejl.';
$messages['filterconnerror'] = 'Kan ikke forbinde til server.';
$messages['filterdeleteerror'] = 'Kunne ikke slette filter. Serverfejl opstod.';
$messages['filterdeleted'] = 'Filter slettet.';
$messages['filtersaved'] = 'Filter gemt.';
$messages['filtersaveerror'] = 'Kunne ikke gemme filter. Serverfejl.';
$messages['filterdeleteconfirm'] = 'Vil du slette det valgte filter?';
$messages['ruledeleteconfirm'] = 'Er du sikker på at du vil slette den valgte regel?';
$messages['actiondeleteconfirm'] = 'Er du sikker på du vil slette den valgte handling?';
$messages['forbiddenchars'] = 'Ulovlige tegn i feltet';
$messages['cannotbeempty'] = 'Feltet kan ikke være tomt.';
$messages['ruleexist'] = 'Filter med dette navn eksisterer allerede.';
$messages['activateerror'] = 'Kan ikke aktivere valgt filter sæt. Server fejl.';
$messages['deactivateerror'] = 'Kan ikke deaktivere valgt filter sæt. Server fejl.';
$messages['deactivated'] = 'Filter(filtre) aktiveret.';
$messages['activated'] = 'Filter(filtre) deaktiveret.';
$messages['moved'] = 'Filter flyttet.';
$messages['moveerror'] = 'Kan ikke flytte valgt filter. Server fejl.';
$messages['nametoolong'] = 'Navn er for langt.';
$messages['namereserved'] = 'Reserveret navn.';
$messages['setexist'] = 'Filtersæt eksisterer allerede.';
$messages['nodata'] = 'Mindst en position skal vælges!';
$messages['invaliddateformat'] = 'Ugyldigt dato- eller tidsformat';
$messages['saveerror'] = 'Kunne ikke gemme data. Server fejl';
