<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Uso in commun';
$labels['myrights'] = 'Derectos de accesso';
$labels['username'] = 'Usator:';
$labels['advanced'] = 'Modo avantiate';
$labels['add'] = 'Adder';
$labels['newuser'] = 'Adder entrata';
$labels['editperms'] = 'Modificar permissiones';
$labels['actions'] = 'Actiones de derecto de accesso...';
$labels['anyone'] = 'Tote le usatores (non importa qui)';
$labels['anonymous'] = 'Hospites (anonyme)';
$labels['identifier'] = 'Identificator';
$labels['acll'] = 'Cercar';
$labels['aclr'] = 'Leger messages';
$labels['acls'] = 'Retener le stato Vidite';
$labels['aclw'] = 'Signales de scriptura';
$labels['acli'] = 'Inserer (copiar in)';
$labels['aclp'] = 'Inviar';
$labels['aclc'] = 'Crear subdossieres';
$labels['aclk'] = 'Crear subdossieres';
$labels['acld'] = 'Deler messages';
$labels['aclt'] = 'Deler messages';
$labels['acle'] = 'Expunger';
$labels['aclx'] = 'Deler dossier';
$labels['acla'] = 'Administrar';
$labels['acln'] = 'Annotar messages';
$labels['aclfull'] = 'Controlo total';
$labels['aclother'] = 'Altere';
$labels['aclread'] = 'Leger';
$labels['aclwrite'] = 'Scriber';
$labels['acldelete'] = 'Deler';
$labels['shortacll'] = 'Cercar';
$labels['shortaclr'] = 'Leger';
$labels['shortacls'] = 'Retener';
$labels['shortaclw'] = 'Scriber';
$labels['shortacli'] = 'Inserer';
$labels['shortaclp'] = 'Inviar';
$labels['shortaclc'] = 'Crear';
$labels['shortaclk'] = 'Crear';
$labels['shortacld'] = 'Deler';
$labels['shortaclt'] = 'Deler';
$labels['shortacle'] = 'Expunger';
$labels['shortaclx'] = 'Deletion de dossier';
$labels['shortacla'] = 'Administrar';
$labels['shortacln'] = 'Annotar';
$labels['shortaclother'] = 'Altere';
$labels['shortaclread'] = 'Leger';
$labels['shortaclwrite'] = 'Scriber';
$labels['shortacldelete'] = 'Deler';
$labels['longacll'] = 'Le dossier es visibile in listas e on pote subscriber se a illo';
$labels['longaclr'] = 'Le dossier pote esser aperite pro lectura';
$labels['longacls'] = 'Le signal "Vidite" de messages pote esser cambiate';
$labels['longaclw'] = 'Le signales e parolas-clave de messages pote esser cambiate, excepte "Vidite" e "Delite"';
$labels['longacli'] = 'Messages pote esser scribite o copiate al dossier';
$labels['longaclp'] = 'Messages pote esser inviate a iste dossier';
$labels['longaclc'] = 'Dossieres pote esser create (o renominate) directemente sub iste dossier';
$labels['longaclk'] = 'Dossieres pote esser create (o renominate) directemente sub iste dossier';
$labels['longacld'] = 'Le signal "Deler" de messages pote esser cambiate';
$labels['longaclt'] = 'Le signal "Deler" de messages pote esser cambiate';
$labels['longacle'] = 'Messages pote esser expungite';
$labels['longaclx'] = 'Le dossier pote esser delite o renominate';
$labels['longacla'] = 'Le derectos de accesso del dossier pote esser cambiate';
$labels['longacln'] = 'Le metadatos commun (annotationes) de messages pote esser cambiate';
$labels['longaclfull'] = 'Controlo total incluse le administration de dossieres';
$labels['longaclread'] = 'Le dossier pote esser aperite pro lectura';
$labels['longaclwrite'] = 'Messages pote esser marcate, scribite o copiate al dossier';
$labels['longacldelete'] = 'Messages pote esser delite';
$labels['longaclother'] = 'Altere derectos de accesso';
$labels['ariasummaryacltable'] = 'Lista de derectos de accesso';
$labels['arialabelaclactions'] = 'Listar actiones';
$labels['arialabelaclform'] = 'Formulario de derectos de accesso';
$messages['deleting'] = 'A deler derectos de accesso...';
$messages['saving'] = 'A salveguardar derectos de accesso...';
$messages['updatesuccess'] = 'Le derectos de accesso ha essite cambiate';
$messages['deletesuccess'] = 'Le derectos de accesso ha essite delite';
$messages['createsuccess'] = 'Le derectos de accesso ha essite addite';
$messages['updateerror'] = 'Impossibile actualisar le derectos de accesso';
$messages['deleteerror'] = 'Impossibile deler derectos de accesso';
$messages['createerror'] = 'Impossibile adder derectos de accesso';
$messages['deleteconfirm'] = 'Es vos secur de voler remover le derectos de accesso del usator(es) seligite?';
$messages['norights'] = 'Nulle derecto ha essite specificate.';
$messages['nouser'] = 'Nulle nomine de usator ha essite specificate.';
