<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = '$product e-posta sistemine hoş geldiniz';
$labels['username'] = 'Kullanıcı adı';
$labels['password'] = 'Parola';
$labels['server'] = 'Sunucu';
$labels['login'] = 'Oturum aç';
$labels['oauthlogin'] = '$provider ile oturum aç';
$labels['menu'] = 'Menü';
$labels['logout'] = 'Kapat';
$labels['mail'] = 'İletiler';
$labels['settings'] = 'Ayarlar';
$labels['addressbook'] = 'Adres defteri';
$labels['darkmode'] = 'Koyu kip';
$labels['lightmode'] = 'Açık kip';
$labels['inbox'] = 'Gelen';
$labels['drafts'] = 'Taslak';
$labels['sent'] = 'Giden';
$labels['trash'] = 'Çöp';
$labels['junk'] = 'İstenmeyen';
$labels['show_real_foldernames'] = 'Özel klasörlerin gerçek adları görüntülensin';
$labels['subject'] = 'Konu';
$labels['from'] = 'Gönderici';
$labels['sender'] = 'Gönderici';
$labels['to'] = 'Alıcı';
$labels['cc'] = 'Kopya';
$labels['bcc'] = 'Gizli kopya';
$labels['replyto'] = 'Yanıt adresi';
$labels['followupto'] = 'İzleme adresi';
$labels['date'] = 'Tarih';
$labels['size'] = 'Boyut';
$labels['priority'] = 'Öncelik';
$labels['organization'] = 'Kuruluş';
$labels['readstatus'] = 'Okunma durumu';
$labels['listoptions'] = 'Seçenekleri listele...';
$labels['listoptionstitle'] = 'Liste seçenekleri';
$labels['mailboxlist'] = 'Klasörler';
$labels['messagesfromto'] = 'İletiler: $from - $to , Toplam: $count';
$labels['threadsfromto'] = 'Yazışmalar: $from - $to, Toplam $count';
$labels['messagenrof'] = 'İleti: $nr / $count';
$labels['fromtoshort'] = '$from - $to , Toplam: $count';
$labels['copy'] = 'Kopyala';
$labels['move'] = 'Taşı';
$labels['moveto'] = 'Şuraya taşı...';
$labels['copyto'] = 'Şuraya Kopyala...';
$labels['download'] = 'İndir';
$labels['open'] = 'Aç';
$labels['showattachment'] = 'Görüntüle';
$labels['showanyway'] = 'Yine de görüntülensin';
$labels['filename'] = 'Dosya adı';
$labels['filesize'] = 'Dosya boyutu';
$labels['addtoaddressbook'] = 'Adres defterine ekle';
$labels['sun'] = 'Paz';
$labels['mon'] = 'Pzt';
$labels['tue'] = 'Sal';
$labels['wed'] = 'Çrş';
$labels['thu'] = 'Per';
$labels['fri'] = 'Cum';
$labels['sat'] = 'Cts';
$labels['sunday'] = 'Pazar';
$labels['monday'] = 'Pazartesi';
$labels['tuesday'] = 'Salı';
$labels['wednesday'] = 'Çarşamba';
$labels['thursday'] = 'Perşembe';
$labels['friday'] = 'Cuma';
$labels['saturday'] = 'Cumartesi';
$labels['jan'] = 'Oca';
$labels['feb'] = 'Şub';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Nis';
$labels['may'] = 'May';
$labels['jun'] = 'Haz';
$labels['jul'] = 'Tem';
$labels['aug'] = 'Ağu';
$labels['sep'] = 'Eyl';
$labels['oct'] = 'Eki';
$labels['nov'] = 'Kas';
$labels['dec'] = 'Ara';
$labels['longjan'] = 'Ocak';
$labels['longfeb'] = 'Şubat';
$labels['longmar'] = 'Mart';
$labels['longapr'] = 'Nisan';
$labels['longmay'] = 'Mayıs';
$labels['longjun'] = 'Haziran';
$labels['longjul'] = 'Temmuz';
$labels['longaug'] = 'Ağustos';
$labels['longsep'] = 'Eylül';
$labels['longoct'] = 'Ekim';
$labels['longnov'] = 'Kasım';
$labels['longdec'] = 'Aralık';
$labels['today'] = 'Bugün';
$labels['refresh'] = 'Yenile';
$labels['checkmail'] = 'İletileri denetle';
$labels['compose'] = 'Hazırla';
$labels['writenewmessage'] = 'Yeni ileti ';
$labels['reply'] = 'Yanıtla';
$labels['replytomessage'] = 'Göndericiye yanıtla';
$labels['replytoallmessage'] = 'Göndericiye ve tüm alıcılara yanıtla';
$labels['replyall'] = 'Toplu yanıtla';
$labels['replylist'] = 'Listeye yanıtla';
$labels['forward'] = 'İlet';
$labels['forwardinline'] = 'Posta içinde ilet';
$labels['forwardattachment'] = 'Ek dosya olarak ilet';
$labels['forwardmessage'] = 'İlet';
$labels['bouncemsg'] = 'Yeniden gönder (sektir)';
$labels['bounce'] = 'Yeniden gönder';
$labels['deletemessage'] = 'İletiyi sil';
$labels['movemessagetotrash'] = 'Çöpe taşı';
$labels['printmessage'] = 'Yazdır';
$labels['previousmessage'] = 'Önceki ileti';
$labels['firstmessage'] = 'İlk ileti';
$labels['nextmessage'] = 'Sonraki ileti';
$labels['lastmessage'] = 'Son ileti';
$labels['backtolist'] = 'İleti listesine dön';
$labels['viewsource'] = 'Kaynağı görüntüle';
$labels['mark'] = 'İşaretle';
$labels['markmessages'] = 'İletileri işaretle';
$labels['markread'] = 'Okunmuş olarak';
$labels['markunread'] = 'Okunmamış olarak';
$labels['markflagged'] = 'İşaretlenmiş olarak';
$labels['markunflagged'] = 'İşaretlenmemiş olarak';
$labels['markundeleted'] = 'Silinmemiş olarak';
$labels['moreactions'] = 'Diğer işlemler...';
$labels['markallread'] = 'Tümünü okunmuş olarak işaretle';
$labels['folders-cur'] = 'Yalnızca seçilmiş klasör';
$labels['folders-sub'] = 'Seçilmiş Klasör ve Alt Klasörleri';
$labels['folders-all'] = 'Tüm klasörler';
$labels['more'] = 'Diğer';
$labels['back'] = 'Geri';
$labels['options'] = 'Ayarlar';
$labels['composeoptions'] = 'İleti seçenekleri';
$labels['optionsandattachments'] = 'Ayarlar ve ek dosyalar';
$labels['actions'] = 'İşlemler';
$labels['first'] = 'İlk';
$labels['last'] = 'Son';
$labels['previous'] = 'Önceki';
$labels['next'] = 'Sonraki';
$labels['select'] = 'Seç';
$labels['selection'] = 'Seçim';
$labels['all'] = 'Tümü';
$labels['none'] = 'Yok';
$labels['currpage'] = 'Geçerli sayfa';
$labels['isread'] = 'Okunmuş';
$labels['unread'] = 'Okunmamışlar';
$labels['flagged'] = 'İşaretlenmişler';
$labels['unflagged'] = 'İşaretlenmemiş';
$labels['unanswered'] = 'Yanıtlanmamışlar';
$labels['withattachment'] = 'Ek dosyası olanlar';
$labels['deleted'] = 'Silinmişler';
$labels['undeleted'] = 'Silinmemişler';
$labels['replied'] = 'Yanıtlanmış';
$labels['forwarded'] = 'İletilmiş';
$labels['invert'] = 'Seçimi ters çevir';
$labels['filter'] = 'Süz';
$labels['list'] = 'Liste';
$labels['threads'] = 'Yazışma';
$labels['expand-all'] = 'Tümünü genişlet';
$labels['expand-unread'] = 'Okunmamışları genişlet';
$labels['collapse-all'] = 'Tümünü daralt';
$labels['threaded'] = 'Yazışma görünümü';
$labels['showunread'] = 'Okunmamış iletileri görüntüle';
$labels['autoexpand_threads'] = 'Yazışma iletileri genişletilsin';
$labels['do_expand'] = 'tüm yazışmalar';
$labels['expand_only_unread'] = 'yalnızca okunmamış iletiler bulunan yazışmalar';
$labels['fromto'] = 'Gönderici/Alıcı';
$labels['flag'] = 'İşaret';
$labels['attachment'] = 'Ek dosya';
$labels['nonesort'] = 'Yok';
$labels['sentdate'] = 'Gönderilme tarihi';
$labels['arrival'] = 'Alınma tarihi';
$labels['asc'] = 'artan';
$labels['desc'] = 'azalan';
$labels['listcolumns'] = 'Sütunları listele';
$labels['listsorting'] = 'Sıralama sütunu';
$labels['listorder'] = 'Sıralama düzeni';
$labels['listmode'] = 'Liste görünümü';
$labels['lmode'] = 'Liste kipi';
$labels['layout'] = 'Görünüm';
$labels['layoutwidescreen'] = 'Geniş ekran';
$labels['layoutdesktop'] = 'Masaüstü';
$labels['layoutlist'] = 'Liste';
$labels['layoutwidescreendesc'] = 'Geniş ekran (3 sütun görünümü)';
$labels['layoutdesktopdesc'] = 'Masaüstü (geniş liste ile aşağıda e-posta ön izlemesi)';
$labels['layoutlistdesc'] = 'Liste (e-posta ön izlemesi olmadan)';
$labels['folderactions'] = 'Klasör İşlemleri...';
$labels['compact'] = 'Sıkıştır';
$labels['empty'] = 'Boşalt';
$labels['importmessages'] = 'İçe aktar';
$labels['mailimportdesc'] = '<a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> ya da <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a> biçiminde dosyalar kullanarak e-postalarınızı yükleyebilirsiniz.';
$labels['mailimportzip'] = 'Birden çok dosya zip arşivi biçiminde sıkıştırılabilir.';
$labels['quota'] = 'Disk kullanımı';
$labels['unknown'] = 'bilinmeyen';
$labels['unlimited'] = 'sınırsız';
$labels['quotatype'] = 'Kota türü';
$labels['quotatotal'] = 'Sınır';
$labels['quotaused'] = 'Kullanılan';
$labels['quotastorage'] = 'Disk boyutu';
$labels['quotamessage'] = 'İleti sayısı';
$labels['shortheaderdate'] = '$date tarihinde';
$labels['shortheaderto'] = '$to alıcısına $date tarihinde';
$labels['shortheaderfrom'] = '$from göndericisinden $date tarihinde';
$labels['quicksearch'] = 'Hızlı arama';
$labels['searchplaceholder'] = 'Arama...';
$labels['resetsearch'] = 'Aramayı sıfırla';
$labels['searchmod'] = 'Arama alanları';
$labels['msgtext'] = 'Tüm ileti alanları';
$labels['body'] = 'Metin';
$labels['type'] = 'Tür';
$labels['namex'] = 'Ad';
$labels['searchscope'] = 'Kapsam';
$labels['currentfolder'] = 'Bu klasör';
$labels['subfolders'] = 'Bu ve alt klasörler';
$labels['allfolders'] = 'Tüm klasörler';
$labels['searchinterval-1W'] = 'Bir haftadan eski';
$labels['searchinterval-1M'] = 'Bir aydan eski';
$labels['searchinterval-1Y'] = 'Bir yıldan eski';
$labels['searchinterval1W'] = 'Bir haftadan yeni';
$labels['searchinterval1M'] = 'Bir aydan yeni';
$labels['searchinterval1Y'] = 'Bir yıldan yeni';
$labels['openinextwin'] = 'Yeni pencerede aç';
$labels['emlsave'] = 'İndir (.eml)';
$labels['changeformattext'] = 'Düz metin biçiminde görüntülensin';
$labels['changeformathtml'] = 'HTML biçiminde görüntülensin';
$labels['editasnew'] = 'Yeni olarak düzenle';
$labels['send'] = 'Gönder';
$labels['sendmessage'] = 'İletiyi gönder';
$labels['savemessage'] = 'Taslak olarak kaydet';
$labels['addattachment'] = 'Dosya ekle';
$labels['charset'] = 'Karakter kodlaması';
$labels['editortype'] = 'Düzenleyici';
$labels['returnreceipt'] = 'Alındı onayı istensin';
$labels['dsn'] = 'Teslim onayı istensin';
$labels['keepformatting'] = 'Biçimlendirme korunsun';
$labels['mailreplyintro'] = '$date, $sender yazmış:';
$labels['originalmessage'] = 'Özgün ileti';
$labels['selectimage'] = 'Görsel seçin';
$labels['addimage'] = 'Görsel ekle';
$labels['selectmedia'] = 'Görüntü seçin';
$labels['addmedia'] = 'Görüntü ekle';
$labels['encrypt'] = 'Şifrele';
$labels['encryptmessage'] = 'İletiyi şifrele';
$labels['encryptmessagemailvelope'] = 'İletinizi Mailvelope ile şifreleyin';
$labels['importpubkeys'] = 'Herkese açık anahtarları içe aktar';
$labels['encryptedsendialog'] = 'Şifrelenmiş ileti gönderiliyor';
$labels['encryptandsign'] = 'Şifrele ve imzala';
$labels['keyid'] = 'Kimlik Anahtarı';
$labels['keylength'] = 'Bit';
$labels['keyexpired'] = 'Süresi geçmiş';
$labels['keyrevoked'] = 'Geçersiz kılınmış';
$labels['bccinstead'] = 'Gizli kopya kullanılsın';
$labels['addheader'] = 'Alıcı ekle (üst bilgi)';
$labels['insert'] = 'Ekle';
$labels['insertcontact'] = 'Kişi ekle';
$labels['recipient'] = 'Alıcı';
$labels['recipientedit'] = 'Alıcıyı düzenle';
$labels['editidents'] = 'Kimlikleri düzenle';
$labels['spellcheck'] = 'Yazım denetimi';
$labels['checkspelling'] = 'Yazımı denetle';
$labels['resumeediting'] = 'Düzenlemeyi sürdür';
$labels['revertto'] = 'Geri al:';
$labels['restore'] = 'Geri yükle';
$labels['restoremessage'] = 'İleti geri yüklensin mi?';
$labels['ignore'] = 'Yok say';
$labels['responses'] = 'Hazır yanıtlar';
$labels['insertresponse'] = 'Hazır yanıt ekle';
$labels['manageresponses'] = 'Hazır yanıt yönetimi';
$labels['newresponse'] = 'Yeni Hazır yanıt ekle';
$labels['addresponse'] = 'Hazır yanıt ekle';
$labels['editresponse'] = 'Hazır yanıtı düzenle';
$labels['editresponses'] = 'Hazır yanıtları düzenle';
$labels['responsename'] = 'Ad';
$labels['responsetext'] = 'Hazır yanıt metni';
$labels['attach'] = 'Dosya ekle';
$labels['attachments'] = 'Ek dosyalar';
$labels['upload'] = 'Yükle';
$labels['uploadprogress'] = '$percent($current / $total)';
$labels['close'] = 'Kapat';
$labels['messageoptions'] = 'İleti ayarları...';
$labels['togglecomposeoptions'] = 'İleti seçeneklerini görüntüle/gizle';
$labels['attachmentrename'] = 'Ek dosyayı yeniden adlandır';
$labels['low'] = 'Düşük';
$labels['lowest'] = 'En düşük';
$labels['normal'] = 'Normal';
$labels['high'] = 'Yüksek';
$labels['highest'] = 'En yüksek';
$labels['nosubject'] = '(konu belirtilmemiş)';
$labels['showimages'] = 'Görselleri görüntüle';
$labels['allow'] = 'İzin ver';
$labels['alwaysshow'] = '$sender tarafından gönderilen görseller her zaman görüntülensin';
$labels['alwaysallow'] = '$sender tarafından gönderilen iletiler her zaman alınsın';
$labels['isdraft'] = 'Bu ileti henüz taslak.';
$labels['andnmore'] = '$nr daha...';
$labels['details'] = 'Ayrıntılar';
$labels['summary'] = 'Özet';
$labels['headers'] = 'Üst bilgiler';
$labels['allheaders'] = 'Tüm üst bilgiler...';
$labels['togglemoreheaders'] = 'Daha fazla ileti üst bilgisi görüntüle';
$labels['togglefullheaders'] = 'İleti üst bilgilerini görüntüle/gizle';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Düz metin';
$labels['savesentmessagein'] = 'Gönderilen ileti şuraya kaydedilsin';
$labels['dontsave'] = 'kaydedilmesin';
$labels['maxuploadsize'] = 'İzin verilen en büyük dosya boyutu $size';
$labels['addcc'] = 'Kopya ekle';
$labels['addbcc'] = 'Gizli kopya ekle';
$labels['addreplyto'] = 'Yanıtlama adresi ekle';
$labels['addfollowupto'] = 'İzleme adresi ekle';
$labels['sendreceipt'] = 'Okundu iletisi gönderilsin mi?';
$labels['mdnrequest'] = 'Bu iletinin göndericisi okuduğunuza dair onay istedi. Onay göndermek ister misiniz ?';
$labels['receiptread'] = 'Alındı onayı (okundu)';
$labels['yourmessage'] = 'İletinizin okundu onayı';
$labels['receiptnote'] = 'Not: Bu okundu onayı iletinizin yalnızca alıcının bilgisayarında görüntülendiğini belirtir. Alıcının ileti içeriğini okuduğunu ya da anladığını kanıtlamaz.';
$labels['sendalwaysto'] = 'Her zaman $email adresine gönderilsin';
$labels['zoomin'] = 'Yakınlaştır';
$labels['zoomout'] = 'Uzaklaştır';
$labels['rotate'] = 'Döndür';
$labels['increaseimage'] = 'Görsel boyutunu büyüt';
$labels['decreaseimage'] = 'Görsel boyutunu küçült';
$labels['rotateimage'] = 'Görseli döndür';
$labels['showtools'] = 'Görsel araçları görüntülensin';
$labels['hidetools'] = 'Görsel araçları gizlensin';
$labels['name'] = 'Görüntülenecek ad';
$labels['firstname'] = 'Ad';
$labels['surname'] = 'Soyad';
$labels['middlename'] = 'İkinci ad';
$labels['nameprefix'] = 'Ön ek';
$labels['namesuffix'] = 'Son ek';
$labels['nickname'] = 'Takma ad';
$labels['jobtitle'] = 'İş unvanı';
$labels['department'] = 'Bölüm';
$labels['gender'] = 'Cinsiyet';
$labels['maidenname'] = 'Kızlık soyadı';
$labels['email'] = 'E-posta';
$labels['phone'] = 'Telefon';
$labels['address'] = 'Adres';
$labels['street'] = 'Sokak';
$labels['locality'] = 'İl';
$labels['zipcode'] = 'Posta kodu';
$labels['region'] = 'Bölge';
$labels['country'] = 'Ülke';
$labels['birthday'] = 'Doğum günü';
$labels['anniversary'] = 'Yıl dönümü';
$labels['website'] = 'Web sayfası';
$labels['instantmessenger'] = 'Anlık iletişim';
$labels['notes'] = 'Notlar';
$labels['male'] = 'Erkek';
$labels['female'] = 'Kadın';
$labels['manager'] = 'Yönetici';
$labels['assistant'] = 'Yardımcı';
$labels['spouse'] = 'Eş';
$labels['allfields'] = 'Tüm alanlar';
$labels['search'] = 'Ara';
$labels['searchresult'] = 'Arama sonucu';
$labels['advsearch'] = 'Gelişmiş arama';
$labels['advanced'] = 'Gelişmiş';
$labels['other'] = 'Diğer';
$labels['printcontact'] = 'Kişiyi yazdır';
$labels['qrcode'] = 'QR kodu';
$labels['typehome'] = 'Ev';
$labels['typework'] = 'İş';
$labels['typeother'] = 'Diğer';
$labels['typemobile'] = 'Cep telefonu';
$labels['typemain'] = 'Ana';
$labels['typehomefax'] = 'Ev faksı';
$labels['typeworkfax'] = 'İş faksı';
$labels['typecar'] = 'Araç';
$labels['typepager'] = 'Çağrı cihazı';
$labels['typevideo'] = 'Görüntülü';
$labels['typeassistant'] = 'Yardımcı';
$labels['typehomepage'] = 'Web sitesi';
$labels['typeblog'] = 'Günlük';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Alan ekle...';
$labels['addcontact'] = 'Kişi ekle';
$labels['editcontact'] = 'Kişiyi düzenle';
$labels['contacts'] = 'Kişiler';
$labels['contactproperties'] = 'Kişi bilgileri';
$labels['contactnameandorg'] = 'Ad ve kuruluş';
$labels['personalinfo'] = 'Kişisel bilgiler';
$labels['personal'] = 'Kişisel';
$labels['contactphoto'] = 'Fotoğraf';
$labels['edit'] = 'Düzenle';
$labels['cancel'] = 'İptal';
$labels['save'] = 'Kaydet';
$labels['delete'] = 'Sil';
$labels['discard'] = 'Yok say';
$labels['continue'] = 'Devam et';
$labels['ok'] = 'Tamam';
$labels['rename'] = 'Yeniden adlandır';
$labels['addphoto'] = 'Ekle';
$labels['replacephoto'] = 'Değiştir';
$labels['uploadphoto'] = 'Fotoğraf yükle';
$labels['choosefile'] = 'Dosyayı seçin...';
$labels['choosefiles'] = 'Dosyaları seçin...';
$labels['browse'] = 'Göz at';
$labels['newcontact'] = 'Yeni kişi ekle';
$labels['deletecontact'] = 'Seçilmiş kişileri sil';
$labels['composeto'] = 'Şu kişiye ileti hazırla';
$labels['contactsfromto'] = 'Kişiler: $from - $to , Toplam: $count';
$labels['print'] = 'Yazdır';
$labels['export'] = 'Dışa aktar';
$labels['exportall'] = 'Tümünü dışa aktar';
$labels['exportsel'] = 'Seçilmişleri dışa aktar';
$labels['exportvcards'] = 'Kişileri vCard biçiminde dışa aktar';
$labels['newgroup'] = 'Yeni grup ekle';
$labels['addgroup'] = 'Grup ekle';
$labels['grouprename'] = 'Grubu yeniden adlandır';
$labels['groupdelete'] = 'Grubu sil';
$labels['groupassign'] = 'Gruba ata...';
$labels['groupremove'] = 'Gruptan çıkar';
$labels['groupremoveselected'] = 'Seçilmiş kişileri gruptan çıkar';
$labels['uponelevel'] = 'Üst düzeye git';
$labels['previouspage'] = 'Önceki sayfayı görüntüle';
$labels['firstpage'] = 'İlk sayfayı görüntüle';
$labels['nextpage'] = 'Sonraki sayfayı görüntüle';
$labels['lastpage'] = 'Son sayfayı görüntüle';
$labels['group'] = 'Grup';
$labels['groups'] = 'Gruplar';
$labels['listgroup'] = 'Grup üyelerini listele';
$labels['personaladrbook'] = 'Kişisel adresler';
$labels['searchsave'] = 'Aramayı kaydet';
$labels['searchdelete'] = 'Aramayı sil';
$labels['import'] = 'İçe aktar';
$labels['importcontacts'] = 'Kişileri içe aktar';
$labels['importfromfile'] = 'Dosyadan içe aktar';
$labels['importtarget'] = 'Kişileri ekle';
$labels['importreplace'] = 'Tüm adres defterinin yerine geçsin';
$labels['importgroups'] = 'Grup atamalarını içe aktar';
$labels['importgroupsall'] = 'Tümü (gerekirse gruplar eklensin)';
$labels['importgroupsexisting'] = 'Yalnızca var olan gruplar';
$labels['importdesc'] = 'Var olan bir adres defterindeki kişileri yükleyebilirsiniz.<br/>Şu anda <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> ve CSV (virgül ile ayrılmış veriler) dosya biçimlerini destekliyoruz.';
$labels['importmapdesc'] = 'CSV verilerini içe aktarmayı başlatmadan önce aşağıdaki alan eşleştirme bilgilerinin doğru olduğundan emin olun.';
$labels['fieldnotmapped'] = 'Alan eşleştirilmemiş (içe aktarılmaz)';
$labels['skipheader'] = 'İlk satır içe aktarılmasın (başlıklar)';
$labels['done'] = 'Tamam';
$labels['settingsfor'] = 'Şunun ayarları';
$labels['about'] = 'Hakkında';
$labels['preferences'] = 'Ayarlar';
$labels['userpreferences'] = 'Kullanıcı ayarları';
$labels['editpreferences'] = 'Kullanıcı ayarlarını düzenle';
$labels['identities'] = 'Kimlikler';
$labels['manageidentities'] = 'Kimlik yönetimi';
$labels['newidentity'] = 'Yeni kimlik ekle';
$labels['addidentity'] = 'Kimlik ekle';
$labels['editidentity'] = 'Kimliği düzenle';
$labels['identityencryption'] = 'Şifreleme';
$labels['preferhtml'] = 'HTML görünümü kullanılsın';
$labels['defaultcharset'] = 'Varsayılan karakter kümesi';
$labels['htmlmessage'] = 'HTML ileti';
$labels['messagepart'] = 'Parça';
$labels['digitalsig'] = 'Sayısal imza';
$labels['dateformat'] = 'Tarih biçimi';
$labels['timeformat'] = 'Saat biçimi';
$labels['prettydate'] = 'Tarihler kısa görüntülensin';
$labels['setdefault'] = 'Varsayılan olarak atansın';
$labels['autodetect'] = 'Otomatik';
$labels['language'] = 'Dil';
$labels['timezone'] = 'Saat dilimi';
$labels['pagesize'] = 'Bir sayfadaki satır sayısı';
$labels['signature'] = 'İmza';
$labels['dstactive'] = 'Yaz saati uygulaması';
$labels['showinextwin'] = 'İleti yeni pencerede açılsın';
$labels['composeextwin'] = 'İleti yeni pencerede hazırlansın';
$labels['htmleditor'] = 'HTML iletileri hazırla';
$labels['htmlonreply'] = 'yalnızca HTML biçimindeki iletiler yanıtlanırken';
$labels['htmlonreplyandforward'] = 'HTML biçimindeki iletiler yanıtlanırken ya da iletilirken';
$labels['htmlsignature'] = 'HTML imza';
$labels['showemail'] = 'E-posta adresi ad ile birlikte görüntülensin';
$labels['previewpane'] = 'Ön izleme panosu görüntülensin';
$labels['skin'] = 'Arayüz görünümü';
$labels['logoutclear'] = 'Oturum kapatıldığında Çöp boşaltılsın';
$labels['logoutcompact'] = 'Oturum kapatıldığında Gelen kutusu sıkıştırılsın';
$labels['uisettings'] = 'Kullanıcı arayüzü';
$labels['serversettings'] = 'Sunucu ayarları';
$labels['mailboxview'] = 'Posta kutusu görünümü';
$labels['mdnrequests'] = 'Alındı onayları';
$labels['askuser'] = 'ne yapılacağı bana sorulsun';
$labels['autosend'] = 'otomatik olarak gönderilsin';
$labels['autosendknown'] = 'adres defterimdekilere gönderilsin, diğerleri bana sorulsun';
$labels['autosendknownignore'] = 'adres defterimdekilere gönderilsin, diğerleri yok sayılsın';
$labels['autosendtrusted'] = 'güvenilir göndericilere alındı iletisi gönderilsin, diğerleri bana sorulsun';
$labels['autosendtrustedignore'] = 'güvenilir göndericilere alındı iletisi gönderilsin, diğerleri yok sayılsın';
$labels['ignorerequest'] = 'yok sayılsın';
$labels['readwhendeleted'] = 'Silinmiş iletiler okunmuş olarak işaretlensin';
$labels['flagfordeletion'] = 'İletiler silinmek yerine silinecek olarak işaretlensin';
$labels['skipdeleted'] = 'Silinmiş iletiler görüntülenmesin';
$labels['deletealways'] = 'İletiler çöpe atılırken sorun çıkarsa tamamen silinsin';
$labels['deletejunk'] = 'İstenmeyenler klasöründeki iletiler doğrudan silinsin';
$labels['showremoteimages'] = 'Uzaktan yüklenen görseller görüntülensin';
$labels['allowremoteresources'] = 'Uzak kaynaklar (görseller, biçemler) kullanılabilsin';
$labels['fromknownsenders'] = 'bilinen göndericilerden';
$labels['fromtrustedsenders'] = 'güvenilir göndericilerden';
$labels['frommycontacts'] = 'kişilerimden';
$labels['always'] = 'her zaman';
$labels['alwaysbutplain'] = 'her zaman, düz metin biçiminde yanıtlama dışında';
$labels['showinlineimages'] = 'İleti ekindeki görseller iletinin altında görüntülensin';
$labels['autosavedraft'] = 'Taslaklar otomatik olarak kaydedilsin';
$labels['everynminutes'] = '$n dakikada bir';
$labels['refreshinterval'] = 'Yenileme sıklığı (yeni iletileri denetleme, vb.)';
$labels['never'] = 'asla';
$labels['immediately'] = 'hemen';
$labels['messagesdisplaying'] = 'İleti görünümü';
$labels['messagescomposition'] = 'Yeni ileti hazırlama';
$labels['mimeparamfolding'] = 'Ek dosya adları';
$labels['2231folding'] = 'Tam RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Tam RFC 2047 (diğer)';
$labels['force7bit'] = '8 bit karakterler için MIME kodlaması kullanılsın';
$labels['savelocalstorage'] = "Tarayıcının yerel depolama alanına kaydedilsin (geçiçi olarak)";
$labels['advancedoptions'] = 'Gelişmiş ayarlar';
$labels['toggleadvancedoptions'] = 'Gelişmiş ayarları görüntüle/gizle';
$labels['focusonnewmessage'] = 'Yeni ileti geldiğinde web tarayıcı penceresine odaklanılsın';
$labels['checkallfolders'] = 'Tüm klasörler yeni iletiler için denetlensin';
$labels['displaynext'] = 'Silme ya da taşıma sonrası sıradaki ileti görüntülensin';
$labels['defaultfont'] = 'HTML iletiler için varsayılan yazı türü';
$labels['mainoptions'] = 'Temel ayarlar';
$labels['browseroptions'] = 'Tarayıcı ayarları';
$labels['section'] = 'Bölüm';
$labels['maintenance'] = 'Bakım';
$labels['newmessage'] = 'Yeni ileti';
$labels['signatureoptions'] = 'İmza ayarları';
$labels['whenreplying'] = 'Yanıtlarken özgün iletiye şu yapılsın';
$labels['replyempty'] = 'alıntılanmasın';
$labels['replytopposting'] = 'yeni ileti alıntı metninin üzerinden başlatılsın';
$labels['replytoppostingnoindent'] = 'yeni ileti alıntı metninin üzerinden başlatılsın (girinti olmadan)';
$labels['replybottomposting'] = 'yeni ileti alıntı metninin altından başlatılsın';
$labels['replyremovesignature'] = 'Yanıtlarken önceki imzalar silinsin';
$labels['autoaddsignature'] = 'İmza otomatik olarak eklensin';
$labels['newmessageonly'] = 'yalnızca yeni iletilere';
$labels['replyandforwardonly'] = 'yalnızca yanıt ve iletmelere';
$labels['insertsignature'] = 'İmza ekle';
$labels['sigbelow'] = 'İmza alıntı metninin altına eklensin';
$labels['sigseparator'] = 'İmza eklenirken standart ayıraç kullanılsın';
$labels['automarkread'] = 'İletiler okunmuş olarak işaretlensin';
$labels['afternseconds'] = '$n saniye sonra';
$labels['reqmdn'] = 'Her zaman alındı onayı istensin';
$labels['reqdsn'] = 'Her zaman teslim edildi onayı istensin';
$labels['replysamefolder'] = 'Yanıtlar iletinin bulunduğu klasöre kaydedilsin';
$labels['defaultabook'] = 'Varsayılan adres defteri';
$labels['autocompletesingle'] = 'Otomatik tamamlanırken alternatif e-posta adresleri atlansın';
$labels['listnamedisplay'] = 'Kişiler görünümü';
$labels['contactformmode'] = 'Kişi formu kipi';
$labels['privatemode'] = 'Kişisel (ev)';
$labels['businessmode'] = 'İş (ofis)';
$labels['collectedaddresses'] = 'Derlenmiş adresler';
$labels['collectedrecipients'] = 'Derlenmiş alıcılar';
$labels['collectedrecipientsopt'] = 'Giden e-posta alıcıları şurada görüntülensin';
$labels['collectedsendersopt'] = 'Güvenilen göndericiler şurada depolansın';
$labels['trustedsenders'] = 'Güvenilen göndericiler';
$labels['spellcheckbeforesend'] = 'İleti gönderilmeden önce yazımı denetlensin';
$labels['spellcheckoptions'] = 'Yazım denetimi ayarları';
$labels['spellcheckignoresyms'] = 'İçinde simge geçen sözcükler yok sayılsın';
$labels['spellcheckignorenums'] = 'İçinde rakam geçen sözcükler yok sayılsın';
$labels['spellcheckignorecaps'] = 'Tümü büyük harf olan sözcükler yok sayılsın';
$labels['addtodict'] = 'Sözlüğe ekle';
$labels['mailtoprotohandler'] = 'mailto: bağlantıları için kullanılacak işleyici';
$labels['standardwindows'] = 'Açılan pencereler standart pencere olarak işlensin';
$labels['forwardmode'] = 'İletiler şu şekilde iletilsin';
$labels['inline'] = 'iletinin içinde';
$labels['asattachment'] = 'ek dosya olarak';
$labels['replyallmode'] = '[Toplu yanıtla] düğmesi varsayılan işlemi';
$labels['replyalldefault'] = 'toplu yanıtlasın';
$labels['replyalllist'] = 'yalnızca posta listesindekileri yanıtlasın (varsa)';
$labels['allmessages'] = 'tüm iletiler';
$labels['olderxdays'] = '$x günden eski';
$labels['folder'] = 'Klasör';
$labels['folders'] = 'Klasörler';
$labels['foldername'] = 'Klasör adı';
$labels['subscribed'] = 'Abonelik';
$labels['messagecount'] = 'İletiler';
$labels['create'] = 'Ekle';
$labels['createfolder'] = 'Yeni klasör ekle';
$labels['managefolders'] = 'Klasör yönetimi';
$labels['specialfolders'] = 'Özel klasörler';
$labels['properties'] = 'Özellikler';
$labels['folderproperties'] = 'Klasör özellikleri';
$labels['parentfolder'] = 'Üst klasör';
$labels['location'] = 'Konum';
$labels['info'] = 'Bilgiler';
$labels['getfoldersize'] = 'Klasör büyüklüğünü öğrenmek için tıklayın';
$labels['changesubscription'] = 'Abonelik durumunu değiştirmek için tıklayın';
$labels['foldertype'] = 'Klasör türü';
$labels['personalfolder'] = 'Kişisel klasör';
$labels['otherfolder'] = 'Diğer kullanıcıların klasörü';
$labels['sharedfolder'] = 'Herkese açık klasör';
$labels['findfolders'] = 'Klasör arama';
$labels['findcontacts'] = 'Kişi arama';
$labels['findmail'] = 'E-posta arama';
$labels['namespace.personal'] = 'Kişisel';
$labels['namespace.other'] = 'Diğer kullanıcılar';
$labels['namespace.shared'] = 'Paylaşılan';
$labels['dualuselabel'] = 'Yalnızca şunu içerebilir';
$labels['dualusemail'] = 'iletiler';
$labels['dualusefolder'] = 'klasörler';
$labels['generate'] = 'Üret';
$labels['encryptioncreatekey'] = 'Yeni anahtar çifti oluştur';
$labels['openmailvelopesettings'] = 'Mailvelope ayarlarını aç';
$labels['encryptionprivkeysinmailvelope'] = 'Mailvelope anahtarlığınızda eşleşen $nr PGP kişisel anahtarı var:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Mailvelope uygulama ekinde bu gönderici kimliği için henüz bir kişisel PGP anahtarı bulunmuyor. Bir kişisel anahtar oluşturup şifrelenmiş iletişimi etkinleştirmek ister misiniz?';
$labels['encryption'] = 'Şifreleme';
$labels['mailvelopeoptions'] = 'Mailvelope ayarları';
$labels['mailvelopemainkeyring'] = 'Mailvelope ana anahtarlığı kullanılsın';
$labels['mailvelopenotfound'] = 'Web tarayıcınızda Mailvelope eklentisi etkinleştirilmemiş ya da kurulmamış.';
$labels['sortby'] = 'Sıralama';
$labels['sortasc'] = 'Artan';
$labels['sortdesc'] = 'Azalan';
$labels['undo'] = 'Geri al';
$labels['installedplugins'] = 'Kurulmuş uygulama ekleri';
$labels['plugin'] = 'Uygulama eki';
$labels['version'] = 'Sürüm';
$labels['source'] = 'Kaynak';
$labels['destination'] = 'Hedef';
$labels['license'] = 'Lisans';
$labels['support'] = 'Destek isteyin';
$labels['savedsearches'] = 'Kaydedilmiş aramalar';
$labels['dateformatY'] = 'YYYY';
$labels['dateformaty'] = 'YY';
$labels['dateformatm'] = 'AA';
$labels['dateformatd'] = 'GG';
$labels['dateformatj'] = 'G';
$labels['dateformatn'] = 'A';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'İngilizce';
$labels['westerneuropean'] = 'Batı Avrupa';
$labels['easterneuropean'] = 'Doğu Avrupa';
$labels['southeasterneuropean'] = 'Güneydoğu Avrupa';
$labels['baltic'] = 'Baltık';
$labels['cyrillic'] = 'Kiril';
$labels['arabic'] = 'Arapça';
$labels['greek'] = 'Yunanca';
$labels['hebrew'] = 'İbranice';
$labels['turkish'] = 'Türkçe';
$labels['nordic'] = 'İskandinav';
$labels['thai'] = 'Tay Dili';
$labels['celtic'] = 'Keltik';
$labels['vietnamese'] = 'Vietnamca';
$labels['japanese'] = 'Japonca';
$labels['korean'] = 'Korece';
$labels['chinese'] = 'Çince';
$labels['arialabeltopnav'] = 'Pencere denetimi';
$labels['arialabeltasknav'] = 'Uygulama görevleri';
$labels['arialabeltoolbar'] = 'Uygulama araç çubuğu';
$labels['arialabellistnav'] = 'Liste gezinmesi';
$labels['arialabelactivetask'] = 'Etkin görevler';
$labels['arialabelmessagessearchfilter'] = 'İleti listeleme süzgeci';
$labels['arialabelmailsearchform'] = 'İleti arama formu';
$labels['arialabelcontactsearchform'] = 'Kişi arama formu';
$labels['arialabelmailquicksearchbox'] = 'İleti arama ifadesi';
$labels['arialabelquicksearchbox'] = 'Arama ifadesi';
$labels['arialabelfoldersearchfilter'] = 'Klasör listeleme süzgeci';
$labels['arialabelfoldersearchform'] = 'Klasör arama formu';
$labels['arialabelfolderlist'] = 'İleti klasörü seçimi';
$labels['arialabelmessagelist'] = 'İletileri listele';
$labels['arialabelmailpreviewframe'] = 'İleti ön izlemesi';
$labels['arialabelmailboxmenu'] = 'Klasör işlemleri menüsü';
$labels['arialabellistselectmenu'] = 'Liste seçme menüsü';
$labels['arialabelthreadselectmenu'] = 'Yazışma listeleme menüsü';
$labels['arialabelmessagelistoptions'] = 'İleti listesi görünüm ve sıralama ayarları';
$labels['arialabelmailimportdialog'] = 'İleti içe aktarma formu';
$labels['arialabelmessagenav'] = 'İleti gezinmesi';
$labels['arialabelmessagebody'] = 'İleti metni';
$labels['arialabelmessageactions'] = 'İleti işlemleri';
$labels['arialabelcontactquicksearch'] = 'Kişi arama formu';
$labels['arialabelcontactsearchbox'] = 'Kişi arama ifadesi';
$labels['arialabelmessageheaders'] = 'İleti üst bilgileri';
$labels['arialabelforwardingoptions'] = 'İletme ayarları';
$labels['arialabelreplyalloptions'] = 'Toplu yanıt ayarları';
$labels['arialabelmoremessageactions'] = 'Diğer ileti işlemleri';
$labels['arialabelmorecontactactions'] = 'Diğer kişi işlemleri';
$labels['arialabelmarkmessagesas'] = 'Seçilmiş iletileri şu şekilde işaretle...';
$labels['arialabelcomposeoptions'] = 'İleti hazırlama ayarları';
$labels['arialabelresponsesmenu'] = 'Hazır yanıtlar menüsü';
$labels['arialabelattachmentuploadform'] = 'Ek dosya yükleme formu';
$labels['arialabelattachmentmenu'] = 'Ek dosya ayarları';
$labels['arialabelmailtomenu'] = 'E-posta adresi ayarları';
$labels['arialabelattachmentpreview'] = 'Ek dosya ön izlemesi';
$labels['ariasummarycomposecontacts'] = 'Kişileri ve grupları alıcı olarak seçmek için listeleme';
$labels['arialabelcontactexportoptions'] = 'Kişi dışa aktarma ayarları';
$labels['arialabelabookgroupoptions'] = 'Adres defteri/grubu ayarları';
$labels['arialabelpreferencesform'] = 'Ayarlar formu';
$labels['arialabelidentityeditfrom'] = 'Kimlik düzenleme formu';
$labels['arialabelresponseeditfrom'] = 'Hazır yanıt düzenleme formu';
$labels['arialabelsearchterms'] = 'Arama ifadeleri';
$labels['arialabeldropactionmenu'] = 'Sürükle bırak işlemleri menüsü';
$labels['arialabelheadersmenu'] = 'Alıcı (üst bilgi) ekleme menüsü';
$labels['arialabelimagetools'] = 'Görsel araçları';
$labels['helplistnavigation'] = 'Tuş takımı ile gezinme listesi';
$labels['helplistkeyboardnavigation'] = "Yukarı / Aşağı ok: Satırı odağa ya da seçime taşır.
Boşluk: Odaklanılmış satırı seçer.
Shift + yukarı/aşağı ok: Yukarı ya da aşağı ek satır seçer.
Ctrl + Boşluk: Odaklanılmış satırı seçime ekler ya da çıkarır.";
$labels['helplistkeyboardnavmessages'] = "Sağ/Sol ok: İleti gruplarını genişletir ya da daraltır (yalnızca yazışma kipinde).
Enter: Seçilmiş ya da odaklanılmış iletiyi açar.
Delete: Seçilmiş iletiyi çöpe atar.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Seçilmiş ya da odaklanılmış kişiyi açar.";
