<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Bienvenue à $product';
$labels['username'] = 'Nom d’utilisateur';
$labels['password'] = 'Mot de passe';
$labels['server'] = 'Serveur';
$labels['login'] = 'Connexion';
$labels['oauthlogin'] = 'Connexion à $provider';
$labels['menu'] = 'Menu';
$labels['logout'] = 'Déconnexion';
$labels['mail'] = 'Courriel';
$labels['settings'] = 'Paramètres';
$labels['addressbook'] = 'Carnet d’adresses';
$labels['darkmode'] = 'Mode sombre';
$labels['lightmode'] = 'Mode clair';
$labels['inbox'] = 'Boîte de réception';
$labels['drafts'] = 'Brouillons';
$labels['sent'] = 'Envoyés';
$labels['trash'] = 'Corbeille';
$labels['junk'] = 'Pourriels';
$labels['show_real_foldernames'] = 'Montrer les noms réels des dossiers spéciaux';
$labels['subject'] = 'Objet';
$labels['from'] = 'De';
$labels['sender'] = 'Expéditeur';
$labels['to'] = 'À';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Cci';
$labels['replyto'] = 'Répondre à';
$labels['followupto'] = 'Faire suivre à';
$labels['date'] = 'Date';
$labels['size'] = 'Taille';
$labels['priority'] = 'Priorité';
$labels['organization'] = 'Organisation';
$labels['readstatus'] = 'État de lecture';
$labels['listoptions'] = 'Options de liste…';
$labels['listoptionstitle'] = 'Options de liste';
$labels['mailboxlist'] = 'Dossiers';
$labels['messagesfromto'] = 'Courriels de $from à $to sur $count';
$labels['threadsfromto'] = 'Fils de $from à $to sur $count';
$labels['messagenrof'] = 'Courriel $nr sur $count';
$labels['fromtoshort'] = '$from – $to de $count';
$labels['copy'] = 'Copier';
$labels['move'] = 'Déplacer';
$labels['moveto'] = 'Déplacer vers…';
$labels['copyto'] = 'Copier vers…';
$labels['download'] = 'Télécharger';
$labels['open'] = 'Ouvrir';
$labels['showattachment'] = 'Afficher';
$labels['showanyway'] = 'Afficher quand même';
$labels['filename'] = 'Nom du fichier';
$labels['filesize'] = 'Taille du fichier';
$labels['addtoaddressbook'] = 'Ajouter au carnet d’adresses';
$labels['sun'] = 'Dim';
$labels['mon'] = 'Lun';
$labels['tue'] = 'Mar';
$labels['wed'] = 'Mer';
$labels['thu'] = 'Jeu';
$labels['fri'] = 'Ven';
$labels['sat'] = 'Sam';
$labels['sunday'] = 'Dimanche';
$labels['monday'] = 'Lundi';
$labels['tuesday'] = 'Mardi';
$labels['wednesday'] = 'Mercredi';
$labels['thursday'] = 'Jeudi';
$labels['friday'] = 'Vendredi';
$labels['saturday'] = 'Samedi';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Fév';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Avr';
$labels['may'] = 'Mai';
$labels['jun'] = 'Jun';
$labels['jul'] = 'Jul';
$labels['aug'] = 'Aoû';
$labels['sep'] = 'Sep';
$labels['oct'] = 'Oct';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Déc';
$labels['longjan'] = 'Janvier';
$labels['longfeb'] = 'Février';
$labels['longmar'] = 'Mars';
$labels['longapr'] = 'Avril';
$labels['longmay'] = 'Mai';
$labels['longjun'] = 'Juin';
$labels['longjul'] = 'Juillet';
$labels['longaug'] = 'Août';
$labels['longsep'] = 'Septembre';
$labels['longoct'] = 'Octobre';
$labels['longnov'] = 'Novembre';
$labels['longdec'] = 'Décembre';
$labels['today'] = 'Aujourd’hui';
$labels['refresh'] = 'Actualiser';
$labels['checkmail'] = 'Relever les nouveaux courriels';
$labels['compose'] = 'Rédiger';
$labels['writenewmessage'] = 'Créer un nouveau courriel';
$labels['reply'] = 'Répondre';
$labels['replytomessage'] = 'Répondre à l’expéditeur';
$labels['replytoallmessage'] = 'Répondre à la liste ou à l’expéditeur et à tous les destinataires';
$labels['replyall'] = 'Répondre à tous';
$labels['replylist'] = 'Répondre à la liste';
$labels['forward'] = 'Transférer';
$labels['forwardinline'] = 'Transférer dans le courriel';
$labels['forwardattachment'] = 'Transférer comme pièce jointe';
$labels['forwardmessage'] = 'Transférer le courriel';
$labels['bouncemsg'] = 'Renvoyer (retourné)';
$labels['bounce'] = 'Renvoyer';
$labels['deletemessage'] = 'Supprimer le courriel';
$labels['movemessagetotrash'] = 'Déplacer le courriel vers la corbeille';
$labels['printmessage'] = 'Imprimer ce courriel';
$labels['previousmessage'] = 'Afficher le courriel précédent';
$labels['firstmessage'] = 'Afficher le premier courriel';
$labels['nextmessage'] = 'Afficher le courriel suivant';
$labels['lastmessage'] = 'Afficher le dernier courriel';
$labels['backtolist'] = 'Retourner à la liste des courriels';
$labels['viewsource'] = 'Afficher la source';
$labels['mark'] = 'Marquer';
$labels['markmessages'] = 'Marquer les courriels';
$labels['markread'] = 'Comme lu';
$labels['markunread'] = 'Comme non lu';
$labels['markflagged'] = 'Comme signalé';
$labels['markunflagged'] = 'Comme non signalé';
$labels['markundeleted'] = 'Comme non supprimé';
$labels['moreactions'] = 'Plus d’actions…';
$labels['markallread'] = 'Tout marquer comme lu';
$labels['folders-cur'] = 'Dossier sélectionné seulement';
$labels['folders-sub'] = 'Dossier sélectionné et ses sous-dossiers';
$labels['folders-all'] = 'Tous les dossiers';
$labels['more'] = 'Plus';
$labels['back'] = 'Retour';
$labels['options'] = 'Options';
$labels['composeoptions'] = 'Options de rédaction';
$labels['optionsandattachments'] = 'Options et pièces jointes';
$labels['actions'] = 'Actions';
$labels['first'] = 'Premier';
$labels['last'] = 'Dernier';
$labels['previous'] = 'Précédent';
$labels['next'] = 'Suivant';
$labels['select'] = 'Sélectionner';
$labels['selection'] = 'Sélection';
$labels['all'] = 'Tous';
$labels['none'] = 'Aucun';
$labels['currpage'] = 'Page courante';
$labels['isread'] = 'Lu';
$labels['unread'] = 'Non lu';
$labels['flagged'] = 'Signalé';
$labels['unflagged'] = 'Non signalé';
$labels['unanswered'] = 'Sans réponse';
$labels['withattachment'] = 'Avec pièce jointe';
$labels['deleted'] = 'Supprimé';
$labels['undeleted'] = 'Non supprimé';
$labels['replied'] = 'Réponse faite';
$labels['forwarded'] = 'Transféré';
$labels['invert'] = 'Inverser';
$labels['filter'] = 'Filtrer';
$labels['list'] = 'Liste';
$labels['threads'] = 'Fils';
$labels['expand-all'] = 'Tout afficher';
$labels['expand-unread'] = 'Afficher les non lus';
$labels['collapse-all'] = 'Fermer tous';
$labels['threaded'] = 'Par fil';
$labels['showunread'] = 'Afficher les courriels non lus';
$labels['autoexpand_threads'] = 'Développer les fils de courriel';
$labels['do_expand'] = 'Tous les fils';
$labels['expand_only_unread'] = 'seulement avec des courriels non lus';
$labels['fromto'] = 'De/À';
$labels['flag'] = 'Signaler';
$labels['attachment'] = 'Pièce jointe';
$labels['nonesort'] = 'Aucun';
$labels['sentdate'] = 'Date d’envoi';
$labels['arrival'] = 'Date d’arrivée';
$labels['asc'] = 'ascendant';
$labels['desc'] = 'descendant';
$labels['listcolumns'] = 'Colonnes de la liste';
$labels['listsorting'] = 'Colonne de tri';
$labels['listorder'] = 'Ordre de tri';
$labels['listmode'] = 'Mode d’affichage en liste';
$labels['lmode'] = 'Mode de listage';
$labels['layout'] = 'Disposition';
$labels['layoutwidescreen'] = 'Écran large';
$labels['layoutdesktop'] = 'Bureau';
$labels['layoutlist'] = 'Liste';
$labels['layoutwidescreendesc'] = 'Écran large (vue sur 3 colonnes)';
$labels['layoutdesktopdesc'] = 'Bureau (liste large et aperçu des courriels dessous)';
$labels['layoutlistdesc'] = 'Liste (pas d’aperçu des courriels)';
$labels['folderactions'] = 'Actions sur les dossiers…';
$labels['compact'] = 'Compacter';
$labels['empty'] = 'Vider';
$labels['importmessages'] = 'Importer des courriels';
$labels['mailimportdesc'] = 'Vous pouvez téléverser des courriels en utilisant des fichiers au format <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> ou <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>.';
$labels['mailimportzip'] = 'Les fichiers multiples peuvent être compressés en fichiers zip.';
$labels['quota'] = 'Utilisation du disque';
$labels['unknown'] = 'inconnue';
$labels['unlimited'] = 'illimitée';
$labels['quotatype'] = 'Type de quota';
$labels['quotatotal'] = 'Limite';
$labels['quotaused'] = 'Utilisé';
$labels['quotastorage'] = 'Espace disque';
$labels['quotamessage'] = 'Nombre de courriels';
$labels['shortheaderdate'] = 'Le $date';
$labels['shortheaderto'] = 'À $to, le $date';
$labels['shortheaderfrom'] = 'De $from, le $date';
$labels['quicksearch'] = 'Recherche rapide';
$labels['searchplaceholder'] = 'Recherche…';
$labels['resetsearch'] = 'Réinitialiser la recherche';
$labels['searchmod'] = 'Modificateurs de recherche';
$labels['msgtext'] = 'Courriel entier';
$labels['body'] = 'Corps';
$labels['type'] = 'Type';
$labels['namex'] = 'Nom';
$labels['searchscope'] = 'Portée';
$labels['currentfolder'] = 'Répertoire actuel';
$labels['subfolders'] = 'Ceci et les sous-dossiers';
$labels['allfolders'] = 'Tous les dossiers';
$labels['searchinterval-1W'] = 'plus d’une semaine';
$labels['searchinterval-1M'] = 'plus d’un mois';
$labels['searchinterval-1Y'] = 'plus d’une année';
$labels['searchinterval1W'] = 'moins d’une semaine';
$labels['searchinterval1M'] = 'moins d’un mois';
$labels['searchinterval1Y'] = 'moins d’une année';
$labels['openinextwin'] = 'Ouvrir dans une nouvelle fenêtre';
$labels['emlsave'] = 'Télécharger (.eml)';
$labels['changeformattext'] = 'Afficher au format texte en clair';
$labels['changeformathtml'] = 'Afficher au format HTML';
$labels['editasnew'] = 'Éditer comme nouveau';
$labels['send'] = 'Envoyer';
$labels['sendmessage'] = 'Envoyer un courriel';
$labels['savemessage'] = 'Enregistrer comme brouillon';
$labels['addattachment'] = 'Joindre un fichier';
$labels['charset'] = 'Jeu de caractères';
$labels['editortype'] = 'Type d’éditeur';
$labels['returnreceipt'] = 'Avis d’ouverture du courriel';
$labels['dsn'] = 'Notification d’état de distribution';
$labels['keepformatting'] = 'Garder le format';
$labels['mailreplyintro'] = 'Le $date, $sender a écrit :';
$labels['originalmessage'] = 'Courriel original';
$labels['selectimage'] = 'Sélectionner l’image';
$labels['addimage'] = 'Ajouter une image';
$labels['selectmedia'] = 'Choisir un film';
$labels['addmedia'] = 'Ajouter un film';
$labels['encrypt'] = 'Chiffrer';
$labels['encryptmessage'] = 'Chiffrer le message';
$labels['encryptmessagemailvelope'] = 'Chiffrer le message avec Mailvelope';
$labels['importpubkeys'] = 'Importer des clés publiques';
$labels['encryptedsendialog'] = 'Envoi du message chiffré';
$labels['encryptandsign'] = 'Chiffrer et signer';
$labels['keyid'] = 'ID de la clé';
$labels['keylength'] = 'bits';
$labels['keyexpired'] = 'Expirée';
$labels['keyrevoked'] = 'Révoquée';
$labels['bccinstead'] = 'Utiliser la Cci';
$labels['addheader'] = 'Ajouter un destinataire (en-tête)';
$labels['insert'] = 'Insérer';
$labels['insertcontact'] = 'Insérer des contacts';
$labels['recipient'] = 'Destinataire';
$labels['recipientedit'] = 'Modification du destinataire';
$labels['editidents'] = 'Éditer les identités';
$labels['spellcheck'] = 'Orthographe';
$labels['checkspelling'] = 'Vérification de l’orthographe';
$labels['resumeediting'] = 'Retourner à l’édition';
$labels['revertto'] = 'Revenir à';
$labels['restore'] = 'Restaurer';
$labels['restoremessage'] = 'Restaurer le courriel ?';
$labels['ignore'] = 'Ignorer';
$labels['responses'] = 'Réponses';
$labels['insertresponse'] = 'Insérer une réponse';
$labels['manageresponses'] = 'Gérer les réponses';
$labels['newresponse'] = 'Créer une nouvelle réponse';
$labels['addresponse'] = 'Ajouter une réponse';
$labels['editresponse'] = 'Éditer la réponse';
$labels['editresponses'] = 'Éditer les réponses';
$labels['responsename'] = 'Nom';
$labels['responsetext'] = 'Texte de la réponse';
$labels['attach'] = 'Joindre';
$labels['attachments'] = 'Pièces jointes';
$labels['upload'] = 'Téléverser';
$labels['uploadprogress'] = '$percent ($current de $total)';
$labels['close'] = 'Fermer';
$labels['messageoptions'] = 'Options de courriel…';
$labels['togglecomposeoptions'] = 'Activer/désactiver les options de rédaction';
$labels['attachmentrename'] = 'Renommer la pièce jointe';
$labels['low'] = 'Basse';
$labels['lowest'] = 'La plus basse';
$labels['normal'] = 'Normale';
$labels['high'] = 'Élevée';
$labels['highest'] = 'La plus élevée';
$labels['nosubject'] = '(pas d’objet)';
$labels['showimages'] = 'Afficher les images';
$labels['allow'] = 'Autoriser';
$labels['alwaysshow'] = 'Toujours afficher les images de $sender';
$labels['alwaysallow'] = 'Toujours autoriser de $sender';
$labels['isdraft'] = 'Ceci est un brouillon.';
$labels['andnmore'] = '$nr de plus…';
$labels['details'] = 'Détails';
$labels['summary'] = 'Résumé';
$labels['headers'] = 'En-têtes';
$labels['allheaders'] = 'Tous les en-têtes…';
$labels['togglemoreheaders'] = 'Afficher plus d’en-têtes de courriels';
$labels['togglefullheaders'] = 'Afficher/masquer les en-têtes brutes de courriels';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Texte en clair';
$labels['savesentmessagein'] = 'Enregistrer le courriel envoyé dans';
$labels['dontsave'] = 'ne pas enregistrer';
$labels['maxuploadsize'] = 'La taille de fichier maximum autorisée est $size';
$labels['addcc'] = 'Ajouter Cc';
$labels['addbcc'] = 'Ajouter une Cci';
$labels['addreplyto'] = 'Ajouter Répondre à';
$labels['addfollowupto'] = 'Ajouter Transférer à';
$labels['sendreceipt'] = 'Envoyer un avis de lecture ?';
$labels['mdnrequest'] = 'L’expéditeur de ce courriel a demandé d’être prévenu quand vous le lirez. Voulez-vous prévenir l’expéditeur ?';
$labels['receiptread'] = 'Avis d’ouverture du courriel (lu)';
$labels['yourmessage'] = 'Ceci est un avis d’ouverture de votre courriel';
$labels['receiptnote'] = 'Note : Cet avis indique seulement que le courriel a été affiché sur l’ordinateur du destinataire. Il n’y a aucune garantie que le destinataire ait lu ou compris le contenu du courriel.';
$labels['sendalwaysto'] = 'Toujours envoyer à $email';
$labels['zoomin'] = 'Zoom avant';
$labels['zoomout'] = 'Zoom arrière';
$labels['rotate'] = 'Rotation';
$labels['increaseimage'] = 'Augmenter la taille de l’image';
$labels['decreaseimage'] = 'Diminuer la taille de l’image';
$labels['rotateimage'] = 'Pivoter l’image';
$labels['showtools'] = 'Afficher les outils de manipulation des images';
$labels['hidetools'] = 'Cacher les outils de manipulation des images';
$labels['name'] = 'Nom d’affichage';
$labels['firstname'] = 'Prénom';
$labels['surname'] = 'Nom de famille';
$labels['middlename'] = 'Second prénom';
$labels['nameprefix'] = 'Préfixe';
$labels['namesuffix'] = 'Suffixe';
$labels['nickname'] = 'Surnom';
$labels['jobtitle'] = 'Appellation d’emploi';
$labels['department'] = 'Service';
$labels['gender'] = 'Sexe';
$labels['maidenname'] = 'Nom de jeune fille';
$labels['email'] = 'Courriel';
$labels['phone'] = 'Téléphone';
$labels['address'] = 'Adresse';
$labels['street'] = 'Rue';
$labels['locality'] = 'Ville';
$labels['zipcode'] = 'Code postal';
$labels['region'] = 'État/province/région';
$labels['country'] = 'Pays';
$labels['birthday'] = 'Date de naissance';
$labels['anniversary'] = 'Anniversaire';
$labels['website'] = 'Site Web';
$labels['instantmessenger'] = 'MI';
$labels['notes'] = 'Notes';
$labels['male'] = 'homme';
$labels['female'] = 'femme';
$labels['manager'] = 'Gestionnaire';
$labels['assistant'] = 'Assistant';
$labels['spouse'] = 'Conjoint/conjointe';
$labels['allfields'] = 'Tous les champs';
$labels['search'] = 'Recherche';
$labels['searchresult'] = 'Résultat de la recherche';
$labels['advsearch'] = 'Recherche avancée';
$labels['advanced'] = 'Détails';
$labels['other'] = 'Autre';
$labels['printcontact'] = 'Imprimer le contact';
$labels['qrcode'] = 'Code QR';
$labels['typehome'] = 'Domicile';
$labels['typework'] = 'Travail';
$labels['typeother'] = 'Autre';
$labels['typemobile'] = 'Téléphone mobile';
$labels['typemain'] = 'Principale';
$labels['typehomefax'] = 'Fax personnel';
$labels['typeworkfax'] = 'Fax professionnel';
$labels['typecar'] = 'Voiture';
$labels['typepager'] = 'Téléavertisseur';
$labels['typevideo'] = 'Vidéo';
$labels['typeassistant'] = 'Assistant';
$labels['typehomepage'] = 'Page d’accueil';
$labels['typeblog'] = 'Blogue';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Ajouter un champ…';
$labels['addcontact'] = 'Ajouter un contact';
$labels['editcontact'] = 'Modifier le contact';
$labels['contacts'] = 'Contacts';
$labels['contactproperties'] = 'Propriétés du contact';
$labels['contactnameandorg'] = 'Nom et organisation';
$labels['personalinfo'] = 'Renseignements personnels';
$labels['personal'] = 'Personnel';
$labels['contactphoto'] = 'Photo du contact';
$labels['edit'] = 'Modifier';
$labels['cancel'] = 'Annuler';
$labels['save'] = 'Enregistrer';
$labels['delete'] = 'Supprimer';
$labels['discard'] = 'Supprimer';
$labels['continue'] = 'Continuer';
$labels['ok'] = 'OK';
$labels['rename'] = 'Renommer';
$labels['addphoto'] = 'Ajouter';
$labels['replacephoto'] = 'Remplacer';
$labels['uploadphoto'] = 'Téléverser une photo';
$labels['choosefile'] = 'Choisir un fichier…';
$labels['choosefiles'] = 'Choisir des fichiers…';
$labels['browse'] = 'Parcourir';
$labels['newcontact'] = 'Créer un nouveau contact';
$labels['deletecontact'] = 'Supprimer les contacts sélectionnés';
$labels['composeto'] = 'Rédiger un courriel à';
$labels['contactsfromto'] = 'Contacts de $from à $to sur $count';
$labels['print'] = 'Imprimer';
$labels['export'] = 'Exporter';
$labels['exportall'] = 'Tout exporter';
$labels['exportsel'] = 'Exporter la sélection';
$labels['exportvcards'] = 'Exporter les contacts au format vCard';
$labels['newgroup'] = 'Créer un nouveau groupe';
$labels['addgroup'] = 'Ajouter un groupe';
$labels['grouprename'] = 'Renommer le groupe';
$labels['groupdelete'] = 'Supprimer le groupe';
$labels['groupassign'] = 'Affecter au groupe…';
$labels['groupremove'] = 'Supprimer du groupe';
$labels['groupremoveselected'] = 'Retirer les contacts sélectionnés du groupe';
$labels['uponelevel'] = 'Monter d’un niveau';
$labels['previouspage'] = 'Afficher page précédente';
$labels['firstpage'] = 'Afficher la première page';
$labels['nextpage'] = 'Afficher la page suivante';
$labels['lastpage'] = 'Afficher la dernière page';
$labels['group'] = 'Groupe';
$labels['groups'] = 'Groupes';
$labels['listgroup'] = 'Lister les membres du groupe';
$labels['personaladrbook'] = 'Adresses personnelles';
$labels['searchsave'] = 'Enregistrer la recherche';
$labels['searchdelete'] = 'Supprimer la recherche';
$labels['import'] = 'Importer';
$labels['importcontacts'] = 'Importer les contacts';
$labels['importfromfile'] = 'Importer d’un fichier';
$labels['importtarget'] = 'Ajouter les contacts à';
$labels['importreplace'] = 'Remplacer le carnet d’adresses entier';
$labels['importgroups'] = 'Importer les affectations de groupe';
$labels['importgroupsall'] = 'Tous (créer les groupes si nécessaire)';
$labels['importgroupsexisting'] = 'Seulement pour les groupes existants';
$labels['importdesc'] = 'Vous pouvez téléverser des contacts à partir d’un carnet d’adresses existant.<br/>Nous prenons actuellement en charge l’importation d’adresses à partir des format de données <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> ou CSV (séparé par des virgules).';
$labels['importmapdesc'] = 'Confirmez que les renseignements de mappage des champs ci-dessous sont justes avant de poursuivre avec l’importation de données séparées par des virgules (CSV)';
$labels['fieldnotmapped'] = 'Le champ n’est pas mappé (ne pas importer)';
$labels['skipheader'] = 'Ne pas importer la première ligne (en-têtes)';
$labels['done'] = 'Terminé';
$labels['settingsfor'] = 'Paramètres pour';
$labels['about'] = 'À propos de';
$labels['preferences'] = 'Préférences';
$labels['userpreferences'] = 'Préférences utilisateur';
$labels['editpreferences'] = 'Modifier les préférences utilisateur';
$labels['identities'] = 'Identités';
$labels['manageidentities'] = 'Gérer les identités';
$labels['newidentity'] = 'Créer une nouvelle identité';
$labels['addidentity'] = 'Ajouter une identité';
$labels['editidentity'] = 'Modifier l’identité';
$labels['identityencryption'] = 'Chiffrement';
$labels['preferhtml'] = 'Afficher en HTML';
$labels['defaultcharset'] = 'Jeu de caractère par défaut';
$labels['htmlmessage'] = 'Courriel HTML';
$labels['messagepart'] = 'Partie';
$labels['digitalsig'] = 'Signature numérique';
$labels['dateformat'] = 'Format de date';
$labels['timeformat'] = 'Format horaire';
$labels['prettydate'] = 'Jolies dates';
$labels['setdefault'] = 'Définir par défaut';
$labels['autodetect'] = 'Automatique';
$labels['language'] = 'Langue';
$labels['timezone'] = 'Fuseau horaire';
$labels['pagesize'] = 'Lignes par page';
$labels['signature'] = 'Signature';
$labels['dstactive'] = 'Heure avancée';
$labels['showinextwin'] = 'Ouvrir le courriel dans une nouvelle fenêtre';
$labels['composeextwin'] = 'Rédiger dans une nouvelle fenêtre';
$labels['htmleditor'] = 'Rédiger des courriels HTML';
$labels['htmlonreply'] = 'en réponse à un courriel en HTML';
$labels['htmlonreplyandforward'] = 'lors d’un transfert ou en réponse à un courriel en HTML';
$labels['htmlsignature'] = 'Signature HTML';
$labels['showemail'] = 'Montrer l’adresse courriel avec le nom d’affichage';
$labels['previewpane'] = 'Montrer le volet de prévisualisation';
$labels['skin'] = 'Habillage de l’interface';
$labels['logoutclear'] = 'Vider la corbeille à la déconnexion';
$labels['logoutcompact'] = 'Compacter la boîte de réception à la déconnexion';
$labels['uisettings'] = 'Interface utilisateur';
$labels['serversettings'] = 'Paramètres du serveur';
$labels['mailboxview'] = 'Vue de la boîte de courriel';
$labels['mdnrequests'] = 'À la demande d’avis d’ouverture du courriel';
$labels['askuser'] = 'me demander';
$labels['autosend'] = 'envoyer un avis';
$labels['autosendknown'] = 'envoyer un avis à mes contacts, sinon me demander';
$labels['autosendknownignore'] = 'envoyer un avis à mes contacts, sinon ignorer';
$labels['autosendtrusted'] = 'envoyer un avis aux expéditeurs de confiance, sinon me demander';
$labels['autosendtrustedignore'] = 'envoyer un avis aux expéditeurs de confiance, sinon ignorer';
$labels['ignorerequest'] = 'ignorer la demande';
$labels['readwhendeleted'] = 'Marquer le courriel comme lu lors de la suppression';
$labels['flagfordeletion'] = 'Signaler le courriel pour la suppression au lieu de le supprimer';
$labels['skipdeleted'] = 'Ne pas montrer les courriels supprimés';
$labels['deletealways'] = 'Si le déplacement des courriels à la corbeille échoue, les supprimer';
$labels['deletejunk'] = 'Supprimer directement les pourriels';
$labels['showremoteimages'] = 'Afficher les images distantes des courriels';
$labels['allowremoteresources'] = 'Autoriser les ressources distantes (images, styles)';
$labels['fromknownsenders'] = 'd’expéditeurs connus';
$labels['fromtrustedsenders'] = 'd’expéditeurs de confiance';
$labels['frommycontacts'] = 'de mes contacts';
$labels['always'] = 'toujours';
$labels['alwaysbutplain'] = 'toujours, sauf lors d’une réponse à un texte en clair';
$labels['showinlineimages'] = 'Afficher les images jointes sous le courriel';
$labels['autosavedraft'] = 'Enregistrer automatiquement un brouillon';
$labels['everynminutes'] = 'toutes les $n minute(s)';
$labels['refreshinterval'] = 'Actualiser (relever les nouveaux courriels, etc.)';
$labels['never'] = 'jamais';
$labels['immediately'] = 'Immédiatement';
$labels['messagesdisplaying'] = 'Affichage des courriels';
$labels['messagescomposition'] = 'Rédaction de courriels';
$labels['mimeparamfolding'] = 'Noms des pièces jointes';
$labels['2231folding'] = 'RFC 2231 complet (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'RFC 2047 complet (autre)';
$labels['force7bit'] = 'Utiliser l’encodage MIME pour les caractères 8 bits';
$labels['savelocalstorage'] = "Enregistrer dans le stockage local du navigateur (temporaire)";
$labels['advancedoptions'] = 'Options avancées';
$labels['toggleadvancedoptions'] = 'Activer/désactiver les options avancées';
$labels['focusonnewmessage'] = 'Cibler la fenêtre du navigateur quand un nouveau courriel arrive';
$labels['checkallfolders'] = 'Vérifier les nouveaux courriels dans tous les dossiers';
$labels['displaynext'] = 'Afficher la prochaine entrée de la liste après suppression ou déplacement';
$labels['defaultfont'] = 'Police par défaut des courriels HTML';
$labels['mainoptions'] = 'Options principales';
$labels['browseroptions'] = 'Options du navigateur';
$labels['section'] = 'Section';
$labels['maintenance'] = 'Maintenance';
$labels['newmessage'] = 'Nouveau courriel';
$labels['signatureoptions'] = 'Options de signature';
$labels['whenreplying'] = 'Lors d’une réponse';
$labels['replyempty'] = 'ne pas citer le courriel original';
$labels['replytopposting'] = 'commencer le nouveau courriel au-dessus de la citation';
$labels['replytoppostingnoindent'] = 'commencer le nouveau courriel au-dessus de la citation (sans indentation)';
$labels['replybottomposting'] = 'commencer le nouveau courriel en-dessous de la citation';
$labels['replyremovesignature'] = 'Lors de la réponse, supprimer la signature originale du courriel ';
$labels['autoaddsignature'] = 'Ajouter la signature automatiquement';
$labels['newmessageonly'] = 'nouveau courriel seulement';
$labels['replyandforwardonly'] = 'réponses et transferts seulement';
$labels['insertsignature'] = 'Insérer la signature';
$labels['sigbelow'] = 'Placer la signature sous le message cité';
$labels['sigseparator'] = 'Forcer le séparateur standard dans les signatures';
$labels['automarkread'] = 'Marquer les courriels comme lus';
$labels['afternseconds'] = 'après $n secondes';
$labels['reqmdn'] = 'Toujours demander un avis d’ouverture du courriel';
$labels['reqdsn'] = 'Toujours demander une notification d’état de distribution';
$labels['replysamefolder'] = 'Placer les réponses dans le dossier du courriel auquel on répond';
$labels['defaultabook'] = 'Carnet d’adresses par défaut';
$labels['autocompletesingle'] = 'Ignorer les adresses de courriel alternatives pour le remplissage automatique';
$labels['listnamedisplay'] = 'Lister les contacts en tant que';
$labels['contactformmode'] = 'Mode du formulaire de contact';
$labels['privatemode'] = 'Privé (domicile)';
$labels['businessmode'] = 'Entreprise (travail)';
$labels['collectedaddresses'] = 'Adresses recueillies';
$labels['collectedrecipients'] = 'Destinataires recueillis';
$labels['collectedrecipientsopt'] = 'Enregistrer les destinataires des courriels sortants dans';
$labels['collectedsendersopt'] = 'Enregistrer les expéditeurs de confiance dans';
$labels['trustedsenders'] = 'Expéditeurs de confiance';
$labels['spellcheckbeforesend'] = 'Vérifier l’orthographe avant d’envoyer un courriel';
$labels['spellcheckoptions'] = 'Options du vérificateur d’orthographe';
$labels['spellcheckignoresyms'] = 'Ignorer les mots avec des symboles';
$labels['spellcheckignorenums'] = 'Ignorer les mots avec des nombres';
$labels['spellcheckignorecaps'] = 'Ignorer les mots entièrement en majuscule';
$labels['addtodict'] = 'Ajouter au dictionnaire';
$labels['mailtoprotohandler'] = 'Enregistrer le gestionnaire de protocole pour les liens mailto:';
$labels['standardwindows'] = 'Gérer les fenêtres surgissantes comme les autres';
$labels['forwardmode'] = 'Transfert de courriels';
$labels['inline'] = 'dans le courriel';
$labels['asattachment'] = 'en pièce jointe';
$labels['replyallmode'] = 'Action par défaut du bouton [Répondre à tous]';
$labels['replyalldefault'] = 'répondre à tous';
$labels['replyalllist'] = 'répondre seulement à la liste de diffusion (si trouvée)';
$labels['allmessages'] = 'tous les courriels';
$labels['olderxdays'] = 'de plus de $x jours';
$labels['folder'] = 'Dossier';
$labels['folders'] = 'Dossiers';
$labels['foldername'] = 'Nom du dossier';
$labels['subscribed'] = 'Abonné';
$labels['messagecount'] = 'Courriels';
$labels['create'] = 'Créer';
$labels['createfolder'] = 'Créer un nouveau dossier';
$labels['managefolders'] = 'Gérer les dossiers';
$labels['specialfolders'] = 'Dossiers spéciaux';
$labels['properties'] = 'Propriétés';
$labels['folderproperties'] = 'Propriétés du dossier';
$labels['parentfolder'] = 'Dossier parent';
$labels['location'] = 'Emplacement';
$labels['info'] = 'Renseignements';
$labels['getfoldersize'] = 'Cliquer pour obtenir la taille de dossier';
$labels['changesubscription'] = 'Cliquer pour modifier l’abonnement';
$labels['foldertype'] = 'Type de dossier';
$labels['personalfolder'] = 'Dossier privé';
$labels['otherfolder'] = 'Dossier d’autres utilisateurs';
$labels['sharedfolder'] = 'Dossier public';
$labels['findfolders'] = 'Trouver des dossiers';
$labels['findcontacts'] = 'Trouver des contacts';
$labels['findmail'] = 'Trouver des courriels';
$labels['namespace.personal'] = 'Personnel';
$labels['namespace.other'] = 'Autres utilisateurs';
$labels['namespace.shared'] = 'Partagé';
$labels['dualuselabel'] = 'Peut seulement contenir des';
$labels['dualusemail'] = 'messages';
$labels['dualusefolder'] = 'dossiers';
$labels['generate'] = 'Générer';
$labels['encryptioncreatekey'] = 'Créer une nouvelle biclé';
$labels['openmailvelopesettings'] = 'Ouvrir les paramètres de Mailvelope';
$labels['encryptionprivkeysinmailvelope'] = 'Vous avez $nr clés PGP privées correspondantes enregistrées dans votre trousseau Mailvelope :';
$labels['encryptionnoprivkeysinmailvelope'] = 'Cette identité d’expéditeur n’a pas encore de clé PGP privée enregistrée dans votre trousseau Mailvelope. Voulez-vous en créer une afin de permettre l’envoi de courriel chiffré ?';
$labels['encryption'] = 'Chiffrement';
$labels['mailvelopeoptions'] = 'Options de Mailvelope';
$labels['mailvelopemainkeyring'] = 'Utiliser le trousseau principal de Mailvelope';
$labels['mailvelopenotfound'] = 'L’extension Mailvelope n’est pas activée ou installée dans votre navigateur.';
$labels['sortby'] = 'Trier par';
$labels['sortasc'] = 'Tri ascendant';
$labels['sortdesc'] = 'Tri descendant';
$labels['undo'] = 'Annuler';
$labels['installedplugins'] = 'Plugiciels installés';
$labels['plugin'] = 'Plugiciel';
$labels['version'] = 'Version';
$labels['source'] = 'Source';
$labels['destination'] = 'Destination';
$labels['license'] = 'Licence';
$labels['support'] = 'Obtenir du soutien';
$labels['savedsearches'] = 'Recherches enregistrées';
$labels['dateformatY'] = 'AAAA';
$labels['dateformaty'] = 'AA';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'JJ';
$labels['dateformatj'] = 'J';
$labels['dateformatn'] = 'M';
$labels['B'] = 'o';
$labels['KB'] = 'ko';
$labels['MB'] = 'Mo';
$labels['GB'] = 'Go';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Anglais';
$labels['westerneuropean'] = 'Europe de l’Ouest';
$labels['easterneuropean'] = 'Europe de l’Est';
$labels['southeasterneuropean'] = 'Europe du Sud-Est';
$labels['baltic'] = 'Baltique';
$labels['cyrillic'] = 'Cyrillique';
$labels['arabic'] = 'Arabe';
$labels['greek'] = 'Grec';
$labels['hebrew'] = 'Hébreu';
$labels['turkish'] = 'Turc';
$labels['nordic'] = 'Nordique';
$labels['thai'] = 'Thaï';
$labels['celtic'] = 'Celtique';
$labels['vietnamese'] = 'Vietnamien';
$labels['japanese'] = 'Japonais';
$labels['korean'] = 'Coréen';
$labels['chinese'] = 'Chinois';
$labels['arialabeltopnav'] = 'Contrôle de la fenêtre';
$labels['arialabeltasknav'] = 'Tâches de l’application';
$labels['arialabeltoolbar'] = 'Barre d’outils de l’application';
$labels['arialabellistnav'] = 'Navigation dans la liste';
$labels['arialabelactivetask'] = 'Tâche active';
$labels['arialabelmessagessearchfilter'] = 'Filtre de listage des courriels';
$labels['arialabelmailsearchform'] = 'Formulaire de recherche de courriels';
$labels['arialabelcontactsearchform'] = 'Formulaire de recherche des contacts';
$labels['arialabelmailquicksearchbox'] = 'Saisie de la recherche de courriels';
$labels['arialabelquicksearchbox'] = 'Saisie de la recherche';
$labels['arialabelfoldersearchfilter'] = 'Filtre de listage des dossiers';
$labels['arialabelfoldersearchform'] = 'Formulaire de recherche de dossiers';
$labels['arialabelfolderlist'] = 'Sélection du dossier des courriels';
$labels['arialabelmessagelist'] = 'Listage de courriels';
$labels['arialabelmailpreviewframe'] = 'Prévisualisation des courriels';
$labels['arialabelmailboxmenu'] = 'Menu d’actions sur les dossiers';
$labels['arialabellistselectmenu'] = 'Menu de sélection de la liste';
$labels['arialabelthreadselectmenu'] = 'Menu de listage des fils';
$labels['arialabelmessagelistoptions'] = 'Options d’affichage et de tri des listes de courriels';
$labels['arialabelmailimportdialog'] = 'Fenêtre d’importation des courriels';
$labels['arialabelmessagenav'] = 'Parcourir les courriels';
$labels['arialabelmessagebody'] = 'Corps du courriel';
$labels['arialabelmessageactions'] = 'Actions sur les courriels';
$labels['arialabelcontactquicksearch'] = 'Formulaire de recherche de contacts';
$labels['arialabelcontactsearchbox'] = 'Saisie de la recherche de contacts';
$labels['arialabelmessageheaders'] = 'En-tête des courriels';
$labels['arialabelforwardingoptions'] = 'Options de transfert';
$labels['arialabelreplyalloptions'] = 'Options de réponse à tous';
$labels['arialabelmoremessageactions'] = 'Actions de courriel supplémentaires';
$labels['arialabelmorecontactactions'] = 'Autres actions de contact';
$labels['arialabelmarkmessagesas'] = 'Marquer les courriels sélectionnés comme…';
$labels['arialabelcomposeoptions'] = 'Options de rédaction';
$labels['arialabelresponsesmenu'] = 'Menu des réponses prédéterminées';
$labels['arialabelattachmentuploadform'] = 'Formulaire de téléversement de pièce jointe';
$labels['arialabelattachmentmenu'] = 'Options des pièces jointes';
$labels['arialabelmailtomenu'] = 'Options d’adresse courriel';
$labels['arialabelattachmentpreview'] = 'Prévisualisation des pièces jointes';
$labels['ariasummarycomposecontacts'] = 'Liste des contacts et des groupes à sélectionner comme destinataires';
$labels['arialabelcontactexportoptions'] = 'Options d’exportation des contacts';
$labels['arialabelabookgroupoptions'] = 'Options du carnet d’adresses, de groupes';
$labels['arialabelpreferencesform'] = 'Formulaire des préférences';
$labels['arialabelidentityeditfrom'] = 'Formulaire de modification de l’identité';
$labels['arialabelresponseeditfrom'] = 'Formulaire de modification des réponses';
$labels['arialabelsearchterms'] = 'Termes de recherche';
$labels['arialabeldropactionmenu'] = 'Menu d’action coller-déposer';
$labels['arialabelheadersmenu'] = 'Menu d’ajout de destinataires (en-tête)';
$labels['arialabelimagetools'] = 'Outils de manipulation des images';
$labels['helplistnavigation'] = 'Navigation au clavier dans la liste';
$labels['helplistkeyboardnavigation'] = "Flèche haut/bas : déplacer la cible de sélection.
Espace : sélectionner la rangée ciblée.
Maj + haut/bas : Sélectionner des rangées supplémentaires
au dessus/en dessous.
Ctl + espace : ajouter la rangée ciblée à la sélection/enlever la rangée ciblée de la sélection.";
$labels['helplistkeyboardnavmessages'] = "Flèche droite/gauche : déplier/replier les fils de courriel (en mode fils seulement).
Entrée : ouvrir le courriel sélectionné/cible.
Suppr : déplacer les courriels sélectionnés vers la corbeille.";
$labels['helplistkeyboardnavcontacts'] = "Entrée : ouvrir le contact sélectionné/cible.";
