tinymce.addI18n('oc',{
"Redo": "Refar",
"Undo": "Desfar",
"Cut": "Talhar",
"Copy": "Copiar",
"Paste": "Pegar",
"Select all": "Seleccionar tot",
"New document": "Document nov\u00e8l",
"Ok": "D'ac\u00f2rdi",
"Cancel": "Anullar",
"Visual aids": "Ajudas visualas",
"Bold": "Gras",
"Italic": "Italica",
"Underline": "Solinhat",
"Strikethrough": "Ralhat",
"Superscript": "Exponent",
"Subscript": "Indici",
"Clear formatting": "Escafar la mesa en forma",
"Align left": "Alinhar a esqu\u00e8rra",
"Align center": "Alinhar al centre",
"Align right": "Alinhar a drecha",
"Justify": "Justificar",
"Bullet list": "Piuses",
"Numbered list": "Lista numerotada",
"Decrease indent": "Demesir l'alin\u00e8a",
"Increase indent": "Aumentar l'alin\u00e8a",
"Close": "Tampar",
"Formats": "Formats",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "V\u00f2stre navigador sup\u00f2rta pas la c\u00f2pia dir\u00e8cta. Merc\u00e9 d'utilizar las t\u00f2cas Ctrl+X\/C\/V.",
"Headers": "Ent\u00e8stas",
"Header 1": "Ent\u00e8sta 1",
"Header 2": "Ent\u00e8sta 2",
"Header 3": "Ent\u00e8sta 3",
"Header 4": "Ent\u00e8sta 4",
"Header 5": "Ent\u00e8sta 5",
"Header 6": "Ent\u00e8sta 6",
"Headings": "T\u00edtols",
"Heading 1": "T\u00edtol 1",
"Heading 2": "T\u00edtol 2",
"Heading 3": "T\u00edtol 3",
"Heading 4": "T\u00edtol 4",
"Heading 5": "T\u00edtol 5",
"Heading 6": "T\u00edtol 6",
"Preformatted": "Preformatat",
"Div": "Div",
"Pre": "Pre",
"Code": "C\u00f2de",
"Paragraph": "Paragraf",
"Blockquote": "Citacion",
"Inline": "En linha",
"Blocks": "Bl\u00f2ts",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Lo quichapapi\u00e8rs es ara en m\u00f2de \"t\u00e8xte plen\". Los contenguts ser\u00e0n pegats sens ret\u00e9ner los formatatges fins al moment que desactivaretz aquesta opcion.",
"Fonts": "Polissas",
"Font Sizes": "Talhas de poli\u00e7a",
"Class": "Class",
"Browse for an image": "Cercar un imatge",
"OR": "O",
"Drop an image here": "Depausatz un imatge aqu\u00ed",
"Upload": "Enviar",
"Block": "Bl\u00f2c",
"Align": "Alinhament",
"Default": "Per defaut",
"Circle": "Cercle",
"Disc": "Disc",
"Square": "Carrat",
"Lower Alpha": "Alfa minuscula",
"Lower Greek": "Gr\u00e8c minuscula",
"Lower Roman": "Roman minuscula",
"Upper Alpha": "Alfa majuscula",
"Upper Roman": "Roman majuscula",
"Anchor...": "Ancora...",
"Name": "Nom",
"Id": "Id",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "Los ID devon comen\u00e7ar amb una letra e \u00e8sser seguit per de letras, nombres, jonhent, punts o  punt-virgulas.",
"You have unsaved changes are you sure you want to navigate away?": "Av\u00e8tz de modificacions pas enregistradas, s\u00e8tz segur que vol\u00e8tz quitar la pagina ?",
"Restore last draft": "Restablir lo darri\u00e8r borrolhon",
"Special character...": "Caract\u00e8r especial...",
"Source code": "C\u00f2de font",
"Insert\/Edit code sample": "Inserir\/Modificar exemple de c\u00f2di",
"Language": "Lenga",
"Code sample...": "Exemple de c\u00f2di...",
"Color Picker": "Trapador de color",
"R": "R",
"G": "V",
"B": "B",
"Left to right": "D'esqu\u00e8rra cap a drecha",
"Right to left": "De drecha cap a esqu\u00e8rra",
"Emoticons...": "Emoticons...",
"Metadata and Document Properties": "Metadonadas e proprietats del document",
"Title": "T\u00edtol",
"Keywords": "Mots claus",
"Description": "Descripcion",
"Robots": "Rob\u00f2ts",
"Author": "Autor",
"Encoding": "Encodatge",
"Fullscreen": "Ecran complet",
"Action": "Accion",
"Shortcut": "Acorchi",
"Help": "Ajuda",
"Address": "Adre\u00e7as",
"Focus to menubar": "Focus to menubar",
"Focus to toolbar": "Focus to toolbar",
"Focus to element path": "Focus to element path",
"Focus to contextual toolbar": "Focus to contextual toolbar",
"Insert link (if link plugin activated)": "Inserir un ligam (se l\u2019extension Ligam es activada)",
"Save (if save plugin activated)": "Enregistrar (se l\u2019exension Enregistrar es activada)",
"Find (if searchreplace plugin activated)": "Cercar (se l\u2019extension Searchreplace es activada)",
"Plugins installed ({0}):": "Extensions installadas ({0})\u202f:",
"Premium plugins:": "Extensions Premium\u202f:",
"Learn more...": "Ne saber mai...",
"You are using {0}": "Utilizatz {0}",
"Plugins": "Extensions",
"Handy Shortcuts": "Acorchis utils",
"Horizontal line": "Linha orizontala",
"Insert\/edit image": "Inserir\/modificar un imatge",
"Image description": "Descripcion de l'imatge",
"Source": "Font",
"Dimensions": "Dimensions",
"Constrain proportions": "Conservar las proporcions",
"General": "General",
"Advanced": "Avan\u00e7at",
"Style": "Estil",
"Vertical space": "Espa\u00e7ament vertical",
"Horizontal space": "Espa\u00e7ament orizontal",
"Border": "Bordadura",
"Insert image": "Inserir un imatge",
"Image...": "Imatge...",
"Image list": "Lista d\u2019imatges",
"Rotate counterclockwise": "Rotacion anti-or\u00e0ria",
"Rotate clockwise": "Rotacion or\u00e0ria",
"Flip vertically": "Revirament vertical",
"Flip horizontally": "Revirament orizontal",
"Edit image": "Modificar l'imatge",
"Image options": "Opcions de l'imatge",
"Zoom in": "Zoom avant",
"Zoom out": "Zoom arri\u00e8r",
"Crop": "Retalhar",
"Resize": "Redimensionar",
"Orientation": "Orientacion",
"Brightness": "Luminositat",
"Sharpen": "Afinar",
"Contrast": "Contraste",
"Color levels": "Niv\u00e8ls de color",
"Gamma": "Gamma",
"Invert": "Inversar",
"Apply": "Aplicar",
"Back": "Retorn",
"Insert date\/time": "Inserir data\/ora",
"Date\/time": "Data\/ora",
"Insert\/Edit Link": "Inserir\/Modificar un ligam",
"Insert\/edit link": "Inserir\/modificar un ligam",
"Text to display": "T\u00e8xte d'afichar",
"Url": "Url",
"Open link in...": "Dobrir lo ligam dins...",
"Current window": "Fen\u00e8stra actuala",
"None": "Pas cap",
"New window": "Fen\u00e8stra nov\u00e8la",
"Remove link": "Suprimir lo ligam",
"Anchors": "Anc\u00f2ras",
"Link...": "Ligam...",
"Paste or type a link": "Pegatz o picatz un ligam",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Sembla que l'URL qu'av\u00e8tz entrada es una adre\u00e7a e-mail. Vol\u00e8tz apondre lo prefix mailto: necessari ?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Sembla que l'URL qu'av\u00e8tz entrada es un ligam ext\u00e8rne. Vol\u00e8tz apondre lo prefix http:\/\/ necessari ?",
"Link list": "Lista de ligams",
"Insert video": "Inserir una vid\u00e8o",
"Insert\/edit video": "Inserir\/modificar una vid\u00e8o",
"Insert\/edit media": "Inserir\/modificar un m\u00e8dia",
"Alternative source": "Font alternativa",
"Alternative source URL": "URL font alternativa",
"Media poster (Image URL)": "Media poster (Image URL)",
"Paste your embed code below:": "Pegatz v\u00f2tre c\u00f2di d'integracion \u00e7aij\u00f3s :",
"Embed": "Integrat",
"Media...": "M\u00e8dia...",
"Nonbreaking space": "Espaci insecable",
"Page break": "Pagina copada",
"Paste as text": "Pegar coma de t\u00e8xte",
"Preview": "Previsualizar",
"Print...": "Imprimir...",
"Save": "Enregistrar",
"Find": "Recercar",
"Replace with": "Rempla\u00e7ar per",
"Replace": "Rempla\u00e7ar",
"Replace all": "Rempla\u00e7ar tot",
"Previous": "Precedent",
"Next": "Seg",
"Find and replace...": "Trobar e rempla\u00e7ar...",
"Could not find the specified string.": "Impossible de trobar la cadena especificada.",
"Match case": "Respectar la cassa",
"Find whole words only": "Cercar mot enti\u00e8r sonque",
"Spell check": "Verificacion ortografica",
"Ignore": "Ignorar",
"Ignore all": "Ignorar tot",
"Finish": "Acabar",
"Add to Dictionary": "Apondre al diccionari",
"Insert table": "Inserir un tabl\u00e8u",
"Table properties": "Proprietats del tabl\u00e8u",
"Delete table": "Suprimir lo tabl\u00e8u",
"Cell": "Cellula",
"Row": "Linha",
"Column": "Colomna",
"Cell properties": "Proprietats de la cellula",
"Merge cells": "Fusionar las cellulas",
"Split cell": "Devesir la cellula",
"Insert row before": "Inserir una linha abans",
"Insert row after": "Inserir una linha apr\u00e8p",
"Delete row": "Suprimir la linha",
"Row properties": "Proprietats de la linha",
"Cut row": "Talhar la linha",
"Copy row": "Copiar la linha",
"Paste row before": "Pegar la linha abans",
"Paste row after": "Pegar la linha apr\u00e8p",
"Insert column before": "Inserir una colomna abans",
"Insert column after": "Inserir una colomna apr\u00e8p",
"Delete column": "Suprimir la colomna",
"Cols": "Colomnas",
"Rows": "Linhas",
"Width": "Largor",
"Height": "Nautor",
"Cell spacing": "Cell spacing",
"Cell padding": "Cell padding",
"Show caption": "Mostrar legenda",
"Left": "Esqu\u00e8rra",
"Center": "Centre",
"Right": "Drecha",
"Cell type": "Tipe de cellula",
"Scope": "Scope",
"Alignment": "Alinhament",
"H Align": "H Align",
"V Align": "V Align",
"Top": "Top",
"Middle": "Mitan",
"Bottom": "Bottom",
"Header cell": "Header cell",
"Row group": "Row group",
"Column group": "Column group",
"Row type": "Tipe de linha",
"Header": "Ent\u00e8sta",
"Body": "C\u00f2s",
"Footer": "P\u00e8 de pagina",
"Border color": "Color de la bordadura",
"Insert template...": "Inserir un mod\u00e8l...",
"Templates": "Mod\u00e8ls",
"Template": "Mod\u00e8l",
"Text color": "Color del t\u00e8xte",
"Background color": "Color de r\u00e8ireplan",
"Custom...": "Personalizar...",
"Custom color": "Color personalizada",
"No color": "Pas de color",
"Remove color": "Tirar la color",
"Table of Contents": "Ensenhador",
"Show blocks": "Afichar los bl\u00f2ts",
"Show invisible characters": "Far veire los caract\u00e8rs invisibles",
"Word count": "Comptador mot",
"Count": "Comptador",
"Document": "Document",
"Selection": "Seleccion",
"Words": "Mots",
"Words: {0}": "Mots : {0}",
"{0} words": "{0} mots",
"File": "Fichi\u00e8r",
"Edit": "Editar",
"Insert": "Inserir",
"View": "Veire",
"Format": "Format",
"Table": "Tabl\u00e8u",
"Tools": "Aisinas",
"Powered by {0}": "Propulsat per {0}",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Z\u00f2na T\u00e8xte Ric. Quichar sus ALT-F9 pel men\u00fa. Quichar sus ALT-F10 per la barra d'aisinas. Quichar sus ALT-0 per d'ajuda.",
"Image title": "T\u00edtol imatge",
"Border width": "Largor bordadura",
"Border style": "Estil bordadura",
"Error": "Error",
"Warn": "Av\u00eds",
"Valid": "Valid",
"To open the popup, press Shift+Enter": "Per dobrir dins una fen\u00e8stra sorgissenta, quichatz Maj+Entrada",
"Rich Text Area. Press ALT-0 for help.": "Rich Text Area. Press ALT-0 for help.",
"System Font": "Polissa sist\u00e8ma",
"Failed to upload image: {0}": "Frac\u00e0s mandad\u00eds imatge : {0}",
"Failed to load plugin: {0} from url {1}": "Failed to load plugin: {0} from url {1}",
"Failed to load plugin url: {0}": "Failed to load plugin url: {0}",
"Failed to initialize plugin: {0}": "Failed to initialize plugin: {0}",
"example": "exemple",
"Search": "Cercar",
"All": "Tot",
"Currency": "Moneda",
"Text": "T\u00e8xte",
"Quotations": "Citacions",
"Mathematical": "Mathematical",
"Extended Latin": "Extended Latin",
"Symbols": "Simb\u00f2ls",
"Arrows": "Fl\u00e8chas",
"User Defined": "User Defined",
"dollar sign": "signe d\u00f2lar",
"currency sign": "Signe devisa",
"euro-currency sign": "signe devisa europenca ",
"colon sign": "signe colon",
"cruzeiro sign": "signe cruzeiro",
"french franc sign": "signe franc",
"lira sign": "signe lira",
"mill sign": "signe mill",
"naira sign": "signe naira",
"peseta sign": "signe peseta",
"rupee sign": "signe roble",
"won sign": "signe won",
"new sheqel sign": "signe sheqel",
"dong sign": "signe dong",
"kip sign": "signe kip",
"tugrik sign": "signe tugrik",
"drachma sign": "signe drachma",
"german penny symbol": "signe devisa germana",
"peso sign": "signe peso",
"guarani sign": "signe guarani",
"austral sign": "signe austral",
"hryvnia sign": "signe hryvnia",
"cedi sign": "signe cedi",
"livre tournois sign": "signe livre tournois",
"spesmilo sign": "signe spesmilo",
"tenge sign": "signe tenge",
"indian rupee sign": "signe roble india",
"turkish lira sign": "signe lira de Turquia",
"nordic mark sign": "signe marc nordic",
"manat sign": "signe manat",
"ruble sign": "signe roble",
"yen character": "signe yen",
"yuan character": "signe yuan",
"yuan character, in hong kong and taiwan": "yuan character, in hong kong and taiwan",
"yen\/yuan character variant one": "yen\/yuan character variant one",
"Loading emoticons...": "Cargament emoticons...",
"Could not load emoticons": "Cargament impossible de las emoticons",
"People": "Gents",
"Animals and Nature": "Animals e Natura",
"Food and Drink": "Beure e manjar",
"Activity": "Activitat",
"Travel and Places": "Viatge e L\u00f2cs",
"Objects": "Obj\u00e8ctes",
"Flags": "Drap\u00e8us",
"Characters": "Caract\u00e8rs",
"Characters (no spaces)": "Caract\u00e8rs (sens espaci)",
"{0} characters": "{0} caract\u00e8rs",
"Error: Form submit field collision.": "Error: Form submit field collision.",
"Error: No form element found.": "Error\u202f: cap d\u2019element formulari pas trobat.",
"Update": "Actualizar",
"Color swatch": "Cambiament de color",
"Turquoise": "Turquesa",
"Green": "Verd",
"Blue": "Blau",
"Purple": "Violet",
"Navy Blue": "Blau marin",
"Dark Turquoise": "Turquesa escur",
"Dark Green": "Verd escur",
"Medium Blue": "Blau mejan",
"Medium Purple": "Violet mejan",
"Midnight Blue": "Blau nu\u00e8ch",
"Yellow": "Jaune",
"Orange": "Irange",
"Red": "Roge",
"Light Gray": "Gris clar",
"Gray": "Gris",
"Dark Yellow": "Jaune escur",
"Dark Orange": "Irange escur",
"Dark Red": "Roge escur",
"Medium Gray": "Gris mejan",
"Dark Gray": "Gris escur",
"Light Green": "Verd clar",
"Light Yellow": "Jaune clar",
"Light Red": "Roge clar",
"Light Purple": "Violet clar",
"Light Blue": "Blau clar",
"Dark Purple": "Violet escur",
"Dark Blue": "Blau escur",
"Black": "Negre",
"White": "Blanc",
"Switch to or from fullscreen mode": "Switch to or from fullscreen mode",
"Open help dialog": "Open help dialog",
"history": "istoric",
"styles": "estils",
"formatting": "formatting",
"alignment": "alinhament",
"indentation": "indentacion",
"permanent pen": "permanent pen",
"comments": "comentaris",
"Format Painter": "Format Painter",
"Insert\/edit iframe": "Insert\/edit iframe",
"Capitalization": "Capitalization",
"lowercase": "lowercase",
"UPPERCASE": "UPPERCASE",
"Title Case": "Title Case",
"Permanent Pen Properties": "Permanent Pen Properties",
"Permanent pen properties...": "Permanent pen properties...",
"Font": "Polissa",
"Size": "Talha",
"More...": "Mai...",
"Spellcheck Language": "Lenga del verificador ortografic",
"Select...": "Seleccionar...",
"Preferences": "Prefer\u00e9ncias",
"Yes": "\u00d2c",
"No": "Non",
"Keyboard Navigation": "Acorchis clavi\u00e8r",
"Version": "Version",
"Anchor": "Anc\u00f2ra",
"Special character": "Caract\u00e8r especial",
"Color": "Color",
"Emoticons": "Emotic\u00f2nas",
"Document properties": "Proprietats del document",
"Insert link": "Inserir un ligam",
"Target": "Cibla",
"Poster": "Publicar",
"Print": "Imprimir",
"Whole words": "Mots enti\u00e8rs",
"Find and replace": "Recercar e rempla\u00e7ar",
"Prev": "Prec",
"Spellcheck": "Corrector ortografic",
"Caption": "Caption",
"Insert template": "Inserir un mod\u00e8l"
});